@@ -37,19 +37,19 @@
 
 #define MAX_SWAPPABLE_DISKS 20
 struct diskGeo {
-	Bit32u ksize;  /* Size in kilobytes */
-	Bit16u secttrack; /* Sectors per track */
-	Bit16u headscyl;  /* Heads per cylinder */
-	Bit16u cylcount;  /* Cylinders per side */
-	Bit16u biosval;   /* Type to return from BIOS */
-    Bit16u bytespersect; /* Bytes per sector */
-	Bit16u rootentries;  /* Root directory entries */
-	Bit8u sectcluster;   /* Sectors per cluster */
-	Bit8u mediaid;       /* Media ID */
+	uint32_t ksize;  /* Size in kilobytes */
+	uint16_t secttrack; /* Sectors per track */
+	uint16_t headscyl;  /* Heads per cylinder */
+	uint16_t cylcount;  /* Cylinders per side */
+	uint16_t biosval;   /* Type to return from BIOS */
+    uint16_t bytespersect; /* Bytes per sector */
+	uint16_t rootentries;  /* Root directory entries */
+	uint8_t sectcluster;   /* Sectors per cluster */
+	uint8_t mediaid;       /* Media ID */
 };
 extern diskGeo DiskGeometryList[];
 
-extern const Bit8u freedos_mbr[];
+extern const uint8_t freedos_mbr[];
 
 class imageDisk {
 public:
@@ -63,39 +63,39 @@ public:
         ID_NFD
 	};
 
-	virtual Bit8u Read_Sector(Bit32u head,Bit32u cylinder,Bit32u sector,void * data,unsigned int req_sector_size=0);
-	virtual Bit8u Write_Sector(Bit32u head,Bit32u cylinder,Bit32u sector,const void * data,unsigned int req_sector_size=0);
-	virtual Bit8u Read_AbsoluteSector(Bit32u sectnum, void * data);
-	virtual Bit8u Write_AbsoluteSector(Bit32u sectnum, const void * data);
+	virtual uint8_t Read_Sector(uint32_t head,uint32_t cylinder,uint32_t sector,void * data,unsigned int req_sector_size=0);
+	virtual uint8_t Write_Sector(uint32_t head,uint32_t cylinder,uint32_t sector,const void * data,unsigned int req_sector_size=0);
+	virtual uint8_t Read_AbsoluteSector(uint32_t sectnum, void * data);
+	virtual uint8_t Write_AbsoluteSector(uint32_t sectnum, const void * data);
 
 	virtual void Set_Reserved_Cylinders(Bitu resCyl);
-	virtual Bit32u Get_Reserved_Cylinders();
-	virtual void Set_Geometry(Bit32u setHeads, Bit32u setCyl, Bit32u setSect, Bit32u setSectSize);
-	virtual void Get_Geometry(Bit32u * getHeads, Bit32u *getCyl, Bit32u *getSect, Bit32u *getSectSize);
-	virtual Bit8u GetBiosType(void);
-	virtual Bit32u getSectSize(void);
-	imageDisk(FILE *imgFile, Bit8u *imgName, Bit32u imgSizeK, bool isHardDisk);
-	imageDisk(FILE* diskimg, const char* diskName, Bit32u cylinders, Bit32u heads, Bit32u sectors, Bit32u sector_size, bool hardDrive);
+	virtual uint32_t Get_Reserved_Cylinders();
+	virtual void Set_Geometry(uint32_t setHeads, uint32_t setCyl, uint32_t setSect, uint32_t setSectSize);
+	virtual void Get_Geometry(uint32_t * getHeads, uint32_t *getCyl, uint32_t *getSect, uint32_t *getSectSize);
+	virtual uint8_t GetBiosType(void);
+	virtual uint32_t getSectSize(void);
+	imageDisk(FILE *imgFile, const char *imgName, uint32_t imgSizeK, bool isHardDisk);
+	imageDisk(FILE* diskimg, const char* diskName, uint32_t cylinders, uint32_t heads, uint32_t sectors, uint32_t sector_size, bool hardDrive);
 	virtual ~imageDisk() { if(diskimg != NULL) { fclose(diskimg); diskimg=NULL; } };
 
     IMAGE_TYPE class_id = ID_BASE;
 	std::string diskname;
     bool active = false;
-    Bit32u sector_size = 512;
-    Bit32u heads = 0;
-    Bit32u cylinders = 0;
-    Bit32u sectors = 0;
+    uint32_t sector_size = 512;
+    uint32_t heads = 0;
+    uint32_t cylinders = 0;
+    uint32_t sectors = 0;
     bool hardDrive = false;
-    Bit64u diskSizeK = 0;
+    uint64_t diskSizeK = 0;
 
 protected:
 	imageDisk(IMAGE_TYPE class_id);
     FILE* diskimg = NULL;
-    Bit8u floppytype = 0;
+    uint8_t floppytype = 0;
 
-    Bit32u reserved_cylinders = 0;
-    Bit64u image_base = 0;
-    Bit64u image_length = 0;
+    uint32_t reserved_cylinders = 0;
+    uint64_t image_base = 0;
+    uint64_t image_length = 0;
 
 private:
     volatile int refcount = 0;
@@ -117,12 +117,12 @@ public:
 
 class imageDiskD88 : public imageDisk {
 public:
-	virtual Bit8u Read_Sector(Bit32u head,Bit32u cylinder,Bit32u sector,void * data,unsigned int req_sector_size=0);
-	virtual Bit8u Write_Sector(Bit32u head,Bit32u cylinder,Bit32u sector,const void * data,unsigned int req_sector_size=0);
-	virtual Bit8u Read_AbsoluteSector(Bit32u sectnum, void * data);
-	virtual Bit8u Write_AbsoluteSector(Bit32u sectnum, const void * data);
+	virtual uint8_t Read_Sector(uint32_t head,uint32_t cylinder,uint32_t sector,void * data,unsigned int req_sector_size=0);
+	virtual uint8_t Write_Sector(uint32_t head,uint32_t cylinder,uint32_t sector,const void * data,unsigned int req_sector_size=0);
+	virtual uint8_t Read_AbsoluteSector(uint32_t sectnum, void * data);
+	virtual uint8_t Write_AbsoluteSector(uint32_t sectnum, const void * data);
 
-	imageDiskD88(FILE *imgFile, Bit8u *imgName, Bit32u imgSizeK, bool isHardDisk);
+	imageDiskD88(FILE *imgFile, uint8_t *imgName, uint32_t imgSizeK, bool isHardDisk);
 	virtual ~imageDiskD88();
 
     unsigned char fd_type_major;
@@ -149,19 +149,19 @@ public:
         }
     };
 
-    vfdentry *findSector(Bit8u head,Bit8u track,Bit8u sector/*TODO: physical head?*/,unsigned int req_sector_size=0);
+    vfdentry *findSector(uint8_t head,uint8_t track,uint8_t sector/*TODO: physical head?*/,unsigned int req_sector_size=0);
 
     std::vector<vfdentry> dents;
 };
 
 class imageDiskNFD : public imageDisk {
 public:
-	virtual Bit8u Read_Sector(Bit32u head,Bit32u cylinder,Bit32u sector,void * data,unsigned int req_sector_size=0);
-	virtual Bit8u Write_Sector(Bit32u head,Bit32u cylinder,Bit32u sector,const void * data,unsigned int req_sector_size=0);
-	virtual Bit8u Read_AbsoluteSector(Bit32u sectnum, void * data);
-	virtual Bit8u Write_AbsoluteSector(Bit32u sectnum, const void * data);
+	virtual uint8_t Read_Sector(uint32_t head,uint32_t cylinder,uint32_t sector,void * data,unsigned int req_sector_size=0);
+	virtual uint8_t Write_Sector(uint32_t head,uint32_t cylinder,uint32_t sector,const void * data,unsigned int req_sector_size=0);
+	virtual uint8_t Read_AbsoluteSector(uint32_t sectnum, void * data);
+	virtual uint8_t Write_AbsoluteSector(uint32_t sectnum, const void * data);
 
-	imageDiskNFD(FILE *imgFile, Bit8u *imgName, Bit32u imgSizeK, bool isHardDisk, unsigned int revision);
+	imageDiskNFD(FILE *imgFile, uint8_t *imgName, uint32_t imgSizeK, bool isHardDisk, unsigned int revision);
 	virtual ~imageDiskNFD();
 
     struct vfdentry {
@@ -179,19 +179,19 @@ public:
         }
     };
 
-    vfdentry *findSector(Bit8u head,Bit8u track,Bit8u sector/*TODO: physical head?*/,unsigned int req_sector_size=0);
+    vfdentry *findSector(uint8_t head,uint8_t track,uint8_t sector/*TODO: physical head?*/,unsigned int req_sector_size=0);
 
     std::vector<vfdentry> dents;
 };
 
 class imageDiskVFD : public imageDisk {
 public:
-	virtual Bit8u Read_Sector(Bit32u head,Bit32u cylinder,Bit32u sector,void * data,unsigned int req_sector_size=0);
-	virtual Bit8u Write_Sector(Bit32u head,Bit32u cylinder,Bit32u sector,const void * data,unsigned int req_sector_size=0);
-	virtual Bit8u Read_AbsoluteSector(Bit32u sectnum, void * data);
-	virtual Bit8u Write_AbsoluteSector(Bit32u sectnum, const void * data);
+	virtual uint8_t Read_Sector(uint32_t head,uint32_t cylinder,uint32_t sector,void * data,unsigned int req_sector_size=0);
+	virtual uint8_t Write_Sector(uint32_t head,uint32_t cylinder,uint32_t sector,const void * data,unsigned int req_sector_size=0);
+	virtual uint8_t Read_AbsoluteSector(uint32_t sectnum, void * data);
+	virtual uint8_t Write_AbsoluteSector(uint32_t sectnum, const void * data);
 
-	imageDiskVFD(FILE *imgFile, Bit8u *imgName, Bit32u imgSizeK, bool isHardDisk);
+	imageDiskVFD(FILE *imgFile, uint8_t *imgName, uint32_t imgSizeK, bool isHardDisk);
 	virtual ~imageDiskVFD();
 
     struct vfdentry {
@@ -217,24 +217,24 @@ public:
         }
     };
 
-    vfdentry *findSector(Bit8u head,Bit8u track,Bit8u sector/*TODO: physical head?*/,unsigned int req_sector_size=0);
+    vfdentry *findSector(uint8_t head,uint8_t track,uint8_t sector/*TODO: physical head?*/,unsigned int req_sector_size=0);
 
     std::vector<vfdentry> dents;
 };
 
 class imageDiskMemory : public imageDisk {
 public:
-	virtual Bit8u Read_AbsoluteSector(Bit32u sectnum, void * data);
-	virtual Bit8u Write_AbsoluteSector(Bit32u sectnum, const void * data);
-	virtual Bit8u GetBiosType(void);
-	virtual void Set_Geometry(Bit32u setHeads, Bit32u setCyl, Bit32u setSect, Bit32u setSectSize);
+	virtual uint8_t Read_AbsoluteSector(uint32_t sectnum, void * data);
+	virtual uint8_t Write_AbsoluteSector(uint32_t sectnum, const void * data);
+	virtual uint8_t GetBiosType(void);
+	virtual void Set_Geometry(uint32_t setHeads, uint32_t setCyl, uint32_t setSect, uint32_t setSectSize);
 	// Parition and format the ramdrive
-	virtual Bit8u Format();
+	virtual uint8_t Format();
 
 	// Create a hard drive image of a specified size; automatically select c/h/s
-	imageDiskMemory(Bit32u imgSizeK);
+	imageDiskMemory(uint32_t imgSizeK);
 	// Create a hard drive image of a specified geometry
-	imageDiskMemory(Bit16u cylinders, Bit16u heads, Bit16u sectors, Bit16u sector_size);
+	imageDiskMemory(uint16_t cylinders, uint16_t heads, uint16_t sectors, uint16_t sector_size);
 	// Create a floppy image of a specified geometry
     imageDiskMemory(const diskGeo& floppyGeometry);
 	// Create a copy-on-write memory image of an existing image
@@ -243,13 +243,13 @@ public:
 
 private:
 	void init(diskGeo diskParams, bool isHardDrive, imageDisk* underlyingImage);
-	bool CalculateFAT(Bit32u partitionStartingSector, Bit32u partitionLength, bool isHardDrive, Bit32u rootEntries, Bit32u* rootSectors, Bit32u* sectorsPerCluster, bool* isFat16, Bit32u* fatSectors, Bit32u* reservedSectors);
+	bool CalculateFAT(uint32_t partitionStartingSector, uint32_t partitionLength, bool isHardDrive, uint32_t rootEntries, uint32_t* rootSectors, uint32_t* sectorsPerCluster, bool* isFat16, uint32_t* fatSectors, uint32_t* reservedSectors);
 
-	Bit8u * * ChunkMap;
-	Bit32u sectors_per_chunk;
-	Bit32u chunk_size;
-	Bit32u total_chunks;
-    Bit32u total_sectors = 0;
+	uint8_t * * ChunkMap;
+	uint32_t sectors_per_chunk;
+	uint32_t chunk_size;
+	uint32_t total_chunks;
+    uint32_t total_sectors = 0;
     imageDisk* underlyingImage = NULL;
 
 	diskGeo floppyInfo;
@@ -272,7 +272,7 @@ public:
 		PARENT_INVALID_MATCH = 0x14,
 		PARENT_INVALID_DATE = 0x15
 	};
-	enum VHDTypes : Bit32u
+	enum VHDTypes : uint32_t
 	{
 		VHD_TYPE_NONE = 0,
 		VHD_TYPE_FIXED = 2,
@@ -280,86 +280,86 @@ public:
 		VHD_TYPE_DIFFERENCING = 4
 	};
     VHDTypes vhdType = VHD_TYPE_NONE;
-	virtual Bit8u Read_AbsoluteSector(Bit32u sectnum, void * data);
-	virtual Bit8u Write_AbsoluteSector(Bit32u sectnum, const void * data);
+	virtual uint8_t Read_AbsoluteSector(uint32_t sectnum, void * data);
+	virtual uint8_t Write_AbsoluteSector(uint32_t sectnum, const void * data);
 	static ErrorCodes Open(const char* fileName, const bool readOnly, imageDisk** disk);
 	static VHDTypes GetVHDType(const char* fileName);
 	virtual ~imageDiskVHD();
 
 private:
 	struct Geometry {
-		Bit16u cylinders;
-		Bit8u heads;
-		Bit8u sectors;
+		uint16_t cylinders;
+		uint8_t heads;
+		uint8_t sectors;
 	};
 	struct VHDFooter {
 		char cookie[8];
-		Bit32u features;
-		Bit32u fileFormatVersion;
-		Bit64u dataOffset;
-		Bit32u timeStamp;
+		uint32_t features;
+		uint32_t fileFormatVersion;
+		uint64_t dataOffset;
+		uint32_t timeStamp;
 		char creatorApp[4];
-		Bit32u creatorVersion;
-		Bit32u creatorHostOS;
-		Bit64u originalSize;
-		Bit64u currentSize;
+		uint32_t creatorVersion;
+		uint32_t creatorHostOS;
+		uint64_t originalSize;
+		uint64_t currentSize;
 		Geometry geometry;
 		VHDTypes diskType;
-		Bit32u checksum;
+		uint32_t checksum;
 		char uniqueId[16];
 		char savedState;
 		char reserved[427];
 
 		void SwapByteOrder();
-		Bit32u CalculateChecksum();
+		uint32_t CalculateChecksum();
 		bool IsValid();
 	};
 	struct ParentLocatorEntry {
-		Bit32u platformCode;
-		Bit32u platformDataSpace;
-		Bit32u platformDataLength;
-		Bit32u reserved;
-		Bit64u platformDataOffset;
+		uint32_t platformCode;
+		uint32_t platformDataSpace;
+		uint32_t platformDataLength;
+		uint32_t reserved;
+		uint64_t platformDataOffset;
 	};
 	struct DynamicHeader {
 		char cookie[8];
-		Bit64u dataOffset;
-		Bit64u tableOffset;
-		Bit32u headerVersion;
-		Bit32u maxTableEntries;
-		Bit32u blockSize;
-		Bit32u checksum;
-		Bit8u parentUniqueId[16];
-		Bit32u parentTimeStamp;
-		Bit32u reserved;
-		Bit16u parentUnicodeName[256];
+		uint64_t dataOffset;
+		uint64_t tableOffset;
+		uint32_t headerVersion;
+		uint32_t maxTableEntries;
+		uint32_t blockSize;
+		uint32_t checksum;
+		uint8_t parentUniqueId[16];
+		uint32_t parentTimeStamp;
+		uint32_t reserved;
+		uint16_t parentUnicodeName[256];
 		ParentLocatorEntry parentLocatorEntry[8];
 		char reserved2[256];
 
 		void SwapByteOrder();
-		Bit32u CalculateChecksum();
+		uint32_t CalculateChecksum();
 		bool IsValid();
 	};
 
 	imageDiskVHD() : imageDisk(ID_VHD) { }
-    static ErrorCodes TryOpenParent(const char* childFileName, const ParentLocatorEntry& entry, const Bit8u* data, const Bit32u dataLength, imageDisk** disk, const Bit8u* uniqueId);
-	static ErrorCodes Open(const char* fileName, const bool readOnly, imageDisk** disk, const Bit8u* matchUniqueId);
-	virtual bool loadBlock(const Bit32u blockNumber);
-	static bool convert_UTF16_for_fopen(std::string &string, const void* data, const Bit32u dataLength);
+    static ErrorCodes TryOpenParent(const char* childFileName, const ParentLocatorEntry& entry, const uint8_t* data, const uint32_t dataLength, imageDisk** disk, const uint8_t* uniqueId);
+	static ErrorCodes Open(const char* fileName, const bool readOnly, imageDisk** disk, const uint8_t* matchUniqueId);
+	virtual bool loadBlock(const uint32_t blockNumber);
+	static bool convert_UTF16_for_fopen(std::string &string, const void* data, const uint32_t dataLength);
 
     imageDisk* parentDisk = NULL;
-	Bit64u footerPosition = 0;
+	uint64_t footerPosition = 0;
     VHDFooter footer = {};
     VHDFooter originalFooter = {};
     bool copiedFooter = false;
     DynamicHeader dynamicHeader = {};
-	Bit32u sectorsPerBlock = 0;
-	Bit32u blockMapSectors = 0;
-	Bit32u blockMapSize = 0;
-	Bit32u currentBlock = 0xFFFFFFFF;
+	uint32_t sectorsPerBlock = 0;
+	uint32_t blockMapSectors = 0;
+	uint32_t blockMapSize = 0;
+	uint32_t currentBlock = 0xFFFFFFFF;
     bool currentBlockAllocated = false;
-	Bit32u currentBlockSectorOffset = 0;
-	Bit8u* currentBlockDirtyMap = 0;
+	uint32_t currentBlockSectorOffset = 0;
+	uint8_t* currentBlockDirtyMap = 0;
 };
 
 /* C++ class implementing El Torito floppy emulation */
@@ -367,7 +367,7 @@ class imageDiskElToritoFloppy : public imageDisk {
 public:
     /* Read_Sector and Write_Sector take care of geometry translation for us,
      * then call the absolute versions. So, we override the absolute versions only */
-    virtual Bit8u Read_AbsoluteSector(Bit32u sectnum, void * data) {
+    virtual uint8_t Read_AbsoluteSector(uint32_t sectnum, void * data) {
         unsigned char buffer[2048];
 
         bool GetMSCDEXDrive(unsigned char drive_letter,CDROM_Interface **_cdrom);
@@ -381,7 +381,7 @@ public:
         memcpy(data,buffer+((sectnum&3)*512),512);
         return 0x00;
     }
-    virtual Bit8u Write_AbsoluteSector(Bit32u sectnum,const void * data) {
+    virtual uint8_t Write_AbsoluteSector(uint32_t sectnum,const void * data) {
         (void)sectnum;//UNUSED
         (void)data;//UNUSED
         return 0x05; /* fail, read only */
@@ -417,7 +417,7 @@ public:
             LOG_MSG("BUG! unsupported floppy_emu_type in El Torito floppy object\n");
         }
 
-        diskSizeK = ((Bit64u)heads * cylinders * sectors * sector_size) / 1024;
+        diskSizeK = ((uint64_t)heads * cylinders * sectors * sector_size) / 1024;
         active = true;
     }
     virtual ~imageDiskElToritoFloppy() {
@@ -433,12 +433,12 @@ public:
     bool active;
     FILE *diskimg;
     std::string diskname;
-    Bit8u floppytype;
+    uint8_t floppytype;
 
-    Bit32u sector_size;
-    Bit32u heads,cylinders,sectors;
-    Bit32u reserved_cylinders;
-    Bit64u current_fpos; */
+    uint32_t sector_size;
+    uint32_t heads,cylinders,sectors;
+    uint32_t reserved_cylinders;
+    uint64_t current_fpos; */
 };
 
 void updateDPT(void);
@@ -453,8 +453,8 @@ void incrementFDD(void);
 extern bool imageDiskChange[MAX_DISK_IMAGES];
 extern imageDisk *imageDiskList[MAX_DISK_IMAGES];
 extern imageDisk *diskSwap[MAX_SWAPPABLE_DISKS];
-extern Bit32s swapPosition;
-extern Bit16u imgDTASeg; /* Real memory location of temporary DTA pointer for fat image disk access */
+extern int32_t swapPosition;
+extern uint16_t imgDTASeg; /* Real memory location of temporary DTA pointer for fat image disk access */
 extern RealPt imgDTAPtr; /* Real memory location of temporary DTA pointer for fat image disk access */
 extern DOS_DTA *imgDTA;
 
