@@ -1,6 +1,11 @@
 
 #include "dos_inc.h"
+#include "../src/builtin/zip.h"
+#include "../src/builtin/cdplay.h"
+#include "../src/builtin/dosmid.h"
+#include "../src/builtin/mpxplay.h"
 #include "../src/builtin/glide2x.h"
+#include "../src/builtin/textutil.h"
 #include "../src/builtin/4DOS_img.h"
 
 extern struct BuiltinFileBlob bfb_DSXMENU_EXE_PC;		// DSXMENU.EXE
@@ -12,6 +17,7 @@ extern struct BuiltinFileBlob bfb_DOS4GW_EXE;		// DOS4GW.EXE
 extern struct BuiltinFileBlob bfb_HEXMEM16_EXE;		// HEXMEM16.EXE
 extern struct BuiltinFileBlob bfb_HEXMEM32_EXE;		// HEXMEM32.EXE
 extern struct BuiltinFileBlob bfb_DEBUG_EXE;		// DEBUG.EXE
+extern struct BuiltinFileBlob bfb_SORT_EXE;		// SORT.EXE
 extern struct BuiltinFileBlob bfb_TREE_EXE;		// TREE.EXE
 extern struct BuiltinFileBlob bfb_MOVE_EXE;		// MOVE.EXE
 extern struct BuiltinFileBlob bfb_MEM_COM;		// MEM.COM
@@ -34,5 +40,9 @@ extern struct BuiltinFileBlob bfb_25_COM_other;	// 25.COM
 extern struct BuiltinFileBlob bfb_4DOS_COM;		// 4DOS.COM
 extern struct BuiltinFileBlob bfb_4DOS_HLP;		// 4DOS.HLP
 extern struct BuiltinFileBlob bfb_4HELP_EXE;	// 4HELP.EXE
+extern struct BuiltinFileBlob bfb_CDPLAY_EXE;	// CDPLAY.EXE
+extern struct BuiltinFileBlob bfb_DOSMID_EXE;	// DOSMID.EXE
+extern struct BuiltinFileBlob bfb_MPXPLAY_EXE;	// MPXPLAY.EXE
 extern struct BuiltinFileBlob bfb_GLIDE2X_OVL;	// GLIDE2X.OVL
+extern struct BuiltinFileBlob bfb_TEXTUTIL_ZIP;	// TEXTUTIL.ZIP
 
