@@ -92,6 +92,7 @@ public:
         opt_showcycles = false;
         opt_earlydebug = false;
         opt_break_start = false;
+        opt_defaultconf = false;
         opt_erasemapper = false;
         opt_resetmapper = false;
         opt_startmapper = false;
@@ -112,7 +113,7 @@ public:
     Section* GetSection(std::string const&_sectionname) const;
     Section* GetSectionFromProperty(char const * const prop) const;
 
-    bool PrintConfig(char const * const configfilename,bool everything=false) const;
+    bool PrintConfig(char const * const configfilename,int everything=-1,bool norem=false) const;
     bool ParseConfigFile(char const * const configfilename);
     void ParseEnv(char ** envp);
     bool SecureMode() const { return secure_mode; }
@@ -134,6 +135,7 @@ public:
     bool opt_erasemapper;
     bool opt_resetmapper;
     bool opt_startmapper;
+    bool opt_defaultconf;
     bool opt_noautoexec;
     bool opt_securemode;
     bool opt_fullscreen;
