@@ -57,8 +57,8 @@ public:
 	virtual bool ReadLine(char * line);
 	bool Goto(const char * where);
 	void Shift(void);
-	Bit16u file_handle;
-	Bit32u location;
+	uint16_t file_handle;
+	uint32_t location;
 	bool echo;
 	DOS_Shell * shell;
 	BatchFile * prev;
@@ -89,7 +89,7 @@ private:
     typedef std::map<std::string, std::string, less_ignore_case<std::string> > cmd_alias_map_t;
     cmd_alias_map_t cmd_alias;
 
-	Bit16u completion_index;
+	uint16_t completion_index;
 	
 private:
 	void ProcessCmdLineEnvVarStitution(char * line);
@@ -172,6 +172,10 @@ public:
      */
 	void CMD_DELETE(char * args);
 
+    /*! \brief      Delete directory tree (DELTREE)
+     */
+	void CMD_DELTREE(char * args);
+
     /*! \brief      Echo command (ECHO)
      */
 	void CMD_ECHO(char * args);
@@ -313,7 +317,7 @@ public:
 #endif
 
 	/* The shell's variables */
-	Bit16u input_handle;
+	uint16_t input_handle;
 	BatchFile * bf;                     //! Batch file to execute
 	bool echo;
 	bool exit;
@@ -327,7 +331,7 @@ public:
 
 struct SHELL_Cmd {
 	const char * name;								/* Command name*/
-	Bit32u flags;									/* Flags about the command */
+	uint32_t flags;									/* Flags about the command */
 	void (DOS_Shell::*handler)(char * args);		/* Handler for this command */
 	const char * help;								/* String with command help */
 };
