@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime();
-my $datestr = sprintf("%04u%02u%02u-%02u%02u%02u",$year+1900,$mon+1,$mday,$hour,$min,$sec);
+my $datestr = sprintf("%04u%02u%02u%02u%02u%02u",$year+1900,$mon+1,$mday,$hour,$min,$sec);
 
 my $ziptool = "vs2015/tool/zip.exe";
 
@@ -24,14 +24,14 @@ if ( "$branch" eq "develop-win-sdl1-async-hack-201802" ) {
 }
 
 $suffix = $subdir;
-$suffix =~ s/^.*\///g;
+$suffix =~ s/^.*\/windows/vsbuild/g;
 
 mkdir "release" unless -d "release";
 mkdir "$subdir" unless -d "$subdir";
 
 die "bin directory not exist" unless -d "bin";
 
-my $zipname = "dosbox-x-windows-$datestr-$suffix.zip";
+my $zipname = "dosbox-x-$suffix-win-$datestr.zip";
 exit 0 if -f $zipname;
 die unless -f $ziptool;
 
