@@ -188,7 +188,7 @@ static void dyn_dop_evgv_xchg(void) {
 	}
 }
 
-static void dyn_xchg_ax(Bit8u reg) {
+static void dyn_xchg_ax(uint8_t reg) {
 	MOV_REG_WORD_TO_HOST_REG(FC_OP1,DRC_REG_EAX,decode.big_op);
 	MOV_REG_WORD_TO_HOST_REG(FC_OP2,reg,decode.big_op);
 	MOV_REG_WORD_FROM_HOST_REG(FC_OP1,reg,decode.big_op);
@@ -227,26 +227,26 @@ static void dyn_dop_gvev_mov(void) {
 	}
 }
 
-static void dyn_dop_byte_imm(DualOps op,Bit8u reg,Bit8u idx) {
+static void dyn_dop_byte_imm(DualOps op,uint8_t reg,uint8_t idx) {
 	MOV_REG_BYTE_TO_HOST_REG_LOW_CANUSEWORD(FC_OP1,reg,idx);
 	gen_mov_byte_to_reg_low_imm_canuseword(FC_OP2,decode_fetchb());
 	dyn_dop_byte_gencall(op);
 	if ((op!=DOP_CMP) && (op!=DOP_TEST)) MOV_REG_BYTE_FROM_HOST_REG_LOW(FC_RETOP,reg,idx);
 }
 
-static void dyn_dop_byte_imm_mem(DualOps op,Bit8u reg,Bit8u idx) {
+static void dyn_dop_byte_imm_mem(DualOps op,uint8_t reg,uint8_t idx) {
 	MOV_REG_BYTE_TO_HOST_REG_LOW_CANUSEWORD(FC_OP1,reg,idx);
 	Bitu val;
 	if (decode_fetchb_imm(val)) {
 		gen_mov_byte_to_reg_low_canuseword(FC_OP2,(void*)val);
 	} else {
-		gen_mov_byte_to_reg_low_imm_canuseword(FC_OP2,(Bit8u)val);
+		gen_mov_byte_to_reg_low_imm_canuseword(FC_OP2,(uint8_t)val);
 	}
 	dyn_dop_byte_gencall(op);
 	if ((op!=DOP_CMP) && (op!=DOP_TEST)) MOV_REG_BYTE_FROM_HOST_REG_LOW(FC_RETOP,reg,idx);
 }
 
-static void dyn_prep_word_imm(Bit8u reg) {
+static void dyn_prep_word_imm(uint8_t reg) {
 	(void)reg;
 
 	Bitu val;
@@ -261,31 +261,31 @@ static void dyn_prep_word_imm(Bit8u reg) {
 			return;
 		}
 	}
-	if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(Bit32u)val);
-	else gen_mov_word_to_reg_imm(FC_OP2,(Bit16u)val);
+	if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(uint32_t)val);
+	else gen_mov_word_to_reg_imm(FC_OP2,(uint16_t)val);
 }
 
-static void dyn_dop_word_imm(DualOps op,Bit8u reg) {
+static void dyn_dop_word_imm(DualOps op,uint8_t reg) {
 	MOV_REG_WORD_TO_HOST_REG(FC_OP1,reg,decode.big_op);
 	dyn_prep_word_imm(reg);
 	dyn_dop_word_gencall(op,decode.big_op);
 	if ((op!=DOP_CMP) && (op!=DOP_TEST)) MOV_REG_WORD_FROM_HOST_REG(FC_RETOP,reg,decode.big_op);
 }
 
-static void dyn_dop_word_imm_old(DualOps op,Bit8u reg,Bitu imm) {
+static void dyn_dop_word_imm_old(DualOps op,uint8_t reg,Bitu imm) {
 	MOV_REG_WORD_TO_HOST_REG(FC_OP1,reg,decode.big_op);
-	if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(Bit32u)imm);
-	else gen_mov_word_to_reg_imm(FC_OP2,(Bit16u)imm);
+	if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(uint32_t)imm);
+	else gen_mov_word_to_reg_imm(FC_OP2,(uint16_t)imm);
 	dyn_dop_word_gencall(op,decode.big_op);
 	if ((op!=DOP_CMP) && (op!=DOP_TEST)) MOV_REG_WORD_FROM_HOST_REG(FC_RETOP,reg,decode.big_op);
 }
 
-static void dyn_mov_byte_imm(Bit8u reg,Bit8u idx,Bit8u imm) {
+static void dyn_mov_byte_imm(uint8_t reg,uint8_t idx,uint8_t imm) {
 	gen_mov_byte_to_reg_low_imm(FC_TMP_BA1,imm);
 	MOV_REG_BYTE_FROM_HOST_REG_LOW(FC_TMP_BA1,reg,idx);
 }
 
-static void dyn_mov_word_imm(Bit8u reg) {
+static void dyn_mov_word_imm(uint8_t reg) {
 	Bitu val;
 	if (decode.big_op) {
 		if (decode_fetchd_imm(val)) {
@@ -300,27 +300,27 @@ static void dyn_mov_word_imm(Bit8u reg) {
 			return;
 		}
 	}
-	if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP1,(Bit32u)val);
-	else gen_mov_word_to_reg_imm(FC_OP1,(Bit16u)val);
+	if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP1,(uint32_t)val);
+	else gen_mov_word_to_reg_imm(FC_OP1,(uint16_t)val);
 	MOV_REG_WORD_FROM_HOST_REG(FC_OP1,reg,decode.big_op);
 }
 
 
-static void dyn_sop_word(SingleOps op,Bit8u reg) {
+static void dyn_sop_word(SingleOps op,uint8_t reg) {
 	MOV_REG_WORD_TO_HOST_REG(FC_OP1,reg,decode.big_op);
 	dyn_sop_word_gencall(op,decode.big_op);
 	MOV_REG_WORD_FROM_HOST_REG(FC_RETOP,reg,decode.big_op);
 }
 
 
-static void dyn_mov_byte_al_direct(Bit32u imm) {
+static void dyn_mov_byte_al_direct(uint32_t imm) {
 	MOV_SEG_PHYS_TO_HOST_REG(FC_ADDR,(decode.seg_prefix_used ? decode.seg_prefix : DRC_SEG_DS));
 	gen_add_imm(FC_ADDR,imm);
 	dyn_read_byte(FC_ADDR,FC_TMP_BA1);
 	MOV_REG_BYTE_FROM_HOST_REG_LOW(FC_TMP_BA1,DRC_REG_EAX,0);
 }
 
-static void dyn_mov_byte_ax_direct(Bit32u imm) {
+static void dyn_mov_byte_ax_direct(uint32_t imm) {
 	MOV_SEG_PHYS_TO_HOST_REG(FC_ADDR,(decode.seg_prefix_used ? decode.seg_prefix : DRC_SEG_DS));
 	gen_add_imm(FC_ADDR,imm);
 	dyn_read_word(FC_ADDR,FC_OP1,decode.big_op);
@@ -334,7 +334,7 @@ static void dyn_mov_byte_direct_al() {
 		if (decode_fetchd_imm(val)) {
 			gen_add(FC_ADDR,(void*)val);
 		} else {
-			gen_add_imm(FC_ADDR,(Bit32u)val);
+			gen_add_imm(FC_ADDR,(uint32_t)val);
 		}
 	} else {
 		gen_add_imm(FC_ADDR,decode_fetchw());
@@ -343,7 +343,7 @@ static void dyn_mov_byte_direct_al() {
 	dyn_write_byte(FC_ADDR,FC_TMP_BA1);
 }
 
-static void dyn_mov_byte_direct_ax(Bit32u imm) {
+static void dyn_mov_byte_direct_ax(uint32_t imm) {
 	MOV_SEG_PHYS_TO_HOST_REG(FC_ADDR,(decode.seg_prefix_used ? decode.seg_prefix : DRC_SEG_DS));
 	gen_add_imm(FC_ADDR,imm);
 	MOV_REG_WORD_TO_HOST_REG(FC_OP1,DRC_REG_EAX,decode.big_op);
@@ -400,7 +400,7 @@ static void dyn_lea(void) {
 }
 
 
-static void dyn_push_seg(Bit8u seg) {
+static void dyn_push_seg(uint8_t seg) {
 	MOV_SEG_VAL_TO_HOST_REG(FC_OP1,seg);
 	if (decode.big_op) {
 		gen_extend_word(false,FC_OP1);
@@ -410,35 +410,35 @@ static void dyn_push_seg(Bit8u seg) {
 	}
 }
 
-static void dyn_pop_seg(Bit8u seg) {
+static void dyn_pop_seg(uint8_t seg) {
 	gen_call_function_II(CPU_PopSeg,seg,decode.big_op);
 	dyn_check_exception(FC_RETOP);
 }
 
-static void dyn_push_reg(Bit8u reg) {
+static void dyn_push_reg(uint8_t reg) {
 	MOV_REG_WORD_TO_HOST_REG(FC_OP1,reg,decode.big_op);
 	if (decode.big_op) gen_call_function_raw(dynrec_push_dword);
 	else gen_call_function_raw(dynrec_push_word);
 }
 
-static void dyn_pop_reg(Bit8u reg) {
+static void dyn_pop_reg(uint8_t reg) {
 	if (decode.big_op) gen_call_function_raw(dynrec_pop_dword);
 	else gen_call_function_raw(dynrec_pop_word);
 	MOV_REG_WORD_FROM_HOST_REG(FC_RETOP,reg,decode.big_op);
 }
 
-static void dyn_push_byte_imm(Bit8s imm) {
-	gen_mov_dword_to_reg_imm(FC_OP1,(Bit32u)imm);
+static void dyn_push_byte_imm(int8_t imm) {
+	gen_mov_dword_to_reg_imm(FC_OP1,(uint32_t)imm);
 	if (decode.big_op) gen_call_function_raw(dynrec_push_dword);
 	else gen_call_function_raw(dynrec_push_word);
 }
 
-static void dyn_push_word_imm(Bit32u imm) {
+static void dyn_push_word_imm(uint32_t imm) {
 	if (decode.big_op) {
 		gen_mov_dword_to_reg_imm(FC_OP1,imm);
 		gen_call_function_raw(dynrec_push_dword);
 	} else {
-		gen_mov_word_to_reg_imm(FC_OP1,(Bit16u)imm);
+		gen_mov_word_to_reg_imm(FC_OP1,(uint16_t)imm);
 		gen_call_function_raw(dynrec_push_word);
 	}
 }
@@ -471,7 +471,7 @@ static void dyn_pop_ev(void) {
 }
 
 
-static void dyn_segprefix(Bit8u seg) {
+static void dyn_segprefix(uint8_t seg) {
 //	if (GCC_UNLIKELY(decode.seg_prefix_used)) IllegalOptionDynrec("dyn_segprefix");
 	decode.seg_prefix=seg;
 	decode.seg_prefix_used=true;
@@ -490,7 +490,7 @@ static void dyn_segprefix(Bit8u seg) {
 	dyn_check_exception(FC_RETOP);
 }
 
-static void dyn_load_seg_off_ea(Bit8u seg) {
+static void dyn_load_seg_off_ea(uint8_t seg) {
 	if (decode.modrm.mod<3) {
 		dyn_fill_ea(FC_ADDR);
 		gen_protect_addr_reg();
@@ -527,16 +527,16 @@ static void dyn_imul_gvev(Bitu immsize) {
 			MOV_REG_WORD_TO_HOST_REG(FC_OP2,decode.modrm.reg,decode.big_op);
 			break;
 		case 1:
-			if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(Bit8s)decode_fetchb());
-			else  gen_mov_word_to_reg_imm(FC_OP2,(Bit8s)decode_fetchb());
+			if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(int8_t)decode_fetchb());
+			else  gen_mov_word_to_reg_imm(FC_OP2,(int8_t)decode_fetchb());
 			break;
 		case 2:
-			if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(Bit16s)decode_fetchw());
-			else gen_mov_word_to_reg_imm(FC_OP2,(Bit16s)decode_fetchw());
+			if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(int16_t)decode_fetchw());
+			else gen_mov_word_to_reg_imm(FC_OP2,(int16_t)decode_fetchw());
 			break;
 		case 4:
-			if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(Bit32s)decode_fetchd());
-			else gen_mov_word_to_reg_imm(FC_OP2,(Bit16u)((Bit32s)decode_fetchd()));
+			if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(int32_t)decode_fetchd());
+			else gen_mov_word_to_reg_imm(FC_OP2,(uint16_t)((int32_t)decode_fetchd()));
 			break;
 	}
 
@@ -600,9 +600,9 @@ static void dyn_grp1_ev_iv(bool withbyte) {
 		if (!withbyte) {
 			dyn_prep_word_imm(FC_OP2);
 		} else {
-			Bits imm=(Bit8s)decode_fetchb(); 
-			if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(Bit32u)imm);
-			else gen_mov_word_to_reg_imm(FC_OP2,(Bit16u)imm);
+			Bits imm=(int8_t)decode_fetchb(); 
+			if (decode.big_op) gen_mov_dword_to_reg_imm(FC_OP2,(uint32_t)imm);
+			else gen_mov_word_to_reg_imm(FC_OP2,(uint16_t)imm);
 		}
 
 		dyn_dop_word_gencall(op,decode.big_op);
@@ -615,7 +615,7 @@ static void dyn_grp1_ev_iv(bool withbyte) {
 		if (!withbyte) {
 			dyn_dop_word_imm(op,decode.modrm.rm);
 		} else {
-			Bits imm=withbyte ? (Bit8s)decode_fetchb() : (decode.big_op ? decode_fetchd(): decode_fetchw()); 
+			Bits imm=withbyte ? (int8_t)decode_fetchb() : (decode.big_op ? decode_fetchd(): decode_fetchw()); 
 			dyn_dop_word_imm_old(op,decode.modrm.rm,imm);
 		}
 	}
@@ -637,7 +637,7 @@ static void dyn_grp2_eb(grp2_types type) {
 		dyn_shift_byte_gencall((ShiftOps)decode.modrm.reg);
 		break;
 	case grp2_imm: {
-		Bit8u imm=decode_fetchb();
+		uint8_t imm=decode_fetchb();
 		if (imm) {
 			gen_mov_byte_to_reg_low_imm_canuseword(FC_OP2,imm&0x1f);
 			dyn_shift_byte_gencall((ShiftOps)decode.modrm.reg);
@@ -680,7 +680,7 @@ static void dyn_grp2_ev(grp2_types type) {
 			dyn_shift_word_gencall((ShiftOps)decode.modrm.reg,decode.big_op);
 			break;
 		}
-		Bit8u imm=(Bit8u)val;
+		uint8_t imm=(uint8_t)val;
 		if (imm) {
 			gen_mov_byte_to_reg_low_imm_canuseword(FC_OP2,imm&0x1f);
 			dyn_shift_word_gencall((ShiftOps)decode.modrm.reg,decode.big_op);
@@ -852,7 +852,7 @@ static Bitu dyn_grp4_ev(void) {
 		gen_mov_regs(FC_ADDR,FC_OP1);
 		gen_protect_addr_reg();
 		gen_mov_word_to_reg(FC_OP1,decode.big_op?(void*)(&reg_eip):(void*)(&reg_ip),decode.big_op);
-		gen_add_imm(FC_OP1,(Bit32u)(decode.code-decode.code_start));
+		gen_add_imm(FC_OP1,(uint32_t)(decode.code-decode.code_start));
 		if (decode.big_op) gen_call_function_raw(dynrec_push_dword);
 		else gen_call_function_raw(dynrec_push_word);
 
@@ -1096,7 +1096,7 @@ static void dyn_sahf(void) {
 }
 
 
-static void dyn_exit_link(Bit32s eip_change) {
+static void dyn_exit_link(int32_t eip_change) {
 	gen_add_direct_word(&reg_eip,(decode.code-decode.code_start)+eip_change,decode.big_op);
 	dyn_reduce_cycles();
 	gen_jmp_ptr(&decode.block->link[0].to,offsetof(CacheBlockDynRec,cache.start));
@@ -1104,8 +1104,8 @@ static void dyn_exit_link(Bit32s eip_change) {
 }
 
 
-static void dyn_branched_exit(BranchTypes btype,Bit32s eip_add) {
-	Bit32u eip_base=decode.code-decode.code_start;
+static void dyn_branched_exit(BranchTypes btype,int32_t eip_add) {
+	uint32_t eip_base=decode.code-decode.code_start;
 	dyn_reduce_cycles();
 
 	dyn_branchflag_to_reg(btype);
@@ -1138,8 +1138,8 @@ static void dyn_set_byte_on_condition(BranchTypes btype) {
 
 static void dyn_loop(LoopTypes type) {
 	dyn_reduce_cycles();
-	Bit8s eip_add=(Bit8s)decode_fetchb();
-	Bit32u eip_base=decode.code-decode.code_start;
+	int8_t eip_add=(int8_t)decode_fetchb();
+	uint32_t eip_base=decode.code-decode.code_start;
 	DRC_PTR_SIZE_IM branch1=0;
 	DRC_PTR_SIZE_IM branch2=0;
 	switch (type) {
@@ -1159,7 +1159,7 @@ static void dyn_loop(LoopTypes type) {
 	case LOOP_NE:
 	case LOOP_NONE:
 		MOV_REG_WORD_TO_HOST_REG(FC_OP1,DRC_REG_ECX,decode.big_addr);
-		gen_add_imm(FC_OP1,(Bit32u)(-1));
+		gen_add_imm(FC_OP1,(uint32_t)(-1));
 		MOV_REG_WORD_FROM_HOST_REG(FC_OP1,DRC_REG_ECX,decode.big_addr);
 		branch2=gen_create_branch_on_zero(FC_OP1,decode.big_addr);
 		break;
@@ -1175,7 +1175,7 @@ static void dyn_loop(LoopTypes type) {
 	if (branch1) {
 		gen_fill_branch(branch1);
 		MOV_REG_WORD_TO_HOST_REG(FC_OP1,DRC_REG_ECX,decode.big_addr);
-		gen_add_imm(FC_OP1,(Bit32u)(-1));
+		gen_add_imm(FC_OP1,(uint32_t)(-1));
 		MOV_REG_WORD_FROM_HOST_REG(FC_OP1,DRC_REG_ECX,decode.big_addr);
 	}
 	// Branch taken
@@ -1186,7 +1186,7 @@ static void dyn_loop(LoopTypes type) {
 }
 
 
-static void dyn_ret_near(Bit16u bytes) {
+static void dyn_ret_near(uint16_t bytes) {
 	dyn_reduce_cycles();
 
 	if (decode.big_op) gen_call_function_raw(dynrec_pop_dword);
@@ -1202,9 +1202,9 @@ static void dyn_ret_near(Bit16u bytes) {
 }
 
 static void dyn_call_near_imm(void) {
-	Bit32s imm;
-	if (decode.big_op) imm=(Bit32s)decode_fetchd();
-	else imm=(Bit16s)decode_fetchw();
+	int32_t imm;
+	if (decode.big_op) imm=(int32_t)decode_fetchd();
+	else imm=(int16_t)decode_fetchw();
 	dyn_set_eip_end(FC_OP1);
 	if (decode.big_op) gen_call_function_raw(dynrec_push_dword);
 	else gen_call_function_raw(dynrec_push_word);
@@ -1237,8 +1237,8 @@ static void dyn_call_far_imm(void) {
 }
 
 static void dyn_jmp_far_imm(void) {
-    Bit16u sel;
-    Bit32u off;
+    uint16_t sel;
+    uint32_t off;
 	off=decode.big_op ? decode_fetchd() : decode_fetchw();
 	sel=decode_fetchw();
 	dyn_reduce_cycles();
@@ -1257,7 +1257,7 @@ static void dyn_iret(void) {
 }
 
 #if !(C_DEBUG)
-static void dyn_interrupt(Bit8u num) {
+static void dyn_interrupt(uint8_t num) {
 	dyn_reduce_cycles();
 	dyn_set_eip_last_end(FC_RETOP);
 	gen_call_function_IIR(CPU_Interrupt,num,CPU_INT_SOFTWARE,FC_RETOP);
@@ -1271,7 +1271,7 @@ static void dyn_string(StringOps op) {
 	if (decode.rep) MOV_REG_WORD_TO_HOST_REG(FC_OP1,DRC_REG_ECX,decode.big_addr);
 	else gen_mov_dword_to_reg_imm(FC_OP1,1);
 	gen_mov_word_to_reg(FC_OP2,&cpu.direction,true);
-	Bit8u di_base_addr=decode.seg_prefix_used ? decode.seg_prefix : DRC_SEG_DS;
+	uint8_t di_base_addr=decode.seg_prefix_used ? decode.seg_prefix : DRC_SEG_DS;
 	switch (op) {
 		case STR_MOVSB:
 			if (decode.big_addr) gen_call_function_mm(dynrec_movsb_dword,(Bitu)DRCD_SEG_PHYS(di_base_addr),(Bitu)DRCD_SEG_PHYS(DRC_SEG_ES));
@@ -1327,13 +1327,13 @@ static void dyn_string(StringOps op) {
 }
 
 
-static void dyn_read_port_byte_direct(Bit8u port) {
+static void dyn_read_port_byte_direct(uint8_t port) {
 	dyn_add_iocheck_var(port,1);
 	gen_call_function_I(IO_ReadB,port);
 	MOV_REG_BYTE_FROM_HOST_REG_LOW(FC_RETOP,DRC_REG_EAX,0);
 }
 
-static void dyn_read_port_word_direct(Bit8u port) {
+static void dyn_read_port_word_direct(uint8_t port) {
 	dyn_add_iocheck_var(port,decode.big_op?4:2);
     if (decode.big_op)
         gen_call_function_I(IO_ReadD,port);
@@ -1342,14 +1342,14 @@ static void dyn_read_port_word_direct(Bit8u port) {
     MOV_REG_WORD_FROM_HOST_REG(FC_RETOP,DRC_REG_EAX,decode.big_op);
 }
 
-static void dyn_write_port_byte_direct(Bit8u port) {
+static void dyn_write_port_byte_direct(uint8_t port) {
 	dyn_add_iocheck_var(port,1);
 	MOV_REG_BYTE_TO_HOST_REG_LOW(FC_RETOP,DRC_REG_EAX,0);
 	gen_extend_byte(false,FC_RETOP);
 	gen_call_function_IR(IO_WriteB,port,FC_RETOP);
 }
 
-static void dyn_write_port_word_direct(Bit8u port) {
+static void dyn_write_port_word_direct(uint8_t port) {
 	dyn_add_iocheck_var(port,decode.big_op?4:2);
 	MOV_REG_WORD_TO_HOST_REG(FC_RETOP,DRC_REG_EAX,decode.big_op);
 	if (!decode.big_op) gen_extend_word(false,FC_RETOP);
@@ -1434,13 +1434,13 @@ static void dyn_leave(void) {
 
 
 static void dynrec_pusha_word(void) {
-	Bit16u old_sp=reg_sp;
+	uint16_t old_sp=reg_sp;
 	CPU_Push16(reg_ax);CPU_Push16(reg_cx);CPU_Push16(reg_dx);CPU_Push16(reg_bx);
 	CPU_Push16(old_sp);CPU_Push16(reg_bp);CPU_Push16(reg_si);CPU_Push16(reg_di);
 }
 
 static void dynrec_pusha_dword(void) {
-	Bit32u tmpesp = reg_esp;
+	uint32_t tmpesp = reg_esp;
 	CPU_Push32(reg_eax);CPU_Push32(reg_ecx);CPU_Push32(reg_edx);CPU_Push32(reg_ebx);
 	CPU_Push32(tmpesp);CPU_Push32(reg_ebp);CPU_Push32(reg_esi);CPU_Push32(reg_edi);
 }
