@@ -43,14 +43,14 @@ extern bool mustCompleteInstruction;
 # define mustCompleteInstruction (0)
 #endif
 
-static Bit16u last_ea86_offset;
+static uint16_t last_ea86_offset;
 
 /* NTS: we special case writes to seg:ffff to emulate 8086 behavior where word read/write wraps around the 64KB segment */
 #if (!C_CORE_INLINE)
 
 #define LoadMb(off) mem_readb(off)
 
-static inline Bit16u LoadMw(Bitu off) {
+static inline uint16_t LoadMw(Bitu off) {
 	if (last_ea86_offset == 0xffff)
 		return (mem_readb(off) | (mem_readb(off-0xffff) << 8));
 
@@ -79,7 +79,7 @@ static void SaveMw(Bitu off,Bitu val) {
 
 #define LoadMb(off) mem_readb_inline(off)
 
-static inline Bit16u LoadMw(Bitu off) {
+static inline uint16_t LoadMw(Bitu off) {
 	if (last_ea86_offset == 0xffff)
 		return (mem_readb_inline((PhysPt)off) | (mem_readb_inline((PhysPt)(off-0xffff)) << 8));
 
@@ -92,11 +92,11 @@ static inline Bit16u LoadMw(Bitu off) {
 
 static void SaveMw(Bitu off,Bitu val) {
 	if (last_ea86_offset == 0xffff) {
-		mem_writeb_inline((PhysPt)off,(Bit8u)val);
-		mem_writeb_inline((PhysPt)(off-0xffff),(Bit8u)(val>>8));
+		mem_writeb_inline((PhysPt)off,(uint8_t)val);
+		mem_writeb_inline((PhysPt)(off-0xffff),(uint8_t)(val>>8));
 	}
 	else {
-		mem_writew_inline((PhysPt)off,(Bit16u)val);
+		mem_writew_inline((PhysPt)off,(uint16_t)val);
 	}
 }
 
@@ -113,6 +113,8 @@ extern Bitu cycle_count;
 #define CPU_PIC_CHECK 1u
 #define CPU_TRAP_CHECK 1u
 
+#define CPU_TRAP_DECODER	CPU_Core_Normal_Trap_Run
+
 #define OPCODE_NONE			0x000u
 #define OPCODE_0F			0x100u
 
@@ -144,7 +146,7 @@ extern Bitu cycle_count;
 
 typedef PhysPt (*GetEAHandler)(void);
 
-static const Bit32u AddrMaskTable[2]={0x0000ffffu,0x0000ffffu};
+static const uint32_t AddrMaskTable[2]={0x0000ffffu,0x0000ffffu};
 
 static struct {
 	Bitu opcode_index;
@@ -171,25 +173,25 @@ static INLINE void FetchDiscardb() {
 	core.cseip+=1;
 }
 
-static INLINE Bit8u FetchPeekb() {
-	Bit8u temp=LoadMb(core.cseip);
+static INLINE uint8_t FetchPeekb() {
+	uint8_t temp=LoadMb(core.cseip);
 	return temp;
 }
 
-static INLINE Bit8u Fetchb() {
-	Bit8u temp=LoadMb(core.cseip);
+static INLINE uint8_t Fetchb() {
+	uint8_t temp=LoadMb(core.cseip);
 	core.cseip+=1;
 	return temp;
 }
 
-static INLINE Bit16u Fetchw() {
-	Bit16u temp=LoadMw(core.cseip);
+static INLINE uint16_t Fetchw() {
+	uint16_t temp=LoadMw(core.cseip);
 	core.cseip+=2;
 	return temp;
 }
 
-static INLINE Bit32u Fetchd() {
-	Bit32u temp=LoadMd(core.cseip);
+static INLINE uint32_t Fetchd() {
+	uint32_t temp=LoadMd(core.cseip);
 	core.cseip+=4;
 	return temp;
 }
