@@ -74,9 +74,9 @@ typedef struct SMSF {
 //! \brief Output and channel control state
 typedef struct SCtrl {
     //! \brief output channel
-    Bit8u           out[4];
+    uint8_t           out[4];
     //! \brief channel volume
-    Bit8u           vol[4];
+    uint8_t           vol[4];
 } TCtrl;
 
 template<typename T1, typename T2>
@@ -217,17 +217,17 @@ private:
 	// Nested Class Definitions
 	class TrackFile {
 	protected:
-		TrackFile(Bit16u _chunkSize) : chunkSize(_chunkSize) {}
+		TrackFile(uint16_t _chunkSize) : chunkSize(_chunkSize) {}
 	public:
 		virtual          ~TrackFile() = default;
-		virtual bool     read(Bit8u *buffer, int seek, int count) = 0;
-		virtual bool     seek(Bit32u offset) = 0;
-		virtual Bit16u   decode(Bit8u *buffer) = 0;
-		virtual Bit16u   getEndian() = 0;
-		virtual Bit32u   getRate() = 0;
-		virtual Bit8u    getChannels() = 0;
+		virtual bool     read(uint8_t *buffer, int seek, int count) = 0;
+		virtual bool     seek(uint32_t offset) = 0;
+		virtual uint16_t   decode(uint8_t *buffer) = 0;
+		virtual uint16_t   getEndian() = 0;
+		virtual uint32_t   getRate() = 0;
+		virtual uint8_t    getChannels() = 0;
 		virtual int      getLength() = 0;
-		const Bit16u chunkSize = 0;
+		const uint16_t chunkSize = 0;
 	};
 
     //! \brief Binary file reader for the image
@@ -240,12 +240,12 @@ private:
 		BinaryFile      (const BinaryFile&) = delete; // prevent copying
 		BinaryFile&     operator= (const BinaryFile&) = delete; // prevent assignment
 
-		bool            read(Bit8u *buffer, int seek, int count);
-		bool            seek(Bit32u offset);
-		Bit16u          decode(Bit8u *buffer);
-		Bit16u          getEndian();
-		Bit32u          getRate() { return 44100; }
-		Bit8u           getChannels() { return 2; }
+		bool            read(uint8_t *buffer, int seek, int count);
+		bool            seek(uint32_t offset);
+		uint16_t          decode(uint8_t *buffer);
+		uint16_t          getEndian();
+		uint32_t          getRate() { return 44100; }
+		uint8_t           getChannels() { return 2; }
 		int             getLength();
 	private:
 		std::ifstream   *file;
@@ -260,12 +260,12 @@ private:
 		AudioFile       (const AudioFile&) = delete; // prevent copying
 		AudioFile&      operator= (const AudioFile&) = delete; // prevent assignment
 
-		bool            read(Bit8u *buffer, int seek, int count) { (void)buffer; (void)seek; (void)count; return false; }
-		bool            seek(Bit32u offset);
-		Bit16u          decode(Bit8u *buffer);
-		Bit16u          getEndian();
-		Bit32u          getRate();
-		Bit8u           getChannels();
+		bool            read(uint8_t *buffer, int seek, int count) { (void)buffer; (void)seek; (void)count; return false; }
+		bool            seek(uint32_t offset);
+		uint16_t          decode(uint8_t *buffer);
+		uint16_t          getEndian();
+		uint32_t          getRate();
+		uint8_t           getChannels();
 		int             getLength();
 	private:
 		Sound_Sample    *sample = nullptr;
@@ -286,7 +286,7 @@ public:
 		TrackFile *file;
 	};
     //! \brief Constructor, with parameter for subunit
-	CDROM_Interface_Image           (Bit8u subUnit);
+	CDROM_Interface_Image           (uint8_t subUnit);
 	virtual ~CDROM_Interface_Image  (void);
 	void	InitNewMedia            (void) {};
 	bool	SetDevice               (char *path, int forceCD);
@@ -305,7 +305,7 @@ public:
 	bool	ReadSectorsHost			(void* buffer, bool raw, unsigned long sector, unsigned long num);
 	bool	LoadUnloadMedia         (bool unload);
 	//! \brief Indicate whether the image has a data track
-	bool	ReadSector              (Bit8u *buffer, bool raw, unsigned long sector);
+	bool	ReadSector              (uint8_t *buffer, bool raw, unsigned long sector);
 	//! \brief Indicate whether the image has a data track
 	bool	HasDataTrack            (void);
     //! \brief Flag to track if images have been initialized
@@ -324,25 +324,25 @@ private:
 		CDROM_Interface_Image *cd;
 		MixerChannel   *channel;
 		SDL_mutex                *mutex             = nullptr;
-		void (MixerChannel::*addFrames) (Bitu, const Bit16s*) = nullptr;
+		void (MixerChannel::*addFrames) (Bitu, const int16_t*) = nullptr;
 		uint32_t                 playedTrackFrames  = 0;
 		uint32_t                 totalTrackFrames   = 0;
 		uint32_t                 startSector        = 0;
 		uint32_t                 totalRedbookFrames = 0;
-		Bit8u   buffer[AUDIO_DECODE_BUFFER_SIZE];
-		Bit32u  startFrame;
-		Bit32u  currFrame;
-		Bit32u  numFrames;
+		uint8_t   buffer[AUDIO_DECODE_BUFFER_SIZE];
+		uint32_t  startFrame;
+		uint32_t  currFrame;
+		uint32_t  numFrames;
 		bool    isPlaying;
 		bool    isPaused;
 		bool    ctrlUsed;
 		TCtrl   ctrlData;
 		TrackFile* trackFile;
-		void     (MixerChannel::*addSamples) (Bitu, const Bit16s*);
-		Bit32u   playbackTotal;
+		void     (MixerChannel::*addSamples) (Bitu, const int16_t*);
+		uint32_t   playbackTotal;
 		int      playbackRemaining;
-		Bit16u   bufferPos;
-		Bit16u   bufferConsumed;
+		uint16_t   bufferPos;
+		uint16_t   bufferConsumed;
 	} player;
 
 	// Private utility functions
@@ -364,7 +364,7 @@ private:
 	std::vector<uint8_t> readBuffer;
 	std::string          mcn;
 	static int           refCount;
-    Bit8u                subUnit;
+    uint8_t                subUnit;
 };
 
 #if defined (WIN32)	/* Win 32 */
@@ -448,7 +448,7 @@ public:
 	bool	StopAudio			(void);
 	void	ChannelControl		(TCtrl ctrl);
 	
-	bool	ReadSector			(Bit8u *buffer, bool raw, unsigned long sector);
+	bool	ReadSector			(uint8_t *buffer, bool raw, unsigned long sector);
 	bool	ReadSectors			(PhysPt buffer, bool raw, unsigned long sector, unsigned long num);
 	/* This is needed for IDE hack, who's buffer does not exist in DOS physical memory */
 	bool	ReadSectorsHost			(void* buffer, bool raw, unsigned long sector, unsigned long num);
@@ -497,7 +497,7 @@ private:
 		CDROM_Interface_Ioctl *cd;
 		MixerChannel	*channel;
 		SDL_mutex		*mutex;
-		Bit8u   buffer[8192];
+		uint8_t   buffer[8192];
 		int     bufLen;
 		int     currFrame;	
 		int     targetFrame;
