@@ -33,20 +33,20 @@ const char * RunningProgram="DOSBOX-X";
 #pragma pack(1)
 #endif
 struct EXE_Header {
-	Bit16u signature;					/* EXE Signature MZ or ZM */
-	Bit16u extrabytes;					/* Bytes on the last page */
-	Bit16u pages;						/* Pages in file */
-	Bit16u relocations;					/* Relocations in file */
-	Bit16u headersize;					/* Paragraphs in header */
-	Bit16u minmemory;					/* Minimum amount of memory */
-	Bit16u maxmemory;					/* Maximum amount of memory */
-	Bit16u initSS;
-	Bit16u initSP;
-	Bit16u checksum;
-	Bit16u initIP;
-	Bit16u initCS;
-	Bit16u reloctable;
-	Bit16u overlay;
+	uint16_t signature;					/* EXE Signature MZ or ZM */
+	uint16_t extrabytes;					/* Bytes on the last page */
+	uint16_t pages;						/* Pages in file */
+	uint16_t relocations;					/* Relocations in file */
+	uint16_t headersize;					/* Paragraphs in header */
+	uint16_t minmemory;					/* Minimum amount of memory */
+	uint16_t maxmemory;					/* Maximum amount of memory */
+	uint16_t initSS;
+	uint16_t initSP;
+	uint16_t checksum;
+	uint16_t initIP;
+	uint16_t initCS;
+	uint16_t reloctable;
+	uint16_t overlay;
 } GCC_ATTRIBUTE(packed);
 #ifdef _MSC_VER
 #pragma pack()
@@ -93,7 +93,8 @@ static void RestoreRegisters(void) {
 	reg_sp+=18;
 }
 
-extern void GFX_SetTitle(Bit32s cycles, Bits frameskip, Bits timing, bool paused);
+extern uint8_t ZDRIVE_NUM;
+extern void GFX_SetTitle(int32_t cycles, int frameskip, Bits timing, bool paused);
 void DOS_UpdatePSPName(void) {
 	DOS_MCB mcb(dos.psp()-1);
 	static char name[9];
@@ -108,10 +109,10 @@ void DOS_UpdatePSPName(void) {
 	GFX_SetTitle(-1,-1,-1,false);
 }
 
-void DOS_Terminate(Bit16u pspseg,bool tsr,Bit8u exitcode) {
+void DOS_Terminate(uint16_t pspseg,bool tsr,uint8_t exitcode) {
 
 	dos.return_code=exitcode;
-	dos.return_mode=(tsr)?(Bit8u)RETURN_TSR:(Bit8u)RETURN_EXIT;
+	dos.return_mode=(tsr)?(uint8_t)RETURN_TSR:(uint8_t)RETURN_EXIT;
 	
 	DOS_PSP curpsp(pspseg);
 	if (pspseg==curpsp.GetParent()) return;
@@ -149,7 +150,7 @@ void DOS_Terminate(Bit16u pspseg,bool tsr,Bit8u exitcode) {
 		CPU_CycleLeft=0;
 		CPU_Cycles=0;
 		CPU_CycleMax=CPU_OldCycleMax;
-		GFX_SetTitle((Bit32s)CPU_OldCycleMax,-1,-1,false);
+		GFX_SetTitle((int32_t)CPU_OldCycleMax,-1,-1,false);
 	} else {
 		GFX_SetTitle(-1,-1,-1,false);
 	}
@@ -164,12 +165,12 @@ void DOS_Terminate(Bit16u pspseg,bool tsr,Bit8u exitcode) {
 	return;
 }
 
-static bool MakeEnv(const char* name, Bit16u* segment) {
+static bool MakeEnv(const char* name, uint16_t* segment) {
 	/* If segment to copy environment is 0 copy the caller's environment */
 	DOS_PSP psp(dos.psp());
 	PhysPt envread,envwrite;
 	unsigned int keepfree;
-	Bit16u envsize=1;
+	uint16_t envsize=1;
 	bool parentenv=true;
 
 	/* below 83 bytes, we must not append the mystery 0x01 + program name string */
@@ -193,7 +194,7 @@ static bool MakeEnv(const char* name, Bit16u* segment) {
 		}
 		envsize += 2;									/* account for trailing \0\0 */
 	}
-	Bit16u size = long2para(envsize+keepfree);
+	uint16_t size = long2para(envsize+keepfree);
 	if (size == 0) size = 1;
 	if (!DOS_AllocateMemory(segment,&size)) return false;
 	envwrite=PhysMake(*segment,0);
@@ -222,10 +223,10 @@ static bool MakeEnv(const char* name, Bit16u* segment) {
 	return true;
 }
 
-bool DOS_NewPSP(Bit16u segment, Bit16u size) {
+bool DOS_NewPSP(uint16_t segment, uint16_t size) {
 	DOS_PSP psp(segment);
 	psp.MakeNew(size);
-	Bit16u parent_psp_seg=psp.GetParent();
+	uint16_t parent_psp_seg=psp.GetParent();
 	DOS_PSP psp_parent(parent_psp_seg);
 	psp.CopyFileTable(&psp_parent,false);
 	// copy command line as well (Kings Quest AGI -cga switch)
@@ -233,10 +234,10 @@ bool DOS_NewPSP(Bit16u segment, Bit16u size) {
 	return true;
 }
 
-bool DOS_ChildPSP(Bit16u segment, Bit16u size) {
+bool DOS_ChildPSP(uint16_t segment, uint16_t size) {
 	DOS_PSP psp(segment);
 	psp.MakeNew(size);
-	Bit16u parent_psp_seg = psp.GetParent();
+	uint16_t parent_psp_seg = psp.GetParent();
 	DOS_PSP psp_parent(parent_psp_seg);
 	psp.CopyFileTable(&psp_parent,true);
 	psp.SetCommandTail(RealMake(parent_psp_seg,0x80));
@@ -251,11 +252,11 @@ bool DOS_ChildPSP(Bit16u segment, Bit16u size) {
 	return true;
 }
 
-static void SetupPSP(Bit16u pspseg,Bit16u memsize,Bit16u envseg) {
+static void SetupPSP(uint16_t pspseg,uint16_t memsize,uint16_t envseg) {
 	/* Fix the PSP for psp and environment MCB's */
-	DOS_MCB mcb((Bit16u)(pspseg-1));
+	DOS_MCB mcb((uint16_t)(pspseg-1));
 	mcb.SetPSPSeg(pspseg);
-	mcb.SetPt((Bit16u)(envseg-1));
+	mcb.SetPt((uint16_t)(envseg-1));
 	mcb.SetPSPSeg(pspseg);
 
 	DOS_PSP psp(pspseg);
@@ -268,7 +269,7 @@ static void SetupPSP(Bit16u pspseg,Bit16u memsize,Bit16u envseg) {
 
 }
 
-static void SetupCMDLine(Bit16u pspseg, const DOS_ParamBlock& block) {
+static void SetupCMDLine(uint16_t pspseg, const DOS_ParamBlock& block) {
 	DOS_PSP psp(pspseg);
 	// if cmdtail==0 it will inited as empty in SetCommandTail
 	psp.SetCommandTail(block.exec.cmdtail);
@@ -281,13 +282,13 @@ static void SetupCMDLine(Bit16u pspseg, const DOS_ParamBlock& block) {
  *        shell without any error message. The least we could do is return
  *        an error code so that the INT 21h EXEC call can print an informative
  *        error message! --J.C. */
-bool DOS_Execute(const char* name, PhysPt block_pt, Bit8u flags) {
+bool DOS_Execute(const char* name, PhysPt block_pt, uint8_t flags) {
 	EXE_Header head;Bitu i;
-	Bit16u fhandle;Bit16u len;Bit32u pos;
-	Bit16u pspseg,envseg,loadseg,memsize=0xffff,readsize;
-	Bit16u maxsize,maxfree=0xffff;
+	uint16_t fhandle;uint16_t len;uint32_t pos;
+	uint16_t pspseg,envseg,loadseg,memsize=0xffff,readsize;
+	uint16_t maxsize,maxfree=0xffff;
 	PhysPt loadaddress;RealPt relocpt;
-    Bit32u headersize = 0, imagesize = 0;
+    uint32_t headersize = 0, imagesize = 0;
 	DOS_ParamBlock block(block_pt);
 
 	block.LoadData();
@@ -302,11 +303,20 @@ bool DOS_Execute(const char* name, PhysPt block_pt, Bit8u flags) {
 	/* Check for EXE or COM File */
 	bool iscom=false;
 	if (!DOS_OpenFile(name,OPEN_READ,&fhandle)) {
-		DOS_SetError(DOSERR_FILE_NOT_FOUND);
-		return false;
+        int16_t fLen = (int16_t)strlen(name);
+        bool shellcom =(!strcasecmp(name+fLen-8, "4DOS.COM") && (fLen == 8 || *(name+fLen-9)=='\\')) || (!strcasecmp(name+fLen-11, "COMMAND.COM") && (fLen == 11 || *(name+fLen-12)=='\\')); // Trap 4DOS.COM and COMMAND.COM
+        char z4dos[]="Z:\\4DOS.COM", zcmd[]="Z:\\COMMAND.COM";
+        if (ZDRIVE_NUM!=25) {
+            z4dos[0]='A'+ZDRIVE_NUM;
+            zcmd[0]='A'+ZDRIVE_NUM;
+        }
+        if (!shellcom || !DOS_OpenFile(!strcasecmp(name+fLen-8, "4DOS.COM")?z4dos:zcmd,OPEN_READ,&fhandle)) {
+            DOS_SetError(DOSERR_FILE_NOT_FOUND);
+            return false;
+        }
 	}
 	len=sizeof(EXE_Header);
-	if (!DOS_ReadFile(fhandle,(Bit8u *)&head,&len)) {
+	if (!DOS_ReadFile(fhandle,(uint8_t *)&head,&len)) {
 		DOS_CloseFile(fhandle);
 		return false;
 	}
@@ -323,7 +333,7 @@ bool DOS_Execute(const char* name, PhysPt block_pt, Bit8u flags) {
 		/* Convert the header to correct endian, i hope this works */
 		HostPt endian=(HostPt)&head;
 		for (i=0;i<sizeof(EXE_Header)/2;i++) {
-			*((Bit16u *)endian)=host_readw(endian);
+			*((uint16_t *)endian)=host_readw(endian);
 			endian+=2;
 		}
 		if ((head.signature!=MAGIC1) && (head.signature!=MAGIC2)) iscom=true;
@@ -336,15 +346,16 @@ bool DOS_Execute(const char* name, PhysPt block_pt, Bit8u flags) {
 			if (imagesize+headersize<512u) imagesize = 512u-headersize;
 		}
 	}
-	Bit8u * loadbuf=(Bit8u *)new Bit8u[0x10000u];
+	uint8_t * loadbuf=(uint8_t *)new uint8_t[0x10000u];
 	if (flags!=OVERLAY) {
 		/* Create an environment block */
 		envseg=block.exec.envseg;
 		if (!MakeEnv(name,&envseg)) {
 			DOS_CloseFile(fhandle);
+			delete [] loadbuf;
 			return false;
 		}
-		Bit16u minsize;
+		uint16_t minsize;
 		/* Get Memory */		
 		DOS_AllocateMemory(&pspseg,&maxfree);
 		if (iscom) {
@@ -352,7 +363,7 @@ bool DOS_Execute(const char* name, PhysPt block_pt, Bit8u flags) {
 			if (machine==MCH_PCJR) {
 				/* try to load file into memory below 96k */ 
 				pos=0;DOS_SeekFile(fhandle,&pos,DOS_SEEK_SET);	
-				Bit16u dataread=0x1800;
+				uint16_t dataread=0x1800;
 				DOS_ReadFile(fhandle,loadbuf,&dataread);
 				if (dataread<0x1800) maxsize=dataread;
 				if (minsize>maxsize) minsize=maxsize;
@@ -373,7 +384,7 @@ bool DOS_Execute(const char* name, PhysPt block_pt, Bit8u flags) {
 			if (iscom) {
 				/* Reduce minimum of needed memory size to filesize */
 				pos=0;DOS_SeekFile(fhandle,&pos,DOS_SEEK_SET);	
-				Bit16u dataread=0xf800;
+				uint16_t dataread=0xf800;
 				DOS_ReadFile(fhandle,loadbuf,&dataread);
 				if (dataread<0xf800) minsize=((dataread+0x10)>>4)+0x20;
 			}
@@ -428,17 +439,17 @@ bool DOS_Execute(const char* name, PhysPt block_pt, Bit8u flags) {
 			loadaddress+=0x8000;imagesize-=0x8000;
 		}
 		if (imagesize>0) {
-			readsize=(Bit16u)imagesize;DOS_ReadFile(fhandle,loadbuf,&readsize);
+			readsize=(uint16_t)imagesize;DOS_ReadFile(fhandle,loadbuf,&readsize);
 			MEM_BlockWrite(loadaddress,loadbuf,readsize);
 //			if (readsize!=imagesize) LOG(LOG_EXEC,LOG_NORMAL)("Illegal header");
 		}
 		/* Relocate the exe image */
-		Bit16u relocate;
+		uint16_t relocate;
 		if (flags==OVERLAY) relocate=block.overlay.relocation;
 		else relocate=loadseg;
 		pos=head.reloctable;DOS_SeekFile(fhandle,&pos,0);
 		for (i=0;i<head.relocations;i++) {
-			readsize=4;DOS_ReadFile(fhandle,(Bit8u *)&relocpt,&readsize);
+			readsize=4;DOS_ReadFile(fhandle,(uint8_t *)&relocpt,&readsize);
 			relocpt=host_readd((HostPt)&relocpt);		//Endianize
 			PhysPt address=PhysMake(RealSeg(relocpt)+loadseg,RealOff(relocpt));
 			mem_writew(address,mem_readw(address)+relocate);
@@ -507,9 +518,9 @@ bool DOS_Execute(const char* name, PhysPt block_pt, Bit8u flags) {
 		/* Setup bx, contains a 0xff in bl and bh if the drive in the fcb is not valid */
 		DOS_FCB fcb1(RealSeg(block.exec.fcb1),RealOff(block.exec.fcb1));
 		DOS_FCB fcb2(RealSeg(block.exec.fcb2),RealOff(block.exec.fcb2));
-		Bit8u d1 = fcb1.GetDrive(); //depends on 0 giving the dos.default drive
+		uint8_t d1 = fcb1.GetDrive(); //depends on 0 giving the dos.default drive
 		if ( (d1>=DOS_DRIVES) || !Drives[d1] ) reg_bl = 0xFF; else reg_bl = 0;
-		Bit8u d2 = fcb2.GetDrive();
+		uint8_t d2 = fcb2.GetDrive();
 		if ( (d2>=DOS_DRIVES) || !Drives[d2] ) reg_bh = 0xFF; else reg_bh = 0;
 
 		/* Write filename in new program MCB */
