@@ -25,10 +25,10 @@
 #include "control.h"
 #include <list>
 
-Bit32u DOS_HMA_LIMIT();
-Bit32u DOS_HMA_FREE_START();
-Bit32u DOS_HMA_GET_FREE_SPACE();
-void DOS_HMA_CLAIMED(Bit16u bytes);
+uint32_t DOS_HMA_LIMIT();
+uint32_t DOS_HMA_FREE_START();
+uint32_t DOS_HMA_GET_FREE_SPACE();
+void DOS_HMA_CLAIMED(uint16_t bytes);
 bool ANSI_SYS_installed();
 
 extern bool enable_share_exe_fake;
@@ -42,7 +42,9 @@ static Bitu call_int2f,call_int2a;
 static std::list<MultiplexHandler*> Multiplex;
 typedef std::list<MultiplexHandler*>::iterator Multiplex_it;
 
-const char *Win_NameThatVXD(Bit16u devid) {
+extern RealPt ipx_callback;
+
+const char *Win_NameThatVXD(uint16_t devid) {
 	switch (devid) {
 		case 0x0006:	return "V86MMGR";
 		case 0x000C:	return "VMD";
@@ -90,7 +92,7 @@ static Bitu INT2A_Handler(void) {
 	return CBRET_NONE;
 }
 
-extern bool i4dos;
+extern bool i4dos, clipboard_dosapi;
 extern RealPt DOS_DriveDataListHead;       // INT 2Fh AX=0803h DRIVER.SYS drive data table list
 
 // INT 2F
@@ -130,14 +132,14 @@ static bool DOS_MultiplexFunctions(void) {
 		if (reg_bx<16) {
 			RealPt sftrealpt=mem_readd(Real2Phys(dos_infoblock.GetPointer())+4);
 			PhysPt sftptr=Real2Phys(sftrealpt);
-			Bit32u sftofs=0x06u+reg_bx*0x3bu;
+			uint32_t sftofs=0x06u+reg_bx*0x3bu;
 
-			if (Files[reg_bx]) mem_writeb(sftptr+sftofs, (Bit8u)(Files[reg_bx]->refCtr));
+			if (Files[reg_bx]) mem_writeb(sftptr+sftofs, (uint8_t)(Files[reg_bx]->refCtr));
 			else mem_writeb(sftptr+sftofs,0);
 
 			if (!Files[reg_bx]) return true;
 
-			Bit32u handle=RealHandle(reg_bx);
+			uint32_t handle=RealHandle(reg_bx);
 			if (handle>=DOS_FILES) {
 				mem_writew(sftptr+sftofs+0x02,0x02);	// file open mode
 				mem_writeb(sftptr+sftofs+0x04,0x00);	// file attribute
@@ -148,17 +150,17 @@ static bool DOS_MultiplexFunctions(void) {
 				mem_writew(sftptr+sftofs+0x11,0);		// size
 				mem_writew(sftptr+sftofs+0x15,0);		// current position
 			} else {
-				Bit8u drive=Files[reg_bx]->GetDrive();
+				uint8_t drive=Files[reg_bx]->GetDrive();
 
-				mem_writew(sftptr+sftofs+0x02,(Bit16u)(Files[reg_bx]->flags&3));	// file open mode
-				mem_writeb(sftptr+sftofs+0x04,(Bit8u)(Files[reg_bx]->attr));		// file attribute
+				mem_writew(sftptr+sftofs+0x02,(uint16_t)(Files[reg_bx]->flags&3));	// file open mode
+				mem_writeb(sftptr+sftofs+0x04,(uint8_t)(Files[reg_bx]->attr));		// file attribute
 				mem_writew(sftptr+sftofs+0x05,0x40|drive);							// device info word
 				mem_writed(sftptr+sftofs+0x07,RealMake(dos.tables.dpb,drive*dos.tables.dpb_size));	// dpb of the drive
 				mem_writew(sftptr+sftofs+0x0d,Files[reg_bx]->time);					// packed file time
 				mem_writew(sftptr+sftofs+0x0f,Files[reg_bx]->date);					// packed file date
-				Bit32u curpos=0;
+				uint32_t curpos=0;
 				Files[reg_bx]->Seek(&curpos,DOS_SEEK_CUR);
-				Bit32u endpos=0;
+				uint32_t endpos=0;
 				Files[reg_bx]->Seek(&endpos,DOS_SEEK_END);
 				mem_writed(sftptr+sftofs+0x11,endpos);		// size
 				mem_writed(sftptr+sftofs+0x15,curpos);		// current position
@@ -244,7 +246,7 @@ static bool DOS_MultiplexFunctions(void) {
         strcpy(name,regpath);
         MEM_BlockWrite(SegPhys(es)+reg_di,name,(Bitu)(strlen(name)+1));
         reg_ax=0;
-        reg_cx=(Bit16u)strlen(name);
+        reg_cx=(uint16_t)strlen(name);
         return true;
     case 0x1614:    /* Set SYSTEM.DAT path */
 		if (dos.version.major < 7) return false;
@@ -381,12 +383,12 @@ static bool DOS_MultiplexFunctions(void) {
 		return true;
 #ifdef WIN32
 	case 0x1700:
-		if(control->SecureMode()) return false;
+		if(control->SecureMode()||!clipboard_dosapi) return false;
 		reg_al = 1;
 		reg_ah = 1;
 		return true;
 	case 0x1701:
-		if(control->SecureMode()) return false;
+		if(control->SecureMode()||!clipboard_dosapi) return false;
 		reg_ax=0;
 		if (OpenClipboard(NULL)) {
 			reg_ax=1;
@@ -394,7 +396,7 @@ static bool DOS_MultiplexFunctions(void) {
 		}
 		return true;
 	case 0x1702:
-		if(control->SecureMode()) return false;
+		if(control->SecureMode()||!clipboard_dosapi) return false;
 		reg_ax=0;
 		if (OpenClipboard(NULL))
 			{
@@ -403,7 +405,7 @@ static bool DOS_MultiplexFunctions(void) {
 			}
 		return true;
 	case 0x1703:
-		if(control->SecureMode()) return false;
+		if(control->SecureMode()||!clipboard_dosapi) return false;
 		reg_ax=0;
 		if ((reg_dx==1||reg_dx==7)&&OpenClipboard(NULL))
 			{
@@ -424,14 +426,14 @@ static bool DOS_MultiplexFunctions(void) {
 			}
 		return true;
 	case 0x1704:
-		if(control->SecureMode()) return false;
+		if(control->SecureMode()||!clipboard_dosapi) return false;
 		reg_ax=0;
 		if ((reg_dx==1||reg_dx==7)&&OpenClipboard(NULL))
 			{
 			if (HANDLE text = GetClipboardData(reg_dx==1?CF_TEXT:CF_OEMTEXT))
 				{
-				reg_ax=(Bit16u)strlen((char *)text)+1;
-				reg_dx=(Bit16u)((strlen((char *)text)+1)/65536);
+				reg_ax=(uint16_t)strlen((char *)text)+1;
+				reg_dx=(uint16_t)((strlen((char *)text)+1)/65536);
 				}
 			else
 				reg_dx=0;
@@ -439,7 +441,7 @@ static bool DOS_MultiplexFunctions(void) {
 			}
 		return true;
 	case 0x1705:
-		if(control->SecureMode()) return false;
+		if(control->SecureMode()||!clipboard_dosapi) return false;
 		reg_ax=0;
 		if ((reg_dx==1||reg_dx==7)&&OpenClipboard(NULL))
 			{
@@ -452,7 +454,7 @@ static bool DOS_MultiplexFunctions(void) {
 			}
 		return true;
 	case 0x1708:
-		if(control->SecureMode()) return false;
+		if(control->SecureMode()||!clipboard_dosapi) return false;
 		reg_ax=1;
 		CloseClipboard();
 		return true;
@@ -478,7 +480,7 @@ static bool DOS_MultiplexFunctions(void) {
         // nor is DOS 5 DOSSHELL active
         return true;
 	case 0x4a01: {	/* Query free hma space */
-		Bit32u limit = DOS_HMA_LIMIT();
+		uint32_t limit = DOS_HMA_LIMIT();
 
 		if (limit == 0) {
 			/* TODO: What does MS-DOS prior to v5.0? */
@@ -489,7 +491,7 @@ static bool DOS_MultiplexFunctions(void) {
 			return true;
 		}
 
-		Bit32u start = DOS_HMA_FREE_START();
+		uint32_t start = DOS_HMA_FREE_START();
 		reg_bx = limit - start; /* free space in bytes */
 		SegSet16(es,0xffff);
 		reg_di = (start + 0x10) & 0xFFFF;
@@ -497,7 +499,7 @@ static bool DOS_MultiplexFunctions(void) {
 			start,limit,DOS_HMA_GET_FREE_SPACE(),(int)reg_bx,(int)SegValue(es),(int)reg_di);
 		} return true;
 	case 0x4a02: {	/* ALLOCATE HMA SPACE */
-		Bit32u limit = DOS_HMA_LIMIT();
+		uint32_t limit = DOS_HMA_LIMIT();
 
 		if (limit == 0) {
 			/* TODO: What does MS-DOS prior to v5.0? */
@@ -514,7 +516,7 @@ static bool DOS_MultiplexFunctions(void) {
 		if (dos.version.major < 7 && (reg_bx & 0xF) != 0)
 			reg_bx = (reg_bx + 0xF) & (~0xF);
 
-		Bit32u start = DOS_HMA_FREE_START();
+		uint32_t start = DOS_HMA_FREE_START();
 		if ((start+reg_bx) > limit) {
 			LOG(LOG_DOSMISC,LOG_DEBUG)("HMA allocation: rejected (not enough room) for %u bytes (0x%x + 0x%x > 0x%x)",reg_bx,
                 (unsigned int)start,(unsigned int)reg_bx,(unsigned int)limit);
@@ -551,6 +553,10 @@ static bool DOS_MultiplexFunctions(void) {
 			reg_ax=0;
 			return true;
 		}
+    case 0x7a00:
+        LOG_MSG("call 2f 7a\n");
+        reg_al=0xff;
+        return true;
     }
 
 	return false;
@@ -568,9 +574,11 @@ void DOS_SetupMisc(void) {
 	RealSetVec(0x2A,CALLBACK_RealPointer(call_int2a));
 }
 
+extern const char* RunningProgram;
 void CALLBACK_DeAllocate(Bitu in);
 
 void DOS_UninstallMisc(void) {
+    if (!strcmp(RunningProgram, "LOADLIN")) return;
 	/* these vectors shouldn't exist when booting a guest OS */
 	if (call_int2a) {
 		RealSetVec(0x2a,0);
