@@ -65,8 +65,9 @@ DOS_Drive_Cache::DOS_Drive_Cache(void) {
     save_dir        = 0;
     srchNr          = 0;
     label[0]        = 0;
+    basePath[0]     = 0;
     nextFreeFindFirst   = 0;
-    for (Bit32u i=0; i<MAX_OPENDIRS; i++) { dirSearch[i] = 0; dirFindFirst[i] = 0; }
+    for (uint32_t i=0; i<MAX_OPENDIRS; i++) { dirSearch[i] = 0; dirFindFirst[i] = 0; }
     SetDirSort(DIRALPHABETICAL);
     updatelabel = true;
 }
@@ -76,8 +77,9 @@ DOS_Drive_Cache::DOS_Drive_Cache(const char* path, DOS_Drive *drive) {
     save_dir        = 0;
     srchNr          = 0;
     label[0]        = 0;
+    basePath[0]     = 0;
     nextFreeFindFirst   = 0;
-    for (Bit32u i=0; i<MAX_OPENDIRS; i++) { dirSearch[i] = 0; dirFindFirst[i] = 0; }
+    for (uint32_t i=0; i<MAX_OPENDIRS; i++) { dirSearch[i] = 0; dirFindFirst[i] = 0; }
     SetDirSort(DIRALPHABETICAL);
     SetBaseDir(path,drive);
     updatelabel = true;
@@ -85,13 +87,13 @@ DOS_Drive_Cache::DOS_Drive_Cache(const char* path, DOS_Drive *drive) {
 
 DOS_Drive_Cache::~DOS_Drive_Cache(void) {
     Clear();
-    for (Bit32u i=0; i<MAX_OPENDIRS; i++) { DeleteFileInfo(dirFindFirst[i]); dirFindFirst[i]=0; }
+    for (uint32_t i=0; i<MAX_OPENDIRS; i++) { DeleteFileInfo(dirFindFirst[i]); dirFindFirst[i]=0; }
 }
 
 void DOS_Drive_Cache::Clear(void) {
     DeleteFileInfo(dirBase); dirBase = 0;
     nextFreeFindFirst   = 0;
-    for (Bit32u i=0; i<MAX_OPENDIRS; i++) dirSearch[i] = 0;
+    for (uint32_t i=0; i<MAX_OPENDIRS; i++) dirSearch[i] = 0;
 }
 
 void DOS_Drive_Cache::EmptyCache(void) {
@@ -100,7 +102,7 @@ void DOS_Drive_Cache::EmptyCache(void) {
     dirBase     = new CFileInfo;
     save_dir    = 0;
     srchNr      = 0;
-    SetBaseDir(basePath,drive);
+    if (basePath[0] != 0) SetBaseDir(basePath,drive);
 }
 
 void DOS_Drive_Cache::SetLabel(const char* vname,bool cdrom,bool allowupdate) {
@@ -114,22 +116,24 @@ void DOS_Drive_Cache::SetLabel(const char* vname,bool cdrom,bool allowupdate) {
     LOG(LOG_DOSMISC,LOG_NORMAL)("DIRCACHE: Set volume label to %s",label);
 }
 
-Bit16u DOS_Drive_Cache::GetFreeID(CFileInfo* dir) {
+uint16_t DOS_Drive_Cache::GetFreeID(CFileInfo* dir) {
     if (dir->id != MAX_OPENDIRS)
         return dir->id;
-    for (Bit16u i=0; i<MAX_OPENDIRS; i++) {
+    for (uint16_t i=0; i<MAX_OPENDIRS; i++) {
         if (!dirSearch[i]) {
             dir->id = i;
             return i;
         }
     }
     LOG(LOG_FILES,LOG_NORMAL)("DIRCACHE: Too many open directories!");
-    dir->id=0;
+    dir->id = 0;
     return 0;
 }
 
 void DOS_Drive_Cache::SetBaseDir(const char* baseDir, DOS_Drive *drive) {
-    Bit16u id;
+    if (strlen(baseDir) == 0) return;
+
+    uint16_t id;
     strcpy(basePath,baseDir);
     this->drive = drive;
     if (OpenDir(baseDir,id)) {
@@ -222,8 +226,8 @@ void DOS_Drive_Cache::AddEntry(const char* path, bool checkExists) {
         Bits index = GetLongName(dir,file);
         if (index>=0) {
             // Check if there are any open search dir that are affected by this...
-            if (dir) for (Bit32u i=0; i<MAX_OPENDIRS; i++) {
-                if ((dirSearch[i]==dir) && ((Bit32u)index<=dirSearch[i]->nextEntry)) 
+            if (dir) for (uint32_t i=0; i<MAX_OPENDIRS; i++) {
+                if ((dirSearch[i]==dir) && ((uint32_t)index<=dirSearch[i]->nextEntry)) 
                     dirSearch[i]->nextEntry++;
             }
         }
@@ -296,10 +300,10 @@ void DOS_Drive_Cache::AddEntryDirOverlay(const char* path, char *sfile, bool che
 			  strcpy(sfile, genname);
 	  }
       if (index>=0) {
-          Bit32u i;
+          uint32_t i;
           // Check if there are any open search dir that are affected by this...
           if (dir) for (i=0; i<MAX_OPENDIRS; i++) {
-              if ((dirSearch[i]==dir) && ((Bit32u)index<=dirSearch[i]->nextEntry)) 
+              if ((dirSearch[i]==dir) && ((uint32_t)index<=dirSearch[i]->nextEntry)) 
                   dirSearch[i]->nextEntry++;
           }
 
@@ -322,7 +326,7 @@ void DOS_Drive_Cache::DeleteEntry(const char* path, bool ignoreLastDir) {
         // Check if there are any open search dir that are affected by this...
         char expand [CROSS_LEN];
         CFileInfo* dir = FindDirInfo(path,expand);
-        if (dir) for (Bit32u i=0; i<MAX_OPENDIRS; i++) {
+        if (dir) for (uint32_t i=0; i<MAX_OPENDIRS; i++) {
             if ((dirSearch[i]==dir) && (dirSearch[i]->nextEntry>0)) 
                 dirSearch[i]->nextEntry--;
         }   
@@ -335,9 +339,9 @@ void DOS_Drive_Cache::CacheOut(const char* path, bool ignoreLastDir) {
     
     if (ignoreLastDir) {
         char tmp[CROSS_LEN] = { 0 };
-        Bit32s len=0;
+        int32_t len=0;
         const char* pos = strrchr(path,CROSS_FILESPLIT);
-        if (pos) len = (Bit32s)(pos - path);
+        if (pos) len = (int32_t)(pos - path);
         if (len>0) { 
             safe_strncpy(tmp,path,len+1); 
         } else  {
@@ -350,12 +354,12 @@ void DOS_Drive_Cache::CacheOut(const char* path, bool ignoreLastDir) {
 
 //  LOG_DEBUG("DIR: Caching out %s : dir %s",expand,dir->orgname);
 //  clear cache first?
-    for (Bit32u i=0; i<MAX_OPENDIRS; i++) {
+    for (uint32_t i=0; i<MAX_OPENDIRS; i++) {
         dirSearch[i] = 0; //free[i] = true;    
     }
     // delete file objects...
     //Maybe check if it is a file and then only delete the file and possibly the long name. instead of all objects in the dir.
-    for(Bit32u i=0; i<dir->fileList.size(); i++) {
+    for(uint32_t i=0; i<dir->fileList.size(); i++) {
         if (dirSearch[srchNr]==dir->fileList[i]) dirSearch[srchNr] = 0;
         DeleteFileInfo(dir->fileList[i]); dir->fileList[i] = 0;
     }
@@ -610,7 +614,8 @@ void DOS_Drive_Cache::CreateShortName(CFileInfo* curDir, CFileInfo* info) {
         // Create number
         char buffer[8];
         info->shortNr = CreateShortNameID(curDir,tmpName);
-        sprintf(buffer,"%d",(int)info->shortNr);
+        if (GCC_UNLIKELY(info->shortNr > 9999999)) E_Exit("~9999999 same name files overflow");
+        sprintf(buffer, "%d", static_cast<unsigned int>(info->shortNr));
         // Copy first letters
         Bits tocopy = 0;
         size_t buflen = strlen(buffer);
@@ -665,7 +670,7 @@ DOS_Drive_Cache::CFileInfo* DOS_Drive_Cache::FindDirInfo(const char* path, char*
     const char* start = path;
     const char*     pos;
     CFileInfo*  curDir = dirBase;
-    Bit16u      id;
+    uint16_t      id;
 
     if (save_dir && (strcmp(path,save_path)==0)) {
         strcpy(expandedPath,save_expanded);
@@ -744,7 +749,7 @@ DOS_Drive_Cache::CFileInfo* DOS_Drive_Cache::FindDirInfo(const char* path, char*
     return curDir;
 }
 
-bool DOS_Drive_Cache::OpenDir(const char* path, Bit16u& id) {
+bool DOS_Drive_Cache::OpenDir(const char* path, uint16_t& id) {
     char expand[CROSS_LEN] = {0};
     CFileInfo* dir = FindDirInfo(path,expand);
     if (OpenDir(dir,expand,id)) {
@@ -754,13 +759,14 @@ bool DOS_Drive_Cache::OpenDir(const char* path, Bit16u& id) {
     return false;
 }
 
-bool DOS_Drive_Cache::OpenDir(CFileInfo* dir, const char* expand, Bit16u& id) {
+bool DOS_Drive_Cache::OpenDir(CFileInfo* dir, const char* expand, uint16_t& id) {
     id = GetFreeID(dir);
     dirSearch[id] = dir;
     char expandcopy [CROSS_LEN];
     strcpy(expandcopy,expand);   
     // Add "/"
-    if (expandcopy[strlen(expandcopy)-1]!=CROSS_FILESPLIT) {
+    size_t expandcopylen = strlen(expandcopy);
+    if (expandcopylen > 0 && expandcopy[expandcopylen - 1] != CROSS_FILESPLIT) {
         char end[2]={CROSS_FILESPLIT,0};
         strcat(expandcopy,end);
     }
@@ -831,7 +837,7 @@ void DOS_Drive_Cache::CopyEntry(CFileInfo* dir, CFileInfo* from) {
     dir->fileList.push_back(info);
 }
 
-bool DOS_Drive_Cache::ReadDir(Bit16u id, char* &result, char * &lresult) {
+bool DOS_Drive_Cache::ReadDir(uint16_t id, char* &result, char * &lresult) {
     // shouldnt happen...
     if (id>=MAX_OPENDIRS) return false;
 
@@ -895,21 +901,21 @@ bool DOS_Drive_Cache::SetResult(CFileInfo* dir, char* &result, char* &lresult, B
 }
 
 // FindFirst / FindNext
-bool DOS_Drive_Cache::FindFirst(char* path, Bit16u& id) {
-    Bit16u  dirID;
+bool DOS_Drive_Cache::FindFirst(char* path, uint16_t& id) {
+    uint16_t  dirID;
     // Cache directory in 
     if (!OpenDir(path,dirID)) return false;
 
     //Find a free slot.
     //If the next one isn't free, move on to the next, if none is free => reset and assume the worst
-    Bit16u local_findcounter = 0;
+    uint16_t local_findcounter = 0;
     while ( local_findcounter < MAX_OPENDIRS ) {
         if (dirFindFirst[this->nextFreeFindFirst] == 0) break;
         if (++this->nextFreeFindFirst >= MAX_OPENDIRS) this->nextFreeFindFirst = 0; //Wrap around
         local_findcounter++;
     }
 
-    Bit16u  dirFindFirstID = this->nextFreeFindFirst++;
+    uint16_t  dirFindFirstID = this->nextFreeFindFirst++;
     if (this->nextFreeFindFirst >= MAX_OPENDIRS) this->nextFreeFindFirst = 0; //Increase and wrap around for the next search.
 
     if (local_findcounter == MAX_OPENDIRS) { //Here is the reset from above.
@@ -947,7 +953,7 @@ bool DOS_Drive_Cache::FindFirst(char* path, Bit16u& id) {
     return true;
 }
 
-bool DOS_Drive_Cache::FindNext(Bit16u id, char* &result, char* &lresult) {
+bool DOS_Drive_Cache::FindNext(uint16_t id, char* &result, char* &lresult) {
     // out of range ?
     if ((id>=MAX_OPENDIRS) || !dirFindFirst[id]) {
         LOG(LOG_DOSMISC,LOG_ERROR)("DIRCACHE: FindFirst/Next failure : ID out of range: %04X",id);
@@ -962,7 +968,7 @@ bool DOS_Drive_Cache::FindNext(Bit16u id, char* &result, char* &lresult) {
 }
 
 void DOS_Drive_Cache::ClearFileInfo(CFileInfo *dir) {
-    for(Bit32u i=0; i<dir->fileList.size(); i++) {
+    for(uint32_t i=0; i<dir->fileList.size(); i++) {
         if (CFileInfo *info = dir->fileList[i])
             ClearFileInfo(info);
     }
