@@ -75,7 +75,7 @@ static double FROUND(double in){
 	case ROUND_Nearest:	
 		if (in-floor(in)>0.5) return (floor(in)+1);
 		else if (in-floor(in)<0.5) return (floor(in));
-		else return (((static_cast<Bit64s>(floor(in)))&1)!=0)?(floor(in)+1):(floor(in));
+		else return (((static_cast<int64_t>(floor(in)))&1)!=0)?(floor(in)+1):(floor(in));
 		break;
 	case ROUND_Down:
 		return (floor(in));
@@ -95,32 +95,32 @@ static double FROUND(double in){
 #define BIAS80 16383
 #define BIAS64 1023
 
-static Real64 FPU_FLD80(PhysPt addr,FPU_Reg_80 &raw) {
+static double FPU_FLD80(PhysPt addr,FPU_Reg_80 &raw) {
 	struct {
-		Bit16s begin;
+		int16_t begin;
 		FPU_Reg eind;
 	} test;
 	test.eind.l.lower = mem_readd(addr);
-	test.eind.l.upper = (Bit32s)mem_readd(addr+4);
-	test.begin = (Bit16s)mem_readw(addr+8);
+	test.eind.l.upper = (int32_t)mem_readd(addr+4);
+	test.begin = (int16_t)mem_readw(addr+8);
    
-	Bit64s exp64 = (((test.begin&0x7fff) - (Bit64s)BIAS80));
-	Bit64s blah = ((exp64 >0)?exp64:-exp64)&0x3ff;
-	Bit64s exp64final = ((exp64 >0)?blah:-blah) +BIAS64;
+	int64_t exp64 = (((test.begin&0x7fff) - (int64_t)BIAS80));
+	int64_t blah = ((exp64 >0)?exp64:-exp64)&0x3ff;
+	int64_t exp64final = ((exp64 >0)?blah:-blah) +BIAS64;
 
-	Bit64s mant64 = (test.eind.ll >> 11) & LONGTYPE(0xfffffffffffff);
-	Bit64s sign = (test.begin&0x8000)?1:0;
+	int64_t mant64 = (test.eind.ll >> 11) & LONGTYPE(0xfffffffffffff);
+	int64_t sign = (test.begin&0x8000)?1:0;
 	FPU_Reg result;
 	result.ll = (sign <<63)|(exp64final << 52)| mant64;
 
-	if(test.eind.l.lower == 0 && (Bit32u)test.eind.l.upper == (Bit32u)0x80000000UL && (test.begin&0x7fff) == 0x7fff) {
+	if(test.eind.l.lower == 0 && (uint32_t)test.eind.l.upper == (uint32_t)0x80000000UL && (test.begin&0x7fff) == 0x7fff) {
 		//Detect INF and -INF (score 3.11 when drawing a slur.)
 		result.d = sign?-HUGE_VAL:HUGE_VAL;
 	}
 
 	/* store the raw value. */
-	raw.raw.l = (Bit64u)test.eind.ll;
-	raw.raw.h = (Bit16u)test.begin;
+	raw.raw.l = (uint64_t)test.eind.ll;
+	raw.raw.h = (uint16_t)test.begin;
 
 	return result.d;
 
@@ -130,28 +130,28 @@ static Real64 FPU_FLD80(PhysPt addr,FPU_Reg_80 &raw) {
 static void FPU_ST80(PhysPt addr,Bitu reg,FPU_Reg_80 &raw,bool use80) {
 	if (use80) {
 		// we have the raw 80-bit IEEE float value. we can just store
-		mem_writed(addr,(Bit32u)raw.raw.l);
-		mem_writed(addr+4,(Bit32u)(raw.raw.l >> (Bit64u)32));
-		mem_writew(addr+8,(Bit16u)raw.raw.h);
+		mem_writed(addr,(uint32_t)raw.raw.l);
+		mem_writed(addr+4,(uint32_t)(raw.raw.l >> (uint64_t)32));
+		mem_writew(addr+8,(uint16_t)raw.raw.h);
 	}
 	else {
 		// convert the "double" type to 80-bit IEEE and store
 		struct {
-			Bit16s begin;
+			int16_t begin;
 			FPU_Reg eind;
 		} test;
-		Bit64s sign80 = ((Bit64u)fpu.regs[reg].ll&ULONGTYPE(0x8000000000000000))?1:0;
-		Bit64s exp80 =  fpu.regs[reg].ll&LONGTYPE(0x7ff0000000000000);
-		Bit64s exp80final = (exp80>>52);
-		Bit64s mant80 = fpu.regs[reg].ll&LONGTYPE(0x000fffffffffffff);
-		Bit64s mant80final = (mant80 << 11);
+		int64_t sign80 = ((uint64_t)fpu.regs[reg].ll&ULONGTYPE(0x8000000000000000))?1:0;
+		int64_t exp80 =  fpu.regs[reg].ll&LONGTYPE(0x7ff0000000000000);
+		int64_t exp80final = (exp80>>52);
+		int64_t mant80 = fpu.regs[reg].ll&LONGTYPE(0x000fffffffffffff);
+		int64_t mant80final = (mant80 << 11);
 		if(fpu.regs[reg].d != 0){ //Zero is a special case
 			// Elvira wants the 8 and tcalc doesn't
-			mant80final |= (Bit64s)ULONGTYPE(0x8000000000000000);
+			mant80final |= (int64_t)ULONGTYPE(0x8000000000000000);
 			//Ca-cyber doesn't like this when result is zero.
 			exp80final += (BIAS80 - BIAS64);
 		}
-		test.begin = (static_cast<Bit16s>(sign80)<<15)| static_cast<Bit16s>(exp80final);
+		test.begin = (static_cast<int16_t>(sign80)<<15)| static_cast<int16_t>(exp80final);
 		test.eind.ll = mant80final;
 		mem_writed(addr,test.eind.l.lower);
 		mem_writed(addr+4,(uint32_t)test.eind.l.upper);
@@ -163,16 +163,16 @@ static void FPU_ST80(PhysPt addr,Bitu reg,FPU_Reg_80 &raw,bool use80) {
 static void FPU_FLD_F32(PhysPt addr,Bitu store_to) {
 	union {
 		float f;
-		Bit32u l;
+		uint32_t l;
 	}	blah;
 	blah.l = mem_readd(addr);
-	fpu.regs[store_to].d = static_cast<Real64>(blah.f);
+	fpu.regs[store_to].d = static_cast<double>(blah.f);
 	fpu.use80[store_to] = false;
 }
 
 static void FPU_FLD_F64(PhysPt addr,Bitu store_to) {
 	fpu.regs[store_to].l.lower = mem_readd(addr);
-	fpu.regs[store_to].l.upper = (Bit32s)mem_readd(addr+4);
+	fpu.regs[store_to].l.upper = (int32_t)mem_readd(addr+4);
 	fpu.use80[store_to] = false;
 }
 
@@ -182,35 +182,35 @@ static void FPU_FLD_F80(PhysPt addr) {
 }
 
 static void FPU_FLD_I16(PhysPt addr,Bitu store_to) {
-	Bit16s blah = (Bit16s)mem_readw(addr);
-	fpu.regs[store_to].d = static_cast<Real64>(blah);
+	int16_t blah = (int16_t)mem_readw(addr);
+	fpu.regs[store_to].d = static_cast<double>(blah);
 	fpu.use80[store_to] = false;
 }
 
 static void FPU_FLD_I32(PhysPt addr,Bitu store_to) {
-	Bit32s blah = (Bit32s)mem_readd(addr);
-	fpu.regs[store_to].d = static_cast<Real64>(blah);
+	int32_t blah = (int32_t)mem_readd(addr);
+	fpu.regs[store_to].d = static_cast<double>(blah);
 	fpu.use80[store_to] = false;
 }
 
 static void FPU_FLD_I64(PhysPt addr,Bitu store_to) {
 	FPU_Reg blah;
 	blah.l.lower = mem_readd(addr);
-	blah.l.upper = (Bit32s)mem_readd(addr+4);
-	fpu.regs[store_to].d = static_cast<Real64>(blah.ll);
+	blah.l.upper = (int32_t)mem_readd(addr+4);
+	fpu.regs[store_to].d = static_cast<double>(blah.ll);
 	// store the signed 64-bit integer in the 80-bit format mantissa with faked exponent.
 	// this is needed for DOS and Windows games that use the Pentium fast memcpy trick, using FLD/FST to copy 64 bits at a time.
 	// I wonder if that trick is what helped spur Intel to make the MMX extensions :)
-	fpu.regs_80[store_to].raw.l = (Bit64u)blah.ll;
-	fpu.regs_80[store_to].raw.h = ((blah.ll/*sign bit*/ >> (Bit64u)63) ? 0x8000u : 0x0000u) + FPU_Reg_80_exponent_bias + 63u; // FIXME: Verify this is correct!
+	fpu.regs_80[store_to].raw.l = (uint64_t)blah.ll;
+	fpu.regs_80[store_to].raw.h = ((blah.ll/*sign bit*/ >> (uint64_t)63) ? 0x8000u : 0x0000u) + FPU_Reg_80_exponent_bias + 63u; // FIXME: Verify this is correct!
 	fpu.use80[store_to] = true;
 }
 
 static void FPU_FBLD(PhysPt addr,Bitu store_to) {
-	Bit64u val = 0;
-	Bit8u in = 0;
-	Bit64u base = 1;
-	for(Bit8u i = 0;i < 9;i++){
+	uint64_t val = 0;
+	uint8_t in = 0;
+	uint64_t base = 1;
+	for(uint8_t i = 0;i < 9;i++){
 		in = mem_readb(addr + i);
 		val += ( (in&0xf) * base); //in&0xf shouldn't be higher then 9
 		base *= 10;
@@ -220,7 +220,7 @@ static void FPU_FBLD(PhysPt addr,Bitu store_to) {
 
 	//last number, only now convert to float in order to get
 	//the best signification
-	Real64 temp = static_cast<Real64>(val);
+	double temp = static_cast<double>(val);
 	in = mem_readb(addr + 9);
 	temp += ( (in&0xf) * base );
 	if(in&0x80) temp *= -1.0;
@@ -246,7 +246,7 @@ static INLINE void FPU_FLD_I16_EA(PhysPt addr) {
 static void FPU_FST_F32(PhysPt addr) {
 	union {
 		float f;
-		Bit32u l;
+		uint32_t l;
 	}	blah;
 	//should depend on rounding method
 	blah.f = static_cast<float>(fpu.regs[TOP].d);
@@ -263,11 +263,11 @@ static void FPU_FST_F80(PhysPt addr) {
 }
 
 static void FPU_FST_I16(PhysPt addr) {
-	mem_writew(addr,(uint16_t)static_cast<Bit16s>(FROUND(fpu.regs[TOP].d)));
+	mem_writew(addr,(uint16_t)static_cast<int16_t>(FROUND(fpu.regs[TOP].d)));
 }
 
 static void FPU_FST_I32(PhysPt addr) {
-	mem_writed(addr,(uint32_t)static_cast<Bit32s>(FROUND(fpu.regs[TOP].d)));
+	mem_writed(addr,(uint32_t)static_cast<int32_t>(FROUND(fpu.regs[TOP].d)));
 }
 
 static void FPU_FST_I64(PhysPt addr) {
@@ -276,11 +276,11 @@ static void FPU_FST_I64(PhysPt addr) {
 		// FIXME: This works so far for DOS demos that use the "Pentium memcpy trick" to copy 64 bits at a time.
 		//        What this code needs to do is take the exponent into account and then clamp the 64-bit int within range.
 		//        This cheap hack is good enough for now.
-		mem_writed(addr,(Bit32u)(fpu.regs_80[TOP].raw.l));
-		mem_writed(addr+4,(Bit32u)(fpu.regs_80[TOP].raw.l >> (Bit64u)32));
+		mem_writed(addr,(uint32_t)(fpu.regs_80[TOP].raw.l));
+		mem_writed(addr+4,(uint32_t)(fpu.regs_80[TOP].raw.l >> (uint64_t)32));
 	}
 	else {
-		blah.ll = static_cast<Bit64s>(FROUND(fpu.regs[TOP].d));
+		blah.ll = static_cast<int64_t>(FROUND(fpu.regs[TOP].d));
 		mem_writed(addr,(uint32_t)blah.l.lower);
 		mem_writed(addr+4,(uint32_t)blah.l.upper);
 	}
@@ -288,30 +288,30 @@ static void FPU_FST_I64(PhysPt addr) {
 
 static void FPU_FBST(PhysPt addr) {
 	FPU_Reg val = fpu.regs[TOP];
-	bool sign = false;
-	if((Bit64u)fpu.regs[TOP].ll & ULONGTYPE(0x8000000000000000)) { //sign
-		sign=true;
-		val.d=-val.d;
-	}
-	//numbers from back to front
-	Real64 temp=val.d;
-	Bitu p;
-	for(Bit8u i=0;i<9;i++){
-		val.d=temp;
-		temp = static_cast<Real64>(static_cast<Bit64s>(floor(val.d/10.0)));
-		p = static_cast<Bitu>(val.d - 10.0*temp);  
-		val.d=temp;
-		temp = static_cast<Real64>(static_cast<Bit64s>(floor(val.d/10.0)));
-		p |= (static_cast<Bitu>(val.d - 10.0*temp)<<4);
+	if(val.ll & LONGTYPE(0x8000000000000000)) { // MSB = sign
+		mem_writeb(addr+9,0x80);
+		val.d = -val.d;
+	} else mem_writeb(addr+9,0);
 
-		mem_writeb(addr+i,(Bit8u)p);
+	uint64_t rndint = static_cast<uint64_t>(FROUND(val.d));
+	// BCD (18 decimal digits) overflow? (0x0DE0B6B3A763FFFF max)
+	if (rndint > LONGTYPE(999999999999999999)) {
+		// write BCD integer indefinite value
+		mem_writed(addr+0,0);
+		mem_writed(addr+4,0xC0000000);
+		mem_writew(addr+8,0xFFFF);
+		return;
 	}
-	val.d=temp;
-	temp = static_cast<Real64>(static_cast<Bit64s>(floor(val.d/10.0)));
-	p = static_cast<Bitu>(val.d - 10.0*temp);
-	if(sign)
-		p|=0x80;
-	mem_writeb(addr+9,(Bit8u)p);
+
+	//numbers from back to front
+	for(uint8_t i=0;i<9;i++){
+		uint64_t temp = rndint / 10;
+		uint8_t p = static_cast<uint8_t>(rndint % 10);
+		rndint = temp / 10;
+		p |= (static_cast<uint8_t>(temp % 10)) << 4;
+		mem_writeb(addr++,p);
+	}
+	// flags? C1 should indicate if value was rounded up
 }
 
 #if defined(WIN32) && defined(_MSC_VER) && (_MSC_VER < 1910)
@@ -346,7 +346,7 @@ static void FPU_FSIN(void){
 }
 
 static void FPU_FSINCOS(void){
-	Real64 temp = fpu.regs[TOP].d;
+	double temp = fpu.regs[TOP].d;
 	fpu.use80[TOP] = false; // we used the less precise version, drop the 80-bit precision
 	fpu.regs[TOP].d = sin(temp);
 	FPU_PUSH(cos(temp));
@@ -509,17 +509,17 @@ static inline void FPU_FCOMI(Bitu st, Bitu other){
 }
 
 static void FPU_FRNDINT(void){
-	Bit64s temp= static_cast<Bit64s>(FROUND(fpu.regs[TOP].d));
+	int64_t temp= static_cast<int64_t>(FROUND(fpu.regs[TOP].d));
 	fpu.regs[TOP].d=static_cast<double>(temp);
 	fpu.use80[TOP] = false;
 }
 
 static void FPU_FPREM(void){
-	Real64 valtop = fpu.regs[TOP].d;
-	Real64 valdiv = fpu.regs[STV(1)].d;
-	Bit64s ressaved = static_cast<Bit64s>( (valtop/valdiv) );
+	double valtop = fpu.regs[TOP].d;
+	double valdiv = fpu.regs[STV(1)].d;
+	int64_t ressaved = static_cast<int64_t>( (valtop/valdiv) );
 // Some backups
-//	Real64 res=valtop - ressaved*valdiv; 
+//	double res=valtop - ressaved*valdiv; 
 //      res= fmod(valtop,valdiv);
 	fpu.use80[TOP] = false; // we used the less precise version, drop the 80-bit precision
 	fpu.regs[TOP].d = valtop - ressaved*valdiv;
@@ -530,14 +530,14 @@ static void FPU_FPREM(void){
 }
 
 static void FPU_FPREM1(void){
-	Real64 valtop = fpu.regs[TOP].d;
-	Real64 valdiv = fpu.regs[STV(1)].d;
+	double valtop = fpu.regs[TOP].d;
+	double valdiv = fpu.regs[STV(1)].d;
 	double quot = valtop/valdiv;
 	double quotf = floor(quot);
-	Bit64s ressaved;
-	if (quot-quotf>0.5) ressaved = static_cast<Bit64s>(quotf+1);
-	else if (quot-quotf<0.5) ressaved = static_cast<Bit64s>(quotf);
-	else ressaved = static_cast<Bit64s>((((static_cast<Bit64s>(quotf))&1)!=0)?(quotf+1):(quotf));
+	int64_t ressaved;
+	if (quot-quotf>0.5) ressaved = static_cast<int64_t>(quotf+1);
+	else if (quot-quotf<0.5) ressaved = static_cast<int64_t>(quotf);
+	else ressaved = static_cast<int64_t>((((static_cast<int64_t>(quotf))&1)!=0)?(quotf+1):(quotf));
 	fpu.use80[TOP] = false; // we used the less precise version, drop the 80-bit precision
 	fpu.regs[TOP].d = valtop - ressaved*valdiv;
 	FPU_SET_C0(static_cast<Bitu>(ressaved&4));
@@ -547,7 +547,7 @@ static void FPU_FPREM1(void){
 }
 
 static void FPU_FXAM(void){
-	if((Bit64u)fpu.regs[TOP].ll & ULONGTYPE(0x8000000000000000))	//sign
+	if((uint64_t)fpu.regs[TOP].ll & ULONGTYPE(0x8000000000000000))	//sign
 	{ 
 		FPU_SET_C1(1);
 	} 
@@ -579,40 +579,40 @@ static void FPU_F2XM1(void){
 
 static void FPU_FYL2X(void){
 	fpu.use80[STV(1)] = false; // we used the less precise version, drop the 80-bit precision
-	fpu.regs[STV(1)].d*=log(fpu.regs[TOP].d)/log(static_cast<Real64>(2.0));
+	fpu.regs[STV(1)].d*=log(fpu.regs[TOP].d)/log(static_cast<double>(2.0));
 	FPU_FPOP();
 	return;
 }
 
 static void FPU_FYL2XP1(void){
 	fpu.use80[STV(1)] = false; // we used the less precise version, drop the 80-bit precision
-	fpu.regs[STV(1)].d*=log(fpu.regs[TOP].d+1.0)/log(static_cast<Real64>(2.0));
+	fpu.regs[STV(1)].d*=log(fpu.regs[TOP].d+1.0)/log(static_cast<double>(2.0));
 	FPU_FPOP();
 	return;
 }
 
 static void FPU_FSCALE(void){
 	fpu.use80[TOP] = false; // we used the less precise version, drop the 80-bit precision
-	fpu.regs[TOP].d *= pow(2.0,static_cast<Real64>(static_cast<Bit64s>(fpu.regs[STV(1)].d)));
+	fpu.regs[TOP].d *= pow(2.0,static_cast<double>(static_cast<int64_t>(fpu.regs[STV(1)].d)));
 	return; //2^x where x is chopped.
 }
 
 static void FPU_FSTENV(PhysPt addr){
 	FPU_SET_TOP(TOP);
 	if(!cpu.code.big) {
-		mem_writew(addr+0,static_cast<Bit16u>(fpu.cw));
-		mem_writew(addr+2,static_cast<Bit16u>(fpu.sw));
-		mem_writew(addr+4,static_cast<Bit16u>(FPU_GetTag()));
+		mem_writew(addr+0,static_cast<uint16_t>(fpu.cw));
+		mem_writew(addr+2,static_cast<uint16_t>(fpu.sw));
+		mem_writew(addr+4,static_cast<uint16_t>(FPU_GetTag()));
 	} else { 
-		mem_writed(addr+0,static_cast<Bit32u>(fpu.cw));
-		mem_writed(addr+4,static_cast<Bit32u>(fpu.sw));
-		mem_writed(addr+8,static_cast<Bit32u>(FPU_GetTag()));
+		mem_writed(addr+0,static_cast<uint32_t>(fpu.cw));
+		mem_writed(addr+4,static_cast<uint32_t>(fpu.sw));
+		mem_writed(addr+8,static_cast<uint32_t>(FPU_GetTag()));
 	}
 }
 
 static void FPU_FLDENV(PhysPt addr){
-	Bit16u tag;
-	Bit32u tagbig;
+	uint16_t tag;
+	uint32_t tagbig;
 	Bitu cw;
 	if(!cpu.code.big) {
 		cw     = mem_readw(addr+0);
@@ -620,9 +620,9 @@ static void FPU_FLDENV(PhysPt addr){
 		tag    = mem_readw(addr+4);
 	} else { 
 		cw     = mem_readd(addr+0);
-		fpu.sw = (Bit16u)mem_readd(addr+4);
+		fpu.sw = (uint16_t)mem_readd(addr+4);
 		tagbig = mem_readd(addr+8);
-		tag    = static_cast<Bit16u>(tagbig);
+		tag    = static_cast<uint16_t>(tagbig);
 	}
 	FPU_SetTag(tag);
 	FPU_SetCW(cw);
@@ -631,8 +631,8 @@ static void FPU_FLDENV(PhysPt addr){
 
 static void FPU_FSAVE(PhysPt addr){
 	FPU_FSTENV(addr);
-	Bit8u start = (cpu.code.big?28:14);
-	for(Bit8u i = 0;i < 8;i++){
+	uint8_t start = (cpu.code.big?28:14);
+	for(uint8_t i = 0;i < 8;i++){
 		FPU_ST80(addr+start,STV(i),/*&*/fpu.regs_80[STV(i)],fpu.use80[STV(i)]);
 		start += 10;
 	}
@@ -641,8 +641,8 @@ static void FPU_FSAVE(PhysPt addr){
 
 static void FPU_FRSTOR(PhysPt addr){
 	FPU_FLDENV(addr);
-	Bit8u start = (cpu.code.big?28:14);
-	for(Bit8u i = 0;i < 8;i++){
+	uint8_t start = (cpu.code.big?28:14);
+	for(uint8_t i = 0;i < 8;i++){
 		fpu.regs[STV(i)].d = FPU_FLD80(addr+start,/*&*/fpu.regs_80[STV(i)]);
 		fpu.use80[STV(i)] = true;
 		start += 10;
@@ -655,11 +655,11 @@ static void FPU_FXTRACT(void) {
 	// if double ever uses a different base please correct this function
 
 	FPU_Reg test = fpu.regs[TOP];
-	Bit64s exp80 =  test.ll&LONGTYPE(0x7ff0000000000000);
-	Bit64s exp80final = (exp80>>52) - BIAS64;
-	Real64 mant = test.d / (pow(2.0,static_cast<Real64>(exp80final)));
+	int64_t exp80 =  test.ll&LONGTYPE(0x7ff0000000000000);
+	int64_t exp80final = (exp80>>52) - BIAS64;
+	double mant = test.d / (pow(2.0,static_cast<double>(exp80final)));
 	fpu.use80[TOP] = false; // we used the less precise version, drop the 80-bit precision
-	fpu.regs[TOP].d = static_cast<Real64>(exp80final);
+	fpu.regs[TOP].d = static_cast<double>(exp80final);
 	FPU_PUSH(mant);
 }
 
