@@ -39,7 +39,7 @@
 		}
 #else
 #define FPUD_LOAD(op,szI,szA)			\
-		Bit16u new_sw;					\
+		uint16_t new_sw;					\
 		__asm {							\
 		__asm	mov		eax, 8			\
 		__asm	shl		eax, 4			\
@@ -60,7 +60,7 @@
 		}
 #else
 #define FPUD_LOAD_EA(op,szI,szA)		\
-		Bit16u new_sw;					\
+		uint16_t new_sw;					\
 		__asm {							\
 		__asm	mov		eax, 8			\
 		__asm	shl		eax, 4			\
@@ -73,7 +73,7 @@
 
 #ifdef WEAK_EXCEPTIONS
 #define FPUD_STORE(op,szI,szA)				\
-		Bit16u save_cw;						\
+		uint16_t save_cw;						\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	mov		eax, TOP			\
@@ -85,7 +85,7 @@
 		}
 #else
 #define FPUD_STORE(op,szI,szA)				\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	fldcw	fpu.cw_mask_all		\
@@ -104,7 +104,7 @@
 
 // handles fsin,fcos,f2xm1,fchs,fabs
 #define FPUD_TRIG(op)				\
-		Bit16u new_sw;				\
+		uint16_t new_sw;				\
 		__asm {						\
 		__asm	mov		eax, TOP	\
 		__asm	shl		eax, 4		\
@@ -118,7 +118,7 @@
 
 // handles fsincos
 #define FPUD_SINCOS()				\
-		Bit16u new_sw;					\
+		uint16_t new_sw;					\
 		__asm {							\
 		__asm	mov		eax, TOP		\
 		__asm	mov		ebx, eax		\
@@ -145,7 +145,7 @@
 
 // handles fptan
 #define FPUD_PTAN()					\
-		Bit16u new_sw;					\
+		uint16_t new_sw;					\
 		__asm {							\
 		__asm	mov		eax, TOP		\
 		__asm	mov		ebx, eax		\
@@ -188,7 +188,7 @@
 		FPU_PREP_PUSH();
 #else
 #define FPUD_XTRACT						\
-		Bit16u new_sw;					\
+		uint16_t new_sw;					\
 		__asm {							\
 		__asm	mov		eax, TOP		\
 		__asm	mov		ebx, eax		\
@@ -210,7 +210,7 @@
 // handles fadd,fmul,fsub,fsubr
 #ifdef WEAK_EXCEPTIONS
 #define FPUD_ARITH1(op)						\
-		Bit16u save_cw;						\
+		uint16_t save_cw;						\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	mov		eax, op1			\
@@ -226,7 +226,7 @@
 		}
 #else
 #define FPUD_ARITH1(op)						\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	fldcw	fpu.cw_mask_all		\
@@ -248,7 +248,7 @@
 // handles fadd,fmul,fsub,fsubr
 #ifdef WEAK_EXCEPTIONS
 #define FPUD_ARITH1_EA(op)					\
-		Bit16u save_cw;						\
+		uint16_t save_cw;						\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	mov		eax, op1			\
@@ -262,7 +262,7 @@
 		}
 #else
 #define FPUD_ARITH1_EA(op)					\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	fldcw	fpu.cw_mask_all		\
@@ -282,7 +282,7 @@
 // handles fsqrt,frndint
 #ifdef WEAK_EXCEPTIONS
 #define FPUD_ARITH2(op)						\
-		Bit16u save_cw;						\
+		uint16_t save_cw;						\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	mov		eax, TOP			\
@@ -295,7 +295,7 @@
 		}
 #else
 #define FPUD_ARITH2(op)						\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	fldcw	fpu.cw_mask_all		\
@@ -314,7 +314,7 @@
 // handles fdiv,fdivr
 // (This is identical to FPUD_ARITH1 but without a WEAK_EXCEPTIONS variant)
 #define FPUD_ARITH3(op)						\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	fldcw	fpu.cw_mask_all		\
@@ -335,7 +335,7 @@
 // handles fdiv,fdivr
 // (This is identical to FPUD_ARITH1_EA but without a WEAK_EXCEPTIONS variant)
 #define FPUD_ARITH3_EA(op)					\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm {								\
 		__asm	fnstcw	save_cw				\
 		__asm	mov		eax, op1			\
@@ -353,7 +353,7 @@
 
 // handles fprem,fprem1,fscale
 #define FPUD_REMAINDER(op)			\
-		Bit16u new_sw;				\
+		uint16_t new_sw;				\
 		__asm {						\
 		__asm	mov		eax, TOP	\
 		__asm	mov		ebx, eax	\
@@ -373,7 +373,7 @@
 
 // handles fcom,fucom
 #define FPUD_COMPARE(op)			\
-		Bit16u new_sw;				\
+		uint16_t new_sw;				\
 		__asm {						\
 		__asm	mov		ebx, op2	\
 		__asm	mov		eax, op1	\
@@ -388,7 +388,7 @@
 		fpu.sw=(new_sw&exc_mask)|(fpu.sw&0x80ff);
 
 #define FPUD_COMPARE_EA(op)			\
-		Bit16u new_sw;				\
+		uint16_t new_sw;				\
 		__asm {						\
 		__asm	mov		eax, op1	\
 		__asm	shl		eax, 4		\
@@ -401,7 +401,7 @@
 
 // handles fxam,ftst
 #define FPUD_EXAMINE(op)			\
-		Bit16u new_sw;				\
+		uint16_t new_sw;				\
 		__asm {						\
 		__asm	mov		eax, TOP	\
 		__asm	shl		eax, 4		\
@@ -431,7 +431,7 @@
 		FPU_FPOP();
 #else
 #define FPUD_WITH_POP(op)			\
-		Bit16u new_sw;				\
+		uint16_t new_sw;				\
 		__asm {						\
 		__asm	mov		eax, TOP	\
 		__asm	mov		ebx, eax	\
@@ -468,7 +468,7 @@
 		FPU_FPOP();
 #else
 #define FPUD_FYL2X(op)				\
-		Bit16u new_sw;				\
+		uint16_t new_sw;				\
 		__asm {						\
 		__asm	mov		eax, TOP	\
 		__asm	mov		ebx, eax	\
@@ -518,7 +518,7 @@
 		);
 #else
 #define FPUD_LOAD(op,szI,szA)				\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fclex						\n"	\
 			#op #szA "	%2				\n"	\
@@ -539,7 +539,7 @@
 		);
 #else
 #define FPUD_LOAD_EA(op,szI,szA)			\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fclex						\n"	\
 			#op #szA "	%1				\n"	\
@@ -553,7 +553,7 @@
 
 #ifdef WEAK_EXCEPTIONS
 #define FPUD_STORE(op,szI,szA)				\
-		Bit16u save_cw;						\
+		uint16_t save_cw;						\
 		__asm__ volatile (					\
 			"fnstcw		%0				\n"	\
 			"fldcw		%3				\n"	\
@@ -565,7 +565,7 @@
 		);
 #else
 #define FPUD_STORE(op,szI,szA)				\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm__ volatile (					\
 			"fnstcw		%1				\n"	\
 			"fldcw		%4				\n"	\
@@ -582,7 +582,7 @@
 
 // handles fsin,fcos,f2xm1,fchs,fabs
 #define FPUD_TRIG(op)						\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%1				\n"	\
 			clx" 						\n"	\
@@ -595,7 +595,7 @@
 
 // handles fsincos
 #define FPUD_SINCOS()					\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%1				\n"	\
 			clx" 						\n"	\
@@ -617,7 +617,7 @@
 
 // handles fptan
 #define FPUD_PTAN()						\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%1				\n"	\
 			clx" 						\n"	\
@@ -650,7 +650,7 @@
 		FPU_PREP_PUSH();
 #else
 #define FPUD_XTRACT						\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%1				\n"	\
 			"fclex						\n"	\
@@ -668,7 +668,7 @@
 // handles fadd,fmul,fsub,fsubr
 #ifdef WEAK_EXCEPTIONS
 #define FPUD_ARITH1(op)						\
-		Bit16u save_cw;						\
+		uint16_t save_cw;						\
 		__asm__ volatile (					\
 			"fnstcw		%0				\n"	\
 			"fldcw		%3				\n"	\
@@ -682,7 +682,7 @@
 		);
 #else
 #define FPUD_ARITH1(op)						\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm__ volatile (					\
 			"fnstcw		%1				\n"	\
 			"fldcw		%4				\n"	\
@@ -702,7 +702,7 @@
 // handles fadd,fmul,fsub,fsubr
 #ifdef WEAK_EXCEPTIONS
 #define FPUD_ARITH1_EA(op)					\
-		Bit16u save_cw;						\
+		uint16_t save_cw;						\
 		__asm__ volatile (					\
 			"fnstcw		%0				\n"	\
 			"fldcw		%2				\n"	\
@@ -715,7 +715,7 @@
 		);
 #else
 #define FPUD_ARITH1_EA(op)					\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm__ volatile (					\
 			"fnstcw		%1				\n"	\
 			"fldcw		%3				\n"	\
@@ -734,7 +734,7 @@
 // handles fsqrt,frndint
 #ifdef WEAK_EXCEPTIONS
 #define FPUD_ARITH2(op)						\
-		Bit16u save_cw;						\
+		uint16_t save_cw;						\
 		__asm__ volatile (					\
 			"fnstcw		%0				\n"	\
 			"fldcw		%2				\n"	\
@@ -747,7 +747,7 @@
 		);
 #else
 #define FPUD_ARITH2(op)						\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm__ volatile (					\
 			"fnstcw		%1				\n"	\
 			"fldcw		%3				\n"	\
@@ -766,7 +766,7 @@
 // handles fdiv,fdivr
 // (This is identical to FPUD_ARITH1 but without a WEAK_EXCEPTIONS variant)
 #define FPUD_ARITH3(op)						\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm__ volatile (					\
 			"fnstcw		%1				\n"	\
 			"fldcw		%4				\n"	\
@@ -785,7 +785,7 @@
 // handles fdiv,fdivr
 // (This is identical to FPUD_ARITH1_EA but without a WEAK_EXCEPTIONS variant)
 #define FPUD_ARITH3_EA(op)					\
-		Bit16u new_sw,save_cw;				\
+		uint16_t new_sw,save_cw;				\
 		__asm__ volatile (					\
 			"fnstcw		%1				\n"	\
 			"fldcw		%3				\n"	\
@@ -802,7 +802,7 @@
 
 // handles fprem,fprem1,fscale
 #define FPUD_REMAINDER(op)					\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%2				\n"	\
 			"fldt		%1				\n"	\
@@ -818,7 +818,7 @@
 
 // handles fcom,fucom
 #define FPUD_COMPARE(op)					\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%2				\n"	\
 			"fldt		%1				\n"	\
@@ -832,7 +832,7 @@
 
 // handles fcom,fucom
 #define FPUD_COMPARE_EA(op)					\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%1				\n"	\
 			clx" 						\n"	\
@@ -845,7 +845,7 @@
 
 // handles fxam,ftst
 #define FPUD_EXAMINE(op)					\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%1				\n"	\
 			clx" 						\n"	\
@@ -871,7 +871,7 @@
 		FPU_FPOP();
 #else
 #define FPUD_WITH_POP(op)					\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%1				\n"	\
 			"fldt		%2				\n"	\
@@ -900,7 +900,7 @@
 		FPU_FPOP();
 #else
 #define FPUD_FYL2X(op)						\
-		Bit16u new_sw;						\
+		uint16_t new_sw;						\
 		__asm__ volatile (					\
 			"fldt		%1				\n"	\
 			"fldt		%2				\n"	\
@@ -928,9 +928,9 @@
 #endif
 
 #ifdef WEAK_EXCEPTIONS
-const Bit16u exc_mask=0x7f00;
+const uint16_t exc_mask=0x7f00;
 #else
-const Bit16u exc_mask=0xffbf;
+const uint16_t exc_mask=0xffbf;
 #endif
 
 static void FPU_FINIT(void) {
@@ -997,12 +997,12 @@ static void FPU_FLD_F80(PhysPt addr) {
 }
 
 static void FPU_FLD_I16(PhysPt addr,Bitu store_to) {
-	fpu.p_regs[8].m1 = (Bit32u)mem_readw(addr);
+	fpu.p_regs[8].m1 = (uint32_t)mem_readw(addr);
 	FPUD_LOAD(fild,WORD,s)
 }
 
 static void FPU_FLD_I16_EA(PhysPt addr) {
-	fpu.p_regs[8].m1 = (Bit32u)mem_readw(addr);
+	fpu.p_regs[8].m1 = (uint32_t)mem_readw(addr);
 	FPUD_LOAD_EA(fild,WORD,s)
 }
 
@@ -1049,7 +1049,7 @@ static void FPU_FST_F80(PhysPt addr) {
 
 static void FPU_FST_I16(PhysPt addr) {
 	FPUD_STORE(fistp,WORD,s)
-	mem_writew(addr,(Bit16u)fpu.p_regs[8].m1);
+	mem_writew(addr,(uint16_t)fpu.p_regs[8].m1);
 }
 
 static void FPU_FST_I32(PhysPt addr) {
@@ -1149,9 +1149,9 @@ static void FPU_FXCH(Bitu stv, Bitu other){
 	fpu.tags[other] = fpu.tags[stv];
 	fpu.tags[stv] = tag;
 
-	Bit32u m1s = fpu.p_regs[other].m1;
-	Bit32u m2s = fpu.p_regs[other].m2;
-	Bit16u m3s = fpu.p_regs[other].m3;
+	uint32_t m1s = fpu.p_regs[other].m1;
+	uint32_t m2s = fpu.p_regs[other].m2;
+	uint16_t m3s = fpu.p_regs[other].m3;
 	fpu.p_regs[other].m1 = fpu.p_regs[stv].m1;
 	fpu.p_regs[other].m2 = fpu.p_regs[stv].m2;
 	fpu.p_regs[other].m3 = fpu.p_regs[stv].m3;
@@ -1260,18 +1260,18 @@ static void FPU_FSCALE(void){
 static void FPU_FSTENV(PhysPt addr){
 	FPU_SET_TOP(TOP);
 	if(!cpu.code.big) {
-		mem_writew(addr+0,static_cast<Bit16u>(fpu.cw));
-		mem_writew(addr+2,static_cast<Bit16u>(fpu.sw));
-		mem_writew(addr+4,static_cast<Bit16u>(FPU_GetTag()));
+		mem_writew(addr+0,static_cast<uint16_t>(fpu.cw));
+		mem_writew(addr+2,static_cast<uint16_t>(fpu.sw));
+		mem_writew(addr+4,static_cast<uint16_t>(FPU_GetTag()));
 	} else { 
-		mem_writed(addr+0,static_cast<Bit32u>(fpu.cw));
-		mem_writed(addr+4,static_cast<Bit32u>(fpu.sw));
-		mem_writed(addr+8,static_cast<Bit32u>(FPU_GetTag()));
+		mem_writed(addr+0,static_cast<uint32_t>(fpu.cw));
+		mem_writed(addr+4,static_cast<uint32_t>(fpu.sw));
+		mem_writed(addr+8,static_cast<uint32_t>(FPU_GetTag()));
 	}
 }
 
 static void FPU_FLDENV(PhysPt addr){
-	Bit16u tag;
+	uint16_t tag;
 	Bitu cw;
 	if(!cpu.code.big) {
 		cw     = mem_readw(addr+0);
@@ -1279,9 +1279,9 @@ static void FPU_FLDENV(PhysPt addr){
 		tag    = mem_readw(addr+4);
 	} else { 
 		cw     = mem_readd(addr+0);
-		fpu.sw = (Bit16u)mem_readd(addr+4);
-		Bit32u tagbig = mem_readd(addr+8);
-		tag    = static_cast<Bit16u>(tagbig);
+		fpu.sw = (uint16_t)mem_readd(addr+4);
+		uint32_t tagbig = mem_readd(addr+8);
+		tag    = static_cast<uint16_t>(tagbig);
 	}
 	FPU_SetTag(tag);
 	FPU_SetCW(cw);
