@@ -102,40 +102,30 @@ static const char *def_menu__toplevel[] =
     "CaptureMenu",
 #endif
     "DriveMenu",
+    "HelpMenu",
     NULL
 };
 
 /* main menu ("MainMenu") */
 static const char *def_menu_main[] =
 {
-    "mapper_mapper",
     "mapper_gui",
+    "mapper_mapper",
     "--",
     "MainSendKey",
-    "--",
-#if !defined(C_EMSCRIPTEN)
-    "wait_on_error",
-#endif
-    "showdetails",
-#if C_DEBUG
-    "--",
-    "mapper_debugger",
-#endif
-#if !defined(MACOSX) && !defined(LINUX) && !defined(HX_DOS) && !defined(C_EMSCRIPTEN)
-    "show_console",
+#if defined(WIN32) || defined(C_SDL2) || defined(LINUX) && C_X11
+    "SharedClipboard",
 #endif
     "--",
     "mapper_capmouse",
     "auto_lock_mouse",
     "WheelToArrow",
-#if defined(WIN32)
-    "direct_mouse_clipboard",
-#endif
-#if !defined(C_EMSCRIPTEN)//FIXME: Reset causes problems with Emscripten
     "--",
+#if !defined(C_EMSCRIPTEN)//FIXME: Reset causes problems with Emscripten
     "mapper_pause",
     "mapper_pauseints",
 #endif
+    "showdetails",
 #if !defined(C_EMSCRIPTEN)//FIXME: Reset causes problems with Emscripten
     "--",
     "mapper_reset",
@@ -153,12 +143,19 @@ static const char *def_menu_main[] =
 /* main -> send key menu ("MenuSendKey") */
 static const char *def_menu_main_sendkey[] =
 {
-    "sendkey_ctrlesc",
-    "sendkey_alttab",
     "sendkey_winlogo",
     "sendkey_winmenu",
-    "--",
+    "sendkey_alttab",
+    "sendkey_ctrlesc",
+    "sendkey_ctrlbreak",
     "sendkey_cad",
+    "--",
+    "sendkey_mapper_winlogo",
+    "sendkey_mapper_winmenu",
+    "sendkey_mapper_alttab",
+    "sendkey_mapper_ctrlesc",
+    "sendkey_mapper_ctrlbreak",
+    "sendkey_mapper_cad",
     NULL
 };
 
@@ -170,6 +167,53 @@ static const char *def_menu_main_wheelarrow[] =
     "wheel_pageupdown",
     "--",
     "wheel_none",
+    "wheel_guest",
+    NULL
+};
+
+/* main -> shared clipboard menu ("SharedClipboard") */
+static const char *def_menu_main_clipboard[] =
+{
+#if defined(WIN32) || defined(C_SDL2)
+    "clipboard_quick",
+    "clipboard_right",
+    "clipboard_middle",
+#endif
+#if defined(WIN32)
+    "--",
+    "clipboard_device",
+    "clipboard_dosapi",
+#endif
+#if defined(WIN32) || defined(C_SDL2)
+    "--",
+    "mapper_copyall",
+#endif
+    "mapper_paste",
+    "clipboard_paste_stop",
+    NULL
+};
+
+/* cpu -> core menu ("CpuSpeedMenu") */
+static const char *def_menu_cpu_speed[] =
+{
+    "cpu88-4",
+    "cpu286-8",
+    "cpu286-12",
+    "cpu286-25",
+    "cpu386-25",
+    "cpu386-33",
+    "cpu486-33",
+    "cpu486-66",
+    "cpu486-100",
+    "cpu486-133",
+    "cpu586-60",
+    "cpu586-66",
+    "cpu586-75",
+    "cpu586-90",
+    "cpu586-100",
+    "cpu586-120",
+    "cpu586-133",
+    "cpu586-166",
     NULL
 };
 
@@ -183,8 +227,8 @@ static const char *def_menu_cpu_core[] =
     "mapper_dynamic",
 #endif
 #if !defined(C_EMSCRIPTEN)//FIXME: Shutdown causes problems with Emscripten
-    "mapper_simple",
-    "mapper_full",
+    "menu_simple",
+    "menu_full",
 #endif
     NULL
 };
@@ -222,6 +266,7 @@ static const char *def_menu_cpu[] =
     "--",
     "mapper_cycleup",
     "mapper_cycledown",
+    "CpuSpeedMenu",
     "mapper_editcycles",
     "--",
     "CpuCoreMenu",
@@ -265,6 +310,27 @@ static const char *def_menu_video_output[] =
     "output_opengl",
     "output_openglnb",
 #endif
+    "--",
+    "doublescan",
+    NULL
+};
+
+/* video text-mode menu ("VideoTextmodeMenu") */
+static const char *def_menu_video_textmode[] =
+{
+    "clear_screen",
+    "vga_9widetext",
+    "--",
+    "text_background",
+    "text_blinking",
+    "--",
+    "line_80x25",
+    "line_80x50",
+    "line_80x60",
+    "line_132x25",
+    "line_132x43",
+    "line_132x50",
+    "line_132x60",
     NULL
 };
 
@@ -299,20 +365,16 @@ static const char *def_menu_video_overscan[] =
     NULL
 };
 
-/* video output menu ("VideoCompatMenu") */
-static const char *def_menu_video_compat[] =
-{
-    "vga_9widetext",
-    "doublescan",
-    NULL
-};
-
 /* video output menu ("VideoPC98Menu") */
 static const char *def_menu_video_pc98[] =
 {
-    "pc98_5mhz_gdc",
+    "pc98_use_uskb",
     "pc98_allow_200scanline",
     "pc98_allow_4partitions",
+    "pc98_5mhz_gdc",
+    "--",
+    "dos_pc98_pit_4mhz",
+    "dos_pc98_pit_5mhz",
     "--",
     "pc98_enable_egc",
     "pc98_enable_grcg",
@@ -325,23 +387,10 @@ static const char *def_menu_video_pc98[] =
     NULL
 };
 
-#if C_DEBUG
-/* video output debug ("VideoDebugMenu") */
-static const char *def_menu_video_debug[] =
-{
-    "debug_blankrefreshtest",
-    "--",
-    "debug_pageflip",
-    "debug_retracepoll",
-    NULL
-};
-#endif
-
 /* video menu ("VideoMenu") */
 static const char *def_menu_video[] =
 {
     "mapper_aspratio",
-    "--",
 #if !defined(HX_DOS)
     "mapper_fullscr",
     "--",
@@ -358,15 +407,10 @@ static const char *def_menu_video[] =
 #endif
 #ifndef MACOSX
     "mapper_togmenu",
-# if !defined(HX_DOS)
-    "--",
-# endif
 #endif
 #if !defined(HX_DOS)
     "mapper_resetsize",
 #endif
-    "--",
-    "VideoFrameskipMenu",
     "--",
     "scaler_forced",
     "VideoScalerMenu",
@@ -374,13 +418,11 @@ static const char *def_menu_video[] =
 #if !defined(C_SDL2)
     "VideoVsyncMenu",
 #endif
-    "VideoOverscanMenu",
-    "VideoCompatMenu",
-    "VideoPC98Menu",
-#if C_DEBUG
     "--",
-    "VideoDebugMenu",
-#endif
+    "VideoOverscanMenu",
+    "VideoFrameskipMenu",
+    "VideoTextmodeMenu",
+    "VideoPC98Menu",
 #ifdef C_D3DSHADERS
     "--",
     "load_d3d_shader",
@@ -395,15 +437,14 @@ static const char *def_menu_dos[] =
     "--",
     "DOSVerMenu",
     "DOSLFNMenu",
-    "--",
-    "DOSPC98Menu",
+    "DOSEMSMenu",
     "--",
 #if defined(WIN32) && !defined(HX_DOS)
     "DOSWinMenu",
 #endif
     "shell_config_commands",
-#if defined(WIN32) && !defined(HX_DOS)
-    "quick_launch",
+#if !defined(HX_DOS)
+    "mapper_quickrun",
 #endif
     "--",
     "quick_reboot",
@@ -418,9 +459,6 @@ static const char *def_menu_dos[] =
 #endif
 #if C_PRINTER
     "mapper_ejectpage",
-#endif
-#if C_DEBUG
-    "DOSDebugMenu",
 #endif
     NULL
 };
@@ -457,11 +495,13 @@ static const char *def_menu_dos_lfn[] =
     NULL
 };
 
-/* DOS pc-98 menu ("DOSPC98Menu") */
-static const char *def_menu_dos_pc98[] =
+/* DOS EMS menu ("DOSEMSMenu") */
+static const char *def_menu_dos_ems[] =
 {
-    "dos_pc98_pit_4mhz",
-    "dos_pc98_pit_5mhz",
+    "dos_ems_true",
+    "dos_ems_board",
+    "dos_ems_emm386",
+    "dos_ems_false",
     NULL
 };
 
@@ -471,16 +511,7 @@ static const char *def_menu_dos_win[] =
 {
     "dos_win_autorun",
     "dos_win_wait",
-    NULL
-};
-#endif
-
-#if C_DEBUG
-/* DOS debug ("DOSDebugMenu") */
-static const char *def_menu_dos_debug[] =
-{
-    "debug_logint21",
-    "debug_logfileio",
+    "dos_win_quiet",
     NULL
 };
 #endif
@@ -495,6 +526,8 @@ static const char *def_menu_sound[] =
     "mapper_recvoldown",
     "--",
     "mixer_info",
+    "sb_info",
+    "midi_info",
     "--",
     "mixer_mute",
     "mixer_swapstereo",
@@ -520,10 +553,12 @@ static const char *def_menu_capture[] =
     "mapper_caprawmidi",
     "--",
 #endif
-    "force_loadstate",
+    "saveoptionmenu",
     "mapper_savestate",
     "mapper_loadstate",
     "saveslotmenu",
+    "browsesavefile",
+    "showstate",
     NULL
 };
 
@@ -533,14 +568,21 @@ static const char *def_menu_capture[] =
 static const char *def_menu_capture_format[] =
 {
     "capture_fmt_avi_zmbv",
-#  if (C_AVCODEC)
     "capture_fmt_mpegts_h264",
-#  endif
     NULL
 };
 # endif
 #endif
 
+/* Save/load options */
+static const char *save_load_options[] =
+{
+    "noremark_savestate",
+    "force_loadstate",
+    "usesavefile",
+    NULL
+};
+
 /* Save slots */
 static const char *def_save_slots[] =
 {
@@ -609,6 +651,47 @@ static const char *def_menu_drive[] =
     NULL
 };
 
+/* help output debug ("HelpDebugMenu") */
+static const char *def_menu_help_debug[] =
+{
+#if C_DEBUG
+    "mapper_debugger",
+#endif
+#if !defined(MACOSX) && !defined(LINUX) && !defined(HX_DOS) && !defined(C_EMSCRIPTEN)
+    "show_console",
+    "wait_on_error",
+#endif
+#if C_DEBUG
+    "--",
+    "debug_blankrefreshtest",
+    "debug_pageflip",
+    "debug_retracepoll",
+    "--",
+    "debug_logint21",
+    "debug_logfileio",
+#endif
+    NULL
+};
+
+/* help menu ("HelpMenu") */
+static const char *def_menu_help[] =
+{
+    "help_intro",
+#if !defined(HX_DOS)
+    "--",
+    "help_homepage",
+    "help_wiki",
+    "help_issue",
+#endif
+#if C_DEBUG || !defined(MACOSX) && !defined(LINUX) && !defined(HX_DOS) && !defined(C_EMSCRIPTEN)
+    "--",
+    "HelpDebugMenu",
+#endif
+    "--",
+    "help_about",
+    NULL
+};
+
 bool DOSBox_isMenuVisible(void) {
     return menu.toggle;
 }
@@ -1212,12 +1295,18 @@ void ConstructSubMenu(DOSBoxMenu::item_handle_t item_id, const char * const * li
          *      array lookup, this is not very inefficient at all. */
 
         if (!strcmp(ref,"--")) {
+            /* separator is allocated on the fly by separator_get and we cannot
+             * rely that parameters are expanded from right to left
+             * -> we must get separator handle first */
+            DOSBoxMenu::item_handle_t separator_handle = separator_get(DOSBoxMenu::separator_type_id);
             mainMenu.displaylist_append(
-                mainMenu.get_item(item_id).display_list, separator_get(DOSBoxMenu::separator_type_id));
+                mainMenu.get_item(item_id).display_list, separator_handle);
         }
         else if (!strcmp(ref,"||")) {
+            /* dito */
+            DOSBoxMenu::item_handle_t separator_handle = separator_get(DOSBoxMenu::vseparator_type_id);
             mainMenu.displaylist_append(
-                mainMenu.get_item(item_id).display_list, separator_get(DOSBoxMenu::vseparator_type_id));
+                mainMenu.get_item(item_id).display_list, separator_handle);
         }
         else if (mainMenu.item_exists(ref)) {
             mainMenu.displaylist_append(
@@ -1245,9 +1334,15 @@ void ConstructMenu(void) {
     /* main mouse wheel movements menu */
     ConstructSubMenu(mainMenu.get_item("WheelToArrow").get_master_id(), def_menu_main_wheelarrow);
 
+    /* shared clipboard menu */
+    ConstructSubMenu(mainMenu.get_item("SharedClipboard").get_master_id(), def_menu_main_clipboard);
+
     /* cpu menu */
     ConstructSubMenu(mainMenu.get_item("CpuMenu").get_master_id(), def_menu_cpu);
 
+    /* cpu speed menu */
+    ConstructSubMenu(mainMenu.get_item("CpuSpeedMenu").get_master_id(), def_menu_cpu_speed);
+
     /* cpu core menu */
     ConstructSubMenu(mainMenu.get_item("CpuCoreMenu").get_master_id(), def_menu_cpu_core);
 
@@ -1289,23 +1384,18 @@ void ConstructMenu(void) {
     /* video output menu */
     ConstructSubMenu(mainMenu.get_item("VideoOutputMenu").get_master_id(), def_menu_video_output);
 
+    /* video text-mode menu */
+    ConstructSubMenu(mainMenu.get_item("VideoTextmodeMenu").get_master_id(), def_menu_video_textmode);
+
     /* video vsync menu */
     ConstructSubMenu(mainMenu.get_item("VideoVsyncMenu").get_master_id(), def_menu_video_vsync);
 
     /* video overscan menu */
     ConstructSubMenu(mainMenu.get_item("VideoOverscanMenu").get_master_id(), def_menu_video_overscan);
 
-    /* video compat menu */
-    ConstructSubMenu(mainMenu.get_item("VideoCompatMenu").get_master_id(), def_menu_video_compat);
-
     /* video PC-98 menu */
     ConstructSubMenu(mainMenu.get_item("VideoPC98Menu").get_master_id(), def_menu_video_pc98);
 
-#if C_DEBUG
-    /* video debug menu */
-    ConstructSubMenu(mainMenu.get_item("VideoDebugMenu").get_master_id(), def_menu_video_debug);
-#endif
-
     /* sound menu */
     ConstructSubMenu(mainMenu.get_item("SoundMenu").get_master_id(), def_menu_sound);
 
@@ -1321,19 +1411,14 @@ void ConstructMenu(void) {
     /* DOS LFN menu */
     ConstructSubMenu(mainMenu.get_item("DOSLFNMenu").get_master_id(), def_menu_dos_lfn);
 
-    /* DOS PC-98 menu */
-    ConstructSubMenu(mainMenu.get_item("DOSPC98Menu").get_master_id(), def_menu_dos_pc98);
+    /* DOS EMS menu */
+    ConstructSubMenu(mainMenu.get_item("DOSEMSMenu").get_master_id(), def_menu_dos_ems);
 
 #if defined(WIN32) && !defined(HX_DOS)
     /* DOS WIN menu */
     ConstructSubMenu(mainMenu.get_item("DOSWinMenu").get_master_id(), def_menu_dos_win);
 #endif
 
-#if C_DEBUG
-    /* DOS debug menu */
-    ConstructSubMenu(mainMenu.get_item("DOSDebugMenu").get_master_id(), def_menu_dos_debug);
-#endif
-
 #if !defined(C_EMSCRIPTEN)
     /* capture menu */
     ConstructSubMenu(mainMenu.get_item("CaptureMenu").get_master_id(), def_menu_capture);
@@ -1345,6 +1430,7 @@ void ConstructMenu(void) {
     ConstructSubMenu(mainMenu.get_item("CaptureFormatMenu").get_master_id(), def_menu_capture_format);
 # endif
 #endif
+    ConstructSubMenu(mainMenu.get_item("saveoptionmenu").get_master_id(), save_load_options);
     ConstructSubMenu(mainMenu.get_item("saveslotmenu").get_master_id(), def_save_slots);
 
     /* Drive menu */
@@ -1361,6 +1447,14 @@ void ConstructMenu(void) {
             }
         }
     }
+
+    /* help menu */
+    ConstructSubMenu(mainMenu.get_item("HelpMenu").get_master_id(), def_menu_help);
+
+#if C_DEBUG || !defined(MACOSX) && !defined(LINUX) && !defined(HX_DOS) && !defined(C_EMSCRIPTEN)
+    /* help debug menu */
+    ConstructSubMenu(mainMenu.get_item("HelpDebugMenu").get_master_id(), def_menu_help_debug);
+#endif
 }
 
 bool MENU_SetBool(std::string secname, std::string value) {
@@ -1863,7 +1957,7 @@ void MENU_Check_Drive(HMENU handle, int cdrom, int floppy, int local, int image,
 }
 
 void MENU_KeyDelayRate(int delay, int rate) {
-    IO_Write(0x60,0xf3); IO_Write(0x60,(Bit8u)(((delay-1)<<5)|(32-rate)));
+    IO_Write(0x60,0xf3); IO_Write(0x60,(uint8_t)(((delay-1)<<5)|(32-rate)));
     LOG_MSG("GUI: Keyboard rate %d, delay %d", rate, delay);
 }
 
