@@ -20,6 +20,8 @@
 #include <sys/types.h>
 #include <assert.h>
 #include <math.h>
+#include <fstream>
+#include <sstream>
 
 #include "dosbox.h"
 #include "video.h"
@@ -31,8 +33,10 @@
 #include "hardware.h"
 #include "support.h"
 #include "sdlmain.h"
+#include "shell.h"
 
 #include "render_scalers.h"
+#include "render_glsl.h"
 #if defined(__SSE__)
 #include <xmmintrin.h>
 #include <emmintrin.h>
@@ -64,10 +68,10 @@ static void Check_Palette(void) {
         case scalerMode15:
         case scalerMode16:
             for (i=render.pal.first;i<=render.pal.last;i++) {
-                Bit8u r=render.pal.rgb[i].red;
-                Bit8u g=render.pal.rgb[i].green;
-                Bit8u b=render.pal.rgb[i].blue;
-                Bit16u newPal = (Bit16u)GFX_GetRGB(r,g,b);
+                uint8_t r=render.pal.rgb[i].red;
+                uint8_t g=render.pal.rgb[i].green;
+                uint8_t b=render.pal.rgb[i].blue;
+                uint16_t newPal = (uint16_t)GFX_GetRGB(r,g,b);
                 if (newPal != render.pal.lut.b16[i]) {
                     render.pal.changed = true;
                     render.pal.modified[i] = 1;
@@ -78,10 +82,10 @@ static void Check_Palette(void) {
         case scalerMode32:
         default:
             for (i=render.pal.first;i<=render.pal.last;i++) {
-                Bit8u r=render.pal.rgb[i].red;
-                Bit8u g=render.pal.rgb[i].green;
-                Bit8u b=render.pal.rgb[i].blue;
-                Bit32u newPal = (Bit32u)GFX_GetRGB(r,g,b);
+                uint8_t r=render.pal.rgb[i].red;
+                uint8_t g=render.pal.rgb[i].green;
+                uint8_t b=render.pal.rgb[i].blue;
+                uint32_t newPal = (uint32_t)GFX_GetRGB(r,g,b);
                 if (newPal != render.pal.lut.b32[i]) {
                     render.pal.changed = true;
                     render.pal.modified[i] = 1;
@@ -95,7 +99,7 @@ static void Check_Palette(void) {
     render.pal.last=0;
 }
 
-void RENDER_SetPal(Bit8u entry,Bit8u red,Bit8u green,Bit8u blue) {
+void RENDER_SetPal(uint8_t entry,uint8_t red,uint8_t green,uint8_t blue) {
     if (GFX_GetBShift() == 0) {
         GFX_palette32bpp[entry] =
             ((uint32_t)red << (uint32_t)16) +
@@ -121,16 +125,40 @@ static void RENDER_EmptyLineHandler(const void * src) {
 }
 
 /*HACK*/
-#if defined(__SSE__) && (defined(_M_AMD64) || defined(__e2k__))
-# define sse2_available (1) /* SSE2 is always available on x86_64 and Elbrus */
+#if defined(_M_AMD64) || defined(__amd64__) || defined(__e2k__)
+/* SSE2 is always available on x86_64 and Elbrus */
+# define sse2_available (1)
+extern bool             avx2_available;
+#elif defined(__SSE__)
+#ifdef __AVX2__
+/* We are building with -mavx2 */
+# define sse2_available (1)
+# define avx2_available (1)
 #else
-# ifdef __SSE__
-extern bool             sse1_available;
 extern bool             sse2_available;
-# endif
+extern bool             avx2_available;
 #endif
 /*END HACK*/
 
+#include <immintrin.h>
+
+#ifdef __GNUC__
+__attribute__((__target__("avx2")))
+#endif
+static inline bool cacheHit_AVX2(const Bitu *src, Bitu *cache, Bits count) {
+    static const Bitu simd_inc = 32 / sizeof(*src);
+    while (count >= (Bits)simd_inc) {
+        __m256i v = _mm256_loadu_si256((const __m256i*)src);
+        __m256i c = _mm256_loadu_si256((const __m256i*)cache);
+        __m256i cmp = _mm256_cmpeq_epi32(v, c);
+        if (GCC_UNLIKELY((unsigned int)_mm256_movemask_epi8(cmp) != 0xFFFFFFFF))
+            return false;
+        count-=(Bits)simd_inc; src+=simd_inc; cache+=simd_inc;
+    }
+    return true;
+}
+#endif // __SSE__
+
 /* NTS: In normal conditions, the renderer at the start of the frame
  *      does not call the scaler but instead compares line by line
  *      from the cache. The instant a line differs, it switches to
@@ -154,9 +182,12 @@ static inline bool RENDER_DrawLine_scanline_cacheHit(const void *s) {
         const Bitu *src = (Bitu*)s;
         Bitu *cache = (Bitu*)(render.scale.cacheRead);
         Bits count = (Bits)render.src.start;
-#if defined(__SSE__)
-        if (sse2_available) {
+#if defined(__SSE__) && !(defined(_M_AMD64) || defined(__amd64__) || defined(__e2k__))
 #define MY_SIZEOF_INT_P sizeof(*src)
+        if (GCC_LIKELY(avx2_available)) {
+            if (!cacheHit_AVX2(src, cache, count))
+                goto cacheMiss;
+        } else if (sse2_available) {
             static const Bitu simd_inc = 16/MY_SIZEOF_INT_P;
             while (count >= (Bits)simd_inc) {
                 __m128i v = _mm_loadu_si128((const __m128i*)src);
@@ -166,10 +197,10 @@ static inline bool RENDER_DrawLine_scanline_cacheHit(const void *s) {
                     goto cacheMiss;
                 count-=(Bits)simd_inc; src+=simd_inc; cache+=simd_inc;
             }
-#undef MY_SIZEOF_INT_P
         }
+#undef MY_SIZEOF_INT_P
         else
-#endif
+#endif // __SSE__
         {
             while (count) {
                 if (GCC_UNLIKELY(src[0] != cache[0]))
@@ -257,16 +288,16 @@ static void RENDER_FinishLineHandler(const void * s) {
 
 static void RENDER_ClearCacheHandler(const void * src) {
     Bitu x, width;
-    Bit32u *srcLine, *cacheLine;
-    srcLine = (Bit32u *)src;
-    cacheLine = (Bit32u *)render.scale.cacheRead;
+    uint32_t *srcLine, *cacheLine;
+    srcLine = (uint32_t *)src;
+    cacheLine = (uint32_t *)render.scale.cacheRead;
     width = render.scale.cachePitch / 4;
     for (x=0;x<width;x++)
         cacheLine[x] = ~srcLine[x];
     render.scale.lineHandler( src );
 }
 
-extern void GFX_SetTitle(Bit32s cycles,Bits frameskip,Bits timing,bool paused);
+extern void GFX_SetTitle(int32_t cycles, int frameskip, Bits timing, bool paused);
 
 bool RENDER_StartUpdate(void) {
     if (GCC_UNLIKELY(render.updating))
@@ -283,7 +314,7 @@ bool RENDER_StartUpdate(void) {
     }
     render.scale.inLine = 0;
     render.scale.outLine = 0;
-    render.scale.cacheRead = (Bit8u*)&scalerSourceCache;
+    render.scale.cacheRead = (uint8_t*)&scalerSourceCache;
     render.scale.outWrite = 0;
     render.scale.outPitch = 0;
     Scaler_ChangedLines[0] = 0;
@@ -351,7 +382,7 @@ void RENDER_EndUpdate( bool abort ) {
             flags |= CAPTURE_FLAG_NOCHANGE;
 
         CAPTURE_AddImage( render.src.width, render.src.height, render.src.bpp, pitch,
-            flags, fps, (Bit8u *)&scalerSourceCache, (Bit8u*)&render.pal.rgb );
+            flags, fps, (uint8_t *)&scalerSourceCache, (uint8_t*)&render.pal.rgb );
     }
     if ( render.scale.outWrite ) {
         GFX_EndUpdate( abort? NULL : Scaler_ChangedLines );
@@ -366,7 +397,7 @@ void RENDER_EndUpdate( bool abort ) {
 #endif
         // Force output to update the screen even if nothing changed...
         // works only with Direct3D output (GFX_StartUpdate() was probably not even called)
-        if (render.forceUpdate) GFX_EndUpdate( 0 );
+        if (RENDER_GetForceUpdate()) GFX_EndUpdate( 0 );
     }
     render.frameskip.index = (render.frameskip.index + 1) & (RENDER_SKIP_CACHE - 1);
     render.updating=false;
@@ -391,7 +422,7 @@ static Bitu MakeAspectTable(Bitu skip,Bitu height,double scaley,Bitu miny) {
             Bitu templines = (Bitu)lines;
             lines -= templines;
             linesadded += templines;
-            Scaler_Aspect[i] = (Bit8u)templines;
+            Scaler_Aspect[i] = (uint8_t)templines;
         } else {
             Scaler_Aspect[i] = 0;
         }
@@ -666,6 +697,9 @@ forcenormal:
     sdl.srcAspect.yToX = (double)sdl.srcAspect.y / sdl.srcAspect.x;
     LOG_MSG("Aspect ratio: %u x %u  xToY=%.3f yToX=%.3f",sdl.srcAspect.x,sdl.srcAspect.y,sdl.srcAspect.xToY,sdl.srcAspect.yToX);
 /* Setup the scaler variables */
+#if C_OPENGL
+    GFX_SetShader(render.shader_src);
+#endif
     gfx_flags=GFX_SetSize(width,height,gfx_flags,gfx_scalew,gfx_scaleh,&RENDER_CallBack);
     if (gfx_flags & GFX_CAN_8)
         render.scale.outMode = scalerMode8;
@@ -813,7 +847,7 @@ static void BlankTestRefresh(bool pressed) {
     BlankDisplay();
 }*/
 
-//extern void GFX_SetTitle(Bit32s cycles, Bits frameskip, Bits timing, bool paused);
+//extern void GFX_SetTitle(int32_t cycles, int frameskip, Bits timing, bool paused);
 static void IncreaseFrameSkip(bool pressed) {
     if (!pressed)
         return;
@@ -846,10 +880,72 @@ static void ChangeScaler(bool pressed) {
 
 void RENDER_UpdateFromScalerSetting(void);
 
+bool RENDER_GetForceUpdate(void) {
+	return render.forceUpdate;
+}
+
 void RENDER_SetForceUpdate(bool f) {
     render.forceUpdate = f;
 }
 
+#if C_OPENGL
+static bool RENDER_GetShader(std::string& shader_path, char *old_src) {
+	char* src;
+	std::stringstream buf;
+	std::ifstream fshader(shader_path.c_str(), std::ios_base::binary);
+	if (!fshader.is_open()) fshader.open((shader_path + ".glsl").c_str(), std::ios_base::binary);
+	if (fshader.is_open()) {
+		buf << fshader.rdbuf();
+		fshader.close();
+	}
+	else if (shader_path == "advinterp2x") buf << advinterp2x_glsl;
+	else if (shader_path == "advinterp3x") buf << advinterp3x_glsl;
+	else if (shader_path == "advmame2x")   buf << advmame2x_glsl;
+	else if (shader_path == "advmame3x")   buf << advmame3x_glsl;
+	else if (shader_path == "rgb2x")       buf << rgb2x_glsl;
+	else if (shader_path == "rgb3x")       buf << rgb3x_glsl;
+	else if (shader_path == "scan2x")      buf << scan2x_glsl;
+	else if (shader_path == "scan3x")      buf << scan3x_glsl;
+	else if (shader_path == "tv2x")        buf << tv2x_glsl;
+	else if (shader_path == "tv3x")        buf << tv3x_glsl;
+	else if (shader_path == "sharp")       buf << sharp_glsl;
+
+	if (!buf.str().empty()) {
+		std::string s = buf.str() + '\n';
+		if (first_shell) {
+			std::string pre_defs;
+			Bitu count = first_shell->GetEnvCount();
+			for (Bitu i=0; i < count; i++) {
+				std::string env;
+				if (!first_shell->GetEnvNum(i, env))
+					continue;
+				if (env.compare(0, 9, "GLSHADER_")==0) {
+					size_t brk = env.find('=');
+					if (brk == std::string::npos) continue;
+					env[brk] = ' ';
+					pre_defs += "#define " + env.substr(9) + '\n';
+				}
+			}
+			if (!pre_defs.empty()) {
+				// if "#version" occurs it must be before anything except comments and whitespace
+				size_t pos = s.find("#version ");
+				if (pos != std::string::npos) pos = s.find('\n', pos+9);
+				if (pos == std::string::npos) pos = 0;
+				else ++pos;
+				s = s.insert(pos, pre_defs);
+			}
+		}
+		// keep the same buffer if contents aren't different
+		if (old_src==NULL || s != old_src) {
+			src = strdup(s.c_str());
+			if (src==NULL) LOG_MSG("WARNING: Couldn't copy shader source");
+		} else src = old_src;
+	} else src = NULL;
+	render.shader_src = src;
+	return src != NULL;
+}
+#endif
+
 void RENDER_UpdateFrameskipMenu(void) {
     char tmp[64];
 
@@ -1060,9 +1156,6 @@ void RENDER_Init() {
 	MAPPER_AddHandler(&AspectRatio_mapper_shortcut, MK_nothing, 0, "aspratio", "AspRatio", &item);
 	item->set_text("Fit to aspect ratio");
 
-    // DEBUG option
-    mainMenu.alloc_item(DOSBoxMenu::item_type_id,"debug_blankrefreshtest");
-
     mainMenu.get_item("vga_9widetext").check(vga.draw.char9_set).refresh_item(mainMenu);
     mainMenu.get_item("doublescan").check(vga.draw.doublescan_set).refresh_item(mainMenu);
     mainMenu.get_item("mapper_aspratio").check(render.aspect).refresh_item(mainMenu);
@@ -1091,10 +1184,36 @@ void RENDER_Init() {
 
     render.autofit=section->Get_bool("autofit");
 
+#if C_OPENGL
+	char* shader_src = render.shader_src;
+    render.shader_def = false;
+	Prop_path *sh = section->Get_path("glshader");
+	std::string f = (std::string)sh->GetValue();
+	if (f.empty() || f=="none" || f=="default") {
+        render.shader_src = NULL;
+        render.shader_def = f=="default";
+	} else if (!RENDER_GetShader(sh->realpath,shader_src)) {
+		std::string path = std::string("glshaders") + CROSS_FILESPLIT + f;
+		if (!RENDER_GetShader(path,shader_src)) {
+            Cross::GetPlatformConfigDir(path);
+            path = path + "glshaders" + CROSS_FILESPLIT + f;
+            if (!RENDER_GetShader(path,shader_src) && (sh->realpath==f || !RENDER_GetShader(f,shader_src))) {
+                sh->SetValue("none");
+                LOG_MSG("Shader file \"%s\" not found", f.c_str());
+            }
+        }
+	} else
+        LOG_MSG("Loaded GLSL shader: %s\n", f.c_str());
+	if (shader_src!=render.shader_src) free(shader_src);
+#endif
+
     //If something changed that needs a ReInit
     // Only ReInit when there is a src.bpp (fixes crashes on startup and directly changing the scaler without a screen specified yet)
     if(running && render.src.bpp && ((render.aspect != aspect) || (render.scale.op != scaleOp) || 
                   (render.scale.size != scalersize) || (render.scale.forced != scalerforced) ||
+#if C_OPENGL
+				  (render.shader_src != shader_src) ||
+#endif
                    render.scale.forced))
         RENDER_CallBack( GFX_CallBackReset );
 
