@@ -35,6 +35,7 @@
 #include "control.h"
 #include "shell.h"
 #include "cpu.h"
+#include "midi.h"
 #include "bios_disk.h"
 #include "../dos/drives.h"
 
@@ -61,7 +62,7 @@ protected:
     std::istringstream      lines;
 };
 
-extern Bit8u                int10_font_14[256 * 14];
+extern uint8_t                int10_font_14[256 * 14];
 
 extern uint32_t             GFX_Rmask;
 extern unsigned char        GFX_Rshift;
@@ -70,14 +71,13 @@ extern unsigned char        GFX_Gshift;
 extern uint32_t             GFX_Bmask;
 extern unsigned char        GFX_Bshift;
 
-extern std::string          saveloaderr;
 extern int                  statusdrive, swapInDisksSpecificDrive;
-extern bool                 dos_kernel_disabled, confres, quit_confirm;
+extern bool                 dos_kernel_disabled, confres;
 extern Bitu                 currentWindowWidth, currentWindowHeight;
 
 extern bool                 MSG_Write(const char *);
 extern void                 LoadMessageFile(const char * fname);
-extern void                 GFX_SetTitle(Bit32s cycles,Bits frameskip,Bits timing,bool paused);
+extern void                 GFX_SetTitle(int32_t cycles, int frameskip, Bits timing, bool paused);
 
 static int                  cursor;
 static bool                 running;
@@ -94,7 +94,7 @@ static SDL_Surface*         background = NULL;
 #ifdef DOSBOXMENU_EXTERNALLY_MANAGED
 static bool                 gui_menu_init = true;
 #endif
-
+int                         shortcutid = -1;
 void                        GFX_GetSizeAndPos(int &x,int &y,int &width, int &height, bool &fullscreen);
 
 #if defined(WIN32) && !defined(HX_DOS)
@@ -102,6 +102,16 @@ void                        WindowsTaskbarUpdatePreviewRegion(void);
 void                        WindowsTaskbarResetPreviewRegion(void);
 #endif
 
+const char *aboutmsg = "DOSBox-X version " VERSION " (" SDL_STRING ", "
+#if defined(_M_X64) || defined (_M_AMD64) || defined (_M_ARM64) || defined (_M_IA64) || defined(__ia64__) || defined(__LP64__) || defined(_WIN64) || defined(__x86_64__) || defined(__aarch64__) || defined(__powerpc64__)
+	"64"
+#else
+	"32"
+#endif
+	"-bit)\nBuild date: " UPDATED_STR "\nCopyright 2011-" COPYRIGHT_END_YEAR " The DOSBox-X Team\nProject maintainer: joncampbell123\nDOSBox-X homepage: https://dosbox-x.com";
+
+const char *intromsg = "Welcome to DOSBox-X, a complete open-source DOS emulator.\nDOSBox-X creates a DOS shell which looks like the plain DOS.\nYou can also run Windows 3.x and 9x inside the DOS machine.";
+
 /* Prepare screen for UI */
 void GUI_LoadFonts(void) {
     GUI::Font::addFont("default",new GUI::BitmapFont(int10_font_14,14,10));
@@ -114,29 +124,29 @@ static void getPixel(Bits x, Bits y, int &r, int &g, int &b, int shift)
     if (x < 0) x = 0;
     if (y < 0) y = 0;
 
-    Bit8u* src = (Bit8u *)&scalerSourceCache;
-    Bit32u pixel;
+    uint8_t* src = (uint8_t *)&scalerSourceCache;
+    uint32_t pixel;
     switch (render.scale.inMode) {
         case scalerMode8:
-            pixel = *((unsigned int)x+(Bit8u*)(src+(unsigned int)y*(unsigned int)render.scale.cachePitch));
+            pixel = *((unsigned int)x+(uint8_t*)(src+(unsigned int)y*(unsigned int)render.scale.cachePitch));
             r += (int)((unsigned int)render.pal.rgb[pixel].red >> (unsigned int)shift);
             g += (int)((unsigned int)render.pal.rgb[pixel].green >> (unsigned int)shift);
             b += (int)((unsigned int)render.pal.rgb[pixel].blue >> (unsigned int)shift);
             break;
         case scalerMode15:
-            pixel = *((unsigned int)x+(Bit16u*)(src+(unsigned int)y*(unsigned int)render.scale.cachePitch));
+            pixel = *((unsigned int)x+(uint16_t*)(src+(unsigned int)y*(unsigned int)render.scale.cachePitch));
             r += (int)((pixel >> (7u+(unsigned int)shift)) & (0xf8u >> (unsigned int)shift));
             g += (int)((pixel >> (2u+(unsigned int)shift)) & (0xf8u >> (unsigned int)shift));
             b += (int)((pixel << (3u-(unsigned int)shift)) & (0xf8u >> (unsigned int)shift));
             break;
         case scalerMode16:
-            pixel = *((unsigned int)x+(Bit16u*)(src+(unsigned int)y*(unsigned int)render.scale.cachePitch));
+            pixel = *((unsigned int)x+(uint16_t*)(src+(unsigned int)y*(unsigned int)render.scale.cachePitch));
             r += (int)((pixel >> (8u+(unsigned int)shift)) & (0xf8u >> shift));
             g += (int)((pixel >> (3u+(unsigned int)shift)) & (0xfcu >> shift));
             b += (int)((pixel << (3u-(unsigned int)shift)) & (0xf8u >> shift));
             break;
         case scalerMode32:
-            pixel = *((unsigned int)x+(Bit32u*)(src+(unsigned int)y*(unsigned int)render.scale.cachePitch));
+            pixel = *((unsigned int)x+(uint32_t*)(src+(unsigned int)y*(unsigned int)render.scale.cachePitch));
             r += (int)(((pixel & GFX_Rmask) >> (GFX_Rshift + shift)) & (0xffu >> shift));
             g += (int)(((pixel & GFX_Gmask) >> (GFX_Gshift + shift)) & (0xffu >> shift));
             b += (int)(((pixel & GFX_Bmask) >> (GFX_Bshift + shift)) & (0xffu >> shift));
@@ -151,6 +161,7 @@ bool gui_menu_exit(DOSBoxMenu * const menu,DOSBoxMenu::item * const menuitem) {
     return true;
 }
 
+extern const char* RunningProgram;
 static GUI::ScreenSDL *UI_Startup(GUI::ScreenSDL *screen) {
     in_gui = true;
 
@@ -165,7 +176,7 @@ static GUI::ScreenSDL *UI_Startup(GUI::ScreenSDL *screen) {
     LoadMessageFile(static_cast<Section_prop*>(control->GetSection("dosbox"))->Get_string("language"));
 
     // Comparable to the code of intro.com, but not the same! (the code of intro.com is called from within a com file)
-    shell_idle = !dos_kernel_disabled && first_shell && (DOS_PSP(dos.psp()).GetSegment() == DOS_PSP(dos.psp()).GetParent());
+    shell_idle = !dos_kernel_disabled && strcmp(RunningProgram, "LOADLIN") && first_shell && (DOS_PSP(dos.psp()).GetSegment() == DOS_PSP(dos.psp()).GetParent());
 
     int sx, sy, sw, sh;
     bool fs;
@@ -224,7 +235,7 @@ static GUI::ScreenSDL *UI_Startup(GUI::ScreenSDL *screen) {
 
         // create screenshot for fade effect
         for (unsigned int y = 0; (int)y < sh_draw; y++) {
-            Bit32u *bg = (Bit32u*)((y+(unsigned int)sy)*(unsigned int)screenshot->pitch + (char*)screenshot->pixels) + (unsigned int)sx;
+            uint32_t *bg = (uint32_t*)((y+(unsigned int)sy)*(unsigned int)screenshot->pitch + (char*)screenshot->pixels) + (unsigned int)sx;
             for (unsigned int x = 0; (int)x < sw_draw; x++) {
                 int r = 0, g = 0, b = 0;
                 getPixel((int)(x*(unsigned int)render.src.width/(unsigned int)sw),
@@ -239,7 +250,7 @@ static GUI::ScreenSDL *UI_Startup(GUI::ScreenSDL *screen) {
         background = SDL_CreateRGBSurface(SDL_SWSURFACE, dw, dh, 32, GUI::Color::RedMask, GUI::Color::GreenMask, GUI::Color::BlueMask, 0);
         SDL_FillRect(background,0,0);
         for (int y = 0; y < sh_draw; y++) {
-            Bit32u *bg = (Bit32u*)((unsigned int)(y+sy)*(unsigned int)background->pitch + (char*)background->pixels) + sx;
+            uint32_t *bg = (uint32_t*)((unsigned int)(y+sy)*(unsigned int)background->pitch + (char*)background->pixels) + sx;
             for (int x = 0; x < sw_draw; x++) {
                 int r = 0, g = 0, b = 0;
                 getPixel(x    *(int)render.src.width/sw, y    *(int)render.src.height/sh, r, g, b, 3); 
@@ -267,7 +278,7 @@ static GUI::ScreenSDL *UI_Startup(GUI::ScreenSDL *screen) {
     if (mouselocked) GFX_CaptureMouse();
 
 #if defined(C_SDL2)
-    extern SDL_Window * GFX_SetSDLSurfaceWindow(Bit16u width, Bit16u height);
+    extern SDL_Window * GFX_SetSDLSurfaceWindow(uint16_t width, uint16_t height);
 
     void GFX_SetResizeable(bool enable);
     GFX_SetResizeable(false);
@@ -352,8 +363,14 @@ static GUI::ScreenSDL *UI_Startup(GUI::ScreenSDL *screen) {
         }
     }
 
-    guiMenu.rebuild();
-    DOSBox_SetMenu(guiMenu);
+    static DOSBoxMenu nullMenu;
+    if (!shortcut || shortcutid<16) {
+        guiMenu.rebuild();
+        DOSBox_SetMenu(guiMenu);
+    } else {
+        nullMenu.rebuild();
+        DOSBox_SetMenu(nullMenu);
+    }
 #endif
 
     if (screen) screen->setSurface(sdlscreen);
@@ -471,7 +488,7 @@ static void UI_RunCommands(GUI::ScreenSDL *s, const std::string &cmds) {
     DOS_Shell temp;
     temp.call = true;
     UI_Shutdown(s);
-    Bit16u n=1; Bit8u c='\n';
+    uint16_t n=1; uint8_t c='\n';
     DOS_WriteFile(STDOUT,&c,&n);
     temp.bf = new VirtualBatch(&temp, cmds);
     temp.RunInternal();
@@ -682,6 +699,98 @@ public:
     }
 };
 
+std::string dispname="";
+std::string CapName(std::string name) {
+    dispname = name;
+    if (name=="sdl"||name=="cpu"||name=="midi"||name=="gus"||name=="dos"||name=="ipx"||name=="ne2000")
+        std::transform(dispname.begin(), dispname.end(), dispname.begin(), ::toupper);
+    else if (name=="dosbox")
+        dispname="Main";
+    else if (name=="pc98")
+        dispname="PC-98";
+    else if (name=="vsync")
+        dispname="V-Sync";
+    else if (name=="4dos")
+        dispname="4DOS.INI";
+    else if (name=="config")
+        dispname="CONFIG.SYS";
+    else if (name=="autoexec")
+        dispname="AUTOEXEC.BAT";
+    else if (name=="sblaster")
+        dispname="Sound Blaster";
+    else if (name=="speaker")
+        dispname="PC Speaker";
+    else if (name=="serial")
+        dispname="Serial Ports";
+    else if (name=="parallel")
+        dispname="Parallel Ports";
+    else if (name=="fdc, primary")
+        dispname="Floppy Port #1";
+    else if (name=="ide, primary")
+        dispname="IDE Port #1";
+    else if (name=="ide, secondary")
+        dispname="IDE Port #2";
+    else if (name=="ide, tertiary")
+        dispname="IDE Port #3";
+    else if (name=="ide, quaternary")
+        dispname="IDE Port #4";
+    else if (name=="ide, quinternary")
+        dispname="IDE Port #5";
+    else if (name=="ide, sexternary")
+        dispname="IDE Port #6";
+    else if (name=="ide, septernary")
+        dispname="IDE Port #7";
+    else if (name=="ide, octernary")
+        dispname="IDE Port #8";
+    else
+        dispname[0] = std::toupper(name[0]);
+    return dispname;
+}
+
+std::string RestoreName(std::string name) {
+    dispname = name;
+    if (name=="Main")
+        dispname="dosbox";
+    else if (name=="PC-98")
+        dispname="pc98";
+    else if (name=="V-Sync")
+        dispname="vsync";
+    else if (name=="4DOS.INI")
+        dispname="4dos";
+    else if (name=="CONFIG.SYS")
+        dispname="config";
+    else if (name=="AUTOEXEC.BAT")
+        dispname="autoexec";
+    else if (name=="Sound Blaster")
+        dispname="sblaster";
+    else if (name=="PC Speaker")
+        dispname="speaker";
+    else if (name=="Serial Ports")
+        dispname="serial";
+    else if (name=="Parallel Ports")
+        dispname="parallel";
+    else if (name=="Floppy Port #1")
+        dispname="fdc, primary";
+    else if (name=="IDE Port #1")
+        dispname="ide, primary";
+    else if (name=="IDE Port #2")
+        dispname="ide, secondary";
+    else if (name=="IDE Port #3")
+        dispname="ide, tertiary";
+    else if (name=="IDE Port #4")
+        dispname="ide, quaternary";
+    else if (name=="IDE Port #5")
+        dispname="ide, quinternary";
+    else if (name=="IDE Port #6")
+        dispname="ide, sexternary";
+    else if (name=="IDE Port #7")
+        dispname="ide, septernary";
+    else if (name=="IDE Port #8")
+        dispname="ide, octernary";
+    return dispname;
+}
+
+GUI::Checkbox *advopt, *saveall;
 static std::map< std::vector<GUI::Char>, GUI::ToplevelWindow* > cfg_windows_active;
 
 class HelpWindow : public GUI::MessageBox2 {
@@ -696,25 +805,26 @@ public:
         }
 
         std::string title(section->GetName());
-        title.at(0) = std::toupper(title.at(0));
-        setTitle("Help for "+title);
+        setTitle("Help for "+CapName(title));
+        title[0] = std::toupper(title[0]);
 
-        Section_prop* sec = dynamic_cast<Section_prop*>(section);
+        Section_prop* sec = dynamic_cast<Section_prop*>(title.substr(0, 4)=="Ide,"?control->GetSection("ide, primary"):section);
         if (sec) {
             std::string msg;
             Property *p;
             int i = 0;
             while ((p = sec->Get_prop(i++))) {
                 std::string help=title=="4dos"&&p->propname=="rem"?"This is the 4DOS.INI file (if you use 4DOS as the command shell).":p->Get_help();
+                if (title!="4dos" && title!="Config" && title!="Autoexec" && !advopt->isChecked() && !p->basic()) continue;
                 msg += std::string("\033[31m")+p->propname+":\033[0m\n"+help+"\n\n";
             }
             if (!msg.empty()) msg.replace(msg.end()-1,msg.end(),"");
             setText(msg);
         } else {
-        std::string name = section->GetName();
-        std::transform(name.begin(), name.end(), name.begin(), (int(*)(int))std::toupper);
-        name += "_CONFIGFILE_HELP";
-        setText(MSG_Get(name.c_str()));
+            std::string name = section->GetName();
+            std::transform(name.begin(), name.end(), name.begin(), (int(*)(int))std::toupper);
+            name += "_CONFIGFILE_HELP";
+            setText(MSG_Get(name.c_str()));
         }
     };
 
@@ -746,12 +856,15 @@ public:
         int button_row_h = 26;
         int button_row_padding_y = 5 + 5;
 
-        int num_prop = 0;
-        while (section->Get_prop(num_prop) != NULL) num_prop++;
+        int num_prop = 0, k=0;
+        while (section->Get_prop(num_prop) != NULL) {
+            if (advopt->isChecked() || section->Get_prop(num_prop)->basic()) k++;
+            num_prop++;
+        }
 
         int allowed_dialog_y = parent->getHeight() - 25 - (border_top + border_bottom) - 50;
 
-        int items_per_col = num_prop;
+        int items_per_col = k;
         int columns = 1;
 
         int scroll_h = items_per_col * row_height;
@@ -775,21 +888,22 @@ public:
             move(this->x,parent->getHeight() - this->getHeight());
 
         std::string title(section->GetName());
+        setTitle("Configuration for "+CapName(title));
         title[0] = std::toupper(title[0]);
-        setTitle("Configuration for "+title);
 
-        GUI::Button *b = new GUI::Button(this, button_row_cx, button_row_y, "Cancel", button_w);
+        GUI::Button *b = new GUI::Button(this, button_row_cx, button_row_y, "Help", button_w);
+        b->addActionHandler(this);
+
+        b = new GUI::Button(this, button_row_cx + (button_w + button_pad_w), button_row_y, "Cancel", button_w);
         b->addActionHandler(this);
         closeButton = b;
 
-        b = new GUI::Button(this, button_row_cx + (button_w + button_pad_w), button_row_y, "Help", button_w);
-        b->addActionHandler(this);
-
         b = new GUI::Button(this, button_row_cx + (button_w + button_pad_w)*2, button_row_y, "OK", button_w);
 
-        int i = 0;
+        int i = 0, j = 0;
         Property *prop;
         while ((prop = section->Get_prop(i))) {
+            if (!advopt->isChecked() && !prop->basic()) {i++;continue;}
             Prop_bool   *pbool   = dynamic_cast<Prop_bool*>(prop);
             Prop_int    *pint    = dynamic_cast<Prop_int*>(prop);
             Prop_double  *pdouble  = dynamic_cast<Prop_double*>(prop);
@@ -799,16 +913,17 @@ public:
             Prop_multival_remain* pmulti_remain = dynamic_cast<Prop_multival_remain*>(prop);
 
             PropertyEditor *p;
-            if (pbool) p = new PropertyEditorBool(wiw, column_width*(i/items_per_col), (i%items_per_col)*row_height, section, prop);
-            else if (phex) p = new PropertyEditorHex(wiw, column_width*(i/items_per_col), (i%items_per_col)*row_height, section, prop);
-            else if (pint) p = new PropertyEditorInt(wiw, column_width*(i/items_per_col), (i%items_per_col)*row_height, section, prop);
-            else if (pdouble) p = new PropertyEditorFloat(wiw, column_width*(i/items_per_col), (i%items_per_col)*row_height, section, prop);
-            else if (pstring) p = new PropertyEditorString(wiw, column_width*(i/items_per_col), (i%items_per_col)*row_height, section, prop);
-            else if (pmulti) p = new PropertyEditorString(wiw, column_width*(i/items_per_col), (i%items_per_col)*row_height, section, prop);
-            else if (pmulti_remain) p = new PropertyEditorString(wiw, column_width*(i/items_per_col), (i%items_per_col)*row_height, section, prop);
+            if (pbool) p = new PropertyEditorBool(wiw, column_width*(j/items_per_col), (j%items_per_col)*row_height, section, prop);
+            else if (phex) p = new PropertyEditorHex(wiw, column_width*(j/items_per_col), (j%items_per_col)*row_height, section, prop);
+            else if (pint) p = new PropertyEditorInt(wiw, column_width*(j/items_per_col), (j%items_per_col)*row_height, section, prop);
+            else if (pdouble) p = new PropertyEditorFloat(wiw, column_width*(j/items_per_col), (j%items_per_col)*row_height, section, prop);
+            else if (pstring) p = new PropertyEditorString(wiw, column_width*(j/items_per_col), (j%items_per_col)*row_height, section, prop);
+            else if (pmulti) p = new PropertyEditorString(wiw, column_width*(j/items_per_col), (j%items_per_col)*row_height, section, prop);
+            else if (pmulti_remain) p = new PropertyEditorString(wiw, column_width*(j/items_per_col), (j%items_per_col)*row_height, section, prop);
             else { i++; continue; }
             b->addActionHandler(p);
             i++;
+            j++;
         }
         b->addActionHandler(this);
 
@@ -939,8 +1054,8 @@ public:
             scroll_h = allowed_dialog_y;
 
         std::string title(section->GetName());
+        setTitle("Configuration for "+CapName(title));
         title[0] = std::toupper(title[0]);
-        setTitle("Configuration for "+title);
 
 		char extra_data[4096] = { 0 };
 		const char * extra = const_cast<char*>(section->data.c_str());
@@ -1194,7 +1309,7 @@ protected:
     GUI::Input *name;
 public:
     SaveDialog(GUI::Screen *parent, int x, int y, const char *title) :
-        ToplevelWindow(parent, x, y, 400, 100 + GUI::titlebar_y_stop, title) {
+        ToplevelWindow(parent, x, y, 400, 130 + GUI::titlebar_y_stop, title) {
         new GUI::Label(this, 5, 10, "Enter filename for configuration file:");
         name = new GUI::Input(this, 5, 30, width - 10 - border_left - border_right);
         extern std::string capturedir;
@@ -1208,15 +1323,18 @@ public:
         } else
             fullpath = "dosbox-x.conf";
         name->setText(fullpath.c_str());
-        (new GUI::Button(this, 120, 60, "Cancel", 70))->addActionHandler(this);
-        (new GUI::Button(this, 210, 60, "OK", 70))->addActionHandler(this);
+        saveall = new GUI::Checkbox(this, 5, 60, "Save all options to the configuration file");
+        Section_prop * section=static_cast<Section_prop *>(control->GetSection("dosbox"));
+        saveall->setChecked(section->Get_bool("show advanced options"));
+        (new GUI::Button(this, 120, 90, "Cancel", 70))->addActionHandler(this);
+        (new GUI::Button(this, 210, 90, "OK", 70))->addActionHandler(this);
     }
 
     void actionExecuted(GUI::ActionEventSource *b, const GUI::String &arg) {
         (void)b;//UNUSED
         // HACK: Attempting to cast a String to void causes "forming reference to void" errors when building with GCC 4.7
         (void)arg.size();//UNUSED
-        if (arg == "OK") control->PrintConfig(name->getText(), true);
+        if (arg == "OK") control->PrintConfig(name->getText(), saveall->isChecked()?1:-1);
         close();
         if(shortcut) running=false;
     }
@@ -1434,6 +1552,67 @@ public:
     }
 };
 
+std::string GetSBtype(), GetSBbase();
+Bitu GetSBirq();
+uint8_t GetSBldma(), GetSBhdma();
+
+class ShowSBInfo : public GUI::ToplevelWindow {
+protected:
+    GUI::Input *name;
+public:
+    ShowSBInfo(GUI::Screen *parent, int x, int y, const char *title) :
+        ToplevelWindow(parent, x, y, 320, 230, title) {
+            std::string sbinfo = "Sound Blaster type: "+GetSBtype()+"\nSound Blaster base: "+GetSBbase()+"\nSound Blaster IRQ: "+std::to_string(GetSBirq())+"\nSound Blaster Low DMA: "+std::to_string(GetSBldma())+"\nSound Blaster High DMA: "+std::to_string(GetSBhdma());
+            std::istringstream in(sbinfo.c_str());
+            int r=0;
+            if (in)	for (std::string line; std::getline(in, line); ) {
+                r+=25;
+                new GUI::Label(this, 40, r, line.c_str());
+            }
+            (new GUI::Button(this, 130, r+30, "Close", 70))->addActionHandler(this);
+    }
+
+    void actionExecuted(GUI::ActionEventSource *b, const GUI::String &arg) {
+        (void)b;//UNUSED
+        if (arg == "Close")
+            close();
+        if (shortcut) running = false;
+    }
+};
+
+extern DB_Midi midi;
+extern std::string sffile;
+class ShowMidiDevice : public GUI::ToplevelWindow {
+protected:
+    GUI::Input *name;
+public:
+    ShowMidiDevice(GUI::Screen *parent, int x, int y, const char *title) :
+        ToplevelWindow(parent, x, y, 320, 260, title) {
+            std::string name=!midi.handler||!midi.handler->GetName()?"-":midi.handler->GetName();
+            if (name.size()) {
+                if (name=="mt32") name="MT32";
+                else if (name=="fluidsynth") name="FluidSynth";
+                else name[0]=toupper(name[0]);
+            }
+            std::string getoplmode(), getoplemu();
+            std::string midiinfo = "MIDI available: "+std::string(midi.available?"Yes":"No")+"\nMIDI device: "+name+"\nMIDI soundfont file / ROM path:\n"+sffile+"\nOPL mode: "+getoplmode()+"\nOPL emulation: "+getoplemu();
+            std::istringstream in(midiinfo.c_str());
+            int r=0;
+            if (in)	for (std::string line; std::getline(in, line); ) {
+                r+=25;
+                new GUI::Label(this, 40, r, line.c_str());
+            }
+            (new GUI::Button(this, 130, r+30, "Close", 70))->addActionHandler(this);
+    }
+
+    void actionExecuted(GUI::ActionEventSource *b, const GUI::String &arg) {
+        (void)b;//UNUSED
+        if (arg == "Close")
+            close();
+        if (shortcut) running = false;
+    }
+};
+
 class ShowDriveInfo : public GUI::ToplevelWindow {
 protected:
     GUI::Input *name;
@@ -1441,7 +1620,7 @@ public:
     ShowDriveInfo(GUI::Screen *parent, int x, int y, const char *title) :
         ToplevelWindow(parent, x, y, 400, 280, title) {
             char name[DOS_NAMELENGTH_ASCII],lname[LFN_NAMELENGTH];
-            Bit32u size;Bit16u date;Bit16u time;Bit8u attr;
+            uint32_t size;uint16_t date;uint16_t time;uint8_t attr;
             /* Command uses dta so set it to our internal dta */
             RealPt save_dta = dos.dta();
             dos.dta(dos.tables.tempdta);
@@ -1557,24 +1736,6 @@ public:
     }
 };
 
-class ShowStateCorrupt : public GUI::ToplevelWindow {
-protected:
-    GUI::Input *name;
-public:
-    ShowStateCorrupt(GUI::Screen *parent, int x, int y, const char *title) :
-        ToplevelWindow(parent, x, y, 420, 120, "Error") {
-            new GUI::Label(this, 30, 20, title);
-            (new GUI::Button(this, 180, 50, "Close", 70))->addActionHandler(this);
-    }
-
-    void actionExecuted(GUI::ActionEventSource *b, const GUI::String &arg) {
-        (void)b;//UNUSED
-        if (arg == "Close")
-            close();
-        if (shortcut) running = false;
-    }
-};
-
 class ShowLoadWarning : public GUI::ToplevelWindow {
 protected:
     GUI::Input *name;
@@ -1597,27 +1758,48 @@ public:
     }
 };
 
-class ShowQuitWarning : public GUI::ToplevelWindow {
+class ShowHelpIntro : public GUI::ToplevelWindow {
 protected:
     GUI::Input *name;
 public:
-    ShowQuitWarning(GUI::Screen *parent, int x, int y, const char *title) :
-        ToplevelWindow(parent, x, y, strcmp(title, "quit1")?430:330, !strcmp(title, "quit3")?180:150, "Quit DOSBox-X warning") {
-            bool forcequit=!strcmp(title, "quit3");
-            new GUI::Label(this, forcequit?20:40, 20, !strcmp(title, "quit1")?"This will quit from DOSBox-X.":(!strcmp(title, "quit2")?"You are currently running a guest system.":"It may be unsafe to quit from DOSBox-X right now"));
-            if (forcequit) new GUI::Label(this, forcequit?20:40, 50, "because one or more files are currently open.");
-            new GUI::Label(this, forcequit?20:40, forcequit?80:50, strcmp(title, "quit1")?"Are you sure to quit anyway now?":"Are you sure?");
-            (new GUI::Button(this, strcmp(title, "quit1")?140:90, forcequit?110:80, "Yes", 70))->addActionHandler(this);
-            (new GUI::Button(this, strcmp(title, "quit1")?230:180, forcequit?110:80, "No", 70))->addActionHandler(this);
+    ShowHelpIntro(GUI::Screen *parent, int x, int y, const char *title) :
+        ToplevelWindow(parent, x, y, 580, 190, title) {
+            std::istringstream in(intromsg);
+            int r=0;
+            if (in)	for (std::string line; std::getline(in, line); ) {
+                r+=25;
+                new GUI::Label(this, 40, r, line.c_str());
+            }
+            (new GUI::Button(this, 260, 110, "Close", 70))->addActionHandler(this);
     }
 
     void actionExecuted(GUI::ActionEventSource *b, const GUI::String &arg) {
         (void)b;//UNUSED
-        if (arg == "Yes")
-            quit_confirm=true;
-        if (arg == "No")
-            quit_confirm=false;
-        close();
+        if (arg == "Close")
+            close();
+        if (shortcut) running = false;
+    }
+};
+
+class ShowHelpAbout : public GUI::ToplevelWindow {
+protected:
+    GUI::Input *name;
+public:
+    ShowHelpAbout(GUI::Screen *parent, int x, int y, const char *title) :
+        ToplevelWindow(parent, x, y, 420, 230, title) {
+            std::istringstream in(aboutmsg);
+            int r=0;
+            if (in)	for (std::string line; std::getline(in, line); ) {
+                r+=25;
+                new GUI::Label(this, 40, r, line.c_str());
+            }
+            (new GUI::Button(this, 180, 155, "Close", 70))->addActionHandler(this);
+    }
+
+    void actionExecuted(GUI::ActionEventSource *b, const GUI::String &arg) {
+        (void)b;//UNUSED
+        if (arg == "Close")
+            close();
         if (shortcut) running = false;
     }
 };
@@ -1637,17 +1819,22 @@ public:
         bar->addItem(0,"Close");
         bar->addMenu("Settings");
         bar->addMenu("Help");
+        bar->addItem(2,"Visit Homepage");
+        bar->addItem(2,"");
         if (!dos_kernel_disabled) {
             /* these do not work until shell help text is registerd */
-            bar->addItem(2,"Introduction");
             bar->addItem(2,"Getting Started");
             bar->addItem(2,"CD-ROM Support");
             bar->addItem(2,"");
         }
+        bar->addItem(2,"Introduction");
         bar->addItem(2,"About");
         bar->addActionHandler(this);
 
         new GUI::Label(this, 10, 30, "Choose a settings group to configure:");
+        advopt = new GUI::Checkbox(this, 340, 30, "Show advanced options");
+        Section_prop * section=static_cast<Section_prop *>(control->GetSection("dosbox"));
+        advopt->setChecked(section->Get_bool("show advanced options"));
 
         Section *sec;
         int gridbtnwidth = 130;
@@ -1664,11 +1851,12 @@ public:
         while ((sec = control->GetSection(i))) {
             if (i != 0 && (i%15) == 0) bar->addItem(1, "|");
             std::string name = sec->GetName();
+            std::string title = CapName(name);
             name[0] = std::toupper(name[0]);
             const auto sz = gridfunc(i);
-            GUI::Button *b = new GUI::Button(this, sz.first, sz.second, name, gridbtnwidth, gridbtnheight);
+            GUI::Button *b = new GUI::Button(this, sz.first, sz.second, title, gridbtnwidth, gridbtnheight);
             b->addActionHandler(this);
-            bar->addItem(1, name);
+            bar->addItem(1, title);
             i++;
         }
 
@@ -1703,7 +1891,7 @@ public:
     }
 
     void actionExecuted(GUI::ActionEventSource *b, const GUI::String &arg) {
-        GUI::String sname = arg;
+        GUI::String sname = RestoreName(arg);
         sname.at(0) = (unsigned int)std::tolower((int)sname.at(0));
         Section *sec;
         if (arg == "Close" || arg == "Cancel" || arg == "Close") {
@@ -1744,11 +1932,19 @@ public:
             else {
                 lookup->second->raise();
             }
+        } else if (arg == "Visit Homepage") {
+            std::string url = "https://dosbox-x.com/";
+#if defined(WIN32)
+            ShellExecute(NULL, "open", url.c_str(), NULL, NULL, SW_SHOWNORMAL);
+#elif defined(LINUX)
+            system(("xdg-open "+url).c_str());
+#elif defined(MACOSX)
+            system(("open "+url).c_str());
+#endif
         } else if (arg == "About") {
-            const char *msg = PACKAGE_STRING " (C) 2002-" COPYRIGHT_END_YEAR " The DOSBox Team\nA fork of DOSBox 0.74 by TheGreatCodeholio\nBuild date: " UPDATED_STR "\n\nFor more info visit http://dosbox-x.com\nBased on DOSBox (http://dosbox.com)\n\n";
-            new GUI::MessageBox2(getScreen(), 100, 150, 480, "About DOSBox-X", msg);
+            new GUI::MessageBox2(getScreen(), 100, 150, 330, "About DOSBox-X", aboutmsg);
         } else if (arg == "Introduction") {
-            new GUI::MessageBox2(getScreen(), 20, 50, 540, "Introduction", MSG_Get("PROGRAM_INTRO"));
+            new GUI::MessageBox2(getScreen(), 20, 50, 540, "Introduction", intromsg);
         } else if (arg == "Getting Started") {
             std::string msg = MSG_Get("PROGRAM_INTRO_MOUNT_START");
 #ifdef WIN32
@@ -1777,7 +1973,7 @@ public:
 static void UI_Execute(GUI::ScreenSDL *screen) {
     SDL_Surface *sdlscreen;
     SDL_Event event;
-    GUI::String configString = GUI::String("DOSBox-X Configuration");
+    GUI::String configString = GUI::String("DOSBox-X Configuration Tool");
 
     sdlscreen = screen->getSurface();
     auto *cfg_wnd = new ConfigurationWindow(screen, 40, 10, configString);
@@ -1837,7 +2033,7 @@ static void UI_Select(GUI::ScreenSDL *screen, int select) {
     Section_prop *section = NULL;
     Section *sec = NULL;
     SDL_Event event;
-    GUI::String configString = GUI::String("DOSBox-X Configuration");
+    GUI::String configString = GUI::String("DOSBox-X Configuration Tool");
 
     sdlscreen = screen->getSurface();
     switch (select) {
@@ -1932,15 +2128,15 @@ static void UI_Select(GUI::ScreenSDL *screen, int select) {
             np4->raise();
             } break;
         case 20: {
-            auto *np5 = new ShowMixerInfo(screen, 90, 70, "Current sound levels in DOSBox-X");
+            auto *np5 = new ShowMixerInfo(screen, 90, 70, "Current sound mixer volumes");
             np5->raise();
             } break;
         case 21: {
-            auto *np6 = new ShowStateCorrupt(screen, 150, 120, "Save state corrupted! Program may not work.");
+            auto *np6 = new ShowSBInfo(screen, 150, 100, "Sound Blaster configuration");
             np6->raise();
             } break;
-        case 22: if (saveloaderr.size()) {
-            auto *np6 = new ShowStateCorrupt(screen, 150, 120, saveloaderr.c_str());
+        case 22: {
+            auto *np6 = new ShowMidiDevice(screen, 150, 100, "Current MIDI configuration");
             np6->raise();
             } break;
         case 23: {
@@ -1963,26 +2159,22 @@ static void UI_Select(GUI::ScreenSDL *screen, int select) {
             auto *np7 = new ShowLoadWarning(screen, 150, 120, "Are you sure to remove the state in this slot?");
             np7->raise();
             } break;
-        case 28: {
-            auto *np8 = new ShowQuitWarning(screen, 150, 120, "quit1");
-            np8->raise();
-            } break;
-        case 29: {
-            auto *np8 = new ShowQuitWarning(screen, 120, 100, "quit2");
-            np8->raise();
-            } break;
-        case 30: {
-            auto *np8 = new ShowQuitWarning(screen, 120, 100, "quit3");
-            np8->raise();
-            } break;
-        case 31: if (statusdrive>-1 && statusdrive<DOS_DRIVES && Drives[statusdrive]) {
+        case 32: if (statusdrive>-1 && statusdrive<DOS_DRIVES && Drives[statusdrive]) {
             auto *np9 = new ShowDriveInfo(screen, 120, 50, "Drive Information");
             np9->raise();
             } break;
-        case 32: {
+        case 33: {
             auto *np10 = new ShowDriveNumber(screen, 110, 70, "Mounted Drive Numbers");
             np10->raise();
             } break;
+        case 34: {
+            auto *np11 = new ShowHelpIntro(screen, 70, 70, "Introduction");
+            np11->raise();
+            } break;
+        case 35: {
+            auto *np11 = new ShowHelpAbout(screen, 110, 70, "About");
+            np11->raise();
+            } break;
         default:
             break;
     }
@@ -2041,11 +2233,13 @@ void GUI_Shortcut(int select) {
         return;
     }
 
+    shortcutid=select;
     shortcut=true;
     GUI::ScreenSDL *screen = UI_Startup(NULL);
     UI_Select(screen,select);
     UI_Shutdown(screen);
     shortcut=false;
+    shortcutid=-1;
     delete screen;
 }
 
