@@ -28,6 +28,7 @@
 #include "mem.h"
 #include "dbopl.h"
 #include "nukedopl.h"
+#include "cpu.h"
 
 #include "mame/emu.h"
 #include "mame/fmopl.h"
@@ -43,16 +44,16 @@ namespace OPL2 {
 	#include "opl.cpp"
 
 	struct Handler : public Adlib::Handler {
-		virtual void WriteReg( Bit32u reg, Bit8u val ) {
+		virtual void WriteReg( uint32_t reg, uint8_t val ) {
 			adlib_write(reg,val);
 		}
-		virtual Bit32u WriteAddr( Bit32u port, Bit8u val ) {
+		virtual uint32_t WriteAddr( uint32_t port, uint8_t val ) {
             (void)port;//UNUSED
 			return val;
 		}
 
 		virtual void Generate( MixerChannel* chan, Bitu samples ) {
-			Bit16s buf[1024];
+			int16_t buf[1024];
 			while( samples > 0 ) {
 				Bitu todo = samples > 1024 ? 1024 : samples;
 				samples -= todo;
@@ -62,7 +63,7 @@ namespace OPL2 {
 		}
 
 		virtual void Init( Bitu rate ) {
-			adlib_init((Bit32u)rate);
+			adlib_init((uint32_t)rate);
 		}
 
 		virtual void SaveState( std::ostream& stream ) {
@@ -110,15 +111,15 @@ namespace OPL3 {
 	#include "opl.cpp"
 
 	struct Handler : public Adlib::Handler {
-		virtual void WriteReg( Bit32u reg, Bit8u val ) {
+		virtual void WriteReg( uint32_t reg, uint8_t val ) {
 			adlib_write(reg,val);
 		}
-		virtual Bit32u WriteAddr( Bit32u port, Bit8u val ) {
+		virtual uint32_t WriteAddr( uint32_t port, uint8_t val ) {
 			adlib_write_index(port, val);
 			return opl_index;
 		}
 		virtual void Generate( MixerChannel* chan, Bitu samples ) {
-			Bit16s buf[1024*2];
+			int16_t buf[1024*2];
 			while( samples > 0 ) {
 				Bitu todo = samples > 1024 ? 1024 : samples;
 				samples -= todo;
@@ -128,7 +129,7 @@ namespace OPL3 {
 		}
 
 		virtual void Init( Bitu rate ) {
-			adlib_init((Bit32u)rate);
+			adlib_init((uint32_t)rate);
 		}
 
 		virtual void SaveState( std::ostream& stream ) {
@@ -175,16 +176,16 @@ namespace NukedOPL {
 
 struct Handler : public Adlib::Handler {
 	opl3_chip chip = {};
-	Bit8u newm = 0;
+	uint8_t newm = 0;
 
-	void WriteReg(Bit32u reg, Bit8u val) override {
-		OPL3_WriteRegBuffered(&chip, (Bit16u)reg, val);
+	void WriteReg(uint32_t reg, uint8_t val) override {
+		OPL3_WriteRegBuffered(&chip, (uint16_t)reg, val);
 		if (reg == 0x105)
 			newm = reg & 0x01;
 	}
 
-	Bit32u WriteAddr(Bit32u port, Bit8u val) override {
-		Bit16u addr;
+	uint32_t WriteAddr(uint32_t port, uint8_t val) override {
+		uint16_t addr;
 		addr = val;
 		if ((port & 2) && (addr == 0x05 || newm)) {
 			addr |= 0x100;
@@ -204,7 +205,7 @@ struct Handler : public Adlib::Handler {
 
 	void Init(Bitu rate) override {
 		newm = 0;
-		OPL3_Reset(&chip, (Bit32u)rate);
+		OPL3_Reset(&chip, (uint32_t)rate);
 	}
 
 	~Handler() {
@@ -218,15 +219,15 @@ namespace MAMEOPL2 {
 struct Handler : public Adlib::Handler {
 	void* chip = NULL;
 
-	virtual void WriteReg(Bit32u reg, Bit8u val) {
+	virtual void WriteReg(uint32_t reg, uint8_t val) {
 		ym3812_write(chip, 0, (int)reg);
 		ym3812_write(chip, 1, (int)val);
 	}
-	virtual Bit32u WriteAddr(Bit32u /*port*/, Bit8u val) {
+	virtual uint32_t WriteAddr(uint32_t /*port*/, uint8_t val) {
 		return val;
 	}
 	virtual void Generate(MixerChannel* chan, Bitu samples) {
-		Bit16s buf[1024 * 2];
+		int16_t buf[1024 * 2];
 		while (samples > 0) {
 			Bitu todo = samples > 1024 ? 1024 : samples;
 			samples -= todo;
@@ -284,18 +285,18 @@ namespace MAMEOPL3 {
 struct Handler : public Adlib::Handler {
 	void* chip = NULL;
 
-	virtual void WriteReg(Bit32u reg, Bit8u val) {
+	virtual void WriteReg(uint32_t reg, uint8_t val) {
 		ymf262_write(chip, 0, (int)reg);
 		ymf262_write(chip, 1, (int)val);
 	}
-	virtual Bit32u WriteAddr(Bit32u /*port*/, Bit8u val) {
+	virtual uint32_t WriteAddr(uint32_t /*port*/, uint8_t val) {
 		return val;
 	}
 	virtual void Generate(MixerChannel* chan, Bitu samples) {
 		//We generate data for 4 channels, but only the first 2 are connected on a pc
-		Bit16s buf[4][1024];
-		Bit16s result[1024][2];
-		Bit16s* buffers[4] = { buf[0], buf[1], buf[2], buf[3] };
+		int16_t buf[4][1024];
+		int16_t result[1024][2];
+		int16_t* buffers[4] = { buf[0], buf[1], buf[2], buf[3] };
 
 		while (samples > 0) {
 			Bitu todo = samples > 1024 ? 1024 : samples;
@@ -359,17 +360,17 @@ namespace OPL2BOARD {
 		Handler(const char* port) {
 			opl2AudioBoard.connect(port);
 		}
-		virtual void WriteReg(Bit32u reg, Bit8u val) {
+		virtual void WriteReg(uint32_t reg, uint8_t val) {
 			opl2AudioBoard.write(reg, val);
 		}
-		virtual Bit32u WriteAddr(Bit32u port, Bit8u val) {
+		virtual uint32_t WriteAddr(uint32_t port, uint8_t val) {
 			(void)port;
 			return val;
 		}
 
 		virtual void Generate(MixerChannel* chan, Bitu samples) {
 			(void)samples;
-			Bit16s buf[1] = { 0 };
+			int16_t buf[1] = { 0 };
 			chan->AddSamples_m16(1, buf);
 		}
 		virtual void Init(Bitu rate) {
@@ -405,17 +406,17 @@ namespace Adlib {
 #define HW_OPL3 2
 
 struct RawHeader {
-	Bit8u id[8];				/* 0x00, "DBRAWOPL" */
-	Bit16u versionHigh;			/* 0x08, size of the data following the m */
-	Bit16u versionLow;			/* 0x0a, size of the data following the m */
-	Bit32u commands;			/* 0x0c, Bit32u amount of command/data pairs */
-	Bit32u milliseconds;		/* 0x10, Bit32u Total milliseconds of data in this chunk */
-	Bit8u hardware;				/* 0x14, Bit8u Hardware Type 0=opl2,1=dual-opl2,2=opl3 */
-	Bit8u format;				/* 0x15, Bit8u Format 0=cmd/data interleaved, 1 maybe all cdms, followed by all data */
-	Bit8u compression;			/* 0x16, Bit8u Compression Type, 0 = No Compression */
-	Bit8u delay256;				/* 0x17, Bit8u Delay 1-256 msec command */
-	Bit8u delayShift8;			/* 0x18, Bit8u (delay + 1)*256 */			
-	Bit8u conversionTableSize;	/* 0x191, Bit8u Raw Conversion Table size */
+	uint8_t id[8];				/* 0x00, "DBRAWOPL" */
+	uint16_t versionHigh;			/* 0x08, size of the data following the m */
+	uint16_t versionLow;			/* 0x0a, size of the data following the m */
+	uint32_t commands;			/* 0x0c, uint32_t amount of command/data pairs */
+	uint32_t milliseconds;		/* 0x10, uint32_t Total milliseconds of data in this chunk */
+	uint8_t hardware;				/* 0x14, uint8_t Hardware Type 0=opl2,1=dual-opl2,2=opl3 */
+	uint8_t format;				/* 0x15, uint8_t Format 0=cmd/data interleaved, 1 maybe all cdms, followed by all data */
+	uint8_t compression;			/* 0x16, uint8_t Compression Type, 0 = No Compression */
+	uint8_t delay256;				/* 0x17, uint8_t Delay 1-256 msec command */
+	uint8_t delayShift8;			/* 0x18, uint8_t (delay + 1)*256 */			
+	uint8_t conversionTableSize;	/* 0x191, uint8_t Raw Conversion Table size */
 } GCC_ATTRIBUTE(packed);
 #ifdef _MSC_VER
 #pragma pack()
@@ -429,34 +430,34 @@ struct RawHeader {
 //Table to map the opl register to one <127 for dro saving
 class Capture {
 	//127 entries to go from raw data to registers
-	Bit8u ToReg[127];
+	uint8_t ToReg[127];
 	//How many entries in the ToPort are used
-	Bit8u RawUsed;
+	uint8_t RawUsed;
 	//256 entries to go from port index to raw data
-	Bit8u ToRaw[256];
-	Bit8u delay256;
-	Bit8u delayShift8;
+	uint8_t ToRaw[256];
+	uint8_t delay256;
+	uint8_t delayShift8;
     RawHeader header = {};
 
 	FILE*	handle;				//File used for writing
-	Bit32u	startTicks;			//Start used to check total raw length on end
-	Bit32u	lastTicks;			//Last ticks when last last cmd was added
-    Bit8u   buf[1024] = {};     //16 added for delay commands and what not
-	Bit32u	bufUsed;
+	uint32_t	startTicks;			//Start used to check total raw length on end
+	uint32_t	lastTicks;			//Last ticks when last last cmd was added
+    uint8_t   buf[1024] = {};     //16 added for delay commands and what not
+	uint32_t	bufUsed;
 #if 0//unused
-    Bit8u	cmd[2];				//Last cmd's sent to either ports
+    uint8_t	cmd[2];				//Last cmd's sent to either ports
 	bool	doneOpl3;
 	bool	doneDualOpl2;
 #endif
 	RegisterCache* cache;
 
-	void MakeEntry( Bit8u reg, Bit8u& raw ) {
+	void MakeEntry( uint8_t reg, uint8_t& raw ) {
 		ToReg[ raw ] = reg;
 		ToRaw[ reg ] = raw;
 		raw++;
 	}
 	void MakeTables( void ) {
-		Bit8u index = 0;
+		uint8_t index = 0;
 		memset( ToReg, 0xff, sizeof ( ToReg ) );
 		memset( ToRaw, 0xff, sizeof ( ToRaw ) );
 		//Select the entries that are valid and the index is the mapping to the index entry
@@ -493,15 +494,15 @@ class Capture {
 		header.commands += bufUsed / 2;
 		bufUsed = 0;
 	}
-	void AddBuf( Bit8u raw, Bit8u val ) {
+	void AddBuf( uint8_t raw, uint8_t val ) {
 		buf[bufUsed++] = raw;
 		buf[bufUsed++] = val;
 		if ( bufUsed >= sizeof( buf ) ) {
 			ClearBuf();
 		}
 	}
-	void AddWrite( Bit32u regFull, Bit8u val ) {
-		Bit8u regMask = regFull & 0xff;
+	void AddWrite( uint32_t regFull, uint8_t val ) {
+		uint8_t regMask = regFull & 0xff;
 		/*
 			Do some special checks if we're doing opl3 or dualopl2 commands
 			Although you could pretty much just stick to always doing opl3 on the player side
@@ -515,7 +516,7 @@ class Capture {
 		if ( header.hardware == HW_OPL2 && regFull >= 0x1b0 && regFull <=0x1b8 && val ) {
 			header.hardware = HW_DUALOPL2;
 		}
-		Bit8u raw = ToRaw[ regMask ];
+		uint8_t raw = ToRaw[ regMask ];
 		if ( raw == 0xff )
 			return;
 		if ( regFull & 0x100 )
@@ -523,8 +524,8 @@ class Capture {
 		AddBuf( raw, val );
 	}
 	void WriteCache( void  ) {
-		Bit16u i;
-        Bit8u val;
+		uint16_t i;
+        uint8_t val;
 		/* Check the registers to add */
 		for (i=0;i<256;i++) {
 			//Skip the note on entries
@@ -564,14 +565,14 @@ class Capture {
 		}
 	}
 public:
-	bool DoWrite( Bit32u regFull, Bit8u val ) {
-		Bit8u regMask = regFull & 0xff;
+	bool DoWrite( uint32_t regFull, uint8_t val ) {
+		uint8_t regMask = regFull & 0xff;
 		//Check the raw index for this register if we actually have to save it
 		if ( handle ) {
 			/*
 				Check if we actually care for this to be logged, else just ignore it
 			*/
-			Bit8u raw = ToRaw[ regMask ];
+			uint8_t raw = ToRaw[ regMask ];
 			if ( raw == 0xff ) {
 				return true;
 			}
@@ -582,8 +583,8 @@ public:
 				return true;
 			/* Check how much time has passed */
 			Bitu passed = PIC_Ticks - lastTicks;
-			lastTicks = (Bit32u)PIC_Ticks;
-			header.milliseconds += (Bit32u)passed;
+			lastTicks = (uint32_t)PIC_Ticks;
+			header.milliseconds += (uint32_t)passed;
 
 			//if ( passed > 0 ) LOG_MSG( "Delay %d", passed ) ;
 			
@@ -594,12 +595,12 @@ public:
 			}
 			while (passed > 0) {
 				if (passed < 257) {			//1-256 millisecond delay
-					AddBuf( delay256, (Bit8u)(passed - 1));
+					AddBuf( delay256, (uint8_t)(passed - 1));
 					passed = 0;
 				} else {
 					Bitu shift = (passed >> 8);
 					passed -= shift << 8;
-					AddBuf( delayShift8, (Bit8u)(shift - 1));
+					AddBuf( delayShift8, (uint8_t)(shift - 1));
 				}
 			}
 			AddWrite( regFull, val );
@@ -629,8 +630,8 @@ skipWrite:
 		/* Write the command that triggered this */
 		AddWrite( regFull, val );
 		//Init the timing information for the next commands
-		lastTicks = (Bit32u)PIC_Ticks;	
-		startTicks = (Bit32u)PIC_Ticks;
+		lastTicks = (uint32_t)PIC_Ticks;	
+		startTicks = (uint32_t)PIC_Ticks;
 		return true;
 	}
 	Capture( RegisterCache* _cache ) {
@@ -654,46 +655,44 @@ Chip
 Chip::Chip() : timer0(80), timer1(320) {
 }
 
-bool Chip::Write( Bit32u reg, Bit8u val ) {
+bool Chip::Write( uint32_t reg, uint8_t val ) {
 	if (adlib_force_timer_overflow_on_polling) {
 		/* detect end of polling loop by whether it writes */
 		last_poll = PIC_FullIndex();
 		poll_counter = 0;
 	}
 
+	//if(reg == 0x02 || reg == 0x03 || reg == 0x04) LOG(LOG_MISC,LOG_ERROR)("write adlib timer %X %X",reg,val);
 	switch ( reg ) {
 	case 0x02:
+		timer0.Update(PIC_FullIndex() );
 		timer0.SetCounter(val);
 		return true;
 	case 0x03:
+		timer1.Update(PIC_FullIndex() );
 		timer1.SetCounter(val);
 		return true;
 	case 0x04:
-		double time;
-		time = PIC_FullIndex();
 		//Reset overflow in both timers
 		if ( val & 0x80 ) {
-			timer0.Reset( time );
-			timer1.Reset( time );
+			timer0.Reset();
+			timer1.Reset();
 		} else {
-			//timer 0 not masked
-			if (val&0x20) {
-				if (val & 0x1) {
-					timer0.Start(time);
-				}
-				else {
-					timer0.Stop();
-				}
+			const double time = PIC_FullIndex();
+			if (val & 0x1) {
+				timer0.Start(time);
 			}
-			//Timer 1 not masked
-			if (val&0x40) {
-				if (val & 0x2) {
-					timer1.Start(time);
-				}
-				else {
-					timer1.Stop();
-				}
+			else {
+				timer0.Stop();
 			}
+			if (val & 0x2) {
+				timer1.Start(time);
+			}
+			else {
+				timer1.Stop();
+			}
+			timer0.SetMask((val & 0x40) > 0);
+			timer1.SetMask((val & 0x20) > 0);
 		}
 		return true;
 	}
@@ -701,7 +700,7 @@ bool Chip::Write( Bit32u reg, Bit8u val ) {
 }
 
 
-Bit8u Chip::Read( ) {
+uint8_t Chip::Read( ) {
 	const double time( PIC_FullIndex() );
 
 	if (adlib_force_timer_overflow_on_polling) {
@@ -727,7 +726,7 @@ Bit8u Chip::Read( ) {
 		last_poll = time;
 	}
 
-	Bit8u ret = 0;
+	uint8_t ret = 0;
 	//Overflow won't be set if a channel is masked
 	if (timer0.Update(time)) {
 		ret |= 0x40;
@@ -740,7 +739,7 @@ Bit8u Chip::Read( ) {
 	return ret;
 }
 
-void Module::CacheWrite( Bit32u reg, Bit8u val ) {
+void Module::CacheWrite( uint32_t reg, uint8_t val ) {
 	//capturing?
 	if ( capture ) {
 		capture->DoWrite( reg, val );
@@ -749,7 +748,7 @@ void Module::CacheWrite( Bit32u reg, Bit8u val ) {
 	cache[ reg ] = val;
 }
 
-void Module::DualWrite( Bit8u index, Bit8u reg, Bit8u val ) {
+void Module::DualWrite( uint8_t index, uint8_t reg, uint8_t val ) {
 	//Make sure you don't use opl3 features
 	//Don't allow write to disable opl3		
 	if ( reg == 5 ) {
@@ -767,12 +766,12 @@ void Module::DualWrite( Bit8u index, Bit8u reg, Bit8u val ) {
 		val &= 0x0f;
 		val |= index ? 0xA0 : 0x50;
 	}
-	Bit32u fullReg = reg + (index ? 0x100u : 0u);
+	uint32_t fullReg = reg + (index ? 0x100u : 0u);
 	handler->WriteReg( fullReg, val );
 	CacheWrite( fullReg, val );
 }
 
-void Module::CtrlWrite( Bit8u val ) {
+void Module::CtrlWrite( uint8_t val ) {
 	switch ( ctrl.index ) {
 	case 0x09: /* Left FM Volume */
 		ctrl.lvol = val;
@@ -806,7 +805,7 @@ Bitu Module::CtrlRead( void ) {
 void Module::PortWrite( Bitu port, Bitu val, Bitu iolen ) {
     (void)iolen;//UNUSED
 	//Keep track of last write time
-	lastUsed = (Bit32u)PIC_Ticks;
+	lastUsed = (uint32_t)PIC_Ticks;
 	//Maybe only enable with a keyon?
 	if ( !mixerChan->enabled ) {
 		mixerChan->Enable(true);
@@ -816,27 +815,27 @@ void Module::PortWrite( Bitu port, Bitu val, Bitu iolen ) {
 		case MODE_OPL3GOLD:
 			if ( port == 0x38b ) {
 				if ( ctrl.active ) {
-					CtrlWrite( (Bit8u)val );
+					CtrlWrite( (uint8_t)val );
 					break;
 				}
 			}
 			//Fall-through if not handled by control chip
 		case MODE_OPL2:
 		case MODE_OPL3:
-			if ( !chip[0].Write( reg.normal, (Bit8u)val ) ) {
-				handler->WriteReg( reg.normal, (Bit8u)val );
-				CacheWrite( reg.normal, (Bit8u)val );
+			if ( !chip[0].Write( reg.normal, (uint8_t)val ) ) {
+				handler->WriteReg( reg.normal, (uint8_t)val );
+				CacheWrite( reg.normal, (uint8_t)val );
 			}
 			break;
 		case MODE_DUALOPL2:
 			//Not a 0x??8 port, then write to a specific port
 			if ( !(port & 0x8) ) {
-				Bit8u index = (Bit8u)(( port & 2 ) >> 1);
-				DualWrite( index, reg.dual[index], (Bit8u)val );
+				uint8_t index = (uint8_t)(( port & 2 ) >> 1);
+				DualWrite( index, reg.dual[index], (uint8_t)val );
 			} else {
 				//Write to both ports
-				DualWrite( 0, reg.dual[0], (Bit8u)val );
-				DualWrite( 1, reg.dual[1], (Bit8u)val );
+				DualWrite( 0, reg.dual[0], (uint8_t)val );
+				DualWrite( 1, reg.dual[1], (uint8_t)val );
 			}
 			break;
 		}
@@ -845,7 +844,7 @@ void Module::PortWrite( Bitu port, Bitu val, Bitu iolen ) {
 		//Make sure to clip them in the right range
 		switch ( mode ) {
 		case MODE_OPL2:
-			reg.normal = handler->WriteAddr( (Bit32u)port, (Bit8u)val ) & 0xff;
+			reg.normal = handler->WriteAddr( (uint32_t)port, (uint8_t)val ) & 0xff;
 			break;
 		case MODE_OPL3GOLD:
 			if ( port == 0x38a ) {
@@ -862,12 +861,12 @@ void Module::PortWrite( Bitu port, Bitu val, Bitu iolen ) {
 			}
 			//Fall-through if not handled by control chip
 		case MODE_OPL3:
-			reg.normal = handler->WriteAddr( (Bit32u)port, (Bit8u)val ) & 0x1ff;
+			reg.normal = handler->WriteAddr( (uint32_t)port, (uint8_t)val ) & 0x1ff;
 			break;
 		case MODE_DUALOPL2:
 			//Not a 0x?88 port, when write to a specific side
 			if ( !(port & 0x8) ) {
-				Bit8u index = ( port & 2 ) >> 1;
+				uint8_t index = ( port & 2 ) >> 1;
 				reg.dual[index] = val & 0xff;
 			} else {
 				reg.dual[0] = val & 0xff;
@@ -881,6 +880,12 @@ void Module::PortWrite( Bitu port, Bitu val, Bitu iolen ) {
 
 Bitu Module::PortRead( Bitu port, Bitu iolen ) {
     (void)iolen;//UNUSED
+	//roughly half a micro (as we already do 1 micro on each port read and some tests revealed it taking 1.5 micros to read an adlib port)
+	Bits delaycyc = (CPU_CycleMax/2048); 
+	if(GCC_UNLIKELY(delaycyc > CPU_Cycles)) delaycyc = CPU_Cycles;
+	CPU_Cycles -= delaycyc;
+	CPU_IODelayRemoved += delaycyc;
+
 	switch ( mode ) {
 	case MODE_OPL2:
 		//We allocated 4 ports, so just return -1 for the higher ones
@@ -947,7 +952,7 @@ static void OPL_CallBack(Bitu len) {
 		Bitu i;
 		for (i=0xb0;i<0xb9;i++) if (module->cache[i]&0x20||module->cache[i+0x100]&0x20) break;
 		if (i==0xb9) module->mixerChan->Enable(false);
-		else module->lastUsed = (Bit32u)PIC_Ticks;
+		else module->lastUsed = (uint32_t)PIC_Ticks;
 	}
 }
 
@@ -984,9 +989,9 @@ void SaveRad() {
 	b[w++] = 0x06;		//default speed and no description
 	//Write 18 instuments for all operators in the cache
 	for ( unsigned int i = 0; i < 18; i++ ) {
-		Bit8u* set = module->cache + ( i / 9 ) * 256;
+		uint8_t* set = module->cache + ( i / 9 ) * 256;
 		Bitu offset = ((i % 9) / 3) * 8 + (i % 3);
-		Bit8u* base = set + offset;
+		uint8_t* base = set + offset;
 		b[w++] = 1 + i;		//instrument number
 		b[w++] = base[0x23];
 		b[w++] = base[0x20];
@@ -1002,7 +1007,7 @@ void SaveRad() {
 	}
 	b[w++] = 0;		//instrument 0, no more instruments following
 	b[w++] = 1;		//1 pattern following
-	//Zero out the remaing part of the file a bit to make rad happy
+	//Zero out the remaining part of the file a bit to make rad happy
 	for ( unsigned int i = 0; i < 64; i++ ) {
 		b[w++] = 0;
 	}
@@ -1033,6 +1038,8 @@ void OPL_SaveRawEvent(bool pressed) {
 
 namespace Adlib {
 
+static std::string usedoplemu = "none";
+
 Module::Module( Section* configuration ) : Module_base(configuration) {
     Bitu sb_addr=0,sb_irq=0,sb_dma=0;
 //	DOSBoxMenu::item *item;
@@ -1101,6 +1108,7 @@ Module::Module( Section* configuration ) : Module_base(configuration) {
 	} else {
 		handler = new DBOPL::Handler();
 	}
+	usedoplemu = oplemu;
 	handler->Init( rate );
 	bool single = false;
 	switch ( oplmode ) {
@@ -1181,6 +1189,25 @@ OPL_Mode Module::oplmode=OPL_none;
 
 }	//Adlib Namespace
 
+std::string getoplmode() {
+	if (Adlib::Module::oplmode == NULL || Adlib::Module::oplmode == OPL_none) return "None";
+    else if (Adlib::Module::oplmode == OPL_cms) return "CMS";
+    else if (Adlib::Module::oplmode == OPL_opl2) return "OPL2";
+    else if (Adlib::Module::oplmode == OPL_dualopl2) return "Dual OPL2";
+    else if (Adlib::Module::oplmode == OPL_opl3) return "OPL3";
+    else if (Adlib::Module::oplmode == OPL_opl3gold) return "OPL3 Gold";
+    else if (Adlib::Module::oplmode == OPL_hardware) return "Hardware";
+    else if (Adlib::Module::oplmode == OPL_hardwareCMS) return "Hardware CMS";
+    else return "Unknown";
+}
+
+std::string getoplemu() {
+    std::string emu=Adlib::usedoplemu;
+    if (emu=="mame") emu="MAME";
+    else if (emu=="opl2board") emu="OPL2 board";
+    else emu[0]=toupper(emu[0]);
+    return emu;
+}
 
 void OPL_Init(Section* sec,OPL_Mode oplmode) {
 	Adlib::Module::oplmode = oplmode;
