@@ -108,7 +108,7 @@ template <enum IO_Type_t iotype> static unsigned int IO_Gen_Callout_Read(Bitu &r
         IO_CalloutObject &obj = vec[scan++];
         if (!obj.isInstalled()) continue;
         if (obj.m_r_handler == NULL) continue;
-        if (!obj.MatchPort((Bit16u)port)) continue;
+        if (!obj.MatchPort((uint16_t)port)) continue;
 
         t_f = obj.m_r_handler(obj,port,iolen);
         if (t_f != NULL) {
@@ -140,7 +140,7 @@ template <enum IO_Type_t iotype> static unsigned int IO_Gen_Callout_Write(IO_Wri
         IO_CalloutObject &obj = vec[scan++];
         if (!obj.isInstalled()) continue;
         if (obj.m_w_handler == NULL) continue;
-        if (!obj.MatchPort((Bit16u)port)) continue;
+        if (!obj.MatchPort((uint16_t)port)) continue;
 
         t_f = obj.m_w_handler(obj,port,iolen);
         if (t_f != NULL) {
@@ -424,7 +424,7 @@ inline void IO_USEC_write_delay(const unsigned int szidx) {
 }
 
 #ifdef ENABLE_PORTLOG
-static Bit8u crtc_index = 0;
+static uint8_t crtc_index = 0;
 const char* const len_type[] = {" 8","16","32"};
 void log_io(Bitu width, bool write, Bitu port, Bitu val) {
 	switch(width) {
@@ -438,8 +438,8 @@ void log_io(Bitu width, bool write, Bitu port, Bitu val) {
 	if (write) {
 		// skip the video cursor position spam
 		if (port==0x3d4) {
-			if (width==0) crtc_index = (Bit8u)val;
-			else if(width==1) crtc_index = (Bit8u)(val>>8);
+			if (width==0) crtc_index = (uint8_t)val;
+			else if(width==1) crtc_index = (uint8_t)(val>>8);
 		}
 		if (crtc_index==0xe || crtc_index==0xf) {
 			if((width==0 && (port==0x3d4 || port==0x3d5))||(width==1 && port==0x3d4))
@@ -489,7 +489,7 @@ void log_io(Bitu width, bool write, Bitu port, Bitu val) {
 #endif
 
 
-void IO_WriteB(Bitu port,Bit8u val) {
+void IO_WriteB(Bitu port,uint8_t val) {
 	log_io(0, true, port, val);
 	if (GCC_UNLIKELY(GETFLAG(VM) && (CPU_IO_Exception(port,1)))) {
 		CPU_ForceV86FakeIO_Out(port,val,1);
@@ -500,7 +500,7 @@ void IO_WriteB(Bitu port,Bit8u val) {
 	}
 }
 
-void IO_WriteW(Bitu port,Bit16u val) {
+void IO_WriteW(Bitu port,uint16_t val) {
 	log_io(1, true, port, val);
 	if (GCC_UNLIKELY(GETFLAG(VM) && (CPU_IO_Exception(port,2)))) {
 		CPU_ForceV86FakeIO_Out(port,val,2);
@@ -511,7 +511,7 @@ void IO_WriteW(Bitu port,Bit16u val) {
 	}
 }
 
-void IO_WriteD(Bitu port,Bit32u val) {
+void IO_WriteD(Bitu port,uint32_t val) {
 	log_io(2, true, port, val);
 	if (GCC_UNLIKELY(GETFLAG(VM) && (CPU_IO_Exception(port,4)))) {
 		CPU_ForceV86FakeIO_Out(port,val,4);
@@ -522,40 +522,40 @@ void IO_WriteD(Bitu port,Bit32u val) {
 	}
 }
 
-Bit8u IO_ReadB(Bitu port) {
-	Bit8u retval;
+uint8_t IO_ReadB(Bitu port) {
+	uint8_t retval;
 	if (GCC_UNLIKELY(GETFLAG(VM) && (CPU_IO_Exception(port,1)))) {
-		return (Bit8u)CPU_ForceV86FakeIO_In(port,1);
+		return (uint8_t)CPU_ForceV86FakeIO_In(port,1);
 	}
 	else {
 		IO_USEC_read_delay(0);
-		retval = (Bit8u)io_readhandlers[0][port](port,1);
+		retval = (uint8_t)io_readhandlers[0][port](port,1);
 	}
 	log_io(0, false, port, retval);
 	return retval;
 }
 
-Bit16u IO_ReadW(Bitu port) {
-	Bit16u retval;
+uint16_t IO_ReadW(Bitu port) {
+	uint16_t retval;
 	if (GCC_UNLIKELY(GETFLAG(VM) && (CPU_IO_Exception(port,2)))) {
-		return (Bit16u)CPU_ForceV86FakeIO_In(port,2);
+		return (uint16_t)CPU_ForceV86FakeIO_In(port,2);
 	}
 	else {
 		IO_USEC_read_delay(1);
-		retval = (Bit16u)io_readhandlers[1][port](port,2);
+		retval = (uint16_t)io_readhandlers[1][port](port,2);
 	}
 	log_io(1, false, port, retval);
 	return retval;
 }
 
-Bit32u IO_ReadD(Bitu port) {
-	Bit32u retval;
+uint32_t IO_ReadD(Bitu port) {
+	uint32_t retval;
 	if (GCC_UNLIKELY(GETFLAG(VM) && (CPU_IO_Exception(port,4)))) {
-		return (Bit32u)CPU_ForceV86FakeIO_In(port,4);
+		return (uint32_t)CPU_ForceV86FakeIO_In(port,4);
 	}
 	else {
 		IO_USEC_read_delay(2);
-		retval = (Bit32u)io_readhandlers[2][port](port,4);
+		retval = (uint32_t)io_readhandlers[2][port](port,4);
 	}
 	log_io(2, false, port, retval);
 	return retval;
@@ -645,7 +645,7 @@ void IO_CalloutObject::Install(Bitu port,Bitu portmask/*IOMASK_ISA_10BIT, etc.*/
             range_mask = 0;
             test = portmask ^ 0xFFFFU;
             while ((test & m) == m) {
-                range_mask = (Bit16u)m;
+                range_mask = (uint16_t)m;
                 m = (m << 1) + 1;
             }
 
@@ -663,7 +663,7 @@ void IO_CalloutObject::Install(Bitu port,Bitu portmask/*IOMASK_ISA_10BIT, etc.*/
             alias_mask = range_mask;
             test = portmask + range_mask; /* will break if portmask & range_mask != 0 */
             while ((test & m) == m) {
-                alias_mask = (Bit16u)m;
+                alias_mask = (uint16_t)m;
                 m = (m << 1) + 1;
             }
 
@@ -708,7 +708,7 @@ void IO_CalloutObject::Install(Bitu port,Bitu portmask/*IOMASK_ISA_10BIT, etc.*/
 		m_port=port;
 		m_mask=0; /* not used */
 		m_range=0; /* not used */
-        io_mask=(Bit16u)portmask;
+        io_mask=(uint16_t)portmask;
         m_r_handler=r_handler;
         m_w_handler=w_handler;
 
