@@ -50,13 +50,13 @@ struct ipxnetaddr {
 	Uint8 netnode[6];
 } localIpxAddr;
 
-Bit32u udpPort;
+uint32_t udpPort;
 bool isIpxServer;
 bool isIpxConnected;
 IPaddress ipxServConnIp;			// IPAddress for client connection to server
 UDPsocket ipxClientSocket;
 int UDPChannel;						// Channel used by UDP connection
-Bit8u recvBuffer[IPXBUFFERSIZE];	// Incoming packet buffer
+uint8_t recvBuffer[IPXBUFFERSIZE];	// Incoming packet buffer
 
 static RealPt ipx_callback;
 
@@ -64,10 +64,10 @@ SDLNet_SocketSet clientSocketSet;
 
 packetBuffer incomingPacket;
 
-static Bit16u socketCount;
-static Bit16u opensockets[SOCKTABLESIZE]; 
+static uint16_t socketCount;
+static uint16_t opensockets[SOCKTABLESIZE]; 
 
-static Bit16u swapByte(Bit16u sockNum) {
+static uint16_t swapByte(uint16_t sockNum) {
 	return ((sockNum>> 8) | (sockNum << 8));
 }
 
@@ -90,7 +90,7 @@ Bitu ECBAmount = 0;
 #endif
 
 
-ECBClass::ECBClass(Bit16u segment, Bit16u offset) {
+ECBClass::ECBClass(uint16_t segment, uint16_t offset) {
 	ECBAddr = RealMake(segment, offset);
 	databuffer = 0;
 	
@@ -126,23 +126,23 @@ ECBClass::ECBClass(Bit16u segment, Bit16u offset) {
 	iuflag = getInUseFlag();
 	mysocket = getSocket();
 }
-void ECBClass::writeDataBuffer(Bit8u* buffer, Bit16u length) {
+void ECBClass::writeDataBuffer(uint8_t* buffer, uint16_t length) {
 	if(databuffer!=0) delete [] databuffer;
-	databuffer = new Bit8u[length];
+	databuffer = new uint8_t[length];
 	memcpy(databuffer,buffer,length);
 	buflen=length;
 
 }
 bool ECBClass::writeData() {
 	Bitu length=buflen;
-	Bit8u* buffer = databuffer;
+	uint8_t* buffer = databuffer;
 	fragmentDescriptor tmpFrag;
 	setInUseFlag(USEFLAG_AVAILABLE);
-	Bit16u fragCount = getFragCount(); 
+	uint16_t fragCount = getFragCount(); 
 	Bitu bufoffset = 0;
-	for(Bit16u i = 0;i < fragCount;i++) {
+	for(uint16_t i = 0;i < fragCount;i++) {
 		getFragDesc(i,&tmpFrag);
-		for(Bit16u t = 0;t < tmpFrag.size;t++) {
+		for(uint16_t t = 0;t < tmpFrag.size;t++) {
 			real_writeb(tmpFrag.segment, tmpFrag.offset + t, buffer[bufoffset]);
 			bufoffset++;
 			if(bufoffset >= length) {
@@ -159,29 +159,29 @@ bool ECBClass::writeData() {
 	return false;
 }
 
-Bit16u ECBClass::getSocket(void) {
+uint16_t ECBClass::getSocket(void) {
 	return swapByte(real_readw(RealSeg(ECBAddr), RealOff(ECBAddr) + 0xa));
 }
 
-Bit8u ECBClass::getInUseFlag(void) {
+uint8_t ECBClass::getInUseFlag(void) {
 	return real_readb(RealSeg(ECBAddr), RealOff(ECBAddr) + 0x8);
 }
 
-void ECBClass::setInUseFlag(Bit8u flagval) {
+void ECBClass::setInUseFlag(uint8_t flagval) {
 	iuflag = flagval;
 	real_writeb(RealSeg(ECBAddr), RealOff(ECBAddr) + 0x8, flagval);
 }
 
-void ECBClass::setCompletionFlag(Bit8u flagval) {
+void ECBClass::setCompletionFlag(uint8_t flagval) {
 	real_writeb(RealSeg(ECBAddr), RealOff(ECBAddr) + 0x9, flagval);
 }
 
-Bit16u ECBClass::getFragCount(void) {
+uint16_t ECBClass::getFragCount(void) {
 	return real_readw(RealSeg(ECBAddr), RealOff(ECBAddr) + 34);
 }
 
-void ECBClass::getFragDesc(Bit16u descNum, fragmentDescriptor *fragDesc) {
-	Bit16u memoff = RealOff(ECBAddr) + 30 + ((descNum+1) * 6);
+void ECBClass::getFragDesc(uint16_t descNum, fragmentDescriptor *fragDesc) {
+	uint16_t memoff = RealOff(ECBAddr) + 30 + ((descNum+1) * 6);
 	fragDesc->offset = real_readw(RealSeg(ECBAddr), memoff);
 	memoff += 2;
 	fragDesc->segment = real_readw(RealSeg(ECBAddr), memoff);
@@ -197,7 +197,7 @@ RealPt ECBClass::getESRAddr(void) {
 }
 
 void ECBClass::NotifyESR(void) {
-	Bit32u ESRval = real_readd(RealSeg(ECBAddr), RealOff(ECBAddr)+4);
+	uint32_t ESRval = real_readd(RealSeg(ECBAddr), RealOff(ECBAddr)+4);
 	if(ESRval || databuffer) { // databuffer: write data at realmode/v86 time
 		// LOG_IPX("ECB: SN%7d to be notified.", SerialNumber);
 		// take the ECB out of the current list
@@ -230,13 +230,13 @@ void ECBClass::NotifyESR(void) {
 	else delete this;
 }
 
-void ECBClass::setImmAddress(Bit8u *immAddr) {
-	for(Bit8u i=0;i<6;i++)
+void ECBClass::setImmAddress(uint8_t *immAddr) {
+	for(uint8_t i=0;i<6;i++)
 		real_writeb(RealSeg(ECBAddr), RealOff(ECBAddr)+28+i, immAddr[i]);
 }
 
-void ECBClass::getImmAddress(Bit8u* immAddr) {
-	for(Bit8u i=0;i<6;i++)
+void ECBClass::getImmAddress(uint8_t* immAddr) {
+	for(uint8_t i=0;i<6;i++)
 		immAddr[i] = real_readb(RealSeg(ECBAddr), RealOff(ECBAddr)+28+i);
 }
 
@@ -263,7 +263,7 @@ ECBClass::~ECBClass() {
 
 
 
-static bool sockInUse(Bit16u sockNum) {
+static bool sockInUse(uint16_t sockNum) {
 	for(Bitu i=0;i<socketCount;i++) {
 		if (opensockets[i] == sockNum) return true;
 	}
@@ -271,7 +271,7 @@ static bool sockInUse(Bit16u sockNum) {
 }
 
 static void OpenSocket(void) {
-	Bit16u sockNum, sockAlloc;
+	uint16_t sockNum, sockAlloc;
 	sockNum = swapByte(reg_dx);
 
 	if(socketCount >= SOCKTABLESIZE) {
@@ -304,7 +304,7 @@ static void OpenSocket(void) {
 }
 
 static void CloseSocket(void) {
-	Bit16u sockNum, i;
+	uint16_t sockNum, i;
 	ECBClass* tmpECB = ECBList;
 	ECBClass* tmp2ECB = ECBList;
 
@@ -381,7 +381,7 @@ static void handleIpxRequest(void) {
 						// es:si
 						// Currently no support for multiple networks
 
-			for(Bit8u i = 0; i < 6; i++) 
+			for(uint8_t i = 0; i < 6; i++) 
 				real_writeb(SegValue(es),reg_di+i,real_readb(SegValue(es),reg_si+i+4));
 
 			reg_cx=1;		// time ticks expected
@@ -464,8 +464,8 @@ static void handleIpxRequest(void) {
 				localIpxAddr.netnode[3], localIpxAddr.netnode[2],
 				localIpxAddr.netnode[1], localIpxAddr.netnode[0]);
 
-			Bit8u * addrptr = (Bit8u *)&localIpxAddr;
-			for(Bit16u i=0;i<10;i++)
+			uint8_t * addrptr = (uint8_t *)&localIpxAddr;
+			for(uint16_t i=0;i<10;i++)
 				real_writeb(SegValue(es),reg_si+i,addrptr[i]);
 			break;
 		}
@@ -563,11 +563,11 @@ static void pingSend(void) {
 	}
 }
 
-static void receivePacket(Bit8u *buffer, Bit16s bufSize) {
+static void receivePacket(uint8_t *buffer, int16_t bufSize) {
 	ECBClass *useECB;
 	ECBClass *nextECB;
-	Bit16u *bufword = (Bit16u *)buffer;
-	Bit16u useSocket = swapByte(bufword[8]);
+	uint16_t *bufword = (uint16_t *)buffer;
+	uint16_t useSocket = swapByte(bufword[8]);
 	IPXHeader * tmpHeader;
 	tmpHeader = (IPXHeader *)buffer;
 
@@ -589,7 +589,7 @@ static void receivePacket(Bit8u *buffer, Bit16s bufSize) {
 	{
 		nextECB = useECB->nextECB;
 		if(useECB->iuflag == USEFLAG_LISTENING && useECB->mysocket == useSocket) {
-			useECB->writeDataBuffer(buffer, (Bit16u)bufSize);
+			useECB->writeDataBuffer(buffer, (uint16_t)bufSize);
 			useECB->NotifyESR();
 			return;
 		}
@@ -621,11 +621,11 @@ void DisconnectFromServer(bool unexpected) {
 }
 
 static void sendPacket(ECBClass* sendecb) {
-	Bit8u outbuffer[IPXBUFFERSIZE];
+	uint8_t outbuffer[IPXBUFFERSIZE];
 	fragmentDescriptor tmpFrag; 
-	Bit16u i, fragCount,t;
-	Bit16s packetsize;
-	Bit16u *wordptr;
+	uint16_t i, fragCount,t;
+	int16_t packetsize;
+	uint16_t *wordptr;
 	Bits result;
 	UDPpacket outPacket;
 		
@@ -637,16 +637,16 @@ static void sendPacket(ECBClass* sendecb) {
 		if(i==0) {
 			// Fragment containing IPX header
 			// Must put source address into header
-			Bit8u * addrptr;
+			uint8_t * addrptr;
 			
 			// source netnum
-			addrptr = (Bit8u *)&localIpxAddr.netnum;
-			for(Bit16u m=0;m<4;m++) {
+			addrptr = (uint8_t *)&localIpxAddr.netnum;
+			for(uint16_t m=0;m<4;m++) {
 				real_writeb(tmpFrag.segment,tmpFrag.offset+m+18,addrptr[m]);
 			}
 			// source node number
-			addrptr = (Bit8u *)&localIpxAddr.netnode;
-			for(Bit16u m=0;m<6;m++) {
+			addrptr = (uint8_t *)&localIpxAddr.netnode;
+			for(uint16_t m=0;m<6;m++) {
 				real_writeb(tmpFrag.segment,tmpFrag.offset+m+22,addrptr[m]);
 			}
 			// Source socket
@@ -669,19 +669,19 @@ static void sendPacket(ECBClass* sendecb) {
 	}
 	
 	// Add length and source socket to IPX header
-	wordptr = (Bit16u *)&outbuffer[0];
+	wordptr = (uint16_t *)&outbuffer[0];
 	// Blank CRC
 	//wordptr[0] = 0xffff;
 	// Length
-	wordptr[1] = swapByte((Bit16u)packetsize);
+	wordptr[1] = swapByte((uint16_t)packetsize);
 	// Source socket
 	//wordptr[14] = swapByte(sendecb->getSocket());
 	
 	sendecb->getFragDesc(0,&tmpFrag);
-	real_writew(tmpFrag.segment,tmpFrag.offset+2, swapByte((Bit16u)packetsize));
+	real_writew(tmpFrag.segment,tmpFrag.offset+2, swapByte((uint16_t)packetsize));
 	
 
-	Bit8u immedAddr[6];
+	uint8_t immedAddr[6];
 	sendecb->getImmAddress(immedAddr);
 	// filter out broadcasts and local loopbacks
 	// Real implementation uses the ImmedAddr to check wether this is a broadcast
@@ -689,13 +689,13 @@ static void sendPacket(ECBClass* sendecb) {
 	bool islocalbroadcast=true;
 	bool isloopback=true;
 
-	Bit8u * addrptr;
+	uint8_t * addrptr;
 			
-	addrptr = (Bit8u *)&localIpxAddr.netnum;
+	addrptr = (uint8_t *)&localIpxAddr.netnum;
 	for(Bitu m=0;m<4;m++) {
 		if(addrptr[m]!=outbuffer[m+0x6])isloopback=false;
 	}
-	addrptr = (Bit8u *)&localIpxAddr.netnode;
+	addrptr = (uint8_t *)&localIpxAddr.netnode;
 	for(Bitu m=0;m<6;m++) {
 		if(addrptr[m]!=outbuffer[m+0xa])isloopback=false;
 		if(immedAddr[m]!=0xff) islocalbroadcast=false;
@@ -752,7 +752,7 @@ bool ConnectToServer(char const *strAddr) {
 	int numsent;
 	UDPpacket regPacket;
 	IPXHeader regHeader;
-	if(!SDLNet_ResolveHost(&ipxServConnIp, strAddr, (Bit16u)udpPort)) {
+	if(!SDLNet_ResolveHost(&ipxServConnIp, strAddr, (uint16_t)udpPort)) {
 
 		// Generate the MAC address.  This is made by zeroing out the first two
 		// octets and then using the actual IP address for the last 4 octets.
@@ -796,7 +796,7 @@ bool ConnectToServer(char const *strAddr) {
 				// Wait for return packet from server.
 				// This will contain our IPX address and port num
 				Bits result;
-				Bit32u ticks, elapsed;
+				uint32_t ticks, elapsed;
 				ticks = GetTicks();
 
 				while(true) {
@@ -855,9 +855,9 @@ public:
 		// Help on connect command
 		if(strcasecmp("connect", helpStr) == 0) {
 			WriteOut("IPXNET CONNECT opens a connection to an IPX tunneling server running on another\n");
-			WriteOut("DOSBox session.  The \"address\" parameter specifies the IP address or host name\n");
-			WriteOut("of the server computer.  One can also specify the UDP port to use.  By default\n");
-			WriteOut("IPXNET uses port 213, the assigned IANA port for IPX tunneling, for its\nconnection.\n\n");
+			WriteOut("DOSBox-X session.  The \"address\" parameter specifies the IP address or the host\n");
+			WriteOut("name of the server computer.  One can also specify the UDP port to use.\n");
+			WriteOut("By default IPXNET uses port 213, the assigned IANA port for IPX tunneling, for\nits connection.\n\n");
 			WriteOut("The syntax for IPXNET CONNECT is:\n\n");
 			WriteOut("IPXNET CONNECT address <port>\n\n");
 			return;
@@ -871,17 +871,17 @@ public:
 		}
 		// Help on the startserver command
 		if(strcasecmp("startserver", helpStr) == 0) {
-			WriteOut("IPXNET STARTSERVER starts and IPX tunneling server on this DOSBox session.  By\n");
-			WriteOut("default, the server will accept connections on UDP port 213, though this can be\n");
-			WriteOut("changed.  Once the server is started, DOSBox will automatically start a client\n");
-			WriteOut("connection to the IPX tunneling server.\n\n");
+			WriteOut("IPXNET STARTSERVER starts and IPX tunneling server on this DOSBox-X session.\n");
+			WriteOut("By default, the server will accept connections on UDP port 213, though this\n");
+			WriteOut("can be changed.  Once the server is started, DOSBox-X will automatically\n");
+			WriteOut("start a client connection to the IPX tunneling server.\n\n");
 			WriteOut("The syntax for IPXNET STARTSERVER is:\n\n");
 			WriteOut("IPXNET STARTSERVER <port>\n\n");
 			return;
 		}
 		// Help on the stop server command
 		if(strcasecmp("stopserver", helpStr) == 0) {
-			WriteOut("IPXNET STOPSERVER stops the IPX tunneling server running on this DosBox\nsession.");
+			WriteOut("IPXNET STOPSERVER stops the IPX tunneling server running on this DOSBox-X\nsession.");
 			WriteOut("  Care should be taken to ensure that all other connections have\nterminated ");
 			WriteOut("as well since stopping the server may cause lockups on other\nmachines still using ");
 			WriteOut("the IPX tunneling server.\n\n");
@@ -900,9 +900,9 @@ public:
 		}
 		// Help on the status command
 		if(strcasecmp("status", helpStr) == 0) {
-			WriteOut("IPXNET STATUS reports the current state of this DOSBox's sessions IPX tunneling\n");
-			WriteOut("network.  For a list of the computers connected to the network use the IPXNET \n");
-			WriteOut("PING command.\n\n");
+			WriteOut("IPXNET STATUS reports the current state of this DOSBox-X's sessions IPX\n");
+			WriteOut("tunneling network.  For a list of the computers connected to the network use\n");
+			WriteOut("the IPXNET PING command.\n\n");
 			WriteOut("The syntax for IPXNET STATUS is:\n\n");
 			WriteOut("IPXNET STATUS\n\n");
 			return;
@@ -911,7 +911,7 @@ public:
 
 	void Run(void)
 	{
-		WriteOut("IPX Tunneling utility for DOSBox\n\n");
+		WriteOut("IPX Tunneling utility for DOSBox-X\n\n");
 		if(!cmd->GetCount()) {
 			WriteOut("The syntax of this command is:\n\n");
 			WriteOut("IPXNET [ CONNECT | DISCONNECT | STARTSERVER | STOPSERVER | PING | HELP |\n         STATUS ]\n\n");
@@ -945,7 +945,7 @@ public:
 					} else {
 						udpPort = (unsigned int)strtol(temp_line.c_str(), NULL, 10);
 					}
-					startsuccess = IPX_StartServer((Bit16u)udpPort);
+					startsuccess = IPX_StartServer((uint16_t)udpPort);
 					if(startsuccess) {
 						WriteOut("IPX Tunneling Server started\n");
 						isIpxServer = true;
@@ -961,7 +961,7 @@ public:
 			}
 			if(strcasecmp("stopserver", temp_line.c_str()) == 0) {
 				if(!isIpxServer) {
-					WriteOut("IPX Tunneling Server not running in this DOSBox session.\n");
+					WriteOut("IPX Tunneling Server not running in this DOSBox-X session.\n");
 				} else {
 					isIpxServer = false;
 					DisconnectFromServer(false);
@@ -1032,7 +1032,7 @@ public:
 			}
 
 			if(strcasecmp("ping", temp_line.c_str()) == 0) {
-				Bit32u ticks;
+				uint32_t ticks;
 				IPXHeader pingHead;
 
 				if(!incomingPacket.connected) {
@@ -1073,7 +1073,7 @@ Bitu IPX_ESRHandler(void) {
 			CALLBACK_RunRealFar(RealSeg(ESRList->getESRAddr()),
 								RealOff(ESRList->getESRAddr()));
 		}
-		delete ESRList;
+		delete ESRList; //Destructor updates this pointer to the next value or NULL
 	}	// while
 
 	IO_WriteB(0xa0,0x63);	//EOI11
@@ -1085,7 +1085,7 @@ Bitu IPX_ESRHandler(void) {
 void VFILE_Remove(const char *name);
 
 // FIXME: VS2015 doesn't seem to like class IPX::dospage
-static Bit16u dospage;
+static uint16_t dospage;
 
 class IPX: public Module_base {
 private:
@@ -1122,7 +1122,7 @@ public:
 		callback_ipxint.Set_RealVec(0x7a);
 
 		callback_esr.Allocate(&IPX_ESRHandler,"IPX_ESR");
-		Bit16u call_ipxesr1 = callback_esr.Get_callback();
+		uint16_t call_ipxesr1 = callback_esr.Get_callback();
 
 		if(!dospage) dospage = DOS_GetMemory(2,"IPX dospage"); // can not be freed yet
 
@@ -1131,29 +1131,29 @@ public:
 		LOG_IPX("ESR callback address: %x, HandlerID %d", phyDospage,call_ipxesr1);
 
 		//save registers
-		phys_writeb(phyDospage+0,(Bit8u)0xFA);    // CLI
-		phys_writeb(phyDospage+1,(Bit8u)0x60);    // PUSHA
-		phys_writeb(phyDospage+2,(Bit8u)0x1E);    // PUSH DS
-		phys_writeb(phyDospage+3,(Bit8u)0x06);    // PUSH ES
-		phys_writew(phyDospage+4,(Bit16u)0xA00F); // PUSH FS
-		phys_writew(phyDospage+6,(Bit16u)0xA80F); // PUSH GS
+		phys_writeb(phyDospage+0,(uint8_t)0xFA);    // CLI
+		phys_writeb(phyDospage+1,(uint8_t)0x60);    // PUSHA
+		phys_writeb(phyDospage+2,(uint8_t)0x1E);    // PUSH DS
+		phys_writeb(phyDospage+3,(uint8_t)0x06);    // PUSH ES
+		phys_writew(phyDospage+4,(uint16_t)0xA00F); // PUSH FS
+		phys_writew(phyDospage+6,(uint16_t)0xA80F); // PUSH GS
  
 		// callback
-		phys_writeb(phyDospage+8,(Bit8u)0xFE);  // GRP 4
-		phys_writeb(phyDospage+9,(Bit8u)0x38);  // Extra Callback instruction
+		phys_writeb(phyDospage+8,(uint8_t)0xFE);  // GRP 4
+		phys_writeb(phyDospage+9,(uint8_t)0x38);  // Extra Callback instruction
 		phys_writew(phyDospage+10,call_ipxesr1);        // Callback identifier
  
 		// register recreation
-		phys_writew(phyDospage+12,(Bit16u)0xA90F); // POP GS
-		phys_writew(phyDospage+14,(Bit16u)0xA10F); // POP FS
-		phys_writeb(phyDospage+16,(Bit8u)0x07);    // POP ES
-		phys_writeb(phyDospage+17,(Bit8u)0x1F);    // POP DS
-		phys_writeb(phyDospage+18,(Bit8u)0x61);    // POPA
-		phys_writeb(phyDospage+19,(Bit8u)0xCF);    // IRET: restores flags, CS, IP
+		phys_writew(phyDospage+12,(uint16_t)0xA90F); // POP GS
+		phys_writew(phyDospage+14,(uint16_t)0xA10F); // POP FS
+		phys_writeb(phyDospage+16,(uint8_t)0x07);    // POP ES
+		phys_writeb(phyDospage+17,(uint8_t)0x1F);    // POP DS
+		phys_writeb(phyDospage+18,(uint8_t)0x61);    // POPA
+		phys_writeb(phyDospage+19,(uint8_t)0xCF);    // IRET: restores flags, CS, IP
  
 		// IPX version 2.12
-		//phys_writeb(phyDospage+27,(Bit8u)0x2);
-		//phys_writeb(phyDospage+28,(Bit8u)0x12);
+		//phys_writeb(phyDospage+27,(uint8_t)0x2);
+		//phys_writeb(phyDospage+28,(uint8_t)0x12);
 		//IPXVERpointer = RealMake(dospage,27);
 
 		RealPt ESRRoutineBase = RealMake(dospage, 0);
@@ -1184,8 +1184,8 @@ public:
 		IO_WriteB(0xa1,IO_ReadB(0xa1)|8);	// disable IRQ11
    
 		PhysPt phyDospage = PhysMake(dospage,0);
-		for(Bit8u i = 0;i < 32;i++)
-			phys_writeb(phyDospage+i,(Bit8u)0x00);
+		for(uint8_t i = 0;i < 32;i++)
+			phys_writeb(phyDospage+i,(uint8_t)0x00);
 
 		VFILE_Remove("IPXNET.COM");
 	}
