@@ -34,24 +34,24 @@
 
 
 static fltype recipsamp;	// inverse of sampling rate
-static Bit16s wavtable[WAVEPREC*3];	// wave form table
+static int16_t wavtable[WAVEPREC*3];	// wave form table
 
 // vibrato/tremolo tables
-static Bit32s vib_table[VIBTAB_SIZE];
-static Bit32s trem_table[TREMTAB_SIZE*2];
+static int32_t vib_table[VIBTAB_SIZE];
+static int32_t trem_table[TREMTAB_SIZE*2];
 
-static Bit32s vibval_const[BLOCKBUF_SIZE];
-static Bit32s tremval_const[BLOCKBUF_SIZE];
+static int32_t vibval_const[BLOCKBUF_SIZE];
+static int32_t tremval_const[BLOCKBUF_SIZE];
 
 // vibrato value tables (used per-operator)
-static Bit32s vibval_var1[BLOCKBUF_SIZE];
-static Bit32s vibval_var2[BLOCKBUF_SIZE];
-//static Bit32s vibval_var3[BLOCKBUF_SIZE];
-//static Bit32s vibval_var4[BLOCKBUF_SIZE];
+static int32_t vibval_var1[BLOCKBUF_SIZE];
+static int32_t vibval_var2[BLOCKBUF_SIZE];
+//static int32_t vibval_var3[BLOCKBUF_SIZE];
+//static int32_t vibval_var4[BLOCKBUF_SIZE];
 
 // vibrato/trmolo value table pointers
-static Bit32s *vibval1, *vibval2, *vibval3, *vibval4;
-static Bit32s *tremval1, *tremval2, *tremval3, *tremval4;
+static int32_t *vibval1, *vibval2, *vibval3, *vibval4;
+static int32_t *tremval1, *tremval2, *tremval3, *tremval4;
 
 
 // key scale level lookup table
@@ -67,10 +67,10 @@ static const fltype frqmul_tab[16] = {
 static fltype frqmul[16];
 
 // key scale levels
-static Bit8u kslev[8][16];
+static uint8_t kslev[8][16];
 
 // map a channel number to the register offset of the modulator (=register base)
-static const Bit8u modulatorbase[9]	= {
+static const uint8_t modulatorbase[9]	= {
 	0,1,2,
 	8,9,10,
 	16,17,18
@@ -78,20 +78,20 @@ static const Bit8u modulatorbase[9]	= {
 
 // map a register base to a modulator operator number or operator number
 #if defined(OPLTYPE_IS_OPL3)
-static const Bit8u regbase2modop[44] = {
+static const uint8_t regbase2modop[44] = {
 	0,1,2,0,1,2,0,0,3,4,5,3,4,5,0,0,6,7,8,6,7,8,					// first set
 	18,19,20,18,19,20,0,0,21,22,23,21,22,23,0,0,24,25,26,24,25,26	// second set
 };
-static const Bit8u regbase2op[44] = {
+static const uint8_t regbase2op[44] = {
 	0,1,2,9,10,11,0,0,3,4,5,12,13,14,0,0,6,7,8,15,16,17,			// first set
 	18,19,20,27,28,29,0,0,21,22,23,30,31,32,0,0,24,25,26,33,34,35	// second set
 };
 #else
-static const Bit8u regbase2modop[22*2] = {
+static const uint8_t regbase2modop[22*2] = {
 	0,1,2,0,1,2,0,0,3,4,5,3,4,5,0,0,6,7,8,6,7,8,
 	0,1,2,0,1,2,0,0,3,4,5,3,4,5,0,0,6,7,8,6,7,8
 };
-static const Bit8u regbase2op[22*2] = {
+static const uint8_t regbase2op[22*2] = {
 	0,1,2,9,10,11,0,0,3,4,5,12,13,14,0,0,6,7,8,15,16,17,
 	0,1,2,9,10,11,0,0,3,4,5,12,13,14,0,0,6,7,8,15,16,17
 };
@@ -99,7 +99,7 @@ static const Bit8u regbase2op[22*2] = {
 
 
 // start of the waveform
-static Bit32u waveform[8] = {
+static uint32_t waveform[8] = {
 	WAVEPREC,
 	WAVEPREC>>1,
 	WAVEPREC,
@@ -111,7 +111,7 @@ static Bit32u waveform[8] = {
 };
 
 // length of the waveform as mask
-static Bit32u wavemask[8] = {
+static uint32_t wavemask[8] = {
 	WAVEPREC-1,
 	WAVEPREC-1,
 	(WAVEPREC>>1)-1,
@@ -123,7 +123,7 @@ static Bit32u wavemask[8] = {
 };
 
 // where the first entry resides
-static Bit32u wavestart[8] = {
+static uint32_t wavestart[8] = {
 	0,
 	WAVEPREC>>1,
 	0,
@@ -149,31 +149,31 @@ static fltype decrelconst[4] = {
 };
 
 
-void operator_advance(op_type* op_pt, Bit32s vib) {
+void operator_advance(op_type* op_pt, int32_t vib) {
 	op_pt->wfpos = op_pt->tcount;						// waveform position
 	
 	// advance waveform time
 	op_pt->tcount += op_pt->tinc;
-	op_pt->tcount += (Bit32u)((Bit32s)(op_pt->tinc)*vib)/FIXEDPT;
+	op_pt->tcount += (uint32_t)((int32_t)(op_pt->tinc)*vib)/FIXEDPT;
 
 	op_pt->generator_pos += generator_add;
 }
 
-void operator_advance_drums(op_type* op_pt1, Bit32s vib1, op_type* op_pt2, Bit32s vib2, op_type* op_pt3, Bit32s vib3) {
-	Bit32u c1 = op_pt1->tcount/FIXEDPT;
-	Bit32u c3 = op_pt3->tcount/FIXEDPT;
-	Bit32u phasebit = (((c1 & 0x88) ^ ((c1<<5) & 0x80)) | ((c3 ^ (c3<<2)) & 0x20)) ? 0x02 : 0x00;
+void operator_advance_drums(op_type* op_pt1, int32_t vib1, op_type* op_pt2, int32_t vib2, op_type* op_pt3, int32_t vib3) {
+	uint32_t c1 = op_pt1->tcount/FIXEDPT;
+	uint32_t c3 = op_pt3->tcount/FIXEDPT;
+	uint32_t phasebit = (((c1 & 0x88) ^ ((c1<<5) & 0x80)) | ((c3 ^ (c3<<2)) & 0x20)) ? 0x02 : 0x00;
 
-	Bit32u noisebit = rand()&1;
+	uint32_t noisebit = rand()&1;
 
-	Bit32u snare_phase_bit = (((Bitu)((op_pt1->tcount/FIXEDPT) / 0x100))&1);
+	uint32_t snare_phase_bit = (((Bitu)((op_pt1->tcount/FIXEDPT) / 0x100))&1);
 
 	//Hihat
-	Bit32u inttm = (phasebit<<8u) | (0x34u<<(phasebit ^ (noisebit<<1u)));
+	uint32_t inttm = (phasebit<<8u) | (0x34u<<(phasebit ^ (noisebit<<1u)));
 	op_pt1->wfpos = inttm*FIXEDPT;				// waveform position
 	// advance waveform time
 	op_pt1->tcount += op_pt1->tinc;
-	op_pt1->tcount += (Bit32u)((Bit32s)(op_pt1->tinc)*vib1)/FIXEDPT;
+	op_pt1->tcount += (uint32_t)((int32_t)(op_pt1->tinc)*vib1)/FIXEDPT;
 	op_pt1->generator_pos += generator_add;
 
 	//Snare
@@ -181,7 +181,7 @@ void operator_advance_drums(op_type* op_pt1, Bit32s vib1, op_type* op_pt2, Bit32
 	op_pt2->wfpos = inttm*FIXEDPT;				// waveform position
 	// advance waveform time
 	op_pt2->tcount += op_pt2->tinc;
-	op_pt2->tcount += (Bit32u)((Bit32s)(op_pt2->tinc)*vib2)/FIXEDPT;
+	op_pt2->tcount += (uint32_t)((int32_t)(op_pt2->tinc)*vib2)/FIXEDPT;
 	op_pt2->generator_pos += generator_add;
 
 	//Cymbal
@@ -189,24 +189,24 @@ void operator_advance_drums(op_type* op_pt1, Bit32s vib1, op_type* op_pt2, Bit32
 	op_pt3->wfpos = inttm*FIXEDPT;				// waveform position
 	// advance waveform time
 	op_pt3->tcount += op_pt3->tinc;
-	op_pt3->tcount += (Bit32u)((Bit32s)(op_pt3->tinc)*vib3)/FIXEDPT;
+	op_pt3->tcount += (uint32_t)((int32_t)(op_pt3->tinc)*vib3)/FIXEDPT;
 	op_pt3->generator_pos += generator_add;
 }
 
 
 // output level is sustained, mode changes only when operator is turned off (->release)
 // or when the keep-sustained bit is turned off (->sustain_nokeep)
-void operator_output(op_type* op_pt, Bit32s modulator, Bit32s trem) {
+void operator_output(op_type* op_pt, int32_t modulator, int32_t trem) {
 	if (op_pt->op_state != OF_TYPE_OFF) {
 		op_pt->lastcval = op_pt->cval;
-		Bit32u i = (Bit32u)(((Bit32s)op_pt->wfpos+modulator)/FIXEDPT);
+		uint32_t i = (uint32_t)(((int32_t)op_pt->wfpos+modulator)/FIXEDPT);
 
 		// wform: -16384 to 16383 (0x4000)
 		// trem :  32768 to 65535 (0x10000)
 		// step_amp: 0.0 to 1.0
 		// vol  : 1/2^14 to 1/2^29 (/0x4000; /1../0x8000)
 
-		op_pt->cval = (Bit32s)(op_pt->step_amp*op_pt->vol*op_pt->cur_wform[i&op_pt->cur_wmask]*trem/16.0);
+		op_pt->cval = (int32_t)(op_pt->step_amp*op_pt->vol*op_pt->cur_wform[i&op_pt->cur_wmask]*trem/16.0);
 	}
 }
 
@@ -218,8 +218,8 @@ void operator_off(op_type* /*op_pt*/) {
 // output level is sustained, mode changes only when operator is turned off (->release)
 // or when the keep-sustained bit is turned off (->sustain_nokeep)
 void operator_sustain(op_type* op_pt) {
-	Bit32u num_steps_add = op_pt->generator_pos/FIXEDPT;	// number of (standardized) samples
-	for (Bit32u ct=0; ct<num_steps_add; ct++) {
+	uint32_t num_steps_add = op_pt->generator_pos/FIXEDPT;	// number of (standardized) samples
+	for (uint32_t ct=0; ct<num_steps_add; ct++) {
 		op_pt->cur_env_step++;
 	}
 	op_pt->generator_pos -= num_steps_add*FIXEDPT;
@@ -233,8 +233,8 @@ void operator_release(op_type* op_pt) {
 		op_pt->amp *= op_pt->releasemul;
 	}
 
-	Bit32u num_steps_add = op_pt->generator_pos/FIXEDPT;	// number of (standardized) samples
-	for (Bit32u ct=0; ct<num_steps_add; ct++) {
+	uint32_t num_steps_add = op_pt->generator_pos/FIXEDPT;	// number of (standardized) samples
+	for (uint32_t ct=0; ct<num_steps_add; ct++) {
 		op_pt->cur_env_step++;						// sample counter
 		if ((op_pt->cur_env_step & op_pt->env_step_r)==0) {
 			if (op_pt->amp <= 0.00000001) {
@@ -258,8 +258,8 @@ void operator_decay(op_type* op_pt) {
 		op_pt->amp *= op_pt->decaymul;
 	}
 
-	Bit32u num_steps_add = op_pt->generator_pos/FIXEDPT;	// number of (standardized) samples
-	for (Bit32u ct=0; ct<num_steps_add; ct++) {
+	uint32_t num_steps_add = op_pt->generator_pos/FIXEDPT;	// number of (standardized) samples
+	for (uint32_t ct=0; ct<num_steps_add; ct++) {
 		op_pt->cur_env_step++;
 		if ((op_pt->cur_env_step & op_pt->env_step_d)==0) {
 			if (op_pt->amp <= op_pt->sustain_level) {
@@ -284,8 +284,8 @@ void operator_decay(op_type* op_pt) {
 void operator_attack(op_type* op_pt) {
 	op_pt->amp = ((op_pt->a3*op_pt->amp + op_pt->a2)*op_pt->amp + op_pt->a1)*op_pt->amp + op_pt->a0;
 
-	Bit32u num_steps_add = op_pt->generator_pos/FIXEDPT;		// number of (standardized) samples
-	for (Bit32u ct=0; ct<num_steps_add; ct++) {
+	uint32_t num_steps_add = op_pt->generator_pos/FIXEDPT;		// number of (standardized) samples
+	for (uint32_t ct=0; ct<num_steps_add; ct++) {
 		op_pt->cur_env_step++;	// next sample
 		if ((op_pt->cur_env_step & op_pt->env_step_a)==0) {		// check if next step already reached
 			if (op_pt->amp > 1.0) {
@@ -331,7 +331,7 @@ void change_attackrate(Bitu regbase, op_type* op_pt) {
 		op_pt->env_step_a = (1<<(steps<=12?12-steps:0))-1;
 
 		Bits step_num = (step_skip<=48)?(4-(step_skip&3)):0;
-		static Bit8u step_skip_mask[5] = {0xff, 0xfe, 0xee, 0xba, 0xaa}; 
+		static uint8_t step_skip_mask[5] = {0xff, 0xfe, 0xee, 0xba, 0xaa}; 
 		op_pt->env_step_skip_a = step_skip_mask[step_num];
 
 #if defined(OPLTYPE_IS_OPL3)
@@ -421,19 +421,19 @@ void change_vibrato(Bitu regbase, op_type* op_pt) {
 // change amount of self-feedback
 void change_feedback(Bitu chanbase, op_type* op_pt) {
 	Bits feedback = adlibreg[ARC_FEEDBACK+chanbase]&14;
-	if (feedback) op_pt->mfbi = (Bit32s)(pow(FL2,(fltype)((feedback>>1)+8)));
+	if (feedback) op_pt->mfbi = (int32_t)(pow(FL2,(fltype)((feedback>>1)+8)));
 	else op_pt->mfbi = 0;
 }
 
 void change_frequency(Bitu chanbase, Bitu regbase, op_type* op_pt) {
 	// frequency
-	Bit32u frn = ((((Bit32u)adlibreg[ARC_KON_BNUM+chanbase])&3)<<8) + (Bit32u)adlibreg[ARC_FREQ_NUM+chanbase];
+	uint32_t frn = ((((uint32_t)adlibreg[ARC_KON_BNUM+chanbase])&3)<<8) + (uint32_t)adlibreg[ARC_FREQ_NUM+chanbase];
 	// block number/octave
-	Bit32u oct = ((((Bit32u)adlibreg[ARC_KON_BNUM+chanbase])>>2)&7);
-	op_pt->freq_high = (Bit32s)((frn>>7)&7);
+	uint32_t oct = ((((uint32_t)adlibreg[ARC_KON_BNUM+chanbase])>>2)&7);
+	op_pt->freq_high = (int32_t)((frn>>7)&7);
 
 	// keysplit
-	Bit32u note_sel = (adlibreg[8]>>6)&1;
+	uint32_t note_sel = (adlibreg[8]>>6)&1;
 	op_pt->toff = ((frn>>9)&(note_sel^1)) | ((frn>>8)&note_sel);
 	op_pt->toff += (oct<<1);
 
@@ -441,7 +441,7 @@ void change_frequency(Bitu chanbase, Bitu regbase, op_type* op_pt) {
 	if (!(adlibreg[ARC_TVS_KSR_MUL+regbase]&0x10)) op_pt->toff >>= 2;
 
 	// 20+a0+b0:
-	op_pt->tinc = (Bit32u)(((fltype)(frn<<oct))*frqmul[adlibreg[ARC_TVS_KSR_MUL+regbase]&15]);
+	op_pt->tinc = (uint32_t)(((fltype)(frn<<oct))*frqmul[adlibreg[ARC_TVS_KSR_MUL+regbase]&15]);
 	// 40+a0+b0:
 	fltype vol_in = (fltype)((fltype)(adlibreg[ARC_KSL_OUTLEV+regbase]&63) +
 							kslmul[adlibreg[ARC_KSL_OUTLEV+regbase]>>6]*kslev[oct][frn>>6]);
@@ -453,7 +453,7 @@ void change_frequency(Bitu chanbase, Bitu regbase, op_type* op_pt) {
 	change_releaserate(regbase,op_pt);
 }
 
-void enable_operator(Bitu regbase, op_type* op_pt, Bit32u act_type) {
+void enable_operator(Bitu regbase, op_type* op_pt, uint32_t act_type) {
 	// check if this is really an off-on transition
 	if (op_pt->act_state == OP_ACT_OFF) {
 		Bits wselbase = (Bits)regbase;
@@ -467,7 +467,7 @@ void enable_operator(Bitu regbase, op_type* op_pt, Bit32u act_type) {
 	}
 }
 
-void disable_operator(op_type* op_pt, Bit32u act_type) {
+void disable_operator(op_type* op_pt, uint32_t act_type) {
 	// check if this is really an on-off transition
 	if (op_pt->act_state != OP_ACT_OFF) {
 		op_pt->act_state &= (~act_type);
@@ -477,12 +477,12 @@ void disable_operator(op_type* op_pt, Bit32u act_type) {
 	}
 }
 
-void adlib_init(Bit32u samplerate) {
-    Bit16s i;
+void adlib_init(uint32_t samplerate) {
+    int16_t i;
 
 	int_samplerate = samplerate;
 
-	generator_add = (Bit32u)(INTFREQU*FIXEDPT/int_samplerate);
+	generator_add = (uint32_t)(INTFREQU*FIXEDPT/int_samplerate);
 
 
 	memset((void *)adlibreg,0,sizeof(adlibreg));
@@ -535,14 +535,14 @@ void adlib_init(Bit32u samplerate) {
 	for (i=4; i<VIBTAB_SIZE; i++) vib_table[i] = vib_table[i-4]*-1;
 
 	// vibrato at ~6.1 ?? (opl3 docs say 6.1, opl4 docs say 6.0, y8950 docs say 6.4)
-	vibtab_add = static_cast<Bit32u>(VIBTAB_SIZE*FIXEDPT_LFO/8192*INTFREQU/int_samplerate);
+	vibtab_add = static_cast<uint32_t>(VIBTAB_SIZE*FIXEDPT_LFO/8192*INTFREQU/int_samplerate);
 	vibtab_pos = 0;
 
 	for (i=0; i<BLOCKBUF_SIZE; i++) vibval_const[i] = 0;
 
 
 	// create tremolo table
-	Bit32s trem_table_int[TREMTAB_SIZE];
+	int32_t trem_table_int[TREMTAB_SIZE];
 	for (i=0; i<14; i++)	trem_table_int[i] = i-13;		// upwards (13 to 26 -> -0.5/6 to 0)
 	for (i=14; i<41; i++)	trem_table_int[i] = -i+14;		// downwards (26 to 0 -> 0 to -1/6)
 	for (i=41; i<53; i++)	trem_table_int[i] = i-40-26;	// upwards (1 to 12 -> -1/6 to -0.5/6)
@@ -550,14 +550,14 @@ void adlib_init(Bit32u samplerate) {
 	for (i=0; i<TREMTAB_SIZE; i++) {
 		// 0.0 .. -26/26*4.8/6 == [0.0 .. -0.8], 4/53 steps == [1 .. 0.57]
 		fltype trem_val1=(fltype)(((fltype)trem_table_int[i])*4.8/26.0/6.0);				// 4.8db
-		fltype trem_val2=(fltype)((fltype)((Bit32s)(trem_table_int[i]/4))*1.2/6.0/6.0);		// 1.2db (larger stepping)
+		fltype trem_val2=(fltype)((fltype)((int32_t)(trem_table_int[i]/4))*1.2/6.0/6.0);		// 1.2db (larger stepping)
 
-		trem_table[i] = (Bit32s)(pow(FL2,trem_val1)*FIXEDPT);
-		trem_table[TREMTAB_SIZE+i] = (Bit32s)(pow(FL2,trem_val2)*FIXEDPT);
+		trem_table[i] = (int32_t)(pow(FL2,trem_val1)*FIXEDPT);
+		trem_table[TREMTAB_SIZE+i] = (int32_t)(pow(FL2,trem_val2)*FIXEDPT);
 	}
 
 	// tremolo at 3.7hz
-	tremtab_add = (Bit32u)((fltype)TREMTAB_SIZE * TREM_FREQ * FIXEDPT_LFO / (fltype)int_samplerate);
+	tremtab_add = (uint32_t)((fltype)TREMTAB_SIZE * TREM_FREQ * FIXEDPT_LFO / (fltype)int_samplerate);
 	tremtab_pos = 0;
 
 	for (i=0; i<BLOCKBUF_SIZE; i++) tremval_const[i] = FIXEDPT;
@@ -569,12 +569,12 @@ void adlib_init(Bit32u samplerate) {
 
 		// create waveform tables
 		for (i=0;i<(WAVEPREC>>1);i++) {
-			wavtable[(i<<1)  +WAVEPREC]	= (Bit16s)(16384*sin((fltype)(i<<1)*PI*2/WAVEPREC));
-			wavtable[(i<<1)+1+WAVEPREC]	= (Bit16s)(16384*sin((fltype)((i<<1)+1)*PI*2/WAVEPREC));
+			wavtable[(i<<1)  +WAVEPREC]	= (int16_t)(16384*sin((fltype)(i<<1)*PI*2/WAVEPREC));
+			wavtable[(i<<1)+1+WAVEPREC]	= (int16_t)(16384*sin((fltype)((i<<1)+1)*PI*2/WAVEPREC));
 			wavtable[i]					= wavtable[(i<<1)  +WAVEPREC];
 			// alternative: (zero-less)
-/*			wavtable[(i<<1)  +WAVEPREC]	= (Bit16s)(16384*sin((fltype)((i<<2)+1)*PI/WAVEPREC));
-			wavtable[(i<<1)+1+WAVEPREC]	= (Bit16s)(16384*sin((fltype)((i<<2)+3)*PI/WAVEPREC));
+/*			wavtable[(i<<1)  +WAVEPREC]	= (int16_t)(16384*sin((fltype)((i<<2)+1)*PI/WAVEPREC));
+			wavtable[(i<<1)+1+WAVEPREC]	= (int16_t)(16384*sin((fltype)((i<<2)+3)*PI/WAVEPREC));
 			wavtable[i]					= wavtable[(i<<1)-1+WAVEPREC]; */
 		}
 		for (i=0;i<(WAVEPREC>>3);i++) {
@@ -586,12 +586,12 @@ void adlib_init(Bit32u samplerate) {
 		kslev[7][0] = 0;	kslev[7][1] = 24;	kslev[7][2] = 32;	kslev[7][3] = 37;
 		kslev[7][4] = 40;	kslev[7][5] = 43;	kslev[7][6] = 45;	kslev[7][7] = 47;
 		kslev[7][8] = 48;
-		for (i=9;i<16;i++) kslev[7][i] = (Bit8u)(i+41);
+		for (i=9;i<16;i++) kslev[7][i] = (uint8_t)(i+41);
 		for (Bits j=6;j>=0;j--) {
 			for (i=0;i<16;i++) {
 				Bits oct = (Bits)kslev[j+1][i]-8;
 				if (oct < 0) oct = 0;
-				kslev[j][i] = (Bit8u)oct;
+				kslev[j][i] = (uint8_t)oct;
 			}
 		}
 	}
@@ -600,8 +600,8 @@ void adlib_init(Bit32u samplerate) {
 
 
 
-void adlib_write(Bitu idx, Bit8u val) {
-	Bit32u second_set = idx&0x100;
+void adlib_write(Bitu idx, uint8_t val) {
+	uint32_t second_set = idx&0x100;
 	adlibreg[idx] = val;
 
 	switch (idx&0xf0) {
@@ -912,7 +912,7 @@ Bitu adlib_reg_read(Bitu port) {
 #endif
 }
 
-void adlib_write_index(Bitu port, Bit8u val) {
+void adlib_write_index(Bitu port, uint8_t val) {
     (void)port;//POSSIBLY UNUSED
 	opl_index = val;
 #if defined(OPLTYPE_IS_OPL3)
@@ -923,10 +923,10 @@ void adlib_write_index(Bitu port, Bit8u val) {
 #endif
 }
 
-static void OPL_INLINE clipit16(Bit32s ival, Bit16s* outval) {
+static void OPL_INLINE clipit16(int32_t ival, int16_t* outval) {
 	if (ival<32768) {
 		if (ival>-32769) {
-			*outval=(Bit16s)ival;
+			*outval=(int16_t)ival;
 		} else {
 			*outval = -32768;
 		}
@@ -954,19 +954,19 @@ static void OPL_INLINE clipit16(Bit32s ival, Bit16s* outval) {
 	outbufl[i] += chanval;
 #endif
 
-void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
+void adlib_getsample(int16_t* sndptr, Bits numsamples) {
 	Bits i, endsamples;
 	op_type* cptr;
 
-	Bit32s outbufl[BLOCKBUF_SIZE];
+	int32_t outbufl[BLOCKBUF_SIZE];
 #if defined(OPLTYPE_IS_OPL3)
 	// second output buffer (right channel for opl3 stereo)
-	Bit32s outbufr[BLOCKBUF_SIZE];
+	int32_t outbufr[BLOCKBUF_SIZE];
 #endif
 
 	// vibrato/tremolo lookup tables (global, to possibly be used by all operators)
-	Bit32s vib_lut[BLOCKBUF_SIZE];
-	Bit32s trem_lut[BLOCKBUF_SIZE];
+	int32_t vib_lut[BLOCKBUF_SIZE];
+	int32_t trem_lut[BLOCKBUF_SIZE];
 
 	Bits samples_to_process = numsamples;
 
@@ -974,14 +974,14 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 		endsamples = samples_to_process-cursmp;
 		if (endsamples>BLOCKBUF_SIZE) endsamples = BLOCKBUF_SIZE;
 
-		memset((void*)&outbufl,0,(unsigned int)endsamples*sizeof(Bit32s));
+		memset((void*)&outbufl,0,(unsigned int)endsamples*sizeof(int32_t));
 #if defined(OPLTYPE_IS_OPL3)
 		// clear second output buffer (opl3 stereo)
-		if (adlibreg[0x105]&1) memset((void*)&outbufr,0,(unsigned int)endsamples*sizeof(Bit32s));
+		if (adlibreg[0x105]&1) memset((void*)&outbufr,0,(unsigned int)endsamples*sizeof(int32_t));
 #endif
 
 		// calculate vibrato/tremolo lookup tables
-		Bit32s vib_tshift = ((adlibreg[ARC_PERC_MODE]&0x40)==0) ? 1 : 0;	// 14cents/7cents switching
+		int32_t vib_tshift = ((adlibreg[ARC_PERC_MODE]&0x40)==0) ? 1 : 0;	// 14cents/7cents switching
 		for (i=0;i<endsamples;i++) {
 			// cycle through vibrato table
 			vibtab_pos += vibtab_add;
@@ -1004,7 +1004,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 					if (cptr[9].vibrato) {
 						vibval1 = vibval_var1;
 						for (i=0;i<endsamples;i++)
-							vibval1[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+							vibval1[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 					} else vibval1 = vibval_const;
 					if (cptr[9].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 					else tremval1 = tremval_const;
@@ -1015,7 +1015,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 						opfuncs[cptr[9].op_state](&cptr[9]);
 						operator_output(&cptr[9],0,tremval1[i]);
 						
-						Bit32s chanval = cptr[9].cval*2;
+						int32_t chanval = cptr[9].cval*2;
 						CHANVAL_OUT
 					}
 				}
@@ -1025,12 +1025,12 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 					if ((cptr[0].vibrato) && (cptr[0].op_state != OF_TYPE_OFF)) {
 						vibval1 = vibval_var1;
 						for (i=0;i<endsamples;i++)
-							vibval1[i] = (Bit32s)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
+							vibval1[i] = (int32_t)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
 					} else vibval1 = vibval_const;
 					if ((cptr[9].vibrato) && (cptr[9].op_state != OF_TYPE_OFF)) {
 						vibval2 = vibval_var2;
 						for (i=0;i<endsamples;i++)
-							vibval2[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+							vibval2[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 					} else vibval2 = vibval_const;
 					if (cptr[0].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 					else tremval1 = tremval_const;
@@ -1047,7 +1047,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 						opfuncs[cptr[9].op_state](&cptr[9]);
 						operator_output(&cptr[9],cptr[0].cval*FIXEDPT,tremval2[i]);
 						
-						Bit32s chanval = cptr[9].cval*2;
+						int32_t chanval = cptr[9].cval*2;
 						CHANVAL_OUT
 					}
 				}
@@ -1059,7 +1059,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 				if (cptr[0].vibrato) {
 					vibval3 = vibval_var1;
 					for (i=0;i<endsamples;i++)
-						vibval3[i] = (Bit32s)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
+						vibval3[i] = (int32_t)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
 				} else vibval3 = vibval_const;
 
 				if (cptr[0].tremolo) tremval3 = trem_lut;	// tremolo enabled, use table
@@ -1070,7 +1070,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 					operator_advance(&cptr[0],vibval3[i]);
 					opfuncs[cptr[0].op_state](&cptr[0]);		//TomTom
 					operator_output(&cptr[0],0,tremval3[i]);
-					Bit32s chanval = cptr[0].cval*2;
+					int32_t chanval = cptr[0].cval*2;
 					CHANVAL_OUT
 				}
 			}
@@ -1082,12 +1082,12 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 				if ((cptr[0].vibrato) && (cptr[0].op_state != OF_TYPE_OFF)) {
 					vibval1 = vibval_var1;
 					for (i=0;i<endsamples;i++)
-						vibval1[i] = (Bit32s)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
+						vibval1[i] = (int32_t)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
 				} else vibval1 = vibval_const;
 				if ((cptr[9].vibrato) && (cptr[9].op_state == OF_TYPE_OFF)) {
 					vibval2 = vibval_var2;
 					for (i=0;i<endsamples;i++)
-						vibval2[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+						vibval2[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 				} else vibval2 = vibval_const;
 
 				if (cptr[0].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
@@ -1099,7 +1099,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 				if ((cptr[9].vibrato) && (cptr[9].op_state == OF_TYPE_OFF)) {
 					vibval4 = vibval_var2;
 					for (i=0;i<endsamples;i++)
-						vibval4[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+						vibval4[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 				} else vibval4 = vibval_const;
 
 				if (cptr[9].tremolo) tremval4 = trem_lut;	// tremolo enabled, use table
@@ -1118,7 +1118,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 					opfuncs[op[8+9].op_state](&op[8+9]);		//Cymbal
 					operator_output(&op[8+9],0,tremval4[i]);
 
-					Bit32s chanval = (op[7].cval + op[7+9].cval + op[8+9].cval)*2;
+					int32_t chanval = (op[7].cval + op[7+9].cval + op[8+9].cval)*2;
 					CHANVAL_OUT
 				}
 			}
@@ -1156,7 +1156,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 							if (cptr[0].vibrato) {
 								vibval1 = vibval_var1;
 								for (i=0;i<endsamples;i++)
-									vibval1[i] = (Bit32s)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
+									vibval1[i] = (int32_t)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
 							} else vibval1 = vibval_const;
 							if (cptr[0].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 							else tremval1 = tremval_const;
@@ -1167,7 +1167,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 								opfuncs[cptr[0].op_state](&cptr[0]);
 								operator_output(&cptr[0],(cptr[0].lastcval+cptr[0].cval)*cptr[0].mfbi/2,tremval1[i]);
 
-								Bit32s chanval = cptr[0].cval;
+								int32_t chanval = cptr[0].cval;
 								CHANVAL_OUT
 							}
 						}
@@ -1176,7 +1176,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 							if ((cptr[9].vibrato) && (cptr[9].op_state != OF_TYPE_OFF)) {
 								vibval1 = vibval_var1;
 								for (i=0;i<endsamples;i++)
-									vibval1[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+									vibval1[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 							} else vibval1 = vibval_const;
 							if (cptr[9].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 							else tremval1 = tremval_const;
@@ -1193,7 +1193,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 								opfuncs[cptr[3].op_state](&cptr[3]);
 								operator_output(&cptr[3],cptr[9].cval*FIXEDPT,tremval2[i]);
 
-								Bit32s chanval = cptr[3].cval;
+								int32_t chanval = cptr[3].cval;
 								CHANVAL_OUT
 							}
 						}
@@ -1208,7 +1208,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 								opfuncs[cptr[3+9].op_state](&cptr[3+9]);
 								operator_output(&cptr[3+9],0,tremval1[i]);
 
-								Bit32s chanval = cptr[3+9].cval;
+								int32_t chanval = cptr[3+9].cval;
 								CHANVAL_OUT
 							}
 						}
@@ -1218,7 +1218,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 							if (cptr[0].vibrato) {
 								vibval1 = vibval_var1;
 								for (i=0;i<endsamples;i++)
-									vibval1[i] = (Bit32s)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
+									vibval1[i] = (int32_t)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
 							} else vibval1 = vibval_const;
 							if (cptr[0].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 							else tremval1 = tremval_const;
@@ -1229,7 +1229,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 								opfuncs[cptr[0].op_state](&cptr[0]);
 								operator_output(&cptr[0],(cptr[0].lastcval+cptr[0].cval)*cptr[0].mfbi/2,tremval1[i]);
 
-								Bit32s chanval = cptr[0].cval;
+								int32_t chanval = cptr[0].cval;
 								CHANVAL_OUT
 							}
 						}
@@ -1238,7 +1238,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 							if ((cptr[9].vibrato) && (cptr[9].op_state != OF_TYPE_OFF)) {
 								vibval1 = vibval_var1;
 								for (i=0;i<endsamples;i++)
-									vibval1[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+									vibval1[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 							} else vibval1 = vibval_const;
 							if (cptr[9].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 							else tremval1 = tremval_const;
@@ -1261,7 +1261,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 								opfuncs[cptr[3+9].op_state](&cptr[3+9]);
 								operator_output(&cptr[3+9],cptr[3].cval*FIXEDPT,tremval3[i]);
 
-								Bit32s chanval = cptr[3+9].cval;
+								int32_t chanval = cptr[3+9].cval;
 								CHANVAL_OUT
 							}
 						}
@@ -1274,12 +1274,12 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 				if ((cptr[0].vibrato) && (cptr[0].op_state != OF_TYPE_OFF)) {
 					vibval1 = vibval_var1;
 					for (i=0;i<endsamples;i++)
-						vibval1[i] = (Bit32s)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
+						vibval1[i] = (int32_t)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
 				} else vibval1 = vibval_const;
 				if ((cptr[9].vibrato) && (cptr[9].op_state != OF_TYPE_OFF)) {
 					vibval2 = vibval_var2;
 					for (i=0;i<endsamples;i++)
-						vibval2[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+						vibval2[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 				} else vibval2 = vibval_const;
 				if (cptr[0].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 				else tremval1 = tremval_const;
@@ -1298,7 +1298,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 					opfuncs[cptr[9].op_state](&cptr[9]);
 					operator_output(&cptr[9],0,tremval2[i]);
 
-					Bit32s chanval = cptr[9].cval + cptr[0].cval;
+					int32_t chanval = cptr[9].cval + cptr[0].cval;
 					CHANVAL_OUT
 				}
 			} else {
@@ -1310,12 +1310,12 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 							if ((cptr[0].vibrato) && (cptr[0].op_state != OF_TYPE_OFF)) {
 								vibval1 = vibval_var1;
 								for (i=0;i<endsamples;i++)
-									vibval1[i] = (Bit32s)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
+									vibval1[i] = (int32_t)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
 							} else vibval1 = vibval_const;
 							if ((cptr[9].vibrato) && (cptr[9].op_state != OF_TYPE_OFF)) {
 								vibval2 = vibval_var2;
 								for (i=0;i<endsamples;i++)
-									vibval2[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+									vibval2[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 							} else vibval2 = vibval_const;
 							if (cptr[0].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 							else tremval1 = tremval_const;
@@ -1332,7 +1332,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 								opfuncs[cptr[9].op_state](&cptr[9]);
 								operator_output(&cptr[9],cptr[0].cval*FIXEDPT,tremval2[i]);
 
-								Bit32s chanval = cptr[9].cval;
+								int32_t chanval = cptr[9].cval;
 								CHANVAL_OUT
 							}
 						}
@@ -1353,7 +1353,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 								opfuncs[cptr[3+9].op_state](&cptr[3+9]);
 								operator_output(&cptr[3+9],cptr[3].cval*FIXEDPT,tremval2[i]);
 
-								Bit32s chanval = cptr[3+9].cval;
+								int32_t chanval = cptr[3+9].cval;
 								CHANVAL_OUT
 							}
 						}
@@ -1365,12 +1365,12 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 							if ((cptr[0].vibrato) && (cptr[0].op_state != OF_TYPE_OFF)) {
 								vibval1 = vibval_var1;
 								for (i=0;i<endsamples;i++)
-									vibval1[i] = (Bit32s)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
+									vibval1[i] = (int32_t)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
 							} else vibval1 = vibval_const;
 							if ((cptr[9].vibrato) && (cptr[9].op_state != OF_TYPE_OFF)) {
 								vibval2 = vibval_var2;
 								for (i=0;i<endsamples;i++)
-									vibval2[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+									vibval2[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 							} else vibval2 = vibval_const;
 							if (cptr[0].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 							else tremval1 = tremval_const;
@@ -1399,7 +1399,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 								opfuncs[cptr[3+9].op_state](&cptr[3+9]);
 								operator_output(&cptr[3+9],cptr[3].cval*FIXEDPT,tremval4[i]);
 
-								Bit32s chanval = cptr[3+9].cval;
+								int32_t chanval = cptr[3+9].cval;
 								CHANVAL_OUT
 							}
 						}
@@ -1412,12 +1412,12 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 				if ((cptr[0].vibrato) && (cptr[0].op_state != OF_TYPE_OFF)) {
 					vibval1 = vibval_var1;
 					for (i=0;i<endsamples;i++)
-						vibval1[i] = (Bit32s)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
+						vibval1[i] = (int32_t)((vib_lut[i]*cptr[0].freq_high/8)*FIXEDPT*VIBFAC);
 				} else vibval1 = vibval_const;
 				if ((cptr[9].vibrato) && (cptr[9].op_state != OF_TYPE_OFF)) {
 					vibval2 = vibval_var2;
 					for (i=0;i<endsamples;i++)
-						vibval2[i] = (Bit32s)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
+						vibval2[i] = (int32_t)((vib_lut[i]*cptr[9].freq_high/8)*FIXEDPT*VIBFAC);
 				} else vibval2 = vibval_const;
 				if (cptr[0].tremolo) tremval1 = trem_lut;	// tremolo enabled, use table
 				else tremval1 = tremval_const;
@@ -1436,7 +1436,7 @@ void adlib_getsample(Bit16s* sndptr, Bits numsamples) {
 					opfuncs[cptr[9].op_state](&cptr[9]);
 					operator_output(&cptr[9],cptr[0].cval*FIXEDPT,tremval2[i]);
 
-					Bit32s chanval = cptr[9].cval;
+					int32_t chanval = cptr[9].cval;
 					CHANVAL_OUT
 				}
 			}
@@ -1574,6 +1574,6 @@ void adlib_loadstate( std::istream& stream )
 	//****************************************************
 
 	for( int lcv=0; lcv<MAXOPERATORS; lcv++ ) {
-		op[lcv].cur_wform = (Bit16s *) ((Bitu) &wavtable + cur_wform_idx[lcv]);
+		op[lcv].cur_wform = (int16_t *) ((Bitu) &wavtable + cur_wform_idx[lcv]);
 	}
 }
