@@ -44,18 +44,18 @@ struct PIC_Controller {
     bool rotate_on_auto_eoi;
     bool single;
     bool request_issr;
-    Bit8u vector_base;
+    uint8_t vector_base;
 
-    Bit8u irr;        // request register
-    Bit8u imr;        // mask register
-    Bit8u imrr;       // mask register reversed (makes bit tests simpler)
-    Bit8u isr;        // in service register
-    Bit8u isrr;       // in service register reversed (makes bit tests simpler)
-    Bit8u isr_ignore; // in service bits to ignore
-    Bit8u active_irq; //currently active irq
+    uint8_t irr;        // request register
+    uint8_t imr;        // mask register
+    uint8_t imrr;       // mask register reversed (makes bit tests simpler)
+    uint8_t isr;        // in service register
+    uint8_t isrr;       // in service register reversed (makes bit tests simpler)
+    uint8_t isr_ignore; // in service bits to ignore
+    uint8_t active_irq; //currently active irq
 
 
-    void set_imr(Bit8u val);
+    void set_imr(uint8_t val);
 
     void check_after_EOI(){
         //Update the active_irq as an EOI is likely to change that.
@@ -69,7 +69,7 @@ struct PIC_Controller {
         }
 
         if(isr == 0) {active_irq = 8; return;}
-        for(Bit8u i = 0, s = 1; i < 8;i++, s<<=1){
+        for(uint8_t i = 0, s = 1; i < 8;i++, s<<=1){
             if (isr & s) {
                 active_irq = i;
                 return;
@@ -85,10 +85,10 @@ struct PIC_Controller {
     //Removes signal to master/cpu that there is an irq ready.
     void deactivate();
 
-    void raise_irq(Bit8u val);
+    void raise_irq(uint8_t val);
 
-    void lower_irq(Bit8u val){
-        Bit8u bit = 1 << ( val);
+    void lower_irq(uint8_t val){
+        uint8_t bit = 1 << ( val);
         if(irr & bit) { //value will change (as it is currently active)
             irr&=~bit;
             if((bit&imrr)&isrr) { //not masked and not in service
@@ -100,7 +100,7 @@ struct PIC_Controller {
     }
 
     //handles all bits and logic related to starting this IRQ, it does NOT start the interrupt on the CPU.
-    void start_irq(Bit8u val);
+    void start_irq(uint8_t val);
 };
 
 int master_cascade_irq = -1;
@@ -114,14 +114,14 @@ bool enable_slave_pic = true; /* if set, emulate slave with cascade to master. i
 bool enable_pc_xt_nmi_mask = false;
 
 void PIC_Controller::check_for_irq(){
-    const Bit8u possible_irq = (irr&imrr)&isrr;
+    const uint8_t possible_irq = (irr&imrr)&isrr;
     if (possible_irq) {
-        Bit8u a_irq = special?8:active_irq;
+        uint8_t a_irq = special?8:active_irq;
 
         if (ignore_cascade_in_service && this == &master && a_irq == (unsigned char)master_cascade_irq)
             a_irq++;
 
-        for(Bit8u i = 0, s = 1; i < a_irq;i++, s<<=1){
+        for(uint8_t i = 0, s = 1; i < a_irq;i++, s<<=1){
             if ( possible_irq & s ) {
                 //There is an irq ready to be served => signal master and/or cpu
                 activate();
@@ -132,8 +132,8 @@ void PIC_Controller::check_for_irq(){
     deactivate(); //No irq, remove signal to master and/or cpu
 }
 
-void PIC_Controller::raise_irq(Bit8u val){
-    Bit8u bit = 1 << (val);
+void PIC_Controller::raise_irq(uint8_t val){
+    uint8_t bit = 1 << (val);
     if((irr & bit)==0) { //value changed (as it is currently not active)
         irr|=bit;
         if((bit&imrr)&isrr) { //not masked and not in service
@@ -149,8 +149,8 @@ void PIC_IRQCheckDelayed(Bitu val) {
     PIC_IRQCheckPending = 0;
 }
 
-void PIC_Controller::set_imr(Bit8u val) {
-    Bit8u change = (imr) ^ (val); //Bits that have changed become 1.
+void PIC_Controller::set_imr(uint8_t val) {
+    uint8_t change = (imr) ^ (val); //Bits that have changed become 1.
     imr  =  val;
     imrr = ~val;
 
@@ -198,7 +198,7 @@ void PIC_Controller::deactivate() {
     }
 }
 
-void PIC_Controller::start_irq(Bit8u val){
+void PIC_Controller::start_irq(uint8_t val){
     irr&=~(1<<(val));
     if (!auto_eoi) {
         if (never_mark_cascade_in_service && this == &master && val == master_cascade_irq) {
@@ -235,6 +235,7 @@ static void write_command(Bitu port,Bitu val,Bitu iolen) {
         if (val&0x04) LOG_MSG("PIC: 4 byte interval not handled");
         if (val&0x08) LOG_MSG("PIC: level triggered mode not handled");
         if (val&0xe0) LOG_MSG("PIC: 8080/8085 mode not handled");
+        pic->set_imr(0);
         pic->single=(val&0x02)==0x02;
         pic->icw_index=1;           // next is ICW2
         pic->icw_words=2 + (val&0x01);  // =3 if ICW4 needed
@@ -467,11 +468,11 @@ static bool IRQ_hack_check_cs_equ_ds(const int IRQ) {
 }
 
 static void slave_startIRQ(){
-    Bit8u pic1_irq = 8;
+    uint8_t pic1_irq = 8;
     bool skipped_irq = false;
-    const Bit8u p = (slave.irr & slave.imrr)&slave.isrr;
-    const Bit8u max = slave.special?8:slave.active_irq;
-    for(Bit8u i = 0,s = 1;i < max;i++, s<<=1) {
+    const uint8_t p = (slave.irr & slave.imrr)&slave.isrr;
+    const uint8_t max = slave.special?8:slave.active_irq;
+    for(uint8_t i = 0,s = 1;i < max;i++, s<<=1) {
         if (p&s) {
             if (PIC_IRQ_hax[i+8] & PIC_irq_hack_cs_equ_ds) {
                 if (!IRQ_hack_check_cs_equ_ds(i+8)) {
@@ -517,9 +518,9 @@ void PIC_runIRQs(void) {
         return; /* NMI has higher priority than PIC */
     }
 
-    const Bit8u p = (master.irr & master.imrr)&master.isrr;
-    Bit8u max = master.special?8:master.active_irq;
-    Bit8u i,s;
+    const uint8_t p = (master.irr & master.imrr)&master.isrr;
+    uint8_t max = master.special?8:master.active_irq;
+    uint8_t i,s;
 
     if (ignore_cascade_in_service && max == (unsigned char)master_cascade_irq)
         max++;
@@ -558,8 +559,8 @@ void PIC_SetIRQMask(Bitu irq, bool masked) {
     Bitu t = irq>7 ? (irq - 8): irq;
     PIC_Controller * pic=&pics[irq>7 ? 1 : 0];
     //clear bit
-    Bit8u bit = 1 <<(t);
-    Bit8u newmask = pic->imr;
+    uint8_t bit = 1 <<(t);
+    uint8_t newmask = pic->imr;
     newmask &= ~bit;
     if (masked) newmask |= bit;
     pic->set_imr(newmask);
@@ -821,7 +822,7 @@ extern Bitu time_limit_ms;
 static unsigned long PIC_benchstart = 0;
 static unsigned long PIC_tickstart = 0;
 
-extern void GFX_SetTitle(Bit32s cycles, Bits frameskip, Bits timing, bool paused);
+extern void GFX_SetTitle(int32_t cycles, int frameskip, Bits timing, bool paused);
 void TIMER_AddTick(void) {
     /* Setup new amount of cycles for PIC */
     PIC_Ticks++;
@@ -1177,7 +1178,7 @@ const void *pic_state_timer_table[] = {
 
 
 //#include <windows.h>
-Bit16u PIC_State_FindEvent( Bitu addr ) {
+uint16_t PIC_State_FindEvent( Bitu addr ) {
 	int size;
 
 	size = sizeof(pic_state_event_table) / sizeof(void *);
@@ -1192,7 +1193,7 @@ Bit16u PIC_State_FindEvent( Bitu addr ) {
 }
 
 
-Bit16u PIC_State_FindTimer( Bitu addr ) {
+uint16_t PIC_State_FindTimer( Bitu addr ) {
 	int size;
 
 	size = sizeof(pic_state_timer_table) / sizeof(void *);
@@ -1207,14 +1208,14 @@ Bit16u PIC_State_FindTimer( Bitu addr ) {
 }
 
 
-Bitu PIC_State_IndexEvent( Bit16u index ) {
+Bitu PIC_State_IndexEvent( uint16_t index ) {
 	if( index == 0xffff ) return 0;
 
 	return (Bitu) (pic_state_event_table[index]);
 }
 
 
-Bitu PIC_State_IndexTimer( Bit16u index ) {
+Bitu PIC_State_IndexTimer( uint16_t index ) {
 	if( index == 0xffff ) return 0;
 
 	return (Bitu) (pic_state_timer_table[index]);
@@ -1234,12 +1235,12 @@ public:
 private:
     virtual void getBytes(std::ostream& stream)
     {
-				Bit16u pic_free_idx, pic_next_idx;
-				Bit16u pic_next_ptr[PIC_QUEUESIZE];
+				uint16_t pic_free_idx, pic_next_idx;
+				uint16_t pic_next_ptr[PIC_QUEUESIZE];
 
 				TickerBlock *ticker_ptr;
-				Bit16u ticker_size;
-				Bit16u ticker_handler_idx;
+				uint16_t ticker_size;
+				uint16_t ticker_handler_idx;
 
 
 				for( int lcv=0; lcv<PIC_QUEUESIZE; lcv++ ) {
@@ -1283,7 +1284,7 @@ private:
 				pic_free_idx = 0xffff;
 				pic_next_idx = 0xffff;
 				for( int lcv=0; lcv<PIC_QUEUESIZE; lcv++ ) {
-					Bit16u event_idx;
+					uint16_t event_idx;
 
 					// - data
 					stream.write(reinterpret_cast<const char*>(&pic_queue.entries[lcv].index), sizeof(pic_queue.entries[lcv].index) );
@@ -1337,8 +1338,8 @@ private:
 
     virtual void setBytes(std::istream& stream)
     {
-				Bit16u free_idx, next_idx;
-				Bit16u ticker_size;
+				uint16_t free_idx, next_idx;
+				uint16_t ticker_size;
 
 
         SerializeGlobalPOD::setBytes(stream);
@@ -1354,7 +1355,7 @@ private:
 
 
 				for( int lcv=0; lcv<PIC_QUEUESIZE; lcv++ ) {
-					Bit16u event_idx, next_idx;
+					uint16_t event_idx, next_idx;
 
 					// - data
 					stream.read(reinterpret_cast<char*>(&pic_queue.entries[lcv].index), sizeof(pic_queue.entries[lcv].index) );
@@ -1412,7 +1413,7 @@ private:
 					TickerBlock *ticker_ptr;
 
 					for( int lcv = 0; lcv<ticker_size; lcv++ ) {
-						Bit16u ticker_idx;
+						uint16_t ticker_idx;
 
 						if( lcv == 0 ) {
 							ticker_ptr = new TickerBlock;
