@@ -33,39 +33,39 @@
 
 struct XGAStatus {
 	struct scissorreg {
-		Bit16u x1, y1, x2, y2;
+		uint16_t x1, y1, x2, y2;
 	} scissors;
 
-	Bit32u readmask;
-	Bit32u writemask;
+	uint32_t readmask;
+	uint32_t writemask;
 
-	Bit32u forecolor;
-	Bit32u backcolor;
+	uint32_t forecolor;
+	uint32_t backcolor;
 
 	Bitu curcommand;
 
-	Bit16u foremix;
-	Bit16u backmix;
+	uint16_t foremix;
+	uint16_t backmix;
 
-	Bit16u curx, cury;
-	Bit16u destx, desty;
+	uint16_t curx, cury;
+	uint16_t destx, desty;
 
-	Bit16u ErrTerm;
-	Bit16u MIPcount;
-	Bit16u MAPcount;
+	uint16_t ErrTerm;
+	uint16_t MIPcount;
+	uint16_t MAPcount;
 
-	Bit16u pix_cntl;
-	Bit16u control1;
-	Bit16u control2;
-	Bit16u read_sel;
+	uint16_t pix_cntl;
+	uint16_t control1;
+	uint16_t control2;
+	uint16_t read_sel;
 
 	struct XGA_WaitCmd {
 		bool newline;
 		bool wait;
-		Bit16u cmd;
-		Bit16u curx, cury;
-		Bit16u x1, y1, x2, y2, sizex, sizey;
-		Bit32u data; /* transient data passed by multiple calls */
+		uint16_t cmd;
+		uint16_t curx, cury;
+		uint16_t x1, y1, x2, y2, sizex, sizey;
+		uint32_t data; /* transient data passed by multiple calls */
 		Bitu datasize;
 		Bitu buswidth;
 	} waitcmd;
@@ -78,31 +78,31 @@ void XGA_Write_Multifunc(Bitu val, Bitu len) {
 	Bitu dataval = val & 0xfff;
 	switch(regselect) {
 		case 0: // minor axis pixel count
-			xga.MIPcount = (Bit16u)dataval;
+			xga.MIPcount = (uint16_t)dataval;
 			break;
 		case 1: // top scissors
-			xga.scissors.y1 = (Bit16u)dataval;
+			xga.scissors.y1 = (uint16_t)dataval;
 			break;
 		case 2: // left
-			xga.scissors.x1 = (Bit16u)dataval;
+			xga.scissors.x1 = (uint16_t)dataval;
 			break;
 		case 3: // bottom
-			xga.scissors.y2 = (Bit16u)dataval;
+			xga.scissors.y2 = (uint16_t)dataval;
 			break;
 		case 4: // right
-			xga.scissors.x2 = (Bit16u)dataval;
+			xga.scissors.x2 = (uint16_t)dataval;
 			break;
 		case 0xa: // data manip control
-			xga.pix_cntl = (Bit16u)dataval;
+			xga.pix_cntl = (uint16_t)dataval;
 			break;
 		case 0xd: // misc 2
-			xga.control2 = (Bit16u)dataval;
+			xga.control2 = (uint16_t)dataval;
 			break;
 		case 0xe:
-			xga.control1 = (Bit16u)dataval;
+			xga.control1 = (uint16_t)dataval;
 			break;
 		case 0xf:
-			xga.read_sel = (Bit16u)dataval;
+			xga.read_sel = (uint16_t)dataval;
 			break;
 		default:
 			LOG_MSG("XGA: Unhandled multifunction command %x", (int)regselect);
@@ -137,26 +137,26 @@ void XGA_DrawPoint(Bitu x, Bitu y, Bitu c) {
 	if(y < xga.scissors.y1) return;
 	if(y > xga.scissors.y2) return;
 
-	Bit32u memaddr = (Bit32u)((y * XGA_SCREEN_WIDTH) + x);
+	uint32_t memaddr = (uint32_t)((y * XGA_SCREEN_WIDTH) + x);
 	/* Need to zero out all unused bits in modes that have any (15-bit or "32"-bit -- the last
 	   one is actually 24-bit. Without this step there may be some graphics corruption (mainly,
 	   during windows dragging. */
 	switch(XGA_COLOR_MODE) {
 		case M_LIN8:
 			if (GCC_UNLIKELY(memaddr >= vga.mem.memsize)) break;
-			vga.mem.linear[memaddr] = (Bit8u)c;
+			vga.mem.linear[memaddr] = (uint8_t)c;
 			break;
 		case M_LIN15:
 			if (GCC_UNLIKELY(memaddr*2 >= vga.mem.memsize)) break;
-			((Bit16u*)(vga.mem.linear))[memaddr] = (Bit16u)(c&0x7fff);
+			((uint16_t*)(vga.mem.linear))[memaddr] = (uint16_t)(c&0x7fff);
 			break;
 		case M_LIN16:
 			if (GCC_UNLIKELY(memaddr*2 >= vga.mem.memsize)) break;
-			((Bit16u*)(vga.mem.linear))[memaddr] = (Bit16u)(c&0xffff);
+			((uint16_t*)(vga.mem.linear))[memaddr] = (uint16_t)(c&0xffff);
 			break;
 		case M_LIN32:
 			if (GCC_UNLIKELY(memaddr*4 >= vga.mem.memsize)) break;
-			((Bit32u*)(vga.mem.linear))[memaddr] = (Bit32u)c;
+			((uint32_t*)(vga.mem.linear))[memaddr] = (uint32_t)c;
 			break;
 		default:
 			break;
@@ -165,7 +165,7 @@ void XGA_DrawPoint(Bitu x, Bitu y, Bitu c) {
 }
 
 Bitu XGA_GetPoint(Bitu x, Bitu y) {
-	Bit32u memaddr = (Bit32u)((y * XGA_SCREEN_WIDTH) + x);
+	uint32_t memaddr = (uint32_t)((y * XGA_SCREEN_WIDTH) + x);
 
 	switch(XGA_COLOR_MODE) {
 	case M_LIN8:
@@ -174,10 +174,10 @@ Bitu XGA_GetPoint(Bitu x, Bitu y) {
 	case M_LIN15:
 	case M_LIN16:
 		if (GCC_UNLIKELY(memaddr*2 >= vga.mem.memsize)) break;
-		return ((Bit16u*)(vga.mem.linear))[memaddr];
+		return ((uint16_t*)(vga.mem.linear))[memaddr];
 	case M_LIN32:
 		if (GCC_UNLIKELY(memaddr*4 >= vga.mem.memsize)) break;
-		return ((Bit32u*)(vga.mem.linear))[memaddr];
+		return ((uint32_t*)(vga.mem.linear))[memaddr];
 	default:
 		break;
 	}
@@ -336,8 +336,8 @@ void XGA_DrawLineVector(Bitu val) {
 		yat += sy;
 	}
 
-	xga.curx = (Bit16u)(xat-1);
-	xga.cury = (Bit16u)yat;
+	xga.curx = (uint16_t)(xat-1);
+	xga.cury = (uint16_t)yat;
 }
 
 void XGA_DrawLineBresenham(Bitu val) {
@@ -355,11 +355,11 @@ void XGA_DrawLineBresenham(Bitu val) {
 
 	// Probably a lot easier way to do this, but this works.
 
-	dminor = (Bits)((Bit16s)xga.desty);
+	dminor = (Bits)((int16_t)xga.desty);
 	if(xga.desty&0x2000) dminor |= ~((Bits)0x1fff);
 	dminor >>= 1;
 
-	destxtmp=(Bits)((Bit16s)xga.destx);
+	destxtmp=(Bits)((int16_t)xga.destx);
 	if(xga.destx&0x2000) destxtmp |= ~((Bits)0x1fff);
 
 
@@ -377,7 +377,7 @@ void XGA_DrawLineBresenham(Bitu val) {
 	} else {
 		sy = -1;
 	}
-	e = (Bits)((Bit16s)xga.ErrTerm);
+	e = (Bits)((int16_t)xga.ErrTerm);
 	if(xga.ErrTerm&0x2000) e |= ~((Bits)0x1fff); /* sign extend 13-bit error term */
 	xat = xga.curx;
 	yat = xga.cury;
@@ -449,11 +449,11 @@ void XGA_DrawLineBresenham(Bitu val) {
 	}
 
 	if(steep) {
-		xga.curx = (Bit16u)xat;
-		xga.cury = (Bit16u)yat;
+		xga.curx = (uint16_t)xat;
+		xga.cury = (uint16_t)yat;
 	} else {
-		xga.curx = (Bit16u)yat;
-		xga.cury = (Bit16u)xat;
+		xga.curx = (uint16_t)yat;
+		xga.cury = (uint16_t)xat;
 	}
 	//	}
 	//}
@@ -461,7 +461,7 @@ void XGA_DrawLineBresenham(Bitu val) {
 }
 
 void XGA_DrawRectangle(Bitu val) {
-	Bit32u xat, yat;
+	uint32_t xat, yat;
 	Bitu srcval;
 	Bitu destval;
 	Bitu dstdata;
@@ -519,8 +519,8 @@ void XGA_DrawRectangle(Bitu val) {
 		}
 		srcy += dy;
 	}
-	xga.curx = (Bit16u)srcx;
-	xga.cury = (Bit16u)srcy;
+	xga.curx = (uint16_t)srcx;
+	xga.cury = (uint16_t)srcy;
 
 	//LOG_MSG("XGA: Draw rect (%d, %d)-(%d, %d), %d", x1, y1, x2, y2, xga.forecolor);
 }
@@ -538,9 +538,9 @@ bool XGA_CheckX(void) {
 		if((xga.waitcmd.cury<2048)&&(xga.waitcmd.cury > xga.waitcmd.y2))
 			xga.waitcmd.wait = false;
 	} else if(xga.waitcmd.curx>=2048) {
-		Bit16u realx = 4096-xga.waitcmd.curx;
+		uint16_t realx = 4096-xga.waitcmd.curx;
 		if(xga.waitcmd.x2>2047) { // x end is negative too
-			Bit16u realxend=4096-xga.waitcmd.x2;
+			uint16_t realxend=4096-xga.waitcmd.x2;
 			if(realx==realxend) {
 				xga.waitcmd.curx = xga.waitcmd.x1;
 				xga.waitcmd.cury++;
@@ -623,7 +623,7 @@ void XGA_DrawWait(Bitu val, Bitu len) {
 							if(len!=4) { // Win 3.11 864 'hack?'
 								if(xga.waitcmd.datasize == 0) {
 									// set it up to wait for the next word
-									xga.waitcmd.data = (Bit32u)val;
+									xga.waitcmd.data = (uint32_t)val;
 									xga.waitcmd.datasize = 2;
 									return;
 								} else {
@@ -730,7 +730,7 @@ void XGA_DrawWait(Bitu val, Bitu len) {
 }
 
 void XGA_BlitRect(Bitu val) {
-	Bit32u xat, yat;
+	uint32_t xat, yat;
 	Bitu srcdata;
 	Bitu dstdata;
 
@@ -909,8 +909,8 @@ void XGA_DrawPattern(Bitu val) {
 
 void XGA_DrawCmd(Bitu val, Bitu len) {
     (void)len;//UNUSED
-	Bit16u cmd;
-	cmd = (Bit16u)(val >> 13ul);
+	uint16_t cmd;
+	cmd = (uint16_t)(val >> 13ul);
 	if (val & 0x800) cmd |= 0x8u; // S3 CMD bit 3
 #if XGA_SHOW_COMMAND_TRACE == 1
 	//LOG_MSG("XGA: Draw command %x", cmd);
@@ -951,8 +951,8 @@ void XGA_DrawCmd(Bitu val, Bitu len) {
 				xga.waitcmd.cury = xga.cury;
 				xga.waitcmd.x1 = xga.curx;
 				xga.waitcmd.y1 = xga.cury;
-				xga.waitcmd.x2 = (Bit16u)((xga.curx + xga.MAPcount)&0x0fff);
-				xga.waitcmd.y2 = (Bit16u)((xga.cury + xga.MIPcount + 1)&0x0fff);
+				xga.waitcmd.x2 = (uint16_t)((xga.curx + xga.MAPcount)&0x0fff);
+				xga.waitcmd.y2 = (uint16_t)((xga.cury + xga.MIPcount + 1)&0x0fff);
 				xga.waitcmd.sizex = xga.MAPcount;
 				xga.waitcmd.sizey = xga.MIPcount + 1;
 				xga.waitcmd.cmd = 2;
@@ -988,20 +988,20 @@ void XGA_DrawCmd(Bitu val, Bitu len) {
 	}
 }
 
-void XGA_SetDualReg(Bit32u& reg, Bitu val) {
+void XGA_SetDualReg(uint32_t& reg, Bitu val) {
 	switch(XGA_COLOR_MODE) {
 	case M_LIN8:
-		reg = (Bit8u)(val&0xff); break;
+		reg = (uint8_t)(val&0xff); break;
 	case M_LIN15:
 	case M_LIN16:
-		reg = (Bit16u)(val&0xffff); break;
+		reg = (uint16_t)(val&0xffff); break;
 	case M_LIN32:
 		if (xga.control1 & 0x200)
-			reg = (Bit32u)val;
+			reg = (uint32_t)val;
 		else if (xga.control1 & 0x10)
-			reg = (reg&0x0000ffff)|((Bit32u)(val<<16));
+			reg = (reg&0x0000ffff)|((uint32_t)(val<<16));
 		else
-			reg = (reg&0xffff0000)|((Bit32u)(val&0x0000ffff));
+			reg = (reg&0xffff0000)|((uint32_t)(val&0x0000ffff));
 		xga.control1 ^= 0x10;
 		break;
 	default:
@@ -1009,12 +1009,12 @@ void XGA_SetDualReg(Bit32u& reg, Bitu val) {
 	}
 }
 
-Bitu XGA_GetDualReg(Bit32u reg) {
+Bitu XGA_GetDualReg(uint32_t reg) {
 	switch(XGA_COLOR_MODE) {
 	case M_LIN8:
-		return (Bit8u)(reg&0xff);
+		return (uint8_t)(reg&0xff);
 	case M_LIN15: case M_LIN16:
-		return (Bit16u)(reg&0xffff);
+		return (uint16_t)(reg&0xffff);
 	case M_LIN32:
 		if (xga.control1 & 0x200) return reg;
 		xga.control1 ^= 0x10;
@@ -1040,45 +1040,45 @@ void XGA_Write(Bitu port, Bitu val, Bitu len) {
 	switch(port) {
 		case 0x8100:// drawing control: row (low word), column (high word)
 					// "CUR_X" and "CUR_Y" (see PORT 82E8h,PORT 86E8h)
-			xga.cury = (Bit16u)(val & 0x0fff);
-			if(len==4) xga.curx = (Bit16u)((val>>16)&0x0fff);
+			xga.cury = (uint16_t)(val & 0x0fff);
+			if(len==4) xga.curx = (uint16_t)((val>>16)&0x0fff);
 			break;
 		case 0x8102:
-			xga.curx = (Bit16u)(val& 0x0fff);
+			xga.curx = (uint16_t)(val& 0x0fff);
 			break;
 
 		case 0x8108:// DWORD drawing control: destination Y and axial step
 					// constant (low word), destination X and axial step
 					// constant (high word) (see PORT 8AE8h,PORT 8EE8h)
-			xga.desty = (Bit16u)(val&0x3FFF);
-			if(len==4) xga.destx = (Bit16u)((val>>16)&0x3fff);
+			xga.desty = (uint16_t)(val&0x3FFF);
+			if(len==4) xga.destx = (uint16_t)((val>>16)&0x3fff);
 			break;
 		case 0x810a:
-			xga.destx = (Bit16u)(val&0x3fff);
+			xga.destx = (uint16_t)(val&0x3fff);
 			break;
 		case 0x8110: // WORD error term (see PORT 92E8h)
-			xga.ErrTerm = (Bit16u)(val&0x3FFF);
+			xga.ErrTerm = (uint16_t)(val&0x3FFF);
 			break;
 
 		case 0x8120: // packed MMIO: DWORD background color (see PORT A2E8h)
-			xga.backcolor = (Bit16u)val;
+			xga.backcolor = (uint16_t)val;
 			break;
 		case 0x8124: // packed MMIO: DWORD foreground color (see PORT A6E8h)
-			xga.forecolor = (Bit16u)val;
+			xga.forecolor = (uint16_t)val;
 			break;
 		case 0x8128: // DWORD	write mask (see PORT AAE8h)
-			xga.writemask = (Bit16u)val;
+			xga.writemask = (uint16_t)val;
 			break;
 		case 0x812C: // DWORD	read mask (see PORT AEE8h)
-			xga.readmask = (Bit16u)val;
+			xga.readmask = (uint16_t)val;
 			break;
 		case 0x8134: // packed MMIO: DWORD	background mix (low word) and
 					 // foreground mix (high word)	(see PORT B6E8h,PORT BAE8h)
 			xga.backmix = val&0xFFFF;
-			if(len==4) xga.foremix = (Bit16u)(val>>16ul);
+			if(len==4) xga.foremix = (uint16_t)(val>>16ul);
 			break;
 		case 0x8136:
-			xga.foremix = (Bit16u)val;
+			xga.foremix = (uint16_t)val;
 			break;
 		case 0x8138:// DWORD top scissors (low word) and left scissors (high
 					// word) (see PORT BEE8h,#P1047)
@@ -1153,10 +1153,10 @@ void XGA_Write(Bitu port, Bitu val, Bitu len) {
 			//LOG_MSG("COLOR_CMP not implemented");
 			break;
 		case 0xb6e8:
-			xga.backmix = (Bit16u)val;
+			xga.backmix = (uint16_t)val;
 			break;
 		case 0xbae8:
-			xga.foremix = (Bit16u)val;
+			xga.foremix = (uint16_t)val;
 			break;
 		case 0xbee8:
 			XGA_Write_Multifunc(val, len);
