@@ -51,7 +51,7 @@ imageDiskVHD::ErrorCodes imageDiskVHD::Open(const char* fileName, const bool rea
 	return Open(fileName, readOnly, disk, 0);
 }
 
-imageDiskVHD::ErrorCodes imageDiskVHD::Open(const char* fileName, const bool readOnly, imageDisk** disk, const Bit8u* matchUniqueId) {
+imageDiskVHD::ErrorCodes imageDiskVHD::Open(const char* fileName, const bool readOnly, imageDisk** disk, const uint8_t* matchUniqueId) {
 	//validate input parameters
 	if (fileName == NULL) return ERROR_OPENING;
 	if (disk == NULL) return ERROR_OPENING;
@@ -67,8 +67,8 @@ imageDiskVHD::ErrorCodes imageDiskVHD::Open(const char* fileName, const bool rea
 	if (ftello64(file) < 512) { fclose(file); return INVALID_DATA; }
 	//read footer
 	if (fseeko64(file, -512L, SEEK_CUR)) { fclose(file); return INVALID_DATA; }
-	Bit64u footerPosition = (Bit64u)((Bit64s)ftello64(file)); /* make sure to sign extend! */
-	if ((Bit64s)footerPosition < 0LL) { fclose(file); return INVALID_DATA; }
+	uint64_t footerPosition = (uint64_t)((int64_t)ftello64(file)); /* make sure to sign extend! */
+	if ((int64_t)footerPosition < 0LL) { fclose(file); return INVALID_DATA; }
 	VHDFooter originalfooter;
 	VHDFooter footer;
 	if (fread(&originalfooter, 512, 1, file) != 1) { fclose(file); return INVALID_DATA; }
@@ -79,7 +79,7 @@ imageDiskVHD::ErrorCodes imageDiskVHD::Open(const char* fileName, const bool rea
 	if (!footer.IsValid()) {
 		//if invalid, read header, and verify checksum on header
 		if (fseeko64(file, 0L, SEEK_SET)) { fclose(file); return INVALID_DATA; }
-		if (fread(&originalfooter, sizeof(Bit8u), 512, file) != 512) { fclose(file); return INVALID_DATA; }
+		if (fread(&originalfooter, sizeof(uint8_t), 512, file) != 512) { fclose(file); return INVALID_DATA; }
 		//convert from big-endian if necessary
 		footer = originalfooter;
 		footer.SwapByteOrder();
@@ -89,7 +89,7 @@ imageDiskVHD::ErrorCodes imageDiskVHD::Open(const char* fileName, const bool rea
 	//check that uniqueId matches
 	if (matchUniqueId && memcmp(matchUniqueId, footer.uniqueId, 16)) { fclose(file); return INVALID_MATCH; }
 	//calculate disk size
-	Bit64u calcDiskSize = (Bit64u)footer.geometry.cylinders * (Bit64u)footer.geometry.heads * (Bit64u)footer.geometry.sectors * (Bit64u)512;
+	uint64_t calcDiskSize = (uint64_t)footer.geometry.cylinders * (uint64_t)footer.geometry.heads * (uint64_t)footer.geometry.sectors * (uint64_t)512;
 	if (!calcDiskSize) { fclose(file); return INVALID_DATA; }
 	//if fixed image, return plain imageDisk rather than imageDiskVFD
 	if (footer.diskType == VHD_TYPE_FIXED) {
@@ -127,7 +127,7 @@ imageDiskVHD::ErrorCodes imageDiskVHD::Open(const char* fileName, const bool rea
 	//read dynamic disk header (applicable for dynamic and differencing types)
 	DynamicHeader dynHeader;
 	if (fseeko64(file, (off_t)footer.dataOffset, SEEK_SET)) { delete vhd; return INVALID_DATA; }
-	if (fread(&dynHeader, sizeof(Bit8u), 1024, file) != 1024) { delete vhd; return INVALID_DATA; }
+	if (fread(&dynHeader, sizeof(uint8_t), 1024, file) != 1024) { delete vhd; return INVALID_DATA; }
 	//swap byte order and validate checksum
 	dynHeader.SwapByteOrder();
 	if (!dynHeader.IsValid()) { delete vhd; return INVALID_DATA; }
@@ -142,14 +142,14 @@ imageDiskVHD::ErrorCodes imageDiskVHD::Open(const char* fileName, const bool rea
 			//ignore entries with platform code 'none'
 			if (dynHeader.parentLocatorEntry[i].platformCode != 0) {
 				//load the platform data, if there is any
-				Bit64u dataOffset = dynHeader.parentLocatorEntry[i].platformDataOffset;
-				Bit32u dataLength = dynHeader.parentLocatorEntry[i].platformDataLength;
-				Bit8u* buffer = 0;
-				if (dataOffset && dataLength && ((Bit64u)dataOffset + dataLength) <= footerPosition) {
+				uint64_t dataOffset = dynHeader.parentLocatorEntry[i].platformDataOffset;
+				uint32_t dataLength = dynHeader.parentLocatorEntry[i].platformDataLength;
+				uint8_t* buffer = 0;
+				if (dataOffset && dataLength && ((uint64_t)dataOffset + dataLength) <= footerPosition) {
 					if (fseeko64(file, (off_t)dataOffset, SEEK_SET)) { delete vhd; return INVALID_DATA; }
-					buffer = (Bit8u*)malloc(dataLength + 2);
+					buffer = (uint8_t*)malloc(dataLength + 2);
 					if (buffer == 0) { delete vhd; return INVALID_DATA; }
-					if (fread(buffer, sizeof(Bit8u), dataLength, file) != dataLength) { free(buffer); delete vhd; return INVALID_DATA; }
+					if (fread(buffer, sizeof(uint8_t), dataLength, file) != dataLength) { free(buffer); delete vhd; return INVALID_DATA; }
 					buffer[dataLength] = 0; //append null character, just in case
 					buffer[dataLength + 1] = 0; //two bytes, because this might be UTF-16
 				}
@@ -170,24 +170,24 @@ imageDiskVHD::ErrorCodes imageDiskVHD::Open(const char* fileName, const bool rea
 	}
 
 	//calculate sectors per block
-	Bit32u sectorsPerBlock = dynHeader.blockSize / 512;
+	uint32_t sectorsPerBlock = dynHeader.blockSize / 512;
 	//calculate block map size
-	Bit32u blockMapSectors = ((
+	uint32_t blockMapSectors = ((
 		((sectorsPerBlock /* 4096 sectors/block (typ) = 4096 bits required */
 		+ 7) / 8) /* convert to bytes and round up to nearest byte; 4096/8 = 512 bytes required */
 		+ 511) / 512); /* convert to sectors and round up to nearest sector; 512/512 = 1 sector */
 	//check that the BAT is large enough for the disk
-	Bit32u tablesRequired = (Bit32u)((calcDiskSize + (dynHeader.blockSize - 1)) / dynHeader.blockSize);
+	uint32_t tablesRequired = (uint32_t)((calcDiskSize + (dynHeader.blockSize - 1)) / dynHeader.blockSize);
 	if (dynHeader.maxTableEntries < tablesRequired) { delete vhd; return INVALID_DATA; }
 	//check that the BAT is contained within the file
-	if (((Bit64u)dynHeader.tableOffset + ((Bit64u)dynHeader.maxTableEntries * (Bit64u)4)) > footerPosition) { delete vhd; return INVALID_DATA; }
+	if (((uint64_t)dynHeader.tableOffset + ((uint64_t)dynHeader.maxTableEntries * (uint64_t)4)) > footerPosition) { delete vhd; return INVALID_DATA; }
 
 	//set remaining variables
 	vhd->dynamicHeader = dynHeader;
 	vhd->blockMapSectors = blockMapSectors;
 	vhd->blockMapSize = blockMapSectors * 512;
 	vhd->sectorsPerBlock = sectorsPerBlock;
-	vhd->currentBlockDirtyMap = (Bit8u*)malloc(vhd->blockMapSize);
+	vhd->currentBlockDirtyMap = (uint8_t*)malloc(vhd->blockMapSize);
 	if (vhd->currentBlockDirtyMap == 0) { delete vhd; return INVALID_DATA; }
 
 	//try loading the first block
@@ -205,7 +205,7 @@ int iso8859_1_encode(int utf32code) {
 }
 
 //this function (1) converts data from UTF-16 to a native string for fopen (depending on the host OS), and (2) converts slashes, if necessary
-bool imageDiskVHD::convert_UTF16_for_fopen(std::string &string, const void* data, const Bit32u dataLength) {
+bool imageDiskVHD::convert_UTF16_for_fopen(std::string &string, const void* data, const uint32_t dataLength) {
 	//note: data is UTF-16 and always little-endian, with no null terminator
 	//dataLength is not the number of characters, but the number of bytes
 
@@ -244,7 +244,7 @@ bool imageDiskVHD::convert_UTF16_for_fopen(std::string &string, const void* data
 	return true;
 }
 
-imageDiskVHD::ErrorCodes imageDiskVHD::TryOpenParent(const char* childFileName, const imageDiskVHD::ParentLocatorEntry& entry, const Bit8u* data, const Bit32u dataLength, imageDisk** disk, const Bit8u* uniqueId) {
+imageDiskVHD::ErrorCodes imageDiskVHD::TryOpenParent(const char* childFileName, const imageDiskVHD::ParentLocatorEntry& entry, const uint8_t* data, const uint32_t dataLength, imageDisk** disk, const uint8_t* uniqueId) {
 	std::string str = "";
 	const char* slashpos = NULL;
 
@@ -297,17 +297,17 @@ imageDiskVHD::ErrorCodes imageDiskVHD::TryOpenParent(const char* childFileName,
 	return ERROR_OPENING; //return ERROR_OPENING if the file does not exist, cannot be accessed, etc
 }
 
-Bit8u imageDiskVHD::Read_AbsoluteSector(Bit32u sectnum, void * data) {
-	Bit32u blockNumber = sectnum / sectorsPerBlock;
-	Bit32u sectorOffset = sectnum % sectorsPerBlock;
+uint8_t imageDiskVHD::Read_AbsoluteSector(uint32_t sectnum, void * data) {
+	uint32_t blockNumber = sectnum / sectorsPerBlock;
+	uint32_t sectorOffset = sectnum % sectorsPerBlock;
 	if (!loadBlock(blockNumber)) return 0x05; //can't load block
 	if (currentBlockAllocated) {
-		Bit32u byteNum = sectorOffset / 8;
-		Bit32u bitNum = sectorOffset % 8;
+		uint32_t byteNum = sectorOffset / 8;
+		uint32_t bitNum = sectorOffset % 8;
 		bool hasData = currentBlockDirtyMap[byteNum] & (1 << (7 - bitNum));
 		if (hasData) {
-			if (fseeko64(diskimg, (off_t)(((Bit64u)currentBlockSectorOffset + blockMapSectors + sectorOffset) * 512ull), SEEK_SET)) return 0x05; //can't seek
-			if (fread(data, sizeof(Bit8u), 512, diskimg) != 512) return 0x05; //can't read
+			if (fseeko64(diskimg, (off_t)(((uint64_t)currentBlockSectorOffset + blockMapSectors + sectorOffset) * 512ull), SEEK_SET)) return 0x05; //can't seek
+			if (fread(data, sizeof(uint8_t), 512, diskimg) != 512) return 0x05; //can't read
 			return 0;
 		}
 	}
@@ -320,59 +320,59 @@ Bit8u imageDiskVHD::Read_AbsoluteSector(Bit32u sectnum, void * data) {
 	}
 }
 
-Bit8u imageDiskVHD::Write_AbsoluteSector(Bit32u sectnum, const void * data) {
-	Bit32u blockNumber = sectnum / sectorsPerBlock;
-	Bit32u sectorOffset = sectnum % sectorsPerBlock;
+uint8_t imageDiskVHD::Write_AbsoluteSector(uint32_t sectnum, const void * data) {
+	uint32_t blockNumber = sectnum / sectorsPerBlock;
+	uint32_t sectorOffset = sectnum % sectorsPerBlock;
 	if (!loadBlock(blockNumber)) return 0x05; //can't load block
 	if (!currentBlockAllocated) {
 		if (!copiedFooter) {
 			//write backup of footer at start of file (should already exist, but we never checked to be sure it is readable or matches the footer we used)
 			if (fseeko64(diskimg, (off_t)0, SEEK_SET)) return 0x05;
-			if (fwrite(&originalFooter, sizeof(Bit8u), 512, diskimg) != 512) return 0x05;
+			if (fwrite(&originalFooter, sizeof(uint8_t), 512, diskimg) != 512) return 0x05;
 			copiedFooter = true;
 			//flush the data to disk after writing the backup footer
 			if (fflush(diskimg)) return 0x05;
 		}
 		//calculate new location of footer, and round up to nearest 512 byte increment "just in case"
-		Bit64u newFooterPosition = (((footerPosition - 512ull + blockMapSize + dynamicHeader.blockSize) + 511ull) / 512ull) * 512ull;
+		uint64_t newFooterPosition = (((footerPosition - 512ull + blockMapSize + dynamicHeader.blockSize) + 511ull) / 512ull) * 512ull;
 		//attempt to extend the length appropriately first (on some operating systems this will extend the file)
 		if (fseeko64(diskimg, (off_t)newFooterPosition + 512, SEEK_SET)) return 0x05;
 		//now write the footer
 		if (fseeko64(diskimg, (off_t)newFooterPosition, SEEK_SET)) return 0x05;
-		if (fwrite(&originalFooter, sizeof(Bit8u), 512, diskimg) != 512) return 0x05;
+		if (fwrite(&originalFooter, sizeof(uint8_t), 512, diskimg) != 512) return 0x05;
 		//save the new block location and new footer position
-		Bit32u newBlockSectorNumber = (Bit32u)((footerPosition + 511ul) / 512ul);
+		uint32_t newBlockSectorNumber = (uint32_t)((footerPosition + 511ul) / 512ul);
 		footerPosition = newFooterPosition;
 		//clear the dirty flags for the new footer position
-		for (Bit32u i = 0; i < blockMapSize; i++) currentBlockDirtyMap[i] = 0;
+		for (uint32_t i = 0; i < blockMapSize; i++) currentBlockDirtyMap[i] = 0;
 		//write the dirty map
 		if (fseeko64(diskimg, (off_t)(newBlockSectorNumber * 512ull), SEEK_SET)) return 0x05;
-		if (fwrite(currentBlockDirtyMap, sizeof(Bit8u), blockMapSize, diskimg) != blockMapSize) return 0x05;
+		if (fwrite(currentBlockDirtyMap, sizeof(uint8_t), blockMapSize, diskimg) != blockMapSize) return 0x05;
 		//flush the data to disk after expanding the file, before allocating the block in the BAT
 		if (fflush(diskimg)) return 0x05;
 		//update the BAT
 		if (fseeko64(diskimg, (off_t)(dynamicHeader.tableOffset + (blockNumber * 4ull)), SEEK_SET)) return 0x05;
-		Bit32u newBlockSectorNumberBE = SDL_SwapBE32(newBlockSectorNumber);
-		if (fwrite(&newBlockSectorNumberBE, sizeof(Bit8u), 4, diskimg) != 4) return false;
+		uint32_t newBlockSectorNumberBE = SDL_SwapBE32(newBlockSectorNumber);
+		if (fwrite(&newBlockSectorNumberBE, sizeof(uint8_t), 4, diskimg) != 4) return false;
 		currentBlockAllocated = true;
 		currentBlockSectorOffset = newBlockSectorNumber;
 		//flush the data to disk after allocating a block
 		if (fflush(diskimg)) return 0x05;
 	}
 	//current block has now been allocated
-	Bit32u byteNum = sectorOffset / 8;
-	Bit32u bitNum = sectorOffset % 8;
+	uint32_t byteNum = sectorOffset / 8;
+	uint32_t bitNum = sectorOffset % 8;
 	bool hasData = currentBlockDirtyMap[byteNum] & (1 << (7 - bitNum));
 	//if the sector hasn't been marked as dirty, mark it as dirty
 	if (!hasData) {
 		currentBlockDirtyMap[byteNum] |= 1 << (7 - bitNum);
 		if (fseeko64(diskimg, (off_t)(currentBlockSectorOffset * 512ull), SEEK_SET)) return 0x05; //can't seek
-		if (fwrite(currentBlockDirtyMap, sizeof(Bit8u), blockMapSize, diskimg) != blockMapSize) return 0x05;
+		if (fwrite(currentBlockDirtyMap, sizeof(uint8_t), blockMapSize, diskimg) != blockMapSize) return 0x05;
 	}
 	//current sector has now been marked as dirty
 	//write the sector
-	if (fseeko64(diskimg, (off_t)(((Bit64u)currentBlockSectorOffset + (Bit64u)blockMapSectors + (Bit64u)sectorOffset) * 512ull), SEEK_SET)) return 0x05; //can't seek
-	if (fwrite(data, sizeof(Bit8u), 512, diskimg) != 512) return 0x05; //can't write
+	if (fseeko64(diskimg, (off_t)(((uint64_t)currentBlockSectorOffset + (uint64_t)blockMapSectors + (uint64_t)sectorOffset) * 512ull), SEEK_SET)) return 0x05; //can't seek
+	if (fwrite(data, sizeof(uint8_t), 512, diskimg) != 512) return 0x05; //can't write
 	return 0;
 }
 
@@ -386,23 +386,23 @@ imageDiskVHD::VHDTypes imageDiskVHD::GetVHDType(const char* fileName) {
 	return ret;
 }
 
-bool imageDiskVHD::loadBlock(const Bit32u blockNumber) {
+bool imageDiskVHD::loadBlock(const uint32_t blockNumber) {
 	if (currentBlock == blockNumber) return true;
 	if (blockNumber >= dynamicHeader.maxTableEntries) return false;
 	if (fseeko64(diskimg, (off_t)(dynamicHeader.tableOffset + (blockNumber * 4ull)), SEEK_SET)) return false;
-	Bit32u blockSectorOffset;
-	if (fread(&blockSectorOffset, sizeof(Bit8u), 4, diskimg) != 4) return false;
+	uint32_t blockSectorOffset;
+	if (fread(&blockSectorOffset, sizeof(uint8_t), 4, diskimg) != 4) return false;
 	blockSectorOffset = SDL_SwapBE32(blockSectorOffset);
 	if (blockSectorOffset == 0xFFFFFFFFul) {
 		currentBlock = blockNumber;
 		currentBlockAllocated = false;
 	}
 	else {
-		if (fseeko64(diskimg, (off_t)(blockSectorOffset * (Bit64u)512), SEEK_SET)) return false;
+		if (fseeko64(diskimg, (off_t)(blockSectorOffset * (uint64_t)512), SEEK_SET)) return false;
 		currentBlock = 0xFFFFFFFFul;
 		currentBlockAllocated = true;
 		currentBlockSectorOffset = blockSectorOffset;
-		if (fread(currentBlockDirtyMap, sizeof(Bit8u), blockMapSize, diskimg) != blockMapSize) return false;
+		if (fread(currentBlockDirtyMap, sizeof(uint8_t), blockMapSize, diskimg) != blockMapSize) return false;
 		currentBlock = blockNumber;
 	}
 	return true;
@@ -429,21 +429,21 @@ void imageDiskVHD::VHDFooter::SwapByteOrder() {
 	originalSize = SDL_SwapBE64(originalSize);
 	currentSize = SDL_SwapBE64(currentSize);
 	geometry.cylinders = SDL_SwapBE16(geometry.cylinders);
-	diskType = (VHDTypes)SDL_SwapBE32((Bit32u)diskType);
+	diskType = (VHDTypes)SDL_SwapBE32((uint32_t)diskType);
 	checksum = SDL_SwapBE32(checksum);
 	//guid might need the byte order swapped also
 	//however, for our purposes (comparing to the parent guid on differential disks),
 	//  it doesn't matter so long as we are consistent
 }
 
-Bit32u imageDiskVHD::VHDFooter::CalculateChecksum() {
+uint32_t imageDiskVHD::VHDFooter::CalculateChecksum() {
 	//checksum is one's complement of sum of bytes excluding the checksum
 	//because of that, the byte order doesn't matter when calculating the checksum
 	//however, the checksum must be stored in the correct byte order or it will not match
 
-	Bit32u ret = 0;
-    const Bit8u* dat = (Bit8u*)this->cookie;
-	Bit32u oldChecksum = checksum;
+	uint32_t ret = 0;
+    const uint8_t* dat = (uint8_t*)this->cookie;
+	uint32_t oldChecksum = checksum;
 	checksum = 0;
 	for (size_t i = 0; i < sizeof(VHDFooter); i++) {
 		ret += dat[i];
@@ -483,14 +483,14 @@ void imageDiskVHD::DynamicHeader::SwapByteOrder() {
 	//  it doesn't matter so long as we are consistent
 }
 
-Bit32u imageDiskVHD::DynamicHeader::CalculateChecksum() {
+uint32_t imageDiskVHD::DynamicHeader::CalculateChecksum() {
 	//checksum is one's complement of sum of bytes excluding the checksum
 	//because of that, the byte order doesn't matter when calculating the checksum
 	//however, the checksum must be stored in the correct byte order or it will not match
 
-	Bit32u ret = 0;
-    const Bit8u* dat = (Bit8u*)this->cookie;
-	Bit32u oldChecksum = checksum;
+	uint32_t ret = 0;
+    const uint8_t* dat = (uint8_t*)this->cookie;
+	uint32_t oldChecksum = checksum;
 	checksum = 0;
 	for (size_t i = 0; i < sizeof(DynamicHeader); i++) {
 		ret += dat[i];
