@@ -97,7 +97,7 @@ bool xms_hma_alloc_non_dos_kernel_control = true;
 struct XMS_Block {
 	Bitu	size;
 	MemHandle mem;
-	Bit8u	locked;
+	uint8_t	locked;
 	bool	free;
 };
 
@@ -105,16 +105,16 @@ struct XMS_Block {
 #pragma pack (1)
 #endif
 struct XMS_MemMove{
-	Bit32u length;
-	Bit16u src_handle;
+	uint32_t length;
+	uint16_t src_handle;
 	union {
 		RealPt realpt;
-		Bit32u offset;
+		uint32_t offset;
 	} src;
-	Bit16u dest_handle;
+	uint16_t dest_handle;
 	union {
 		RealPt realpt;
-		Bit32u offset;
+		uint32_t offset;
 	} dest;
 
 } GCC_ATTRIBUTE(packed);
@@ -135,7 +135,7 @@ Bitu XMS_EnableA20(bool enable) {
     }
     else {
         // IBM PC/AT: Port 0x92, bit 1, set if A20 enabled
-        Bit8u val = IO_Read(0x92);
+        uint8_t val = IO_Read(0x92);
         if (enable) IO_Write(0x92,val | 2);
         else		IO_Write(0x92,val & ~2);
     }
@@ -187,10 +187,10 @@ static INLINE bool InvalidHandle(Bitu handle) {
 	return (!handle || (handle>=XMS_HANDLES) || xms_handles[handle].free);
 }
 
-Bitu XMS_QueryFreeMemory(Bit32u& largestFree, Bit32u& totalFree) {
+Bitu XMS_QueryFreeMemory(uint32_t& largestFree, uint32_t& totalFree) {
 	/* Scan the tree for free memory and find largest free block */
-	totalFree=(Bit32u)(MEM_FreeTotal()*4);
-	largestFree=(Bit32u)(MEM_FreeLargest()*4);
+	totalFree=(uint32_t)(MEM_FreeTotal()*4);
+	largestFree=(uint32_t)(MEM_FreeLargest()*4);
 	if (!totalFree) return XMS_OUT_OF_SPACE;
 	return 0;
 }
@@ -212,9 +212,9 @@ void XMS_ZeroAllocation(MemHandle mem,unsigned int pages) {
 extern bool enable_a20_on_windows_init;
 extern bool dbg_zero_on_xms_allocmem;
 
-Bitu XMS_AllocateMemory(Bitu size, Bit16u& handle) {	// size = kb
+Bitu XMS_AllocateMemory(Bitu size, uint16_t& handle) {	// size = kb
 	/* Find free handle */
-	Bit16u index=1;
+	uint16_t index=1;
 	while (!xms_handles[index].free) {
 		if (++index>=XMS_HANDLES) return XMS_OUT_OF_HANDLES;
 	}
@@ -257,7 +257,7 @@ Bitu XMS_MoveMemory(PhysPt bpt) {
 	Bitu src_handle=mem_readw(bpt+offsetof(XMS_MemMove,src_handle));
 	union {
 		RealPt realpt;
-		Bit32u offset;
+		uint32_t offset;
 	} src,dest;
 	src.offset=mem_readd(bpt+offsetof(XMS_MemMove,src.offset));
 	Bitu dest_handle=mem_readw(bpt+offsetof(XMS_MemMove,dest_handle));
@@ -319,7 +319,7 @@ Bitu XMS_MoveMemory(PhysPt bpt) {
     return 0;
 }
 
-Bitu XMS_LockMemory(Bitu handle, Bit32u& address) {
+Bitu XMS_LockMemory(Bitu handle, uint32_t& address) {
 	if (InvalidHandle(handle)) return XMS_INVALID_HANDLE;
 	if (xms_handles[handle].locked<255) xms_handles[handle].locked++;
 	address = (unsigned long)xms_handles[handle].mem * 4096UL;
@@ -335,7 +335,7 @@ Bitu XMS_UnlockMemory(Bitu handle) {
 	return XMS_BLOCK_NOT_LOCKED;
 }
 
-Bitu XMS_GetHandleInformation(Bitu handle, Bit8u& lockCount, Bit8u& numFree, Bit32u& size) {
+Bitu XMS_GetHandleInformation(Bitu handle, uint8_t& lockCount, uint8_t& numFree, uint32_t& size) {
 	if (InvalidHandle(handle)) return XMS_INVALID_HANDLE;
 	lockCount = xms_handles[handle].locked;
 	/* Find available blocks */
@@ -343,7 +343,7 @@ Bitu XMS_GetHandleInformation(Bitu handle, Bit8u& lockCount, Bit8u& numFree, Bit
 	for (Bitu i=1;i<XMS_HANDLES;i++) {
 		if (xms_handles[i].free) numFree++;
 	}
-	size=(Bit32u)(xms_handles[handle].size);
+	size=(uint32_t)(xms_handles[handle].size);
 	return 0;
 }
 
@@ -373,7 +373,7 @@ static bool multiplex_xms(void) {
 }
 
 INLINE void SET_RESULT(Bitu res,bool touch_bl_on_succes=true) {
-	if(touch_bl_on_succes || res) reg_bl = (Bit8u)res;
+	if(touch_bl_on_succes || res) reg_bl = (uint8_t)res;
 	reg_ax = (res==0)?1:0;
 }
 
@@ -487,11 +487,11 @@ Bitu XMS_Handler(void) {
         SET_RESULT(XMS_LocalDisableA20());
 		break;
 	case XMS_QUERY_A20:											/* 07 */
-		reg_ax = (Bit16u)XMS_GetEnabledA20();
+		reg_ax = (uint16_t)XMS_GetEnabledA20();
 		reg_bl = 0;
 		break;
 	case XMS_QUERY_FREE_EXTENDED_MEMORY:						/* 08 */
-		reg_bl = (Bit8u)XMS_QueryFreeMemory(reg_eax,reg_edx);
+		reg_bl = (uint8_t)XMS_QueryFreeMemory(reg_eax,reg_edx);
 		if (reg_eax > 65535) reg_eax = 65535; /* cap sizes for older DOS programs. newer ones use function 0x88 */
 		if (reg_edx > 65535) reg_edx = 65535;
 		break;
@@ -499,13 +499,13 @@ Bitu XMS_Handler(void) {
 		{ /* Chopping off bits 16-31 to fall through to ALLOCATE_EXTENDED_MEMORY is inaccurate.
 		     The Extended Memory Specification states you use all of EDX, so programs can request
 		     64MB or more. Even if DOSBox does not (yet) support >= 64MB of RAM. */
-		Bit16u handle = 0;
+		uint16_t handle = 0;
 		SET_RESULT(XMS_AllocateMemory(reg_edx,handle));
 		reg_dx = handle;
 		} break;
 	case XMS_ALLOCATE_EXTENDED_MEMORY:							/* 09 */
 		{
-		Bit16u handle = 0;
+		uint16_t handle = 0;
 		SET_RESULT(XMS_AllocateMemory(reg_dx,handle));
 		reg_dx = handle;
 		} break;
@@ -516,13 +516,13 @@ Bitu XMS_Handler(void) {
 		SET_RESULT(XMS_MoveMemory(SegPhys(ds)+reg_si),false);
 		break;
 	case XMS_LOCK_EXTENDED_MEMORY_BLOCK: {						/* 0c */
-		Bit32u address;
+		uint32_t address;
 		Bitu res = XMS_LockMemory(reg_dx, address);
-		if(res) reg_bl = (Bit8u)res;
+		if(res) reg_bl = (uint8_t)res;
 		reg_ax = (res==0);
 		if (res==0) { // success
-			reg_bx=(Bit16u)(address & 0xFFFF);
-			reg_dx=(Bit16u)(address >> 16);
+			reg_bx=(uint16_t)(address & 0xFFFF);
+			reg_dx=(uint16_t)(address >> 16);
 		}
 		} break;
 	case XMS_UNLOCK_EXTENDED_MEMORY_BLOCK:						/* 0d */
@@ -544,7 +544,7 @@ Bitu XMS_Handler(void) {
 			reg_bl=XMS_FUNCTION_NOT_IMPLEMENTED;
 			break;
 		}
-		Bit16u umb_start=dos_infoblock.GetStartOfUMBChain();
+		uint16_t umb_start=dos_infoblock.GetStartOfUMBChain();
 		if (umb_start==0xffff) {
 			reg_ax=0;
 			reg_bl=UMB_NO_BLOCKS_AVAILABLE;
@@ -553,12 +553,12 @@ Bitu XMS_Handler(void) {
 		}
 		/* Save status and linkage of upper UMB chain and link upper
 		   memory to the regular MCB chain */
-		Bit8u umb_flag=dos_infoblock.GetUMBChainState();
+		uint8_t umb_flag=dos_infoblock.GetUMBChainState();
 		if ((umb_flag&1)==0) DOS_LinkUMBsToMemChain(1);
-		Bit8u old_memstrat=DOS_GetMemAllocStrategy()&0xff;
+		uint8_t old_memstrat=DOS_GetMemAllocStrategy()&0xff;
 		DOS_SetMemAllocStrategy(0x40);	// search in UMBs only
 
-		Bit16u size=reg_dx;Bit16u seg;
+		uint16_t size=reg_dx;uint16_t seg;
 		if (DOS_AllocateMemory(&seg,&size)) {
 			reg_ax=1;
 			reg_bx=seg;
@@ -570,7 +570,7 @@ Bitu XMS_Handler(void) {
 		}
 
 		/* Restore status and linkage of upper UMB chain */
-		Bit8u current_umb_flag=dos_infoblock.GetUMBChainState();
+		uint8_t current_umb_flag=dos_infoblock.GetUMBChainState();
 		if ((current_umb_flag&1)!=(umb_flag&1)) DOS_LinkUMBsToMemChain(umb_flag);
 		DOS_SetMemAllocStrategy(old_memstrat);
 		}
@@ -591,13 +591,13 @@ Bitu XMS_Handler(void) {
 		reg_bl=UMB_NO_BLOCKS_AVAILABLE;
 		break;
 	case XMS_QUERY_ANY_FREE_MEMORY:								/* 88 */
-		reg_bl = (Bit8u)XMS_QueryFreeMemory(reg_eax,reg_edx);
-		reg_ecx = (Bit32u)((MEM_TotalPages()*MEM_PAGESIZE)-1);			// highest known physical memory address
+		reg_bl = (uint8_t)XMS_QueryFreeMemory(reg_eax,reg_edx);
+		reg_ecx = (uint32_t)((MEM_TotalPages()*MEM_PAGESIZE)-1);			// highest known physical memory address
 		break;
 	case XMS_GET_EMB_HANDLE_INFORMATION_EXT: {					/* 8e */
-		Bit8u free_handles;
+		uint8_t free_handles;
 		Bitu result = XMS_GetHandleInformation(reg_dx,reg_bh,free_handles,reg_edx);
-		if (result != 0) reg_bl = (Bit8u)result;
+		if (result != 0) reg_bl = (uint8_t)result;
 		else reg_cx = free_handles;
 		reg_ax = (result==0);
 		} break;
@@ -739,10 +739,10 @@ public:
 
 		if (first_umb_seg == 0) {
 			first_umb_seg = DOS_PRIVATE_SEGMENT_END;
-			if (first_umb_seg < (Bit16u)VGA_BIOS_SEG_END)
-				first_umb_seg = (Bit16u)VGA_BIOS_SEG_END;
+			if (first_umb_seg < (uint16_t)VGA_BIOS_SEG_END)
+				first_umb_seg = (uint16_t)VGA_BIOS_SEG_END;
 		}
-		if (first_umb_size == 0) first_umb_size = (Bit16u)(ROMBIOS_MinAllocatedLoc()>>4);
+		if (first_umb_size == 0) first_umb_size = (uint16_t)(ROMBIOS_MinAllocatedLoc()>>4);
 
 		if (first_umb_seg < 0xC000 || first_umb_seg < DOS_PRIVATE_SEGMENT_END) {
 			LOG(LOG_MISC,LOG_WARN)("UMB blocks before 0xD000 conflict with VGA (0xA000-0xBFFF), VGA BIOS (0xC000-0xC7FF) and DOSBox private area (0x%04x-0x%04x)",
@@ -794,7 +794,7 @@ public:
         if (ems_available && first_umb_size >= GetEMSPageFrameSegment()) {
             assert(GetEMSPageFrameSegment() >= 0xA000);
             LOG(LOG_MISC,LOG_DEBUG)("UMB overlaps EMS page frame at 0x%04x, truncating region",(unsigned int)GetEMSPageFrameSegment());
-            first_umb_size = (Bit16u)(GetEMSPageFrameSegment() - 1);
+            first_umb_size = (uint16_t)(GetEMSPageFrameSegment() - 1);
         }
         /* UMB cannot interfere with EGC 4th graphics bitplane on PC-98 */
         /* TODO: Allow UMB into E000:xxxx if emulating a PC-98 that lacks 16-color mode. */
@@ -854,10 +854,11 @@ public:
 };
 
 static XMS* test = NULL;
+extern const char* RunningProgram;
 
 void XMS_DoShutDown() {
 	if (test != NULL) {
-		delete test;	
+		if (strcmp(RunningProgram, "LOADLIN")) delete test;
 		test = NULL;
 	}
 }
