@@ -3,7 +3,7 @@
  *
  *  Copyright (C) 2001-2017  Ryan C. Gordon <icculus@icculus.org>
  *  Copyright (C) 2018-2019  Kevin R. Croft <krcroft@gmail.com>
- *  Copyright (C) 2020-2020  The dosbox-staging team
+ *  Copyright (C) 2020-2020  The DOSBox Staging Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -133,7 +133,7 @@ static Uint32 FLAC_read(Sound_Sample *sample)
     const drflac_uint64 rc = drflac_read_pcm_frames_s16(dr,
                                                         internal->buffer_size / (dr->channels * sizeof(drflac_int16)),
                                                         (drflac_int16 *) internal->buffer);
-    return rc * dr->channels * sizeof (drflac_int16);
+    return (Uint32)(rc * dr->channels * sizeof (drflac_int16));
 } /* FLAC_read */
 
 
