@@ -3,7 +3,7 @@
  *
  *  Copyright (C) 2001-2017  Ryan C. Gordon <icculus@icculus.org>
  *  Copyright (C) 2018-2019  Kevin R. Croft <krcroft@gmail.com>
- *  Copyright (C) 2020-2020  The dosbox-staging team
+ *  Copyright (C) 2020-2020  The DOSBox Staging Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -105,7 +105,7 @@ static Uint32 MP3_read(Sound_Sample* const sample)
 
     // setup our 16-bit output buffer
     drmp3_int16* out_buffer = (drmp3_int16 *)(internal->buffer);
-    drmp3_uint16 remaining_frames = (internal->buffer_size  / sizeof(drmp3_int16)) / channels;
+    drmp3_uint16 remaining_frames = (drmp3_uint16)((internal->buffer_size  / sizeof(drmp3_int16)) / channels);
 
     // LOG_MSG("read: remaining_frames: %u", remaining_frames);
     drmp3_uint16 total_samples_read = 0;
@@ -113,7 +113,7 @@ static Uint32 MP3_read(Sound_Sample* const sample)
         const drmp3_uint16 num_frames = (remaining_frames > in_buffer_frame_capacity) ? in_buffer_frame_capacity : remaining_frames;
 
         // LOG_MSG("read-while: num_frames: %u", num_frames);
-        const drmp3_uint16 frames_just_read = drmp3_read_pcm_frames_f32(p_mp3->p_dr, num_frames, in_buffer);
+        const drmp3_uint16 frames_just_read = (drmp3_uint16)drmp3_read_pcm_frames_f32(p_mp3->p_dr, num_frames, in_buffer);
 
         // LOG_MSG("read-while: frames_just_read: %u", frames_just_read);
         if (frames_just_read == 0) break; // Reached the end.
