@@ -14,6 +14,7 @@
 #include <algorithm>
 
 #include "sdlmain.h"
+#include "render.h"
 
 using namespace std;
 
@@ -27,6 +28,56 @@ PFNGLBUFFERDATAARBPROC glBufferDataARB = NULL;
 PFNGLMAPBUFFERARBPROC glMapBufferARB = NULL;
 PFNGLUNMAPBUFFERARBPROC glUnmapBufferARB = NULL;
 
+/* Apple defines these functions in their GL header (as core functions)
+ * so we can't use their names as function pointers. We can't link
+ * directly as some platforms may not have them. So they get their own
+ * namespace here to keep the official names but avoid collisions.
+ */
+namespace gl2 {
+PFNGLATTACHSHADERPROC glAttachShader = NULL;
+PFNGLCOMPILESHADERPROC glCompileShader = NULL;
+PFNGLCREATEPROGRAMPROC glCreateProgram = NULL;
+PFNGLCREATESHADERPROC glCreateShader = NULL;
+PFNGLDELETEPROGRAMPROC glDeleteProgram = NULL;
+PFNGLDELETESHADERPROC glDeleteShader = NULL;
+PFNGLENABLEVERTEXATTRIBARRAYPROC glEnableVertexAttribArray = NULL;
+PFNGLGETATTRIBLOCATIONPROC glGetAttribLocation = NULL;
+PFNGLGETPROGRAMIVPROC glGetProgramiv = NULL;
+PFNGLGETPROGRAMINFOLOGPROC glGetProgramInfoLog = NULL;
+PFNGLGETSHADERIVPROC glGetShaderiv = NULL;
+PFNGLGETSHADERINFOLOGPROC glGetShaderInfoLog = NULL;
+PFNGLGETUNIFORMLOCATIONPROC glGetUniformLocation = NULL;
+PFNGLLINKPROGRAMPROC glLinkProgram = NULL;
+PFNGLSHADERSOURCEPROC_NP glShaderSource = NULL;
+PFNGLUNIFORM2FPROC glUniform2f = NULL;
+PFNGLUNIFORM1IPROC glUniform1i = NULL;
+PFNGLUSEPROGRAMPROC glUseProgram = NULL;
+PFNGLVERTEXATTRIBPOINTERPROC glVertexAttribPointer = NULL;
+}
+
+/* "using" is meant to hide identical names declared in outer scope
+ * but is unreliable, so just redefine instead.
+ */
+#define glAttachShader            gl2::glAttachShader
+#define glCompileShader           gl2::glCompileShader
+#define glCreateProgram           gl2::glCreateProgram
+#define glCreateShader            gl2::glCreateShader
+#define glDeleteProgram           gl2::glDeleteProgram
+#define glDeleteShader            gl2::glDeleteShader
+#define glEnableVertexAttribArray gl2::glEnableVertexAttribArray
+#define glGetAttribLocation       gl2::glGetAttribLocation
+#define glGetProgramiv            gl2::glGetProgramiv
+#define glGetProgramInfoLog       gl2::glGetProgramInfoLog
+#define glGetShaderiv             gl2::glGetShaderiv
+#define glGetShaderInfoLog        gl2::glGetShaderInfoLog
+#define glGetUniformLocation      gl2::glGetUniformLocation
+#define glLinkProgram             gl2::glLinkProgram
+#define glShaderSource            gl2::glShaderSource
+#define glUniform2f               gl2::glUniform2f
+#define glUniform1i               gl2::glUniform1i
+#define glUseProgram              gl2::glUseProgram
+#define glVertexAttribPointer     gl2::glVertexAttribPointer
+
 #if C_OPENGL && DOSBOXMENU_TYPE == DOSBOXMENU_SDLDRAW
 extern unsigned int SDLDrawGenFontTextureUnitPerRow;
 extern unsigned int SDLDrawGenFontTextureRows;
@@ -42,12 +93,12 @@ int Voodoo_OGL_GetWidth();
 int Voodoo_OGL_GetHeight();
 bool Voodoo_OGL_Active();
 
-static SDL_Surface* SetupSurfaceScaledOpenGL(Bit32u sdl_flags, Bit32u bpp) 
+static SDL_Surface* SetupSurfaceScaledOpenGL(uint32_t sdl_flags, uint32_t bpp) 
 {
-    Bit16u fixedWidth;
-    Bit16u fixedHeight;
-    Bit16u windowWidth;
-    Bit16u windowHeight;
+    uint16_t fixedWidth;
+    uint16_t fixedHeight;
+    uint16_t windowWidth;
+    uint16_t windowHeight;
 
 retry:
 #if defined(C_SDL2)
@@ -99,9 +150,9 @@ retry:
         int scale = 1;
 
         if (cw == 0)
-            cw = (Bit16u)(sdl.draw.width*sdl.draw.scalex);
+            cw = (uint16_t)(sdl.draw.width*sdl.draw.scalex);
         if (ch == 0)
-            ch = (Bit16u)(sdl.draw.height*sdl.draw.scaley);
+            ch = (uint16_t)(sdl.draw.height*sdl.draw.scaley);
 
         while ((cw / scale) >= (640 * 2) && (ch / scale) >= (400 * 2))
             scale++;
@@ -118,8 +169,8 @@ retry:
     if (Voodoo_OGL_GetWidth() != 0 && Voodoo_OGL_GetHeight() != 0 && Voodoo_OGL_Active() && sdl.desktop.prevent_fullscreen)
     { 
         /* 3Dfx openGL do not allow resize */
-        sdl.clip.w = windowWidth = (Bit16u)Voodoo_OGL_GetWidth();
-        sdl.clip.h = windowHeight = (Bit16u)Voodoo_OGL_GetHeight();
+        sdl.clip.w = windowWidth = (uint16_t)Voodoo_OGL_GetWidth();
+        sdl.clip.h = windowHeight = (uint16_t)Voodoo_OGL_GetHeight();
     }
     else if (fixedWidth && fixedHeight) 
     {
@@ -129,8 +180,8 @@ retry:
     }
     else 
     {
-        windowWidth = (Bit16u)(sdl.draw.width * sdl.draw.scalex);
-        windowHeight = (Bit16u)(sdl.draw.height * sdl.draw.scaley);
+        windowWidth = (uint16_t)(sdl.draw.width * sdl.draw.scalex);
+        windowHeight = (uint16_t)(sdl.draw.height * sdl.draw.scaley);
         if (render.aspect) aspectCorrectExtend(windowWidth, windowHeight);
         sdl.clip.w = windowWidth; sdl.clip.h = windowHeight;
     }
@@ -221,6 +272,76 @@ Bitu OUTPUT_OPENGL_GetBestMode(Bitu flags)
     return flags;
 }
 
+/* Create a GLSL shader object, load the shader source, and compile the shader. */
+static GLuint BuildShader ( GLenum type, const char *shaderSrc ) {
+	GLuint shader;
+	GLint compiled;
+	const char* src_strings[2];
+	std::string top;
+
+	// look for "#version" because it has to occur first
+	const char *ver = strstr(shaderSrc, "#version ");
+	if (ver) {
+		const char *endline = strchr(ver+9, '\n');
+		if (endline) {
+			top.assign(shaderSrc, endline-shaderSrc+1);
+			shaderSrc = endline+1;
+		}
+	}
+
+	top += (type==GL_VERTEX_SHADER) ? "#define VERTEX 1\n":"#define FRAGMENT 1\n";
+	if (!sdl_opengl.bilinear)
+		top += "#define OPENGLNB 1\n";
+
+	src_strings[0] = top.c_str();
+	src_strings[1] = shaderSrc;
+
+	// Create the shader object
+	shader = glCreateShader(type);
+	if (shader == 0) return 0;
+
+	// Load the shader source
+	glShaderSource(shader, 2, src_strings, NULL);
+
+	// Compile the shader
+	glCompileShader(shader);
+
+	// Check the compile status
+	glGetShaderiv(shader, GL_COMPILE_STATUS, &compiled);
+
+	if (!compiled) {
+		char* infoLog = NULL;
+		GLint infoLen = 0;
+		glGetShaderiv(shader, GL_INFO_LOG_LENGTH, &infoLen);
+
+		if (infoLen>1) infoLog = (char*)malloc(infoLen);
+		if (infoLog) {
+			glGetShaderInfoLog(shader, infoLen, NULL, infoLog);
+			LOG_MSG("Error compiling shader: %s", infoLog);
+			free(infoLog);
+		} else LOG_MSG("Error getting shader compilation log");
+
+		glDeleteShader(shader);
+		return 0;
+	}
+
+	return shader;
+}
+
+static bool LoadGLShaders(const char *src, GLuint *vertex, GLuint *fragment) {
+	GLuint s = BuildShader(GL_VERTEX_SHADER, src);
+	if (s) {
+		*vertex = s;
+		s = BuildShader(GL_FRAGMENT_SHADER, src);
+		if (s) {
+			*fragment = s;
+			return true;
+		}
+		glDeleteShader(*vertex);
+	}
+	return false;
+}
+
 Bitu OUTPUT_OPENGL_SetSize()
 {
     Bitu retFlags = 0;
@@ -256,10 +377,11 @@ Bitu OUTPUT_OPENGL_SetSize()
 # endif
 #endif
 
+    // try 32 bits first then 16
 #if defined(C_SDL2)
-    SetupSurfaceScaledOpenGL(SDL_WINDOW_RESIZABLE, 0);
+    if (SetupSurfaceScaledOpenGL(SDL_WINDOW_RESIZABLE,32)==NULL) SetupSurfaceScaledOpenGL(SDL_WINDOW_RESIZABLE,16);
 #else
-    SetupSurfaceScaledOpenGL(SDL_RESIZABLE, 0);
+    if (SetupSurfaceScaledOpenGL(SDL_RESIZABLE,32)==NULL) SetupSurfaceScaledOpenGL(SDL_RESIZABLE,16);
 #endif
     if (!sdl.surface || sdl.surface->format->BitsPerPixel < 15)
     {
@@ -290,6 +412,109 @@ Bitu OUTPUT_OPENGL_SetSize()
         return 0;
     }
 
+    if (sdl_opengl.use_shader && sdl_opengl.shader_src == NULL && !sdl_opengl.shader_def) sdl_opengl.use_shader = false;
+    if (sdl_opengl.use_shader) {
+        GLuint prog=0;
+        // reset error
+        glGetError();
+        glGetIntegerv(GL_CURRENT_PROGRAM, (GLint*)&prog);
+        // if there was an error this context doesn't support shaders
+        if (glGetError()==GL_NO_ERROR && (sdl_opengl.program_object==0 || prog!=sdl_opengl.program_object)) {
+            // check if existing program is valid
+            if (sdl_opengl.program_object) {
+                glUseProgram(sdl_opengl.program_object);
+                if (glGetError() != GL_NO_ERROR) {
+                    // program is not usable (probably new context), purge it
+                    glDeleteProgram(sdl_opengl.program_object);
+                    sdl_opengl.program_object = 0;
+                }
+            }
+
+            // does program need to be rebuilt?
+            if (sdl_opengl.program_object == 0) {
+                GLuint vertexShader, fragmentShader;
+                const char *src = sdl_opengl.shader_src;
+                if (src && !LoadGLShaders(src, &vertexShader, &fragmentShader)) {
+                    LOG_MSG("SDL:OPENGL:Failed to compile shader, falling back to default");
+                    src = NULL;
+                }
+                if (src == NULL && !LoadGLShaders(shader_src_default, &vertexShader, &fragmentShader)) {
+                    LOG_MSG("SDL:OPENGL:Failed to compile default shader!");
+                    return 0;
+                }
+
+                sdl_opengl.program_object = glCreateProgram();
+                if (!sdl_opengl.program_object) {
+                    glDeleteShader(vertexShader);
+                    glDeleteShader(fragmentShader);
+                    LOG_MSG("SDL:OPENGL:Can't create program object, falling back to surface");
+                    return 0;
+                }
+#if DOSBOXMENU_TYPE == DOSBOXMENU_SDLDRAW
+                // Todo: Make SDL-drawn menu work with custom GLSL shaders
+                if (!sdl.desktop.prevent_fullscreen) {
+                    menu.toggle=false;
+                    mainMenu.showMenu(false);
+                    mainMenu.get_item("mapper_togmenu").check(!menu.toggle).refresh_item(mainMenu);
+                }
+#endif
+                glAttachShader(sdl_opengl.program_object, vertexShader);
+                glAttachShader(sdl_opengl.program_object, fragmentShader);
+                // Link the program
+                glLinkProgram(sdl_opengl.program_object);
+                // Even if we *are* successful, we may delete the shader objects
+                glDeleteShader(vertexShader);
+                glDeleteShader(fragmentShader);
+
+                // Check the link status
+                GLint isProgramLinked;
+                glGetProgramiv(sdl_opengl.program_object, GL_LINK_STATUS, &isProgramLinked);
+                if (!isProgramLinked) {
+                    char * infoLog = NULL;
+                    GLint infoLen = 0;
+
+                    glGetProgramiv(sdl_opengl.program_object, GL_INFO_LOG_LENGTH, &infoLen);
+                    if (infoLen>1) infoLog = (char*)malloc(infoLen);
+                    if (infoLog) {
+                        glGetProgramInfoLog(sdl_opengl.program_object, infoLen, NULL, infoLog);
+                        LOG_MSG("SDL:OPENGL:Error linking program:\n %s", infoLog);
+                        free(infoLog);
+                    } else LOG_MSG("SDL:OPENGL:Failed to retrieve program link log");
+
+                    glDeleteProgram(sdl_opengl.program_object);
+                    sdl_opengl.program_object = 0;
+                    return 0;
+                }
+
+                glUseProgram(sdl_opengl.program_object);
+
+                GLint u = glGetAttribLocation(sdl_opengl.program_object, "a_position");
+                // upper left
+                sdl_opengl.vertex_data[0] = -1.0f;
+                sdl_opengl.vertex_data[1] = 1.0f;
+                // lower left
+                sdl_opengl.vertex_data[2] = -1.0f;
+                sdl_opengl.vertex_data[3] = -3.0f;
+                // upper right
+                sdl_opengl.vertex_data[4] = 3.0f;
+                sdl_opengl.vertex_data[5] = 1.0f;
+                // Load the vertex positions
+                glVertexAttribPointer(u, 2, GL_FLOAT, GL_FALSE, 0, sdl_opengl.vertex_data);
+                glEnableVertexAttribArray(u);
+
+                u = glGetUniformLocation(sdl_opengl.program_object, "rubyTexture");
+                glUniform1i(u, 0);
+
+                sdl_opengl.ruby.texture_size = glGetUniformLocation(sdl_opengl.program_object, "rubyTextureSize");
+                sdl_opengl.ruby.input_size = glGetUniformLocation(sdl_opengl.program_object, "rubyInputSize");
+                sdl_opengl.ruby.output_size = glGetUniformLocation(sdl_opengl.program_object, "rubyOutputSize");
+                sdl_opengl.ruby.frame_count = glGetUniformLocation(sdl_opengl.program_object, "rubyFrameCount");
+                // Don't force updating unless a shader depends on frame_count
+                RENDER_SetForceUpdate(sdl_opengl.ruby.frame_count != (GLint)-1);
+            }
+        }
+    }
+
     /* Create the texture and display list */
     if (sdl_opengl.pixel_buffer_object) 
     {
@@ -315,8 +540,13 @@ Bitu OUTPUT_OPENGL_SetSize()
     }
 #endif
 
-    glViewport(0, 0, sdl.surface->w, sdl.surface->h);
-    glDeleteTextures(1, &sdl_opengl.texture);
+    if (!sdl.desktop.fullscreen)
+        glViewport(0, 0, sdl.surface->w, sdl.surface->h);
+    else if (sdl_opengl.use_shader)
+        glViewport((sdl.surface->w-sdl.clip.w)/2,(sdl.surface->h-sdl.clip.h)/2,sdl.clip.w,sdl.clip.h);
+    else
+        glViewport(sdl.clip.x,sdl.clip.y,sdl.clip.w,sdl.clip.h);
+    if (sdl_opengl.texture > 0) glDeleteTextures(1, &sdl_opengl.texture);
     glGenTextures(1, &sdl_opengl.texture);
     glBindTexture(GL_TEXTURE_2D, sdl_opengl.texture);
     glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
@@ -337,11 +567,11 @@ Bitu OUTPUT_OPENGL_SetSize()
     sdl_opengl.menudraw_countdown = 3; // two GL buffers with possible triple buffering behind our back
     sdl_opengl.clear_countdown = 3; // two GL buffers with possible triple buffering behind our back
 
-    glClearColor(0.0, 0.0, 0.0, 1.0);
+    glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
     glClear(GL_COLOR_BUFFER_BIT);
     // SDL_GL_SwapBuffers();
     // glClear(GL_COLOR_BUFFER_BIT);
-    glShadeModel(GL_FLAT);
+    //glShadeModel(GL_FLAT);
     glBlendFunc(GL_ONE, GL_ZERO);
     glDisable(GL_DEPTH_TEST);
     glDisable(GL_LIGHTING);
@@ -353,36 +583,45 @@ Bitu OUTPUT_OPENGL_SetSize()
     glDisable(GL_STENCIL_TEST);
     glEnable(GL_TEXTURE_2D);
 
-    glMatrixMode(GL_MODELVIEW);
-    glLoadIdentity();
+    if (sdl_opengl.program_object) {
+        // Set shader variables
+        glUniform2f(sdl_opengl.ruby.texture_size, (float)texsize, (float)texsize);
+        glUniform2f(sdl_opengl.ruby.input_size, (float)adjTexWidth, (float)adjTexHeight);
+        glUniform2f(sdl_opengl.ruby.output_size, sdl.clip.w, sdl.clip.h);
+        // The following uniform is *not* set right now
+        sdl_opengl.actual_frame_count = 0;
+    } else {
+        glMatrixMode(GL_MODELVIEW);
+        glLoadIdentity();
 
-    glMatrixMode(GL_PROJECTION);
-    glLoadIdentity();
-    glOrtho(0, sdl.surface->w, sdl.surface->h, 0, -1, 1);
+        glMatrixMode(GL_PROJECTION);
+        glLoadIdentity();
+        glOrtho(0, sdl.surface->w, sdl.surface->h, 0, -1, 1);
 
-    glMatrixMode(GL_TEXTURE);
-    glLoadIdentity();
-    glScaled(1.0 / texsize, 1.0 / texsize, 1.0);
+        glMatrixMode(GL_TEXTURE);
+        glLoadIdentity();
+        glScaled(1.0 / texsize, 1.0 / texsize, 1.0);
 
-    // if (glIsList(sdl_opengl.displaylist)) 
-    //   glDeleteLists(sdl_opengl.displaylist, 1);
-    // sdl_opengl.displaylist = glGenLists(1);
-    sdl_opengl.displaylist = 1;
+        // if (glIsList(sdl_opengl.displaylist))
+        //   glDeleteLists(sdl_opengl.displaylist, 1);
+        // sdl_opengl.displaylist = glGenLists(1);
+        sdl_opengl.displaylist = 1;
 
-    glNewList(sdl_opengl.displaylist, GL_COMPILE);
-    glBindTexture(GL_TEXTURE_2D, sdl_opengl.texture);
+        glNewList(sdl_opengl.displaylist, GL_COMPILE);
+        glBindTexture(GL_TEXTURE_2D, sdl_opengl.texture);
 
-    glBegin(GL_QUADS);
+        glBegin(GL_QUADS);
 
-    glTexCoord2i(0, 0); glVertex2i((GLint)sdl.clip.x, (GLint)sdl.clip.y); // lower left
-    glTexCoord2i((GLint)adjTexWidth, 0); glVertex2i((GLint)sdl.clip.x + (GLint)sdl.clip.w, (GLint)sdl.clip.y); // lower right
-    glTexCoord2i((GLint)adjTexWidth, (GLint)adjTexHeight); glVertex2i((GLint)sdl.clip.x + (GLint)sdl.clip.w, (GLint)sdl.clip.y + (GLint)sdl.clip.h); // upper right
-    glTexCoord2i(0, (GLint)adjTexHeight); glVertex2i((GLint)sdl.clip.x, (GLint)sdl.clip.y + (GLint)sdl.clip.h); // upper left
+        glTexCoord2i(0, 0); glVertex2i((GLint)sdl.clip.x, (GLint)sdl.clip.y); // lower left
+        glTexCoord2i((GLint)adjTexWidth, 0); glVertex2i((GLint)sdl.clip.x + (GLint)sdl.clip.w, (GLint)sdl.clip.y); // lower right
+        glTexCoord2i((GLint)adjTexWidth, (GLint)adjTexHeight); glVertex2i((GLint)sdl.clip.x + (GLint)sdl.clip.w, (GLint)sdl.clip.y + (GLint)sdl.clip.h); // upper right
+        glTexCoord2i(0, (GLint)adjTexHeight); glVertex2i((GLint)sdl.clip.x, (GLint)sdl.clip.y + (GLint)sdl.clip.h); // upper left
 
-    glEnd();
-    glEndList();
+        glEnd();
+        glEndList();
 
-    glBindTexture(GL_TEXTURE_2D, 0);
+        glBindTexture(GL_TEXTURE_2D, 0);
+    }
 
 #if DOSBOXMENU_TYPE == DOSBOXMENU_SDLDRAW
     void GFX_DrawSDLMenu(DOSBoxMenu &menu, DOSBoxMenu::displaylist &dl);
@@ -426,7 +665,7 @@ Bitu OUTPUT_OPENGL_SetSize()
 
         /* load the font */
         {
-            extern Bit8u int10_font_16[256 * 16];
+            extern uint8_t int10_font_16[256 * 16];
 
             uint32_t tmp[8 * 16];
             unsigned int x, y, c;
@@ -464,13 +703,13 @@ Bitu OUTPUT_OPENGL_SetSize()
     return retFlags;
 }
 
-bool OUTPUT_OPENGL_StartUpdate(Bit8u* &pixels, Bitu &pitch)
+bool OUTPUT_OPENGL_StartUpdate(uint8_t* &pixels, Bitu &pitch)
 {
 #if C_XBRZ    
     if (sdl_xbrz.enable && sdl_xbrz.scale_on) 
     {
         sdl_xbrz.renderbuf.resize(sdl.draw.width * sdl.draw.height);
-        pixels = sdl_xbrz.renderbuf.empty() ? nullptr : reinterpret_cast<Bit8u*>(&sdl_xbrz.renderbuf[0]);
+        pixels = sdl_xbrz.renderbuf.empty() ? nullptr : reinterpret_cast<uint8_t*>(&sdl_xbrz.renderbuf[0]);
         pitch = sdl.draw.width * sizeof(uint32_t);
     }
     else
@@ -479,11 +718,11 @@ bool OUTPUT_OPENGL_StartUpdate(Bit8u* &pixels, Bitu &pitch)
         if (sdl_opengl.pixel_buffer_object)
         {
             glBindBufferARB(GL_PIXEL_UNPACK_BUFFER_EXT, sdl_opengl.buffer);
-            pixels = (Bit8u *)glMapBufferARB(GL_PIXEL_UNPACK_BUFFER_EXT, GL_WRITE_ONLY);
+            pixels = (uint8_t *)glMapBufferARB(GL_PIXEL_UNPACK_BUFFER_EXT, GL_WRITE_ONLY);
         }
         else
         {
-            pixels = (Bit8u *)sdl_opengl.framebuf;
+            pixels = (uint8_t *)sdl_opengl.framebuf;
         }
         pitch = sdl_opengl.pitch;
     }
@@ -492,14 +731,14 @@ bool OUTPUT_OPENGL_StartUpdate(Bit8u* &pixels, Bitu &pitch)
     return true;
 }
 
-void OUTPUT_OPENGL_EndUpdate(const Bit16u *changedLines)
+void OUTPUT_OPENGL_EndUpdate(const uint16_t *changedLines)
 {
     if (!(sdl.must_redraw_all && changedLines == NULL)) 
     {
         if (sdl_opengl.clear_countdown > 0)
         {
             sdl_opengl.clear_countdown--;
-            glClearColor(0.0, 0.0, 0.0, 1.0);
+            glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
             glClear(GL_COLOR_BUFFER_BIT);
         }
 
@@ -516,8 +755,8 @@ void OUTPUT_OPENGL_EndUpdate(const Bit16u *changedLines)
         if (sdl_xbrz.enable && sdl_xbrz.scale_on)
         {
             // OpenGL pixel buffer is precreated for direct xBRZ output, while xBRZ render buffer is used for rendering
-            const Bit32u srcWidth = sdl.draw.width;
-            const Bit32u srcHeight = sdl.draw.height;
+            const uint32_t srcWidth = sdl.draw.width;
+            const uint32_t srcHeight = sdl.draw.height;
 
             if (sdl_xbrz.renderbuf.size() == (unsigned int)srcWidth * (unsigned int)srcHeight && srcWidth > 0 && srcHeight > 0)
             {
@@ -566,7 +805,7 @@ void OUTPUT_OPENGL_EndUpdate(const Bit16u *changedLines)
                     // works on Linux
                     GL_UNSIGNED_INT_8_8_8_8_REV,
 #endif
-                    (Bit8u *)sdl_opengl.framebuf);
+                    (uint8_t *)sdl_opengl.framebuf);
             }
             glCallList(sdl_opengl.displaylist);
             SDL_GL_SwapBuffers();
@@ -591,8 +830,8 @@ void OUTPUT_OPENGL_EndUpdate(const Bit16u *changedLines)
 #endif
                 (void*)0);
             glBindBufferARB(GL_PIXEL_UNPACK_BUFFER_EXT, 0);
-            glCallList(sdl_opengl.displaylist);
-            SDL_GL_SwapBuffers();
+            //glCallList(sdl_opengl.displaylist);
+            //SDL_GL_SwapBuffers();
         }
         else if (changedLines) 
         {
@@ -609,7 +848,7 @@ void OUTPUT_OPENGL_EndUpdate(const Bit16u *changedLines)
                 }
                 else 
                 {
-                    Bit8u *pixels = (Bit8u *)sdl_opengl.framebuf + y * sdl_opengl.pitch;
+                    uint8_t *pixels = (uint8_t *)sdl_opengl.framebuf + y * sdl_opengl.pitch;
                     Bitu height = changedLines[index];
                     glTexSubImage2D(GL_TEXTURE_2D, 0, 0, (int)y,
                         (int)sdl.draw.width, (int)height, GL_BGRA_EXT,
@@ -625,6 +864,12 @@ void OUTPUT_OPENGL_EndUpdate(const Bit16u *changedLines)
                 }
                 index++;
             }
+        } else
+            return;
+        if (sdl_opengl.program_object) {
+            glUniform1i(sdl_opengl.ruby.frame_count, sdl_opengl.actual_frame_count++);
+            glDrawArrays(GL_TRIANGLES, 0, 3);
+        } else
             glCallList(sdl_opengl.displaylist);
 
 #if 0 /* DEBUG Prove to me that you're drawing the damn texture */
@@ -659,7 +904,6 @@ void OUTPUT_OPENGL_EndUpdate(const Bit16u *changedLines)
 #endif
 
             SDL_GL_SwapBuffers();
-        }
 
         if (!menu.hidecycles && !sdl.desktop.fullscreen) frames++;
     }
