@@ -4,7 +4,7 @@
 #define DOSBOX_OUTPUT_TOOLS_XBRZ_H
 
 #if C_XBRZ || C_SURFACE_POSTRENDER_ASPECT
-#include <xBRZ/xbrz_tools.h>
+#include <libs/xBRZ/xbrz_tools.h>
 #include <cmath>
 
 #if defined(WIN32) && !defined(__MINGW32__) && !defined(HX_DOS)
@@ -15,7 +15,7 @@
 #endif /*C_XBRZ || C_SURFACE_POSTRENDER_ASPECT*/
 
 #if C_XBRZ
-#include <xBRZ/xbrz.h>
+#include <libs/xBRZ/xbrz.h>
 
 struct SDL_xBRZ {
     // configuration
@@ -37,7 +37,7 @@ extern SDL_xBRZ sdl_xbrz;
 void xBRZ_Initialize();
 void xBRZ_Change_Options(Section_prop* section);
 bool xBRZ_SetScaleParameters(int srcWidth, int srcHeight, int dstWidth, int dstHeight);
-void xBRZ_Render(const uint32_t* renderBuf, uint32_t* xbrzBuf, const Bit16u *changedLines, const int srcWidth, const int srcHeight, int scalingFactor);
+void xBRZ_Render(const uint32_t* renderBuf, uint32_t* xbrzBuf, const uint16_t *changedLines, const int srcWidth, const int srcHeight, int scalingFactor);
 void xBRZ_PostScale(const uint32_t* src, const int srcWidth, const int srcHeight, const int srcPitch,
     uint32_t* tgt, const int tgtWidth, const int tgtHeight, const int tgtPitch,
     const bool bilinear, const int task_granularity);
