@@ -33,6 +33,7 @@
 #include "../dos/drives.h"
 #ifdef WIN32
 #include "../dos/cdrom.h"
+#include <shellapi.h>
 #endif
 
 #ifdef _MSC_VER
@@ -48,6 +49,8 @@
 
 bool clearline=false;
 extern int lfn_filefind_handle;
+extern bool DOS_BreakFlag;
+extern bool DOS_BreakConioFlag;
 
 void DOS_Shell::ShowPrompt(void) {
 	char dir[DOS_PATHLENGTH];
@@ -84,13 +87,13 @@ void DOS_Shell::ShowPrompt(void) {
 			case 'S': WriteOut(" "); break;
 			case 'T': {
 				Bitu ticks=(Bitu)(((65536.0 * 100.0)/(double)PIT_TICK_RATE)* mem_readd(BIOS_TIMER));
-				reg_dl=(Bit8u)((Bitu)ticks % 100);
+				reg_dl=(uint8_t)((Bitu)ticks % 100);
 				ticks/=100;
-				reg_dh=(Bit8u)((Bitu)ticks % 60);
+				reg_dh=(uint8_t)((Bitu)ticks % 60);
 				ticks/=60;
-				reg_cl=(Bit8u)((Bitu)ticks % 60);
+				reg_cl=(uint8_t)((Bitu)ticks % 60);
 				ticks/=60;
-				reg_ch=(Bit8u)((Bitu)ticks % 24);
+				reg_ch=(uint8_t)((Bitu)ticks % 24);
 				WriteOut("%2d:%02d:%02d.%02d",reg_ch,reg_cl,reg_dh,reg_dl);
 				break;
 			}
@@ -104,14 +107,14 @@ void DOS_Shell::ShowPrompt(void) {
 	}
 }
 
-static void outc(Bit8u c) {
-	Bit16u n=1;
+static void outc(uint8_t c) {
+	uint16_t n=1;
 	DOS_WriteFile(STDOUT,&c,&n);
 }
 
 static void backone() {
 	BIOS_NCOLS;
-	Bit8u page=real_readb(BIOSMEM_SEG,BIOSMEM_CURRENT_PAGE);
+	uint8_t page=real_readb(BIOSMEM_SEG,BIOSMEM_CURRENT_PAGE);
 	if (CURSOR_POS_COL(page)>0)
 		outc(8);
 	else if (CURSOR_POS_ROW(page)>0)
@@ -121,26 +124,26 @@ static void backone() {
 //! \brief Moves the caret to prev row/last column when column is 0 (video mode 0).
 void MoveCaretBackwards()
 {
-	Bit8u col, row;
-	const Bit8u page(0);
+	uint8_t col, row;
+	const uint8_t page(0);
 	INT10_GetCursorPos(&row, &col, page);
 
 	if (col != 0) 
 		return;
 
-	Bit16u cols;
+	uint16_t cols;
 	INT10_GetScreenColumns(&cols);
-	INT10_SetCursorPos(row - 1, static_cast<Bit8u>(cols), page);
+	INT10_SetCursorPos(row - 1, static_cast<uint8_t>(cols), page);
 }
 
 /* NTS: buffer pointed to by "line" must be at least CMD_MAXLINE+1 large */
 void DOS_Shell::InputCommand(char * line) {
 	Bitu size=CMD_MAXLINE-2; //lastcharacter+0
-	Bit8u c;Bit16u n=1;
-	Bit16u str_len=0;Bit16u str_index=0;
-	Bit16u len=0;
+	uint8_t c;uint16_t n=1;
+	uint16_t str_len=0;uint16_t str_index=0;
+	uint16_t len=0;
 	bool current_hist=false; // current command stored in history?
-    Bit16u cr;
+    uint16_t cr;
 
     input_eof = false;
 	line[0] = '\0';
@@ -167,10 +170,10 @@ void DOS_Shell::InputCommand(char * line) {
         }
 
         if (input_handle != STDIN) { /* FIXME: Need DOS_IsATTY() or somesuch */
-            cr = (Bit16u)c; /* we're not reading from the console */
+            cr = (uint16_t)c; /* we're not reading from the console */
         }
         else if (IS_PC98_ARCH) {
-            extern Bit16u last_int16_code;
+            extern uint16_t last_int16_code;
 
             /* shift state is needed for some key combinations not directly supported by CON driver.
              * bit 4 = CTRL
@@ -237,20 +240,20 @@ void DOS_Shell::InputCommand(char * line) {
                         cr = 0;
                 }
                 else {
-                    cr = (Bit16u)c;
+                    cr = (uint16_t)c;
                 }
             }
             else {
-                cr = (Bit16u)c;
+                cr = (uint16_t)c;
             }
         }
         else {
             if (c == 0) {
 				DOS_ReadFile(input_handle,&c,&n);
-                cr = (Bit16u)c << (Bit16u)8;
+                cr = (uint16_t)c << (uint16_t)8;
             }
             else {
-                cr = (Bit16u)c;
+                cr = (uint16_t)c;
             }
         }
 
@@ -260,11 +263,11 @@ void DOS_Shell::InputCommand(char * line) {
                 it_history = l_history.begin();
                 if (it_history != l_history.end() && it_history->length() > str_len) {
                     const char *reader = &(it_history->c_str())[str_len];
-                    while ((c = (Bit8u)(*reader++))) {
+                    while ((c = (uint8_t)(*reader++))) {
                         line[str_index ++] = (char)c;
                         DOS_WriteFile(STDOUT,&c,&n);
                     }
-                    str_len = str_index = (Bit16u)it_history->length();
+                    str_len = str_index = (uint16_t)it_history->length();
                     size = (unsigned int)CMD_MAXLINE - str_index - 2u;
                     line[str_len] = 0;
                 }
@@ -295,7 +298,7 @@ void DOS_Shell::InputCommand(char * line) {
 					const auto lgt = MIN(pos, end) - (line + str_index);
 					
 					for (auto i = 0; i < lgt; i++)
-						outc(static_cast<Bit8u>(line[str_index++]));
+						outc(static_cast<uint8_t>(line[str_index++]));
 				}	
         		break;
 			case 0x7300: /*CTRL + LEFT : cmd.exe-like previous word*/
@@ -325,7 +328,7 @@ void DOS_Shell::InputCommand(char * line) {
         		break;
             case 0x4D00:	/* RIGHT */
                 if (str_index < str_len) {
-                    outc((Bit8u)line[str_index++]);
+                    outc((uint8_t)line[str_index++]);
                 }
                 break;
 
@@ -347,7 +350,7 @@ void DOS_Shell::InputCommand(char * line) {
 
             case 0x4F00:	/* END */
                 while (str_index < str_len) {
-                    outc((Bit8u)line[str_index++]);
+                    outc((uint8_t)line[str_index++]);
                 }
                 break;
 
@@ -362,7 +365,7 @@ void DOS_Shell::InputCommand(char * line) {
 
                 // ensure we're at end to handle all cases
                 while (str_index < str_len) {
-                    outc((Bit8u)line[str_index++]);
+                    outc((uint8_t)line[str_index++]);
                 }
 
                 for (;str_index>0; str_index--) {
@@ -370,10 +373,10 @@ void DOS_Shell::InputCommand(char * line) {
                     backone(); outc(' '); backone();
                 }
                 strcpy(line, it_history->c_str());
-                len = (Bit16u)it_history->length();
+                len = (uint16_t)it_history->length();
                 str_len = str_index = len;
                 size = (unsigned int)CMD_MAXLINE - str_index - 2u;
-                DOS_WriteFile(STDOUT, (Bit8u *)line, &len);
+                DOS_WriteFile(STDOUT, (uint8_t *)line, &len);
                 ++it_history;
                 break;
 
@@ -396,7 +399,7 @@ void DOS_Shell::InputCommand(char * line) {
 
                 // ensure we're at end to handle all cases
                 while (str_index < str_len) {
-                    outc((Bit8u)line[str_index++]);
+                    outc((uint8_t)line[str_index++]);
                 }
 
                 for (;str_index>0; str_index--) {
@@ -404,18 +407,18 @@ void DOS_Shell::InputCommand(char * line) {
                     backone(); outc(' '); backone();
                 }
                 strcpy(line, it_history->c_str());
-                len = (Bit16u)it_history->length();
+                len = (uint16_t)it_history->length();
                 str_len = str_index = len;
                 size = (unsigned int)CMD_MAXLINE - str_index - 2u;
-                DOS_WriteFile(STDOUT, (Bit8u *)line, &len);
+                DOS_WriteFile(STDOUT, (uint8_t *)line, &len);
                 ++it_history;
 
                 break;
             case 0x5300:/* DELETE */
                 {
                     if(str_index>=str_len) break;
-                    Bit16u a=str_len-str_index-1;
-                    Bit8u* text=reinterpret_cast<Bit8u*>(&line[str_index+1]);
+                    uint16_t a=str_len-str_index-1;
+                    uint8_t* text=reinterpret_cast<uint8_t*>(&line[str_index+1]);
                     DOS_WriteFile(STDOUT,text,&a);//write buffer to screen
                     outc(' ');backone();
                     for(Bitu i=str_index;i<(str_len-1u);i++) {
@@ -438,25 +441,25 @@ void DOS_Shell::InputCommand(char * line) {
                         }
 
                         strcpy(&line[completion_index], it_completion->c_str());
-                        len = (Bit16u)it_completion->length();
+                        len = (uint16_t)it_completion->length();
                         str_len = str_index = (Bitu)(completion_index + len);
                         size = (unsigned int)CMD_MAXLINE - str_index - 2u;
-                        DOS_WriteFile(STDOUT, (Bit8u *)it_completion->c_str(), &len);
+                        DOS_WriteFile(STDOUT, (uint8_t *)it_completion->c_str(), &len);
                     }
                 }
                 break;
             case 0x08:				/* BackSpace */
                 if (str_index) {
                     backone();
-                    Bit32u str_remain=(Bit32u)(str_len - str_index);
+                    uint32_t str_remain=(uint32_t)(str_len - str_index);
                     size++;
                     if (str_remain) {
                         memmove(&line[str_index-1],&line[str_index],str_remain);
                         line[--str_len]=0;
                         str_index --;
                         /* Go back to redraw */
-                        for (Bit16u i=str_index; i < str_len; i++)
-                            outc((Bit8u)line[i]);
+                        for (uint16_t i=str_index; i < str_len; i++)
+                            outc((uint8_t)line[i]);
                     } else {
                         line[--str_index] = '\0';
                         str_len--;
@@ -477,6 +480,8 @@ void DOS_Shell::InputCommand(char * line) {
                 if(!echo) outc('\n');
                 size = 0;       // stop the next loop
                 str_len = 0;    // prevent multiple adds of the same line
+                DOS_BreakFlag = false; // clear break flag so the next program doesn't get hit with it
+                DOS_BreakConioFlag = false;
                 break;
             case 0x0d:				/* Don't care, and return */
                 if(!echo) { outc('\r'); outc('\n'); }
@@ -525,7 +530,7 @@ void DOS_Shell::InputCommand(char * line) {
 
                         if (p_completion_start) {
                             p_completion_start ++;
-                            completion_index = (Bit16u)(str_len - strlen(p_completion_start));
+                            completion_index = (uint16_t)(str_len - strlen(p_completion_start));
                         } else {
                             p_completion_start = line;
                             completion_index = 0;
@@ -533,9 +538,9 @@ void DOS_Shell::InputCommand(char * line) {
 						k=completion_index;
 
                         const char *path;
-						if ((path = strrchr(line+completion_index,':'))) completion_index = (Bit16u)(path-line+1);
-                        if ((path = strrchr(line+completion_index,'\\'))) completion_index = (Bit16u)(path-line+1);
-                        if ((path = strrchr(line+completion_index,'/'))) completion_index = (Bit16u)(path-line+1);
+						if ((path = strrchr(line+completion_index,':'))) completion_index = (uint16_t)(path-line+1);
+                        if ((path = strrchr(line+completion_index,'\\'))) completion_index = (uint16_t)(path-line+1);
+                        if ((path = strrchr(line+completion_index,'/'))) completion_index = (uint16_t)(path-line+1);
 
                         // build the completion list
                         char mask[DOS_PATHLENGTH+2] = {0}, smask[DOS_PATHLENGTH] = {0};
@@ -600,7 +605,7 @@ void DOS_Shell::InputCommand(char * line) {
 
                         DOS_DTA dta(dos.dta());
 						char name[DOS_NAMELENGTH_ASCII], lname[LFN_NAMELENGTH], qlname[LFN_NAMELENGTH+2];
-                        Bit32u sz;Bit16u date;Bit16u time;Bit8u att;
+                        uint32_t sz;uint16_t date;uint16_t time;uint8_t att;
 
                         std::list<std::string> executable;
 						q=0;r=0;
@@ -651,10 +656,10 @@ void DOS_Shell::InputCommand(char * line) {
                         }
 
                         strcpy(&line[completion_index], it_completion->c_str());
-                        len = (Bit16u)it_completion->length();
+                        len = (uint16_t)it_completion->length();
                         str_len = str_index = (Bitu)(completion_index + len);
                         size = (unsigned int)CMD_MAXLINE - str_index - 2u;
-                        DOS_WriteFile(STDOUT, (Bit8u *)it_completion->c_str(), &len);
+                        DOS_WriteFile(STDOUT, (uint8_t *)it_completion->c_str(), &len);
                     }
                 }
                 break;
@@ -700,8 +705,8 @@ void DOS_Shell::InputCommand(char * line) {
                 if (l_completion.size()) l_completion.clear();
                 if(str_index < str_len && !INT10_GetInsertState()) { //mem_readb(BIOS_KEYBOARD_FLAGS1)&0x80) dev_con.h ?
                     outc(' ');//move cursor one to the right.
-                    Bit16u a = str_len - str_index;
-                    Bit8u* text=reinterpret_cast<Bit8u*>(&line[str_index]);
+                    uint16_t a = str_len - str_index;
+                    uint8_t* text=reinterpret_cast<uint8_t*>(&line[str_index]);
                     DOS_WriteFile(STDOUT,text,&a);//write buffer to screen
                     backone();//undo the cursor the right.
                     for(Bitu i=str_len;i>str_index;i--) {
@@ -729,7 +734,7 @@ void DOS_Shell::InputCommand(char * line) {
 
 	// remove current command from history if it's there
 	if (current_hist) {
-		current_hist=false;
+		// current_hist=false;
 		l_history.pop_front();
 	}
 
@@ -881,7 +886,7 @@ overflow:
 std::string full_arguments = "";
 intptr_t hret=0;
 bool infix=false, winautorun=false;
-extern bool packerr, reqwin, startwait, ctrlbrk, mountwarning;
+extern bool packerr, reqwin, startwait, startquiet, ctrlbrk, mountwarning;
 #if defined (WIN32) && !defined(HX_DOS)
 void EndRunProcess() {
     if(hret) {
@@ -897,7 +902,7 @@ bool DOS_Shell::Execute(char* name, const char* args) {
 /* return true  => don't check for hardware changes in do_command 
  * return false =>       check for hardware changes in do_command */
 	char fullname[DOS_PATHLENGTH+4]; //stores results from Which
-    const char* p_fullname;
+	const char* p_fullname;
 	char line[CMD_MAXLINE];
 	if(strlen(args)!= 0){
 		if(*args != ' '){ //put a space in front
@@ -913,13 +918,13 @@ bool DOS_Shell::Execute(char* name, const char* args) {
 		line[0]=0;
 	}
 
+	const Section_prop* sec = static_cast<Section_prop*>(control->GetSection("dos"));
 	/* check for a drive change */
 	if (((strcmp(name + 1, ":") == 0) || (strcmp(name + 1, ":\\") == 0)) && isalpha(*name) && !control->SecureMode())
 	{
 		if (strrchr(name,'\\')) { WriteOut(MSG_Get("SHELL_EXECUTE_ILLEGAL_COMMAND"),name); return true; }
 		if (!DOS_SetDrive(toupper(name[0])-'A')) {
 #ifdef WIN32
-            const Section_prop* sec = 0; sec = static_cast<Section_prop*>(control->GetSection("dos"));
 			if(!sec->Get_bool("automount")) { WriteOut(MSG_Get("SHELL_EXECUTE_DRIVE_NOT_FOUND"),toupper(name[0])); return true; }
 			// automount: attempt direct letter to drive map.
 			int type=GetDriveType(name);
@@ -933,7 +938,7 @@ first_1:
 			else { WriteOut(MSG_Get("SHELL_EXECUTE_DRIVE_NOT_FOUND"),toupper(name[0])); return true; }
 
 first_2:
-		Bit8u c;Bit16u n=1;
+		uint8_t c;uint16_t n=1;
 		DOS_ReadFile (STDIN,&c,&n);
 		do switch (c) {
 			case 'n':			case 'N':
@@ -1067,7 +1072,7 @@ continue_1:
 		cmdtail.count = 0;
         memset(&cmdtail.buffer,0,CTBUF); //Else some part of the string is unitialized (valgrind)
         if (strlen(line)>=CTBUF) line[CTBUF-1]=0;
-		cmdtail.count=(Bit8u)strlen(line);
+		cmdtail.count=(uint8_t)strlen(line);
 		memcpy(cmdtail.buffer,line,strlen(line));
 		cmdtail.buffer[strlen(line)]=0xd;
 		/* Copy command line in stack block too */
@@ -1097,8 +1102,8 @@ continue_1:
 		parseline[255] = parseline[256] = parseline[257] = 0; //Just to be safe.
 
 		/* Parse FCB (first two parameters) and put them into the current DOS_PSP */
-		Bit8u add;
-		Bit16u skip = 0;
+		uint8_t add;
+		uint16_t skip = 0;
 		//find first argument, we end up at parseline[256] if there is only one argument (similar for the second), which exists and is 0.
 		while(skip < 256 && parseline[skip] == 0) skip++;
 		FCB_Parsename(dos.psp(),0x5C,0x01,parseline + skip,&add);
@@ -1116,8 +1121,8 @@ continue_1:
 		block.SaveData();
 #if 0
 		/* Save CS:IP to some point where i can return them from */
-		Bit32u oldeip=reg_eip;
-		Bit16u oldcs=SegValue(cs);
+		uint32_t oldeip=reg_eip;
+		uint16_t oldcs=SegValue(cs);
 		RealPt newcsip=CALLBACK_RealPointer(call_shellstop);
 		SegSet16(cs,RealSeg(newcsip));
 		reg_ip=RealOff(newcsip);
@@ -1140,13 +1145,13 @@ continue_1:
 		reg_eip=oldeip;
 		SegSet16(cs,oldcs);
 #endif
-		if (packerr&&!infix) {
-			Bit16u segment;
-			Bit16u blocks = (Bit16u)(64*1024/16);
+		if (packerr&&!infix&&sec->Get_bool("autoloadfix")) {
+			uint16_t segment;
+			uint16_t blocks = (uint16_t)(64*1024/16);
 			if (DOS_AllocateMemory(&segment,&blocks)) {
-				DOS_MCB mcb((Bit16u)(segment-1));
+				DOS_MCB mcb((uint16_t)(segment-1));
 				mcb.SetPSPSeg(0x40);
-				WriteOut("\r\nNow run it with LOADFIX..\r\n");
+				WriteOut("\r\n\033[41;1m\033[1;37;1mDOSBox-X\033[0m Failed to load the executable\r\n\033[41;1m\033[37;1mDOSBox-X\033[0m Now try again with LOADFIX...\r\n");
 				infix=true;
 				Execute(name, args);
 				infix=false;
@@ -1156,8 +1161,8 @@ continue_1:
 		} else if (winautorun&&reqwin&&!control->SecureMode()) {
             char comline[256], *p=comline;
             char winDirCur[512], winDirNew[512], winName[256];
-            Bit8u drive;
-            if (!DOS_MakeName(name, winDirNew, &drive)) return false;
+            uint8_t drive;
+            if (!DOS_MakeName(fullname, winDirNew, &drive)) return false;
             if (GetCurrentDirectory(512, winDirCur)&&(!strncmp(Drives[drive]->GetInfo(),"local ",6)||!strncmp(Drives[drive]->GetInfo(),"CDRom ",6))) {
                 bool useoverlay=false;
                 Overlay_Drive *odp = dynamic_cast<Overlay_Drive*>(Drives[drive]);
@@ -1181,28 +1186,52 @@ continue_1:
                     strcat(winDirNew, Drives[drive]->curdir);
                 }
                 if (SetCurrentDirectory(winDirNew)) {
+                    SHELLEXECUTEINFO lpExecInfo;
                     strcpy(comline, args);
                     strcpy(comline, trim(p));
-                    char qwinName[258];
-                    sprintf(qwinName,"\"%s\"",winName);
-                    WriteOut("Now run it as a Windows application...\r\n");
-                    hret = _spawnl(P_NOWAIT, winName, qwinName, comline, NULL);
+                    if (!startquiet) WriteOut("Now run it as a Windows application...\r\n");
+                    char dir[CROSS_LEN+15];
+                    DWORD temp = (DWORD)SHGetFileInfo(winName,NULL,NULL,NULL,SHGFI_EXETYPE);
+                    if (temp==0) temp = (DWORD)SHGetFileInfo((std::string(winDirNew)+"\\"+std::string(fullname)).c_str(),NULL,NULL,NULL,SHGFI_EXETYPE);
+                    if (HIWORD(temp)==0 && LOWORD(temp)==0x4550) { // Console applications
+                        lpExecInfo.cbSize  = sizeof(SHELLEXECUTEINFO);
+                        lpExecInfo.fMask=SEE_MASK_DOENVSUBST|SEE_MASK_NOCLOSEPROCESS;
+                        lpExecInfo.hwnd = NULL;
+                        lpExecInfo.lpVerb = "open";
+                        lpExecInfo.lpDirectory = NULL;
+                        lpExecInfo.nShow = SW_SHOW;
+                        lpExecInfo.hInstApp = (HINSTANCE) SE_ERR_DDEFAIL;
+                        strcpy(dir, "/C \"");
+                        strcat(dir, winName);
+                        strcat(dir, " ");
+                        strcat(dir, comline);
+                        strcat(dir, " & echo( & echo The command execution is completed. & pause\"");
+                        lpExecInfo.lpFile = "CMD.EXE";
+                        lpExecInfo.lpParameters = dir;
+                        ShellExecuteEx(&lpExecInfo);
+                        hret = (intptr_t)lpExecInfo.hProcess;
+                    } else {
+                        char qwinName[258];
+                        sprintf(qwinName,"\"%s\"",winName);
+                        hret = _spawnl(P_NOWAIT, winName, qwinName, comline, NULL);
+                    }
                     SetCurrentDirectory(winDirCur);
                     if (startwait && hret > 0) {
-                        bool first=true;
+                        int count=0;
                         ctrlbrk=false;
                         DWORD exitCode = 0;
+                        GetExitCodeProcess((HANDLE)hret, &exitCode);
                         while (GetExitCodeProcess((HANDLE)hret, &exitCode) && exitCode == STILL_ACTIVE) {
                             CALLBACK_Idle();
                             if (ctrlbrk) {
-                                Bit8u c;Bit16u n=1;
+                                uint8_t c;uint16_t n=1;
                                 DOS_ReadFile (STDIN,&c,&n);
                                 if (c == 3) WriteOut("^C\n");
                                 EndRunProcess();
                                 exitCode=0;
                                 break;
                             }
-                            if (first) {WriteOut("(Press Ctrl+C to exit immediately)\n");first=false;}
+                            if (++count==20000&&!startquiet) WriteOut("(Press Ctrl+C to exit immediately)\n");
                         }
                         dos.return_code = exitCode&255;
                         dos.return_mode = 0;
@@ -1211,12 +1240,14 @@ continue_1:
                         hret = 0;
                     else
                         hret = errno;
-                    DOS_SetError((Bit16u)hret);
+                    DOS_SetError((uint16_t)hret);
                     bool ret=hret == 0;
                     hret=0;
                     return ret;
-                }
-            }
+                } else if (startquiet)
+                    WriteOut("This program cannot be run in DOS mode.\n");
+            } else if (startquiet)
+                WriteOut("This program cannot be run in DOS mode.\n");
 #endif
         }
 		packerr=false;
