@@ -1,8 +1,8 @@
 #define PACKAGE "dosbox-x"
 #define PACKAGE_BUGREPORT "https://github.com/joncampbell123/dosbox-x/issues"
 #define PACKAGE_NAME "dosbox-x"
-#define PACKAGE_STRING "dosbox-x 0.83.5"
+#define PACKAGE_STRING "dosbox-x 0.83.7"
 #define PACKAGE_TARNAME "dosbox-x"
-#define PACKAGE_URL "http://dosbox-x.software"
-#define PACKAGE_VERSION "0.83.5"
-#define VERSION "0.83.5"
+#define PACKAGE_URL "https://dosbox-x.com"
+#define PACKAGE_VERSION "0.83.7"
+#define VERSION "0.83.7"
